(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2724739,     103747]*)
(*NotebookOutlinePosition[   2732778,     103930]*)
(*  CellTagsIndexPosition[   2731471,     103898]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Resonance Phenomena", "Title"],

Cell["\<\
Resonance phenomena simulated by finite differences and biased \
noise inputs\
\>", "Subtitle"],

Cell["\<\
In Lecture-21.nb, a second-order differencing scheme that \
iteratively solved  y'' + \[Beta]y' + \[Gamma]y=0  with the specification of \
two initial values.
Modify this to add a little random noise to y[i] at each step and observe how \
this behaves---this version will store the noise added at each iteration so \
that it can be visualized later....\
\>", "Text"],

Cell[BoxData[
    \(GrowListGeneralNoise[
        ValuesList_List, \ \[CapitalDelta]_\ , \ \[Alpha]_\ , \ \[Beta]_, 
        randomamp_]\  := 
      Module[{Minus1 = ValuesList[\([1, \(-1\)]\)], \ 
          Minus2\  = \ ValuesList[\([1, \(-2\)]\)], \ 
          noise\  = \ 
            Random[Real, {\(-randomamp\), 
                randomamp}]}, \[IndentingNewLine]{\[IndentingNewLine]Append[
            ValuesList[\([1]\)], \[IndentingNewLine]2*Minus1\  - \ 
              Minus2\  + \ \[CapitalDelta]\ *\((\[Beta]*\((Minus2\  - \ 
                          Minus1)\)\  - \[Alpha]*\[CapitalDelta]*
                      Minus2)\)\  + noise], \[IndentingNewLine]Append[
            ValuesList[\([2]\)], noise]}]\)], "Input",
  CellTags->"mmtag:23:noise__addition_to_simulated_differential_equation"],

Cell[TextData[{
  "Setting up a function that takes particular parameters and a \"noise \
amplitude\" of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]]
}], "Text"],

Cell[BoxData[
    \(GrowListSpecificNoise[InitialList_List]\ \  := \ 
      GrowListGeneralNoise[InitialList,  .001, 2, 0, 
        10^\((\(-5\))\)]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[GrowListSpecificNoise, {{1, 1}, {0, 0}}, 10]\)], "Input",
  CellTags->"mmtag:23:Nest[]"],

Cell[BoxData[
    \({{1, 1, 0.9999914117795936`, 0.9999843172559986`, 0.999969270477182`, 
        0.9999428093699526`, 0.9999162597036201`, 0.9998880386207231`, 
        0.9998566204455593`, 0.9998204523904113`, 0.9997817799724843`, 
        0.9997317440858904`}, {0, 0, \(-6.588220406492501`*^-6\), 
        3.4936968113379294`*^-6, \(-5.9522723980085235`*^-6\), \
\(-9.414359778354513`*^-6\), 1.911379437887737`*^-6, 
        3.284690542412207`*^-7, \(-1.1972597473456777`*^-6\), \
\(-2.750103907047068`*^-6\), \(-5.046495380609433`*^-7\), \
\(-9.363827762203964`*^-6\)}}\)], "Output",
  CellTags->"mmtag:23:Nest[]"]
}, Open  ]],

Cell[BoxData[
    \(\(TheData\  = \ 
        Nest[GrowListSpecificNoise, {{1, 1}, {0, 0}}, 20000];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[TheData[\([1]\)]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.302571 0.300742 [
[.26188 .29007 -22 -20 ]
[.26188 .29007 22 0 ]
[.49995 .29007 -27 -20 ]
[.49995 .29007 27 0 ]
[.73802 .29007 -27 -20 ]
[.73802 .29007 27 0 ]
[.9761 .29007 -27 -20 ]
[.9761 .29007 27 0 ]
[.01131 .00183 -26.9375 -10 ]
[.01131 .00183 0 10 ]
[.01131 .1522 -41.9375 -10 ]
[.01131 .1522 0 10 ]
[.01131 .45294 -29 -10 ]
[.01131 .45294 0 10 ]
[.01131 .60331 -14 -10 ]
[.01131 .60331 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .30257 m
.26188 .30882 L
s
gsave
.26188 .29007 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .30257 m
.49995 .30882 L
s
gsave
.49995 .29007 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .30257 m
.73802 .30882 L
s
gsave
.73802 .29007 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .30257 m
.9761 .30882 L
s
gsave
.9761 .29007 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .30257 m
.07142 .30632 L
s
.11904 .30257 m
.11904 .30632 L
s
.16665 .30257 m
.16665 .30632 L
s
.21427 .30257 m
.21427 .30632 L
s
.3095 .30257 m
.3095 .30632 L
s
.35711 .30257 m
.35711 .30632 L
s
.40472 .30257 m
.40472 .30632 L
s
.45234 .30257 m
.45234 .30632 L
s
.54757 .30257 m
.54757 .30632 L
s
.59518 .30257 m
.59518 .30632 L
s
.6428 .30257 m
.6428 .30632 L
s
.69041 .30257 m
.69041 .30632 L
s
.78564 .30257 m
.78564 .30632 L
s
.83325 .30257 m
.83325 .30632 L
s
.88087 .30257 m
.88087 .30632 L
s
.92848 .30257 m
.92848 .30632 L
s
.01 w
0 .30257 m
1 .30257 L
s
.25 Mabswid
.02381 .00183 m
.03006 .00183 L
s
gsave
.01131 .00183 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .1522 m
.03006 .1522 L
s
gsave
.01131 .1522 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45294 m
.03006 .45294 L
s
gsave
.01131 .45294 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60331 m
.03006 .60331 L
s
gsave
.01131 .60331 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0319 m
.02756 .0319 L
s
.02381 .06198 m
.02756 .06198 L
s
.02381 .09205 m
.02756 .09205 L
s
.02381 .12213 m
.02756 .12213 L
s
.02381 .18227 m
.02756 .18227 L
s
.02381 .21235 m
.02756 .21235 L
s
.02381 .24242 m
.02756 .24242 L
s
.02381 .2725 m
.02756 .2725 L
s
.02381 .33264 m
.02756 .33264 L
s
.02381 .36272 m
.02756 .36272 L
s
.02381 .39279 m
.02756 .39279 L
s
.02381 .42287 m
.02756 .42287 L
s
.02381 .48302 m
.02756 .48302 L
s
.02381 .51309 m
.02756 .51309 L
s
.02381 .54316 m
.02756 .54316 L
s
.02381 .57324 m
.02756 .57324 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .60331 Mdot
.0239 .60331 Mdot
.02395 .60331 Mdot
.024 .60331 Mdot
.02405 .6033 Mdot
.0241 .6033 Mdot
.02414 .60329 Mdot
.02419 .60329 Mdot
.02424 .60329 Mdot
.02429 .60328 Mdot
.02433 .60328 Mdot
.02438 .60328 Mdot
.02443 .60328 Mdot
.02448 .60328 Mdot
.02452 .60329 Mdot
.02457 .60329 Mdot
.02462 .6033 Mdot
.02467 .6033 Mdot
.02471 .60331 Mdot
.02476 .60331 Mdot
.02481 .60331 Mdot
.02486 .60332 Mdot
.0249 .60332 Mdot
.02495 .60332 Mdot
.025 .60332 Mdot
.02505 .60332 Mdot
.0251 .60332 Mdot
.02514 .60332 Mdot
.02519 .60332 Mdot
.02524 .60331 Mdot
.02529 .6033 Mdot
.02533 .6033 Mdot
.02538 .60328 Mdot
.02543 .60328 Mdot
.02548 .60326 Mdot
.02552 .60325 Mdot
.02557 .60324 Mdot
.02562 .60323 Mdot
.02567 .60322 Mdot
.02571 .60321 Mdot
.02576 .6032 Mdot
.02581 .6032 Mdot
.02586 .60319 Mdot
.0259 .60318 Mdot
.02595 .60317 Mdot
.026 .60316 Mdot
.02605 .60316 Mdot
.0261 .60315 Mdot
.02614 .60315 Mdot
.02619 .60314 Mdot
.02624 .60313 Mdot
.02629 .60312 Mdot
.02633 .6031 Mdot
.02638 .60309 Mdot
.02643 .60308 Mdot
.02648 .60307 Mdot
.02652 .60305 Mdot
.02657 .60304 Mdot
.02662 .60303 Mdot
.02667 .60301 Mdot
.02671 .60299 Mdot
.02676 .60297 Mdot
.02681 .60295 Mdot
.02686 .60292 Mdot
.0269 .6029 Mdot
.02695 .60287 Mdot
.027 .60284 Mdot
.02705 .60282 Mdot
.02709 .6028 Mdot
.02714 .60277 Mdot
.02719 .60275 Mdot
.02724 .60272 Mdot
.02729 .6027 Mdot
.02733 .60268 Mdot
.02738 .60265 Mdot
.02743 .60263 Mdot
.02748 .6026 Mdot
.02752 .60257 Mdot
.02757 .60254 Mdot
.02762 .60251 Mdot
.02767 .60247 Mdot
.02771 .60244 Mdot
.02776 .6024 Mdot
.02781 .60236 Mdot
.02786 .60232 Mdot
.0279 .60228 Mdot
.02795 .60224 Mdot
.028 .6022 Mdot
.02805 .60216 Mdot
.02809 .60212 Mdot
.02814 .60208 Mdot
.02819 .60203 Mdot
.02824 .60199 Mdot
.02829 .60194 Mdot
.02833 .6019 Mdot
.02838 .60185 Mdot
.02843 .60181 Mdot
.02848 .60176 Mdot
.02852 .60171 Mdot
.02857 .60165 Mdot
.02862 .6016 Mdot
.02867 .60154 Mdot
.02871 .60148 Mdot
.02876 .60143 Mdot
.02881 .60137 Mdot
.02886 .60132 Mdot
.0289 .60126 Mdot
.02895 .6012 Mdot
.029 .60114 Mdot
.02905 .60109 Mdot
.02909 .60103 Mdot
.02914 .60097 Mdot
.02919 .60092 Mdot
.02924 .60086 Mdot
.02929 .6008 Mdot
.02933 .60074 Mdot
.02938 .60068 Mdot
.02943 .60062 Mdot
.02948 .60057 Mdot
.02952 .60051 Mdot
.02957 .60045 Mdot
.02962 .60039 Mdot
.02967 .60033 Mdot
.02971 .60027 Mdot
.02976 .60022 Mdot
.02981 .60016 Mdot
.02986 .6001 Mdot
.0299 .60004 Mdot
.02995 .59999 Mdot
.03 .59993 Mdot
.03005 .59988 Mdot
.03009 .59982 Mdot
.03014 .59977 Mdot
.03019 .59971 Mdot
.03024 .59965 Mdot
.03029 .59959 Mdot
.03033 .59953 Mdot
.03038 .59946 Mdot
.03043 .5994 Mdot
.03048 .59933 Mdot
.03052 .59927 Mdot
.03057 .5992 Mdot
.03062 .59913 Mdot
.03067 .59905 Mdot
.03071 .59898 Mdot
.03076 .5989 Mdot
.03081 .59883 Mdot
.03086 .59876 Mdot
.0309 .59868 Mdot
.03095 .59861 Mdot
.031 .59853 Mdot
.03105 .59846 Mdot
.03109 .59838 Mdot
.03114 .59831 Mdot
.03119 .59823 Mdot
.03124 .59814 Mdot
.03128 .59806 Mdot
.03133 .59797 Mdot
.03138 .59788 Mdot
.03143 .5978 Mdot
.03148 .59771 Mdot
.03152 .59762 Mdot
.03157 .59754 Mdot
.03162 .59745 Mdot
.03167 .59736 Mdot
.03171 .59727 Mdot
.03176 .59717 Mdot
.03181 .59708 Mdot
.03186 .59698 Mdot
.0319 .59688 Mdot
.03195 .59677 Mdot
.032 .59667 Mdot
.03205 .59656 Mdot
.03209 .59646 Mdot
.03214 .59634 Mdot
.03219 .59624 Mdot
.03224 .59613 Mdot
.03228 .59602 Mdot
.03233 .59591 Mdot
.03238 .5958 Mdot
.03243 .59569 Mdot
.03248 .59558 Mdot
.03252 .59547 Mdot
.03257 .59536 Mdot
.03262 .59524 Mdot
.03267 .59513 Mdot
.03271 .59501 Mdot
.03276 .5949 Mdot
.03281 .59479 Mdot
.03286 .59468 Mdot
.0329 .59457 Mdot
.03295 .59445 Mdot
.033 .59434 Mdot
.03305 .59423 Mdot
.03309 .59412 Mdot
.03314 .59401 Mdot
.03319 .5939 Mdot
.03324 .59379 Mdot
.03328 .59367 Mdot
.03333 .59356 Mdot
.03338 .59344 Mdot
.03343 .59332 Mdot
.03348 .5932 Mdot
.03352 .59308 Mdot
.03357 .59295 Mdot
.03362 .59283 Mdot
.03367 .5927 Mdot
.03371 .59258 Mdot
.03376 .59245 Mdot
.03381 .59232 Mdot
.03386 .5922 Mdot
.0339 .59207 Mdot
.03395 .59194 Mdot
.034 .59181 Mdot
.03405 .59168 Mdot
.03409 .59155 Mdot
.03414 .59141 Mdot
.03419 .59128 Mdot
.03424 .59115 Mdot
.03428 .59102 Mdot
.03433 .59088 Mdot
.03438 .59075 Mdot
.03443 .59061 Mdot
.03448 .59046 Mdot
.03452 .59032 Mdot
.03457 .59017 Mdot
.03462 .59002 Mdot
.03467 .58987 Mdot
.03471 .58972 Mdot
.03476 .58957 Mdot
.03481 .58942 Mdot
.03486 .58926 Mdot
.0349 .58911 Mdot
.03495 .58895 Mdot
.035 .58879 Mdot
.03505 .58863 Mdot
.03509 .58847 Mdot
.03514 .58831 Mdot
.03519 .58814 Mdot
.03524 .58798 Mdot
.03528 .58782 Mdot
.03533 .58766 Mdot
.03538 .5875 Mdot
.03543 .58733 Mdot
.03548 .58717 Mdot
.03552 .58701 Mdot
.03557 .58684 Mdot
.03562 .58668 Mdot
.03567 .58651 Mdot
.03571 .58634 Mdot
.03576 .58616 Mdot
.03581 .58599 Mdot
.03586 .58582 Mdot
.0359 .58564 Mdot
.03595 .58546 Mdot
.036 .58529 Mdot
.03605 .58511 Mdot
.03609 .58494 Mdot
.03614 .58476 Mdot
.03619 .58459 Mdot
.03624 .58441 Mdot
.03628 .58424 Mdot
.03633 .58406 Mdot
.03638 .58389 Mdot
.03643 .58371 Mdot
.03647 .58353 Mdot
.03652 .58335 Mdot
.03657 .58317 Mdot
.03662 .58299 Mdot
.03667 .5828 Mdot
.03671 .58262 Mdot
.03676 .58244 Mdot
.03681 .58226 Mdot
.03686 .58208 Mdot
.0369 .58189 Mdot
.03695 .58171 Mdot
.037 .58152 Mdot
.03705 .58133 Mdot
.03709 .58114 Mdot
.03714 .58095 Mdot
.03719 .58076 Mdot
.03724 .58057 Mdot
.03728 .58037 Mdot
.03733 .58018 Mdot
.03738 .57999 Mdot
.03743 .57979 Mdot
.03747 .57959 Mdot
.03752 .5794 Mdot
.03757 .5792 Mdot
.03762 .57901 Mdot
.03767 .57882 Mdot
.03771 .57862 Mdot
.03776 .57843 Mdot
.03781 .57823 Mdot
.03786 .57803 Mdot
.0379 .57783 Mdot
.03795 .57764 Mdot
.038 .57744 Mdot
.03805 .57725 Mdot
.03809 .57705 Mdot
.03814 .57686 Mdot
.03819 .57666 Mdot
.03824 .57647 Mdot
.03828 .57627 Mdot
.03833 .57607 Mdot
.03838 .57588 Mdot
.03843 .57568 Mdot
.03847 .57549 Mdot
.03852 .57529 Mdot
.03857 .5751 Mdot
.03862 .5749 Mdot
.03867 .5747 Mdot
.03871 .57451 Mdot
.03876 .57432 Mdot
.03881 .57412 Mdot
.03886 .57392 Mdot
.0389 .57373 Mdot
.03895 .57353 Mdot
.039 .57333 Mdot
.03905 .57312 Mdot
.03909 .57292 Mdot
.03914 .57271 Mdot
.03919 .57251 Mdot
.03924 .57231 Mdot
.03928 .5721 Mdot
.03933 .5719 Mdot
.03938 .57169 Mdot
.03943 .57149 Mdot
.03947 .57128 Mdot
.03952 .57108 Mdot
.03957 .57087 Mdot
.03962 .57066 Mdot
.03967 .57046 Mdot
.03971 .57025 Mdot
.03976 .57004 Mdot
.03981 .56984 Mdot
.03986 .56963 Mdot
.0399 .56942 Mdot
.03995 .56922 Mdot
.04 .56901 Mdot
.04005 .56881 Mdot
.04009 .5686 Mdot
.04014 .56839 Mdot
.04019 .56818 Mdot
.04024 .56797 Mdot
.04028 .56776 Mdot
.04033 .56755 Mdot
.04038 .56734 Mdot
.04043 .56713 Mdot
.04047 .56691 Mdot
.04052 .5667 Mdot
.04057 .56649 Mdot
.04062 .56628 Mdot
.04066 .56607 Mdot
.04071 .56586 Mdot
.04076 .56566 Mdot
.04081 .56545 Mdot
.04086 .56524 Mdot
.0409 .56503 Mdot
.04095 .56481 Mdot
.041 .5646 Mdot
.04105 .56439 Mdot
.04109 .56417 Mdot
.04114 .56396 Mdot
.04119 .56375 Mdot
.04124 .56354 Mdot
.04128 .56333 Mdot
.04133 .56311 Mdot
.04138 .5629 Mdot
.04143 .56269 Mdot
.04147 .56247 Mdot
.04152 .56226 Mdot
.04157 .56204 Mdot
.04162 .56183 Mdot
.04166 .56162 Mdot
.04171 .56141 Mdot
.04176 .5612 Mdot
.04181 .56099 Mdot
.04186 .56077 Mdot
.0419 .56055 Mdot
.04195 .56034 Mdot
.042 .56012 Mdot
.04205 .55991 Mdot
.04209 .5597 Mdot
.04214 .55949 Mdot
.04219 .55928 Mdot
.04224 .55907 Mdot
.04228 .55885 Mdot
.04233 .55864 Mdot
.04238 .55842 Mdot
.04243 .5582 Mdot
.04247 .55798 Mdot
.04252 .55777 Mdot
.04257 .55756 Mdot
.04262 .55734 Mdot
.04266 .55712 Mdot
.04271 .55691 Mdot
.04276 .55669 Mdot
.04281 .55647 Mdot
.04286 .55625 Mdot
.0429 .55603 Mdot
.04295 .55582 Mdot
.043 .5556 Mdot
.04305 .55538 Mdot
.04309 .55516 Mdot
.04314 .55494 Mdot
.04319 .55472 Mdot
.04324 .5545 Mdot
.04328 .55428 Mdot
.04333 .55406 Mdot
.04338 .55384 Mdot
.04343 .55361 Mdot
.04347 .55339 Mdot
.04352 .55316 Mdot
.04357 .55293 Mdot
.04362 .5527 Mdot
.04366 .55247 Mdot
.04371 .55225 Mdot
.04376 .55202 Mdot
.04381 .55179 Mdot
.04386 .55156 Mdot
.0439 .55133 Mdot
.04395 .5511 Mdot
.044 .55087 Mdot
.04405 .55064 Mdot
.04409 .55041 Mdot
.04414 .55019 Mdot
.04419 .54996 Mdot
.04424 .54973 Mdot
.04428 .54951 Mdot
.04433 .54928 Mdot
.04438 .54905 Mdot
.04443 .54883 Mdot
.04447 .5486 Mdot
.04452 .54838 Mdot
.04457 .54815 Mdot
.04462 .54792 Mdot
.04466 .54769 Mdot
.04471 .54746 Mdot
.04476 .54723 Mdot
.04481 .54699 Mdot
.04486 .54676 Mdot
.0449 .54652 Mdot
.04495 .54629 Mdot
.045 .54606 Mdot
.04505 .54582 Mdot
.04509 .54559 Mdot
.04514 .54535 Mdot
.04519 .54511 Mdot
.04524 .54488 Mdot
.04528 .54464 Mdot
.04533 .5444 Mdot
.04538 .54417 Mdot
.04543 .54394 Mdot
.04547 .5437 Mdot
.04552 .54347 Mdot
.04557 .54323 Mdot
.04562 .543 Mdot
.04566 .54276 Mdot
.04571 .54252 Mdot
.04576 .54228 Mdot
.04581 .54204 Mdot
.04585 .5418 Mdot
.0459 .54157 Mdot
.04595 .54133 Mdot
.046 .54109 Mdot
.04605 .54086 Mdot
.04609 .54062 Mdot
.04614 .54038 Mdot
.04619 .54015 Mdot
.04624 .53991 Mdot
.04628 .53967 Mdot
.04633 .53943 Mdot
.04638 .53919 Mdot
.04643 .53895 Mdot
.04647 .53871 Mdot
.04652 .53846 Mdot
.04657 .53821 Mdot
.04662 .53797 Mdot
.04666 .53773 Mdot
.04671 .53749 Mdot
.04676 .53724 Mdot
.04681 .537 Mdot
.04685 .53675 Mdot
.0469 .53651 Mdot
.04695 .53626 Mdot
.047 .536 Mdot
.04705 .53575 Mdot
.04709 .5355 Mdot
.04714 .53525 Mdot
.04719 .535 Mdot
.04724 .53475 Mdot
.04728 .5345 Mdot
.04733 .53425 Mdot
.04738 .534 Mdot
.04743 .53375 Mdot
.04747 .5335 Mdot
.04752 .53325 Mdot
.04757 .533 Mdot
.04762 .53275 Mdot
.04766 .53251 Mdot
.04771 .53226 Mdot
.04776 .532 Mdot
.04781 .53175 Mdot
.04785 .5315 Mdot
.0479 .53124 Mdot
.04795 .53099 Mdot
.048 .53073 Mdot
.04805 .53047 Mdot
.04809 .53021 Mdot
.04814 .52994 Mdot
.04819 .52968 Mdot
.04824 .52942 Mdot
.04828 .52915 Mdot
.04833 .52888 Mdot
.04838 .52862 Mdot
.04843 .52835 Mdot
.04847 .52808 Mdot
.04852 .52781 Mdot
.04857 .52754 Mdot
.04862 .52726 Mdot
.04866 .52699 Mdot
.04871 .52672 Mdot
.04876 .52644 Mdot
.04881 .52617 Mdot
.04885 .52589 Mdot
.0489 .52561 Mdot
.04895 .52533 Mdot
.049 .52504 Mdot
.04905 .52476 Mdot
.04909 .52447 Mdot
.04914 .52419 Mdot
.04919 .5239 Mdot
.04924 .52361 Mdot
.04928 .52332 Mdot
.04933 .52303 Mdot
.04938 .52274 Mdot
.04943 .52246 Mdot
.04947 .52217 Mdot
.04952 .52188 Mdot
.04957 .52159 Mdot
.04962 .52129 Mdot
.04966 .521 Mdot
.04971 .52071 Mdot
.04976 .52041 Mdot
.04981 .52012 Mdot
.04985 .51983 Mdot
.0499 .51953 Mdot
.04995 .51924 Mdot
.05 .51894 Mdot
.05004 .51864 Mdot
.05009 .51834 Mdot
.05014 .51804 Mdot
.05019 .51774 Mdot
.05024 .51745 Mdot
.05028 .51715 Mdot
.05033 .51685 Mdot
.05038 .51655 Mdot
.05043 .51625 Mdot
.05047 .51595 Mdot
.05052 .51566 Mdot
.05057 .51536 Mdot
.05062 .51506 Mdot
.05066 .51476 Mdot
.05071 .51446 Mdot
.05076 .51416 Mdot
.05081 .51386 Mdot
.05085 .51356 Mdot
.0509 .51326 Mdot
.05095 .51296 Mdot
.051 .51266 Mdot
.05104 .51236 Mdot
.05109 .51205 Mdot
.05114 .51175 Mdot
.05119 .51144 Mdot
.05124 .51112 Mdot
.05128 .51081 Mdot
.05133 .5105 Mdot
.05138 .51019 Mdot
.05143 .50988 Mdot
.05147 .50957 Mdot
.05152 .50927 Mdot
.05157 .50896 Mdot
.05162 .50866 Mdot
.05166 .50835 Mdot
.05171 .50805 Mdot
.05176 .50775 Mdot
.05181 .50744 Mdot
.05185 .50714 Mdot
.0519 .50683 Mdot
.05195 .50652 Mdot
.052 .50622 Mdot
.05204 .50591 Mdot
.05209 .5056 Mdot
.05214 .50529 Mdot
.05219 .50497 Mdot
.05224 .50466 Mdot
.05228 .50434 Mdot
.05233 .50402 Mdot
.05238 .50371 Mdot
.05243 .50339 Mdot
.05247 .50307 Mdot
.05252 .50275 Mdot
.05257 .50243 Mdot
.05262 .50211 Mdot
.05266 .50179 Mdot
.05271 .50147 Mdot
.05276 .50115 Mdot
.05281 .50082 Mdot
.05285 .50049 Mdot
.0529 .50017 Mdot
.05295 .49984 Mdot
.053 .49952 Mdot
.05304 .49919 Mdot
.05309 .49887 Mdot
.05314 .49854 Mdot
.05319 .4982 Mdot
.05324 .49787 Mdot
.05328 .49754 Mdot
.05333 .4972 Mdot
.05338 .49687 Mdot
.05343 .49653 Mdot
.05347 .49619 Mdot
.05352 .49585 Mdot
.05357 .49551 Mdot
.05362 .49517 Mdot
.05366 .49483 Mdot
.05371 .49449 Mdot
.05376 .49415 Mdot
.05381 .49381 Mdot
.05385 .49346 Mdot
.0539 .49312 Mdot
.05395 .49277 Mdot
.054 .49242 Mdot
.05404 .49208 Mdot
.05409 .49173 Mdot
.05414 .49138 Mdot
.05419 .49103 Mdot
.05424 .49068 Mdot
.05428 .49033 Mdot
.05433 .48998 Mdot
.05438 .48963 Mdot
.05443 .48928 Mdot
.05447 .48893 Mdot
.05452 .48858 Mdot
.05457 .48823 Mdot
.05462 .48788 Mdot
.05466 .48753 Mdot
.05471 .48717 Mdot
.05476 .48682 Mdot
.05481 .48646 Mdot
.05485 .48611 Mdot
.0549 .48576 Mdot
.05495 .48541 Mdot
.055 .48506 Mdot
.05504 .48471 Mdot
.05509 .48436 Mdot
.05514 .48401 Mdot
.05519 .48365 Mdot
.05523 .4833 Mdot
.05528 .48295 Mdot
.05533 .48259 Mdot
.05538 .48223 Mdot
.05543 .48188 Mdot
.05547 .48153 Mdot
.05552 .48117 Mdot
.05557 .48082 Mdot
.05562 .48047 Mdot
.05566 .48012 Mdot
.05571 .47976 Mdot
.05576 .47941 Mdot
.05581 .47905 Mdot
.05585 .47869 Mdot
.0559 .47833 Mdot
.05595 .47797 Mdot
.056 .47761 Mdot
.05604 .47725 Mdot
.05609 .47689 Mdot
.05614 .47653 Mdot
.05619 .47617 Mdot
.05623 .47581 Mdot
.05628 .47544 Mdot
.05633 .47508 Mdot
.05638 .47472 Mdot
.05643 .47435 Mdot
.05647 .47399 Mdot
.05652 .47363 Mdot
.05657 .47327 Mdot
.05662 .4729 Mdot
.05666 .47254 Mdot
.05671 .47219 Mdot
.05676 .47183 Mdot
.05681 .47147 Mdot
.05685 .47112 Mdot
.0569 .47077 Mdot
.05695 .47041 Mdot
.057 .47006 Mdot
.05704 .4697 Mdot
.05709 .46934 Mdot
.05714 .46899 Mdot
.05719 .46863 Mdot
.05723 .46827 Mdot
.05728 .46791 Mdot
.05733 .46755 Mdot
.05738 .46718 Mdot
.05743 .46681 Mdot
.05747 .46645 Mdot
.05752 .46608 Mdot
.05757 .46572 Mdot
.05762 .46536 Mdot
.05766 .46499 Mdot
.05771 .46463 Mdot
.05776 .46427 Mdot
.05781 .46391 Mdot
.05785 .46354 Mdot
.0579 .46318 Mdot
.05795 .46282 Mdot
.058 .46247 Mdot
.05804 .46211 Mdot
.05809 .46175 Mdot
.05814 .46139 Mdot
.05819 .46103 Mdot
.05823 .46067 Mdot
.05828 .46032 Mdot
.05833 .45995 Mdot
.05838 .45959 Mdot
.05843 .45923 Mdot
.05847 .45887 Mdot
.05852 .45851 Mdot
.05857 .45815 Mdot
.05862 .45779 Mdot
.05866 .45743 Mdot
.05871 .45706 Mdot
.05876 .4567 Mdot
.05881 .45633 Mdot
.05885 .45597 Mdot
.0589 .45559 Mdot
.05895 .45522 Mdot
.059 .45485 Mdot
.05904 .45448 Mdot
.05909 .45411 Mdot
.05914 .45374 Mdot
.05919 .45337 Mdot
.05923 .453 Mdot
.05928 .45262 Mdot
.05933 .45225 Mdot
.05938 .45188 Mdot
.05943 .4515 Mdot
.05947 .45113 Mdot
.05952 .45076 Mdot
.05957 .45039 Mdot
.05962 .45002 Mdot
.05966 .44965 Mdot
.05971 .44928 Mdot
.05976 .44891 Mdot
.05981 .44854 Mdot
.05985 .44817 Mdot
.0599 .44779 Mdot
.05995 .44742 Mdot
.06 .44705 Mdot
.06004 .44667 Mdot
.06009 .4463 Mdot
.06014 .44593 Mdot
.06019 .44555 Mdot
.06023 .44518 Mdot
.06028 .4448 Mdot
.06033 .44443 Mdot
.06038 .44406 Mdot
.06042 .44369 Mdot
.06047 .44331 Mdot
.06052 .44294 Mdot
.06057 .44257 Mdot
.06062 .44219 Mdot
.06066 .44182 Mdot
.06071 .44144 Mdot
.06076 .44106 Mdot
.06081 .44068 Mdot
.06085 .44029 Mdot
.0609 .43992 Mdot
.06095 .43954 Mdot
.061 .43916 Mdot
.06104 .43878 Mdot
.06109 .4384 Mdot
.06114 .43802 Mdot
.06119 .43764 Mdot
.06123 .43726 Mdot
.06128 .43689 Mdot
.06133 .43651 Mdot
.06138 .43613 Mdot
.06142 .43575 Mdot
.06147 .43537 Mdot
.06152 .43499 Mdot
.06157 .43461 Mdot
.06162 .43424 Mdot
.06166 .43386 Mdot
.06171 .43349 Mdot
.06176 .43312 Mdot
.06181 .43274 Mdot
.06185 .43237 Mdot
.0619 .432 Mdot
.06195 .43162 Mdot
.062 .43125 Mdot
.06204 .43087 Mdot
.06209 .4305 Mdot
.06214 .43012 Mdot
.06219 .42974 Mdot
.06223 .42936 Mdot
.06228 .42897 Mdot
.06233 .42859 Mdot
.06238 .42821 Mdot
.06242 .42783 Mdot
.06247 .42744 Mdot
.06252 .42705 Mdot
.06257 .42667 Mdot
.06262 .42628 Mdot
.06266 .42588 Mdot
.06271 .42549 Mdot
.06276 .4251 Mdot
.06281 .42471 Mdot
.06285 .42431 Mdot
.0629 .42392 Mdot
.06295 .42353 Mdot
.063 .42314 Mdot
.06304 .42276 Mdot
.06309 .42237 Mdot
.06314 .42197 Mdot
.06319 .42158 Mdot
.06323 .42119 Mdot
.06328 .42079 Mdot
.06333 .4204 Mdot
.06338 .42 Mdot
.06342 .4196 Mdot
.06347 .4192 Mdot
.06352 .4188 Mdot
.06357 .4184 Mdot
.06362 .418 Mdot
.06366 .4176 Mdot
.06371 .4172 Mdot
.06376 .4168 Mdot
.06381 .4164 Mdot
.06385 .416 Mdot
.0639 .41561 Mdot
.06395 .41521 Mdot
.064 .41481 Mdot
.06404 .41441 Mdot
.06409 .41401 Mdot
.06414 .4136 Mdot
.06419 .4132 Mdot
.06423 .4128 Mdot
.06428 .41239 Mdot
.06433 .41199 Mdot
.06438 .41158 Mdot
.06442 .41118 Mdot
.06447 .41077 Mdot
.06452 .41037 Mdot
.06457 .40996 Mdot
.06461 .40955 Mdot
.06466 .40914 Mdot
.06471 .40873 Mdot
.06476 .40831 Mdot
.06481 .4079 Mdot
.06485 .40748 Mdot
.0649 .40706 Mdot
.06495 .40664 Mdot
.065 .40623 Mdot
.06504 .40581 Mdot
.06509 .40538 Mdot
.06514 .40496 Mdot
.06519 .40454 Mdot
.06523 .40412 Mdot
.06528 .4037 Mdot
.06533 .40328 Mdot
.06538 .40286 Mdot
.06542 .40244 Mdot
.06547 .40203 Mdot
.06552 .40161 Mdot
.06557 .40119 Mdot
.06561 .40078 Mdot
.06566 .40036 Mdot
.06571 .39995 Mdot
.06576 .39953 Mdot
.06581 .39911 Mdot
.06585 .3987 Mdot
.0659 .39828 Mdot
.06595 .39787 Mdot
.066 .39746 Mdot
.06604 .39704 Mdot
.06609 .39662 Mdot
.06614 .39621 Mdot
.06619 .39579 Mdot
.06623 .39538 Mdot
.06628 .39496 Mdot
.06633 .39455 Mdot
.06638 .39414 Mdot
.06642 .39372 Mdot
.06647 .39331 Mdot
.06652 .3929 Mdot
.06657 .39249 Mdot
.06661 .39207 Mdot
.06666 .39165 Mdot
.06671 .39124 Mdot
.06676 .39082 Mdot
.06681 .39041 Mdot
.06685 .38999 Mdot
.0669 .38957 Mdot
.06695 .38915 Mdot
.067 .38872 Mdot
.06704 .3883 Mdot
.06709 .38788 Mdot
.06714 .38746 Mdot
.06719 .38704 Mdot
.06723 .38662 Mdot
.06728 .38619 Mdot
.06733 .38578 Mdot
.06738 .38536 Mdot
.06742 .38494 Mdot
.06747 .38452 Mdot
.06752 .3841 Mdot
.06757 .38368 Mdot
.06761 .38327 Mdot
.06766 .38286 Mdot
.06771 .38244 Mdot
.06776 .38203 Mdot
.06781 .38162 Mdot
.06785 .3812 Mdot
.0679 .38079 Mdot
.06795 .38037 Mdot
.068 .37996 Mdot
.06804 .37954 Mdot
.06809 .37912 Mdot
.06814 .3787 Mdot
.06819 .37828 Mdot
.06823 .37786 Mdot
.06828 .37744 Mdot
.06833 .37702 Mdot
.06838 .3766 Mdot
.06842 .37618 Mdot
.06847 .37576 Mdot
.06852 .37534 Mdot
.06857 .37492 Mdot
.06861 .3745 Mdot
.06866 .37408 Mdot
.06871 .37366 Mdot
.06876 .37324 Mdot
.06881 .37282 Mdot
.06885 .37239 Mdot
.0689 .37197 Mdot
.06895 .37155 Mdot
.069 .37112 Mdot
.06904 .3707 Mdot
.06909 .37028 Mdot
.06914 .36985 Mdot
.06919 .36942 Mdot
.06923 .369 Mdot
.06928 .36858 Mdot
.06933 .36816 Mdot
.06938 .36774 Mdot
.06942 .36731 Mdot
.06947 .36689 Mdot
.06952 .36647 Mdot
.06957 .36605 Mdot
.06961 .36563 Mdot
.06966 .36521 Mdot
.06971 .36479 Mdot
.06976 .36437 Mdot
.0698 .36395 Mdot
.06985 .36353 Mdot
.0699 .36312 Mdot
.06995 .3627 Mdot
.07 .36228 Mdot
.07004 .36186 Mdot
.07009 .36144 Mdot
.07014 .36102 Mdot
.07019 .36061 Mdot
.07023 .36019 Mdot
.07028 .35978 Mdot
.07033 .35936 Mdot
.07038 .35895 Mdot
.07042 .35853 Mdot
.07047 .35811 Mdot
.07052 .35769 Mdot
.07057 .35727 Mdot
.07061 .35685 Mdot
.07066 .35643 Mdot
.07071 .35601 Mdot
.07076 .35559 Mdot
.0708 .35517 Mdot
.07085 .35475 Mdot
.0709 .35434 Mdot
.07095 .35392 Mdot
.071 .3535 Mdot
.07104 .35309 Mdot
.07109 .35267 Mdot
.07114 .35226 Mdot
.07119 .35184 Mdot
.07123 .35142 Mdot
.07128 .35101 Mdot
.07133 .35059 Mdot
.07138 .35017 Mdot
.07142 .34975 Mdot
.07147 .34933 Mdot
.07152 .34892 Mdot
.07157 .3485 Mdot
.07161 .34809 Mdot
.07166 .34767 Mdot
.07171 .34725 Mdot
.07176 .34684 Mdot
.0718 .34641 Mdot
.07185 .34599 Mdot
.0719 .34557 Mdot
.07195 .34516 Mdot
.072 .34474 Mdot
.07204 .34432 Mdot
.07209 .3439 Mdot
.07214 .34348 Mdot
.07219 .34306 Mdot
.07223 .34264 Mdot
.07228 .34223 Mdot
.07233 .3418 Mdot
.07238 .34139 Mdot
.07242 .34097 Mdot
.07247 .34055 Mdot
.07252 .34012 Mdot
.07257 .3397 Mdot
.07261 .33928 Mdot
.07266 .33886 Mdot
.07271 .33844 Mdot
.07276 .33802 Mdot
.0728 .3376 Mdot
.07285 .33718 Mdot
.0729 .33675 Mdot
.07295 .33633 Mdot
.073 .33591 Mdot
.07304 .33548 Mdot
.07309 .33506 Mdot
.07314 .33463 Mdot
.07319 .33421 Mdot
.07323 .33379 Mdot
.07328 .33336 Mdot
.07333 .33293 Mdot
.07338 .3325 Mdot
.07342 .33207 Mdot
.07347 .33164 Mdot
.07352 .33121 Mdot
.07357 .33078 Mdot
.07361 .33034 Mdot
.07366 .32991 Mdot
.07371 .32948 Mdot
.07376 .32906 Mdot
.0738 .32863 Mdot
.07385 .32821 Mdot
.0739 .32778 Mdot
.07395 .32735 Mdot
.07399 .32692 Mdot
.07404 .32649 Mdot
.07409 .32606 Mdot
.07414 .32564 Mdot
.07419 .32521 Mdot
.07423 .32479 Mdot
.07428 .32436 Mdot
.07433 .32394 Mdot
.07438 .32351 Mdot
.07442 .32308 Mdot
.07447 .32266 Mdot
.07452 .32223 Mdot
.07457 .3218 Mdot
.07461 .32138 Mdot
.07466 .32095 Mdot
.07471 .32053 Mdot
.07476 .3201 Mdot
.0748 .31967 Mdot
.07485 .31925 Mdot
.0749 .31882 Mdot
.07495 .31839 Mdot
.07499 .31797 Mdot
.07504 .31754 Mdot
.07509 .31711 Mdot
.07514 .31668 Mdot
.07519 .31626 Mdot
.07523 .31583 Mdot
.07528 .31541 Mdot
.07533 .31498 Mdot
.07538 .31456 Mdot
.07542 .31413 Mdot
.07547 .3137 Mdot
.07552 .31327 Mdot
.07557 .31285 Mdot
.07561 .31242 Mdot
.07566 .31199 Mdot
.07571 .31156 Mdot
.07576 .31113 Mdot
.0758 .31069 Mdot
.07585 .31026 Mdot
.0759 .30982 Mdot
.07595 .30938 Mdot
.07599 .30894 Mdot
.07604 .3085 Mdot
.07609 .30806 Mdot
.07614 .30762 Mdot
.07619 .30718 Mdot
.07623 .30674 Mdot
.07628 .3063 Mdot
.07633 .30587 Mdot
.07638 .30543 Mdot
.07642 .30499 Mdot
.07647 .30455 Mdot
.07652 .3041 Mdot
.07657 .30366 Mdot
.07661 .30321 Mdot
.07666 .30276 Mdot
.07671 .30232 Mdot
.07676 .30187 Mdot
.0768 .30142 Mdot
.07685 .30097 Mdot
.0769 .30052 Mdot
.07695 .30007 Mdot
.07699 .29962 Mdot
.07704 .29917 Mdot
.07709 .29872 Mdot
.07714 .29827 Mdot
.07719 .29782 Mdot
.07723 .29737 Mdot
.07728 .29692 Mdot
.07733 .29647 Mdot
.07738 .29602 Mdot
.07742 .29557 Mdot
.07747 .29512 Mdot
.07752 .29466 Mdot
.07757 .29421 Mdot
.07761 .29375 Mdot
.07766 .2933 Mdot
.07771 .29285 Mdot
.07776 .29239 Mdot
.0778 .29194 Mdot
.07785 .29148 Mdot
.0779 .29102 Mdot
.07795 .29057 Mdot
.07799 .29012 Mdot
.07804 .28966 Mdot
.07809 .28921 Mdot
.07814 .28875 Mdot
.07819 .2883 Mdot
.07823 .28785 Mdot
.07828 .2874 Mdot
.07833 .28694 Mdot
.07838 .28649 Mdot
.07842 .28604 Mdot
.07847 .28559 Mdot
.07852 .28514 Mdot
.07857 .28469 Mdot
.07861 .28424 Mdot
.07866 .28379 Mdot
.07871 .28334 Mdot
.07876 .28289 Mdot
.0788 .28244 Mdot
.07885 .28199 Mdot
.0789 .28154 Mdot
.07895 .28109 Mdot
.07899 .28064 Mdot
.07904 .28019 Mdot
.07909 .27974 Mdot
.07914 .27929 Mdot
.07918 .27884 Mdot
.07923 .2784 Mdot
.07928 .27796 Mdot
.07933 .27751 Mdot
.07938 .27706 Mdot
.07942 .27662 Mdot
.07947 .27617 Mdot
.07952 .27572 Mdot
.07957 .27527 Mdot
.07961 .27482 Mdot
.07966 .27437 Mdot
.07971 .27392 Mdot
.07976 .27346 Mdot
.0798 .27301 Mdot
.07985 .27255 Mdot
.0799 .2721 Mdot
.07995 .27164 Mdot
.07999 .27118 Mdot
.08004 .27072 Mdot
.08009 .27026 Mdot
.08014 .26981 Mdot
.08018 .26935 Mdot
.08023 .26889 Mdot
.08028 .26844 Mdot
.08033 .26799 Mdot
.08038 .26753 Mdot
.08042 .26708 Mdot
.08047 .26664 Mdot
.08052 .26619 Mdot
.08057 .26575 Mdot
.08061 .26531 Mdot
.08066 .26486 Mdot
.08071 .26442 Mdot
.08076 .26398 Mdot
.0808 .26353 Mdot
.08085 .26309 Mdot
.0809 .26264 Mdot
.08095 .2622 Mdot
.08099 .26175 Mdot
.08104 .26131 Mdot
.08109 .26087 Mdot
.08114 .26043 Mdot
.08118 .25999 Mdot
.08123 .25955 Mdot
.08128 .25911 Mdot
.08133 .25867 Mdot
.08138 .25823 Mdot
.08142 .2578 Mdot
.08147 .25736 Mdot
.08152 .25693 Mdot
.08157 .25649 Mdot
.08161 .25606 Mdot
.08166 .25563 Mdot
.08171 .25521 Mdot
.08176 .25478 Mdot
.0818 .25435 Mdot
.08185 .25391 Mdot
.0819 .25348 Mdot
.08195 .25305 Mdot
.08199 .25263 Mdot
.08204 .2522 Mdot
.08209 .25178 Mdot
.08214 .25136 Mdot
.08218 .25093 Mdot
.08223 .25051 Mdot
.08228 .25009 Mdot
.08233 .24967 Mdot
.08238 .24924 Mdot
.08242 .24882 Mdot
.08247 .24841 Mdot
.08252 .24799 Mdot
.08257 .24757 Mdot
.08261 .24715 Mdot
.08266 .24674 Mdot
.08271 .24632 Mdot
.08276 .2459 Mdot
.0828 .24548 Mdot
.08285 .24506 Mdot
.0829 .24464 Mdot
.08295 .24423 Mdot
.08299 .24381 Mdot
.08304 .24339 Mdot
.08309 .24297 Mdot
.08314 .24255 Mdot
.08318 .24213 Mdot
.08323 .24171 Mdot
.08328 .24129 Mdot
.08333 .24088 Mdot
.08337 .24046 Mdot
.08342 .24005 Mdot
.08347 .23963 Mdot
.08352 .23921 Mdot
.08357 .23879 Mdot
.08361 .23837 Mdot
.08366 .23795 Mdot
.08371 .23754 Mdot
.08376 .23712 Mdot
.0838 .2367 Mdot
.08385 .23629 Mdot
.0839 .23587 Mdot
.08395 .23545 Mdot
.08399 .23503 Mdot
.08404 .23461 Mdot
.08409 .23419 Mdot
.08414 .23377 Mdot
.08418 .23335 Mdot
.08423 .23293 Mdot
.08428 .23252 Mdot
.08433 .2321 Mdot
.08437 .23169 Mdot
.08442 .23128 Mdot
.08447 .23086 Mdot
.08452 .23045 Mdot
.08457 .23004 Mdot
.08461 .22964 Mdot
.08466 .22923 Mdot
.08471 .22882 Mdot
.08476 .22841 Mdot
.0848 .228 Mdot
.08485 .2276 Mdot
.0849 .2272 Mdot
.08495 .22679 Mdot
.08499 .22639 Mdot
.08504 .22599 Mdot
.08509 .22558 Mdot
.08514 .22518 Mdot
.08518 .22478 Mdot
.08523 .22438 Mdot
.08528 .22397 Mdot
.08533 .22357 Mdot
.08537 .22316 Mdot
.08542 .22275 Mdot
.08547 .22235 Mdot
.08552 .22194 Mdot
.08557 .22153 Mdot
.08561 .22113 Mdot
.08566 .22072 Mdot
.08571 .22032 Mdot
.08576 .21992 Mdot
.0858 .21952 Mdot
.08585 .21912 Mdot
.0859 .21871 Mdot
.08595 .21831 Mdot
.08599 .2179 Mdot
.08604 .2175 Mdot
.08609 .21709 Mdot
.08614 .21669 Mdot
.08618 .21628 Mdot
.08623 .21587 Mdot
.08628 .21547 Mdot
.08633 .21506 Mdot
.08637 .21465 Mdot
.08642 .21424 Mdot
.08647 .21383 Mdot
.08652 .21341 Mdot
.08657 .21299 Mdot
.08661 .21257 Mdot
.08666 .21215 Mdot
.08671 .21173 Mdot
.08676 .21131 Mdot
.0868 .2109 Mdot
.08685 .21047 Mdot
.0869 .21005 Mdot
.08695 .20963 Mdot
.08699 .20921 Mdot
.08704 .20878 Mdot
.08709 .20836 Mdot
.08714 .20794 Mdot
.08718 .20752 Mdot
.08723 .2071 Mdot
.08728 .20668 Mdot
.08733 .20626 Mdot
.08737 .20584 Mdot
.08742 .20542 Mdot
.08747 .205 Mdot
.08752 .20458 Mdot
.08757 .20416 Mdot
.08761 .20373 Mdot
.08766 .20331 Mdot
.08771 .20289 Mdot
.08776 .20247 Mdot
.0878 .20205 Mdot
.08785 .20164 Mdot
.0879 .20122 Mdot
.08795 .2008 Mdot
.08799 .20038 Mdot
.08804 .19997 Mdot
.08809 .19955 Mdot
.08814 .19914 Mdot
.08818 .19873 Mdot
.08823 .19832 Mdot
.08828 .19791 Mdot
.08833 .1975 Mdot
.08837 .19709 Mdot
.08842 .19667 Mdot
.08847 .19627 Mdot
.08852 .19586 Mdot
.08856 .19545 Mdot
.08861 .19505 Mdot
.08866 .19464 Mdot
.08871 .19424 Mdot
.08876 .19384 Mdot
.0888 .19343 Mdot
.08885 .19303 Mdot
.0889 .19263 Mdot
.08895 .19223 Mdot
.08899 .19184 Mdot
.08904 .19144 Mdot
.08909 .19104 Mdot
.08914 .19065 Mdot
.08918 .19025 Mdot
.08923 .18985 Mdot
.08928 .18946 Mdot
.08933 .18906 Mdot
.08937 .18866 Mdot
.08942 .18827 Mdot
.08947 .18788 Mdot
.08952 .18749 Mdot
.08956 .18709 Mdot
.08961 .1867 Mdot
.08966 .18631 Mdot
.08971 .18593 Mdot
.08976 .18554 Mdot
.0898 .18514 Mdot
.08985 .18475 Mdot
.0899 .18436 Mdot
.08995 .18397 Mdot
.08999 .18359 Mdot
.09004 .1832 Mdot
.09009 .18281 Mdot
.09014 .18242 Mdot
.09018 .18203 Mdot
.09023 .18164 Mdot
.09028 .18125 Mdot
.09033 .18086 Mdot
.09037 .18047 Mdot
.09042 .18008 Mdot
.09047 .17969 Mdot
.09052 .17931 Mdot
.09056 .17892 Mdot
.09061 .17853 Mdot
.09066 .17815 Mdot
.09071 .17777 Mdot
.09076 .17739 Mdot
.0908 .17701 Mdot
.09085 .17664 Mdot
.0909 .17626 Mdot
.09095 .17588 Mdot
.09099 .17551 Mdot
.09104 .17513 Mdot
.09109 .17475 Mdot
.09114 .17437 Mdot
.09118 .174 Mdot
.09123 .17363 Mdot
.09128 .17326 Mdot
.09133 .1729 Mdot
.09137 .17253 Mdot
.09142 .17217 Mdot
.09147 .1718 Mdot
.09152 .17143 Mdot
.09156 .17107 Mdot
.09161 .1707 Mdot
.09166 .17033 Mdot
.09171 .16997 Mdot
.09176 .1696 Mdot
.0918 .16924 Mdot
.09185 .16888 Mdot
.0919 .16852 Mdot
.09195 .16816 Mdot
.09199 .1678 Mdot
.09204 .16745 Mdot
.09209 .16709 Mdot
.09214 .16674 Mdot
.09218 .16638 Mdot
.09223 .16603 Mdot
.09228 .16567 Mdot
.09233 .16532 Mdot
.09237 .16497 Mdot
.09242 .16462 Mdot
.09247 .16427 Mdot
.09252 .16392 Mdot
.09256 .16356 Mdot
.09261 .16321 Mdot
.09266 .16286 Mdot
.09271 .1625 Mdot
.09276 .16215 Mdot
.0928 .1618 Mdot
.09285 .16145 Mdot
.0929 .16109 Mdot
.09295 .16074 Mdot
.09299 .16038 Mdot
.09304 .16003 Mdot
.09309 .15967 Mdot
.09314 .15932 Mdot
.09318 .15896 Mdot
.09323 .1586 Mdot
.09328 .15824 Mdot
.09333 .15788 Mdot
.09337 .15752 Mdot
.09342 .15716 Mdot
.09347 .1568 Mdot
.09352 .15644 Mdot
.09356 .15609 Mdot
.09361 .15573 Mdot
.09366 .15537 Mdot
.09371 .15501 Mdot
.09375 .15465 Mdot
.0938 .15429 Mdot
.09385 .15393 Mdot
.0939 .15357 Mdot
.09395 .15322 Mdot
.09399 .15286 Mdot
.09404 .1525 Mdot
.09409 .15213 Mdot
.09414 .15177 Mdot
.09418 .15141 Mdot
.09423 .15105 Mdot
.09428 .15069 Mdot
.09433 .15034 Mdot
.09437 .14998 Mdot
.09442 .14963 Mdot
.09447 .14928 Mdot
.09452 .14892 Mdot
.09456 .14857 Mdot
.09461 .14821 Mdot
.09466 .14785 Mdot
.09471 .1475 Mdot
.09475 .14715 Mdot
.0948 .1468 Mdot
.09485 .14645 Mdot
.0949 .1461 Mdot
.09495 .14575 Mdot
.09499 .1454 Mdot
.09504 .14505 Mdot
.09509 .1447 Mdot
.09514 .14435 Mdot
.09518 .144 Mdot
.09523 .14366 Mdot
.09528 .14331 Mdot
.09533 .14297 Mdot
.09537 .14262 Mdot
.09542 .14228 Mdot
.09547 .14194 Mdot
.09552 .1416 Mdot
.09556 .14126 Mdot
.09561 .14092 Mdot
.09566 .14058 Mdot
.09571 .14024 Mdot
.09575 .1399 Mdot
.0958 .13956 Mdot
.09585 .13922 Mdot
.0959 .13888 Mdot
.09595 .13854 Mdot
.09599 .13819 Mdot
.09604 .13785 Mdot
.09609 .13751 Mdot
.09614 .13717 Mdot
.09618 .13682 Mdot
.09623 .13648 Mdot
.09628 .13613 Mdot
.09633 .13579 Mdot
.09637 .13544 Mdot
.09642 .13509 Mdot
.09647 .13475 Mdot
.09652 .1344 Mdot
.09656 .13405 Mdot
.09661 .13369 Mdot
.09666 .13335 Mdot
.09671 .133 Mdot
.09675 .13265 Mdot
.0968 .13231 Mdot
.09685 .13197 Mdot
.0969 .13162 Mdot
.09695 .13128 Mdot
.09699 .13095 Mdot
.09704 .13061 Mdot
.09709 .13028 Mdot
.09714 .12994 Mdot
.09718 .12961 Mdot
.09723 .12927 Mdot
.09728 .12894 Mdot
.09733 .1286 Mdot
.09737 .12826 Mdot
.09742 .12793 Mdot
.09747 .12759 Mdot
.09752 .12726 Mdot
.09756 .12692 Mdot
.09761 .12659 Mdot
.09766 .12625 Mdot
.09771 .12592 Mdot
.09775 .12558 Mdot
.0978 .12524 Mdot
.09785 .1249 Mdot
.0979 .12456 Mdot
.09794 .12422 Mdot
.09799 .12388 Mdot
.09804 .12354 Mdot
.09809 .12321 Mdot
.09814 .12287 Mdot
.09818 .12253 Mdot
.09823 .1222 Mdot
.09828 .12186 Mdot
.09833 .12153 Mdot
.09837 .1212 Mdot
.09842 .12087 Mdot
.09847 .12054 Mdot
.09852 .1202 Mdot
.09856 .11987 Mdot
.09861 .11953 Mdot
.09866 .11919 Mdot
.09871 .11885 Mdot
.09875 .11852 Mdot
.0988 .11819 Mdot
.09885 .11786 Mdot
.0989 .11752 Mdot
.09894 .11719 Mdot
.09899 .11685 Mdot
.09904 .11652 Mdot
.09909 .11618 Mdot
.09914 .11585 Mdot
.09918 .11552 Mdot
.09923 .11519 Mdot
.09928 .11487 Mdot
.09933 .11455 Mdot
.09937 .11422 Mdot
.09942 .1139 Mdot
.09947 .11358 Mdot
.09952 .11325 Mdot
.09956 .11293 Mdot
.09961 .1126 Mdot
.09966 .11227 Mdot
.09971 .11194 Mdot
.09975 .11161 Mdot
.0998 .11128 Mdot
.09985 .11095 Mdot
.0999 .11062 Mdot
.09994 .11029 Mdot
.09999 .10997 Mdot
.10004 .10964 Mdot
.10009 .10932 Mdot
.10014 .109 Mdot
.10018 .10868 Mdot
.10023 .10836 Mdot
.10028 .10804 Mdot
.10033 .10772 Mdot
.10037 .1074 Mdot
.10042 .10708 Mdot
.10047 .10676 Mdot
.10052 .10645 Mdot
.10056 .10613 Mdot
.10061 .10582 Mdot
.10066 .10551 Mdot
.10071 .1052 Mdot
.10075 .10489 Mdot
.1008 .10458 Mdot
.10085 .10427 Mdot
.1009 .10397 Mdot
.10094 .10366 Mdot
.10099 .10335 Mdot
.10104 .10305 Mdot
.10109 .10274 Mdot
.10114 .10244 Mdot
.10118 .10213 Mdot
.10123 .10183 Mdot
.10128 .10153 Mdot
.10133 .10123 Mdot
.10137 .10093 Mdot
.10142 .10064 Mdot
.10147 .10034 Mdot
.10152 .10005 Mdot
.10156 .09976 Mdot
.10161 .09948 Mdot
.10166 .09919 Mdot
.10171 .0989 Mdot
.10175 .09861 Mdot
.1018 .09833 Mdot
.10185 .09804 Mdot
.1019 .09775 Mdot
.10194 .09746 Mdot
.10199 .09718 Mdot
.10204 .09689 Mdot
.10209 .0966 Mdot
.10214 .09631 Mdot
.10218 .09602 Mdot
.10223 .09573 Mdot
.10228 .09544 Mdot
.10233 .09516 Mdot
.10237 .09487 Mdot
.10242 .09458 Mdot
.10247 .09429 Mdot
.10252 .09401 Mdot
.10256 .09372 Mdot
.10261 .09344 Mdot
.10266 .09316 Mdot
.10271 .09288 Mdot
.10275 .0926 Mdot
.1028 .09232 Mdot
.10285 .09204 Mdot
.1029 .09176 Mdot
.10294 .09149 Mdot
.10299 .09121 Mdot
.10304 .09093 Mdot
.10309 .09065 Mdot
.10313 .09038 Mdot
.10318 .0901 Mdot
.10323 .08983 Mdot
.10328 .08955 Mdot
.10333 .08928 Mdot
.10337 .08901 Mdot
.10342 .08874 Mdot
.10347 .08847 Mdot
.10352 .0882 Mdot
.10356 .08793 Mdot
.10361 .08767 Mdot
.10366 .0874 Mdot
.10371 .08713 Mdot
.10375 .08686 Mdot
.1038 .08659 Mdot
.10385 .08633 Mdot
.1039 .08607 Mdot
.10394 .0858 Mdot
.10399 .08554 Mdot
.10404 .08528 Mdot
.10409 .08502 Mdot
.10413 .08477 Mdot
.10418 .08451 Mdot
.10423 .08425 Mdot
.10428 .084 Mdot
.10433 .08375 Mdot
.10437 .0835 Mdot
.10442 .08324 Mdot
.10447 .08299 Mdot
.10452 .08274 Mdot
.10456 .08249 Mdot
.10461 .08224 Mdot
.10466 .082 Mdot
.10471 .08175 Mdot
.10475 .0815 Mdot
.1048 .08125 Mdot
.10485 .08101 Mdot
.1049 .08076 Mdot
.10494 .08052 Mdot
.10499 .08027 Mdot
.10504 .08003 Mdot
.10509 .07979 Mdot
.10513 .07955 Mdot
.10518 .0793 Mdot
.10523 .07906 Mdot
.10528 .07882 Mdot
.10533 .07858 Mdot
.10537 .07833 Mdot
.10542 .07809 Mdot
.10547 .07785 Mdot
.10552 .07762 Mdot
.10556 .07738 Mdot
.10561 .07715 Mdot
.10566 .07692 Mdot
.10571 .07668 Mdot
.10575 .07645 Mdot
.1058 .07622 Mdot
.10585 .07599 Mdot
.1059 .07576 Mdot
.10594 .07553 Mdot
.10599 .07531 Mdot
.10604 .07508 Mdot
.10609 .07485 Mdot
.10613 .07463 Mdot
.10618 .0744 Mdot
.10623 .07417 Mdot
.10628 .07394 Mdot
.10633 .07371 Mdot
.10637 .07348 Mdot
.10642 .07325 Mdot
.10647 .07302 Mdot
.10652 .0728 Mdot
.10656 .07258 Mdot
.10661 .07236 Mdot
.10666 .07214 Mdot
.10671 .07192 Mdot
.10675 .0717 Mdot
.1068 .07148 Mdot
.10685 .07126 Mdot
.1069 .07104 Mdot
.10694 .07082 Mdot
.10699 .0706 Mdot
.10704 .07038 Mdot
.10709 .07016 Mdot
.10713 .06993 Mdot
.10718 .06971 Mdot
.10723 .06948 Mdot
.10728 .06926 Mdot
.10732 .06903 Mdot
.10737 .06881 Mdot
.10742 .06859 Mdot
.10747 .06837 Mdot
.10752 .06815 Mdot
.10756 .06793 Mdot
.10761 .06771 Mdot
.10766 .06749 Mdot
.10771 .06727 Mdot
.10775 .06705 Mdot
.1078 .06683 Mdot
.10785 .06661 Mdot
.1079 .06639 Mdot
.10794 .06617 Mdot
.10799 .06595 Mdot
.10804 .06574 Mdot
.10809 .06552 Mdot
.10813 .06531 Mdot
.10818 .0651 Mdot
.10823 .06489 Mdot
.10828 .06469 Mdot
.10832 .06448 Mdot
.10837 .06428 Mdot
.10842 .06408 Mdot
.10847 .06388 Mdot
.10852 .06368 Mdot
.10856 .06349 Mdot
.10861 .06329 Mdot
.10866 .0631 Mdot
.10871 .06291 Mdot
.10875 .06272 Mdot
.1088 .06252 Mdot
.10885 .06233 Mdot
.1089 .06213 Mdot
.10894 .06194 Mdot
.10899 .06174 Mdot
.10904 .06155 Mdot
.10909 .06136 Mdot
.10913 .06117 Mdot
.10918 .06098 Mdot
.10923 .06078 Mdot
.10928 .06059 Mdot
.10932 .0604 Mdot
.10937 .06021 Mdot
.10942 .06001 Mdot
.10947 .05983 Mdot
.10952 .05964 Mdot
.10956 .05945 Mdot
.10961 .05926 Mdot
.10966 .05907 Mdot
.10971 .05888 Mdot
.10975 .05869 Mdot
.1098 .05851 Mdot
.10985 .05832 Mdot
.1099 .05813 Mdot
.10994 .05795 Mdot
.10999 .05777 Mdot
.11004 .05759 Mdot
.11009 .05741 Mdot
.11013 .05723 Mdot
.11018 .05706 Mdot
.11023 .05689 Mdot
.11028 .05671 Mdot
.11032 .05654 Mdot
.11037 .05636 Mdot
.11042 .05619 Mdot
.11047 .05602 Mdot
.11052 .05585 Mdot
.11056 .05567 Mdot
.11061 .0555 Mdot
.11066 .05532 Mdot
.11071 .05514 Mdot
.11075 .05497 Mdot
.1108 .0548 Mdot
.11085 .05463 Mdot
.1109 .05446 Mdot
.11094 .05429 Mdot
.11099 .05412 Mdot
.11104 .05395 Mdot
.11109 .05378 Mdot
.11113 .0536 Mdot
.11118 .05343 Mdot
.11123 .05326 Mdot
.11128 .05309 Mdot
.11132 .05292 Mdot
.11137 .05275 Mdot
.11142 .05258 Mdot
.11147 .0524 Mdot
.11152 .05222 Mdot
.11156 .05205 Mdot
.11161 .05187 Mdot
.11166 .05169 Mdot
.11171 .05151 Mdot
.11175 .05133 Mdot
.1118 .05115 Mdot
.11185 .05098 Mdot
.1119 .0508 Mdot
.11194 .05063 Mdot
.11199 .05045 Mdot
.11204 .05028 Mdot
.11209 .0501 Mdot
.11213 .04993 Mdot
.11218 .04976 Mdot
.11223 .04959 Mdot
.11228 .04941 Mdot
.11232 .04923 Mdot
.11237 .04906 Mdot
.11242 .04889 Mdot
.11247 .04872 Mdot
.11251 .04855 Mdot
.11256 .04839 Mdot
.11261 .04822 Mdot
.11266 .04806 Mdot
.11271 .0479 Mdot
.11275 .04774 Mdot
.1128 .04759 Mdot
.11285 .04743 Mdot
.1129 .04728 Mdot
.11294 .04713 Mdot
.11299 .04699 Mdot
.11304 .04684 Mdot
.11309 .04668 Mdot
.11313 .04653 Mdot
.11318 .04638 Mdot
.11323 .04623 Mdot
.11328 .04608 Mdot
.11332 .04593 Mdot
.11337 .04577 Mdot
.11342 .04561 Mdot
.11347 .04546 Mdot
.11351 .0453 Mdot
.11356 .04514 Mdot
.11361 .04498 Mdot
.11366 .04482 Mdot
.11371 .04467 Mdot
.11375 .04451 Mdot
.1138 .04436 Mdot
.11385 .04421 Mdot
.1139 .04406 Mdot
.11394 .04391 Mdot
.11399 .04377 Mdot
.11404 .04362 Mdot
.11409 .04347 Mdot
.11413 .04333 Mdot
.11418 .04319 Mdot
.11423 .04304 Mdot
.11428 .0429 Mdot
.11432 .04276 Mdot
.11437 .04262 Mdot
.11442 .04248 Mdot
.11447 .04234 Mdot
.11451 .0422 Mdot
.11456 .04206 Mdot
.11461 .04192 Mdot
.11466 .04177 Mdot
.11471 .04163 Mdot
.11475 .04149 Mdot
.1148 .04135 Mdot
.11485 .04121 Mdot
.1149 .04107 Mdot
.11494 .04094 Mdot
.11499 .0408 Mdot
.11504 .04066 Mdot
.11509 .04053 Mdot
.11513 .04039 Mdot
.11518 .04026 Mdot
.11523 .04012 Mdot
.11528 .03998 Mdot
.11532 .03985 Mdot
.11537 .03972 Mdot
.11542 .03958 Mdot
.11547 .03944 Mdot
.11551 .03931 Mdot
.11556 .03917 Mdot
.11561 .03904 Mdot
.11566 .03891 Mdot
.11571 .03878 Mdot
.11575 .03864 Mdot
.1158 .03851 Mdot
.11585 .03838 Mdot
.1159 .03825 Mdot
.11594 .03811 Mdot
.11599 .03798 Mdot
.11604 .03785 Mdot
.11609 .03772 Mdot
.11613 .03758 Mdot
.11618 .03745 Mdot
.11623 .03732 Mdot
.11628 .03719 Mdot
.11632 .03706 Mdot
.11637 .03693 Mdot
.11642 .03681 Mdot
.11647 .03669 Mdot
.11651 .03656 Mdot
.11656 .03644 Mdot
.11661 .03631 Mdot
.11666 .03619 Mdot
.1167 .03606 Mdot
.11675 .03594 Mdot
.1168 .03582 Mdot
.11685 .03569 Mdot
.1169 .03557 Mdot
.11694 .03545 Mdot
.11699 .03533 Mdot
.11704 .03521 Mdot
.11709 .03508 Mdot
.11713 .03496 Mdot
.11718 .03484 Mdot
.11723 .03473 Mdot
.11728 .03461 Mdot
.11732 .0345 Mdot
.11737 .03438 Mdot
.11742 .03427 Mdot
.11747 .03415 Mdot
.11751 .03404 Mdot
.11756 .03393 Mdot
.11761 .03382 Mdot
.11766 .03372 Mdot
.1177 .03361 Mdot
.11775 .0335 Mdot
.1178 .0334 Mdot
.11785 .0333 Mdot
.1179 .0332 Mdot
.11794 .0331 Mdot
.11799 .033 Mdot
.11804 .0329 Mdot
.11809 .0328 Mdot
.11813 .03271 Mdot
.11818 .03261 Mdot
.11823 .03251 Mdot
.11828 .03242 Mdot
.11832 .03232 Mdot
.11837 .03223 Mdot
.11842 .03213 Mdot
.11847 .03204 Mdot
.11851 .03195 Mdot
.11856 .03185 Mdot
.11861 .03176 Mdot
.11866 .03167 Mdot
.1187 .03157 Mdot
.11875 .03149 Mdot
.1188 .0314 Mdot
.11885 .03131 Mdot
.1189 .03122 Mdot
.11894 .03113 Mdot
.11899 .03105 Mdot
.11904 .03096 Mdot
.11909 .03087 Mdot
.11913 .03079 Mdot
.11918 .0307 Mdot
.11923 .03062 Mdot
.11928 .03054 Mdot
.11932 .03046 Mdot
.11937 .03038 Mdot
.11942 .0303 Mdot
.11947 .03022 Mdot
.11951 .03014 Mdot
.11956 .03006 Mdot
.11961 .02998 Mdot
.11966 .02991 Mdot
.1197 .02983 Mdot
.11975 .02975 Mdot
.1198 .02967 Mdot
.11985 .0296 Mdot
.1199 .02952 Mdot
.11994 .02944 Mdot
.11999 .02935 Mdot
.12004 .02927 Mdot
.12009 .02919 Mdot
.12013 .02911 Mdot
.12018 .02904 Mdot
.12023 .02896 Mdot
.12028 .02889 Mdot
.12032 .02882 Mdot
.12037 .02875 Mdot
.12042 .02868 Mdot
.12047 .02861 Mdot
.12051 .02853 Mdot
.12056 .02846 Mdot
.12061 .02839 Mdot
.12066 .02833 Mdot
.1207 .02826 Mdot
.12075 .02819 Mdot
.1208 .02813 Mdot
.12085 .02807 Mdot
.1209 .02801 Mdot
.12094 .02795 Mdot
.12099 .02789 Mdot
.12104 .02783 Mdot
.12109 .02777 Mdot
.12113 .02771 Mdot
.12118 .02765 Mdot
.12123 .02759 Mdot
.12128 .02754 Mdot
.12132 .02748 Mdot
.12137 .02742 Mdot
.12142 .02737 Mdot
.12147 .02732 Mdot
.12151 .02726 Mdot
.12156 .02721 Mdot
.12161 .02716 Mdot
.12166 .02711 Mdot
.1217 .02706 Mdot
.12175 .02702 Mdot
.1218 .02697 Mdot
.12185 .02693 Mdot
.12189 .02688 Mdot
.12194 .02684 Mdot
.12199 .02679 Mdot
.12204 .02675 Mdot
.12209 .02671 Mdot
.12213 .02667 Mdot
.12218 .02663 Mdot
.12223 .0266 Mdot
.12228 .02656 Mdot
.12232 .02652 Mdot
.12237 .02649 Mdot
.12242 .02645 Mdot
.12247 .02642 Mdot
.12251 .02639 Mdot
.12256 .02636 Mdot
.12261 .02633 Mdot
.12266 .02631 Mdot
.1227 .02628 Mdot
.12275 .02626 Mdot
.1228 .02624 Mdot
.12285 .02622 Mdot
.12289 .02619 Mdot
.12294 .02617 Mdot
.12299 .02615 Mdot
.12304 .02613 Mdot
.12309 .02611 Mdot
.12313 .02609 Mdot
.12318 .02607 Mdot
.12323 .02604 Mdot
.12328 .02602 Mdot
.12332 .026 Mdot
.12337 .02598 Mdot
.12342 .02596 Mdot
.12347 .02594 Mdot
.12351 .02593 Mdot
.12356 .02591 Mdot
.12361 .0259 Mdot
.12366 .02588 Mdot
.1237 .02587 Mdot
.12375 .02585 Mdot
.1238 .02584 Mdot
.12385 .02584 Mdot
.12389 .02583 Mdot
.12394 .02583 Mdot
.12399 .02583 Mdot
.12404 .02583 Mdot
.12409 .02583 Mdot
.12413 .02584 Mdot
.12418 .02585 Mdot
.12423 .02585 Mdot
.12428 .02587 Mdot
.12432 .02588 Mdot
.12437 .02589 Mdot
.12442 .0259 Mdot
.12447 .02591 Mdot
.12451 .02592 Mdot
.12456 .02593 Mdot
.12461 .02594 Mdot
.12466 .02595 Mdot
.1247 .02596 Mdot
.12475 .02597 Mdot
.1248 .02597 Mdot
.12485 .02598 Mdot
.12489 .02599 Mdot
.12494 .02599 Mdot
.12499 .026 Mdot
.12504 .026 Mdot
.12509 .026 Mdot
.12513 .026 Mdot
.12518 .026 Mdot
.12523 .026 Mdot
.12528 .026 Mdot
.12532 .026 Mdot
.12537 .02601 Mdot
.12542 .02601 Mdot
.12547 .02602 Mdot
.12551 .02602 Mdot
.12556 .02602 Mdot
.12561 .02603 Mdot
.12566 .02603 Mdot
.1257 .02604 Mdot
.12575 .02604 Mdot
.1258 .02605 Mdot
.12585 .02605 Mdot
.12589 .02606 Mdot
.12594 .02606 Mdot
.12599 .02606 Mdot
.12604 .02606 Mdot
.12609 .02606 Mdot
.12613 .02606 Mdot
.12618 .02606 Mdot
.12623 .02607 Mdot
.12628 .02607 Mdot
.12632 .02608 Mdot
.12637 .02609 Mdot
.12642 .0261 Mdot
.12647 .02611 Mdot
.12651 .02612 Mdot
.12656 .02614 Mdot
.12661 .02615 Mdot
.12666 .02617 Mdot
.1267 .02619 Mdot
.12675 .02621 Mdot
.1268 .02623 Mdot
.12685 .02625 Mdot
.12689 .02627 Mdot
.12694 .02629 Mdot
.12699 .02632 Mdot
.12704 .02634 Mdot
.12708 .02637 Mdot
.12713 .02639 Mdot
.12718 .02642 Mdot
.12723 .02645 Mdot
.12728 .02647 Mdot
.12732 .0265 Mdot
.12737 .02653 Mdot
.12742 .02656 Mdot
.12747 .02659 Mdot
.12751 .02663 Mdot
.12756 .02666 Mdot
.12761 .02669 Mdot
.12766 .02673 Mdot
.1277 .02676 Mdot
.12775 .02679 Mdot
.1278 .02683 Mdot
.12785 .02686 Mdot
.12789 .02689 Mdot
.12794 .02693 Mdot
.12799 .02697 Mdot
.12804 .02701 Mdot
.12808 .02705 Mdot
.12813 .02709 Mdot
.12818 .02713 Mdot
.12823 .02717 Mdot
.12828 .0272 Mdot
.12832 .02724 Mdot
.12837 .02728 Mdot
.12842 .02732 Mdot
.12847 .02736 Mdot
.12851 .02741 Mdot
.12856 .02745 Mdot
.12861 .02749 Mdot
.12866 .02753 Mdot
.1287 .02758 Mdot
.12875 .02762 Mdot
.1288 .02767 Mdot
.12885 .02771 Mdot
.12889 .02775 Mdot
.12894 .02779 Mdot
.12899 .02783 Mdot
.12904 .02787 Mdot
.12908 .02791 Mdot
.12913 .02795 Mdot
.12918 .028 Mdot
.12923 .02804 Mdot
.12928 .02808 Mdot
.12932 .02812 Mdot
.12937 .02816 Mdot
.12942 .02821 Mdot
.12947 .02825 Mdot
.12951 .0283 Mdot
.12956 .02835 Mdot
.12961 .0284 Mdot
.12966 .02844 Mdot
.1297 .02849 Mdot
.12975 .02854 Mdot
.1298 .02858 Mdot
.12985 .02863 Mdot
.12989 .02868 Mdot
.12994 .02872 Mdot
.12999 .02876 Mdot
.13004 .02881 Mdot
.13008 .02885 Mdot
.13013 .02889 Mdot
.13018 .02893 Mdot
.13023 .02897 Mdot
.13028 .02901 Mdot
.13032 .02905 Mdot
.13037 .0291 Mdot
.13042 .02914 Mdot
.13047 .02919 Mdot
.13051 .02924 Mdot
.13056 .02929 Mdot
.13061 .02934 Mdot
.13066 .0294 Mdot
.1307 .02945 Mdot
.13075 .02951 Mdot
.1308 .02957 Mdot
.13085 .02963 Mdot
.13089 .02969 Mdot
.13094 .02975 Mdot
.13099 .02981 Mdot
.13104 .02987 Mdot
.13108 .02993 Mdot
.13113 .03 Mdot
.13118 .03006 Mdot
.13123 .03012 Mdot
.13127 .03018 Mdot
.13132 .03024 Mdot
.13137 .0303 Mdot
.13142 .03036 Mdot
.13147 .03042 Mdot
.13151 .03049 Mdot
.13156 .03056 Mdot
.13161 .03063 Mdot
.13166 .0307 Mdot
.1317 .03077 Mdot
.13175 .03085 Mdot
.1318 .03093 Mdot
.13185 .031 Mdot
.13189 .03108 Mdot
.13194 .03115 Mdot
.13199 .03123 Mdot
.13204 .0313 Mdot
.13208 .03138 Mdot
.13213 .03146 Mdot
.13218 .03154 Mdot
.13223 .03163 Mdot
.13227 .03171 Mdot
.13232 .03179 Mdot
.13237 .03187 Mdot
.13242 .03196 Mdot
.13247 .03205 Mdot
.13251 .03213 Mdot
.13256 .03222 Mdot
.13261 .0323 Mdot
.13266 .03239 Mdot
.1327 .03247 Mdot
.13275 .03256 Mdot
.1328 .03265 Mdot
.13285 .03274 Mdot
.13289 .03283 Mdot
.13294 .03292 Mdot
.13299 .03301 Mdot
.13304 .0331 Mdot
.13308 .0332 Mdot
.13313 .03329 Mdot
.13318 .03339 Mdot
.13323 .03348 Mdot
.13327 .03358 Mdot
.13332 .03368 Mdot
.13337 .03378 Mdot
.13342 .03388 Mdot
.13347 .03399 Mdot
.13351 .03409 Mdot
.13356 .0342 Mdot
.13361 .03431 Mdot
.13366 .03443 Mdot
.1337 .03454 Mdot
.13375 .03466 Mdot
.1338 .03477 Mdot
.13385 .03489 Mdot
.13389 .03501 Mdot
.13394 .03513 Mdot
.13399 .03526 Mdot
.13404 .03538 Mdot
.13408 .03551 Mdot
.13413 .03563 Mdot
.13418 .03576 Mdot
.13423 .03588 Mdot
.13427 .03601 Mdot
.13432 .03613 Mdot
.13437 .03626 Mdot
.13442 .03639 Mdot
.13447 .03652 Mdot
.13451 .03665 Mdot
.13456 .03678 Mdot
.13461 .03691 Mdot
.13466 .03705 Mdot
.1347 .03718 Mdot
.13475 .03732 Mdot
.1348 .03745 Mdot
.13485 .03759 Mdot
.13489 .03773 Mdot
.13494 .03786 Mdot
.13499 .03799 Mdot
.13504 .03812 Mdot
.13508 .03826 Mdot
.13513 .03839 Mdot
.13518 .03852 Mdot
.13523 .03865 Mdot
.13527 .03878 Mdot
.13532 .03892 Mdot
.13537 .03906 Mdot
.13542 .0392 Mdot
.13547 .03934 Mdot
.13551 .03948 Mdot
.13556 .03962 Mdot
.13561 .03976 Mdot
.13566 .0399 Mdot
.1357 .04005 Mdot
.13575 .04019 Mdot
.1358 .04034 Mdot
.13585 .04049 Mdot
.13589 .04064 Mdot
.13594 .04079 Mdot
.13599 .04095 Mdot
.13604 .0411 Mdot
.13608 .04126 Mdot
.13613 .04141 Mdot
.13618 .04157 Mdot
.13623 .04172 Mdot
.13627 .04187 Mdot
.13632 .04202 Mdot
.13637 .04218 Mdot
.13642 .04233 Mdot
.13646 .04248 Mdot
.13651 .04263 Mdot
.13656 .04279 Mdot
.13661 .04294 Mdot
.13666 .04309 Mdot
.1367 .04324 Mdot
.13675 .04339 Mdot
.1368 .04355 Mdot
.13685 .0437 Mdot
.13689 .04385 Mdot
.13694 .044 Mdot
.13699 .04415 Mdot
.13704 .0443 Mdot
.13708 .04445 Mdot
.13713 .0446 Mdot
.13718 .04476 Mdot
.13723 .04491 Mdot
.13727 .04507 Mdot
.13732 .04522 Mdot
.13737 .04538 Mdot
.13742 .04553 Mdot
.13746 .04569 Mdot
.13751 .04584 Mdot
.13756 .046 Mdot
.13761 .04616 Mdot
.13766 .04632 Mdot
.1377 .04648 Mdot
.13775 .04664 Mdot
.1378 .0468 Mdot
.13785 .04697 Mdot
.13789 .04713 Mdot
.13794 .04729 Mdot
.13799 .04746 Mdot
.13804 .04762 Mdot
.13808 .04778 Mdot
.13813 .04795 Mdot
.13818 .04812 Mdot
.13823 .04828 Mdot
.13827 .04845 Mdot
.13832 .04862 Mdot
.13837 .04879 Mdot
.13842 .04897 Mdot
.13846 .04914 Mdot
.13851 .04931 Mdot
.13856 .04948 Mdot
.13861 .04965 Mdot
.13866 .04983 Mdot
.1387 .05 Mdot
.13875 .05018 Mdot
.1388 .05035 Mdot
.13885 .05053 Mdot
.13889 .05071 Mdot
.13894 .05088 Mdot
.13899 .05106 Mdot
.13904 .05124 Mdot
.13908 .05141 Mdot
.13913 .05159 Mdot
.13918 .05176 Mdot
.13923 .05194 Mdot
.13927 .05211 Mdot
.13932 .05229 Mdot
.13937 .05246 Mdot
.13942 .05264 Mdot
.13946 .05281 Mdot
.13951 .05299 Mdot
.13956 .05316 Mdot
.13961 .05334 Mdot
.13966 .05351 Mdot
.1397 .0537 Mdot
.13975 .05388 Mdot
.1398 .05406 Mdot
.13985 .05425 Mdot
.13989 .05443 Mdot
.13994 .05462 Mdot
.13999 .05481 Mdot
.14004 .055 Mdot
.14008 .05519 Mdot
.14013 .05538 Mdot
.14018 .05558 Mdot
.14023 .05578 Mdot
.14027 .05598 Mdot
.14032 .05618 Mdot
.14037 .05638 Mdot
.14042 .05659 Mdot
.14046 .05679 Mdot
.14051 .05698 Mdot
.14056 .05718 Mdot
.14061 .05739 Mdot
.14065 .05759 Mdot
.1407 .05779 Mdot
.14075 .05799 Mdot
.1408 .05819 Mdot
.14085 .05839 Mdot
.14089 .05859 Mdot
.14094 .05879 Mdot
.14099 .05899 Mdot
.14104 .05919 Mdot
.14108 .05939 Mdot
.14113 .05959 Mdot
.14118 .05979 Mdot
.14123 .06 Mdot
.14127 .0602 Mdot
.14132 .06041 Mdot
.14137 .06062 Mdot
.14142 .06083 Mdot
.14146 .06104 Mdot
.14151 .06126 Mdot
.14156 .06147 Mdot
.14161 .06169 Mdot
.14165 .0619 Mdot
.1417 .06212 Mdot
.14175 .06234 Mdot
.1418 .06256 Mdot
.14185 .06278 Mdot
.14189 .063 Mdot
.14194 .06322 Mdot
.14199 .06344 Mdot
.14204 .06366 Mdot
.14208 .06388 Mdot
.14213 .0641 Mdot
.14218 .06433 Mdot
.14223 .06456 Mdot
.14227 .06478 Mdot
.14232 .06501 Mdot
.14237 .06525 Mdot
.14242 .06548 Mdot
.14246 .06571 Mdot
.14251 .06594 Mdot
.14256 .06617 Mdot
.14261 .0664 Mdot
.14265 .06664 Mdot
.1427 .06688 Mdot
.14275 .06711 Mdot
.1428 .06734 Mdot
.14285 .06758 Mdot
.14289 .06781 Mdot
.14294 .06805 Mdot
.14299 .06829 Mdot
.14304 .06853 Mdot
.14308 .06876 Mdot
.14313 .069 Mdot
.14318 .06923 Mdot
.14323 .06947 Mdot
.14327 .06971 Mdot
.14332 .06994 Mdot
.14337 .07018 Mdot
.14342 .07042 Mdot
.14346 .07067 Mdot
.14351 .07091 Mdot
.14356 .07116 Mdot
.14361 .07141 Mdot
.14365 .07165 Mdot
.1437 .0719 Mdot
.14375 .07214 Mdot
.1438 .07239 Mdot
.14385 .07264 Mdot
.14389 .0729 Mdot
.14394 .07315 Mdot
.14399 .0734 Mdot
.14404 .07365 Mdot
.14408 .07391 Mdot
.14413 .07416 Mdot
.14418 .07441 Mdot
.14423 .07467 Mdot
.14427 .07492 Mdot
.14432 .07518 Mdot
.14437 .07543 Mdot
.14442 .07568 Mdot
.14446 .07593 Mdot
.14451 .07618 Mdot
.14456 .07644 Mdot
.14461 .07669 Mdot
.14465 .07693 Mdot
.1447 .07718 Mdot
.14475 .07744 Mdot
.1448 .07768 Mdot
.14485 .07793 Mdot
.14489 .07818 Mdot
.14494 .07844 Mdot
.14499 .07868 Mdot
.14504 .07893 Mdot
.14508 .07918 Mdot
.14513 .07943 Mdot
.14518 .07968 Mdot
.14523 .07992 Mdot
.14527 .08017 Mdot
.14532 .08042 Mdot
.14537 .08066 Mdot
.14542 .08091 Mdot
.14546 .08116 Mdot
.14551 .0814 Mdot
.14556 .08165 Mdot
.14561 .0819 Mdot
.14565 .08214 Mdot
.1457 .08238 Mdot
.14575 .08262 Mdot
.1458 .08287 Mdot
.14584 .08311 Mdot
.14589 .08335 Mdot
.14594 .08359 Mdot
.14599 .08384 Mdot
.14604 .08408 Mdot
.14608 .08432 Mdot
.14613 .08457 Mdot
.14618 .08482 Mdot
.14623 .08507 Mdot
.14627 .08532 Mdot
.14632 .08558 Mdot
.14637 .08583 Mdot
.14642 .08608 Mdot
.14646 .08634 Mdot
.14651 .08659 Mdot
.14656 .08685 Mdot
.14661 .0871 Mdot
.14665 .08736 Mdot
.1467 .08761 Mdot
.14675 .08786 Mdot
.1468 .08811 Mdot
.14684 .08836 Mdot
.14689 .08861 Mdot
.14694 .08886 Mdot
.14699 .08911 Mdot
.14704 .08936 Mdot
.14708 .08961 Mdot
.14713 .08987 Mdot
.14718 .09012 Mdot
.14723 .09038 Mdot
.14727 .09064 Mdot
.14732 .09089 Mdot
.14737 .09115 Mdot
.14742 .09141 Mdot
.14746 .09167 Mdot
.14751 .09193 Mdot
.14756 .09219 Mdot
.14761 .09245 Mdot
.14765 .09271 Mdot
.1477 .09296 Mdot
.14775 .09322 Mdot
.1478 .09347 Mdot
.14784 .09373 Mdot
.14789 .09399 Mdot
.14794 .09426 Mdot
.14799 .09452 Mdot
.14804 .09479 Mdot
.14808 .09506 Mdot
.14813 .09533 Mdot
.14818 .09561 Mdot
.14823 .09588 Mdot
.14827 .09615 Mdot
.14832 .09642 Mdot
.14837 .09669 Mdot
.14842 .09696 Mdot
.14846 .09723 Mdot
.14851 .0975 Mdot
.14856 .09777 Mdot
.14861 .09805 Mdot
.14865 .09833 Mdot
.1487 .0986 Mdot
.14875 .09888 Mdot
.1488 .09916 Mdot
.14884 .09943 Mdot
.14889 .09971 Mdot
.14894 .09999 Mdot
.14899 .10027 Mdot
.14904 .10055 Mdot
.14908 .10083 Mdot
.14913 .10111 Mdot
.14918 .10139 Mdot
.14923 .10166 Mdot
.14927 .10194 Mdot
.14932 .10221 Mdot
.14937 .10249 Mdot
.14942 .10276 Mdot
.14946 .10304 Mdot
.14951 .10332 Mdot
.14956 .1036 Mdot
.14961 .10388 Mdot
.14965 .10416 Mdot
.1497 .10443 Mdot
.14975 .10471 Mdot
.1498 .10498 Mdot
.14984 .10526 Mdot
.14989 .10553 Mdot
.14994 .10581 Mdot
.14999 .10609 Mdot
.15003 .10636 Mdot
.15008 .10664 Mdot
.15013 .10692 Mdot
.15018 .10721 Mdot
.15023 .1075 Mdot
.15027 .10778 Mdot
.15032 .10807 Mdot
.15037 .10836 Mdot
.15042 .10865 Mdot
.15046 .10894 Mdot
.15051 .10923 Mdot
.15056 .10952 Mdot
.15061 .10981 Mdot
.15065 .11011 Mdot
.1507 .11041 Mdot
.15075 .1107 Mdot
.1508 .111 Mdot
.15084 .11129 Mdot
.15089 .11159 Mdot
.15094 .11188 Mdot
.15099 .11218 Mdot
.15103 .11247 Mdot
.15108 .11277 Mdot
.15113 .11306 Mdot
.15118 .11336 Mdot
.15123 .11365 Mdot
.15127 .11395 Mdot
.15132 .11425 Mdot
.15137 .11455 Mdot
.15142 .11485 Mdot
.15146 .11514 Mdot
.15151 .11544 Mdot
.15156 .11574 Mdot
.15161 .11603 Mdot
.15165 .11633 Mdot
.1517 .11663 Mdot
.15175 .11692 Mdot
.1518 .11722 Mdot
.15184 .11752 Mdot
.15189 .11783 Mdot
.15194 .11813 Mdot
.15199 .11844 Mdot
.15203 .11874 Mdot
.15208 .11905 Mdot
.15213 .11937 Mdot
.15218 .11968 Mdot
.15223 .11999 Mdot
.15227 .1203 Mdot
.15232 .12061 Mdot
.15237 .12092 Mdot
.15242 .12122 Mdot
.15246 .12154 Mdot
.15251 .12185 Mdot
.15256 .12216 Mdot
.15261 .12247 Mdot
.15265 .12278 Mdot
.1527 .12309 Mdot
.15275 .1234 Mdot
.1528 .1237 Mdot
.15284 .12401 Mdot
.15289 .12432 Mdot
.15294 .12463 Mdot
.15299 .12494 Mdot
.15303 .12525 Mdot
.15308 .12556 Mdot
.15313 .12587 Mdot
.15318 .12618 Mdot
.15323 .12648 Mdot
.15327 .12679 Mdot
.15332 .12709 Mdot
.15337 .1274 Mdot
.15342 .1277 Mdot
.15346 .12801 Mdot
.15351 .12831 Mdot
.15356 .12861 Mdot
.15361 .12891 Mdot
.15365 .12921 Mdot
.1537 .12952 Mdot
.15375 .12982 Mdot
.1538 .13013 Mdot
.15384 .13044 Mdot
.15389 .13075 Mdot
.15394 .13106 Mdot
.15399 .13137 Mdot
.15403 .13168 Mdot
.15408 .13198 Mdot
.15413 .13229 Mdot
.15418 .1326 Mdot
.15423 .1329 Mdot
.15427 .1332 Mdot
.15432 .13351 Mdot
.15437 .13382 Mdot
.15442 .13413 Mdot
.15446 .13444 Mdot
.15451 .13475 Mdot
.15456 .13506 Mdot
.15461 .13538 Mdot
.15465 .13569 Mdot
.1547 .13601 Mdot
.15475 .13633 Mdot
.1548 .13664 Mdot
.15484 .13696 Mdot
.15489 .13727 Mdot
.15494 .13759 Mdot
.15499 .13791 Mdot
.15503 .13822 Mdot
.15508 .13854 Mdot
.15513 .13886 Mdot
.15518 .13918 Mdot
.15522 .1395 Mdot
.15527 .13983 Mdot
.15532 .14015 Mdot
.15537 .14048 Mdot
.15542 .1408 Mdot
.15546 .14113 Mdot
.15551 .14145 Mdot
.15556 .14178 Mdot
.15561 .1421 Mdot
.15565 .14243 Mdot
.1557 .14275 Mdot
.15575 .14308 Mdot
.1558 .14341 Mdot
.15584 .14373 Mdot
.15589 .14406 Mdot
.15594 .1444 Mdot
.15599 .14473 Mdot
.15603 .14506 Mdot
.15608 .14539 Mdot
.15613 .14573 Mdot
.15618 .14606 Mdot
.15622 .1464 Mdot
.15627 .14674 Mdot
.15632 .14707 Mdot
.15637 .14741 Mdot
.15642 .14775 Mdot
.15646 .14809 Mdot
.15651 .14844 Mdot
.15656 .14878 Mdot
.15661 .14912 Mdot
.15665 .14947 Mdot
.1567 .14982 Mdot
.15675 .15016 Mdot
.1568 .15051 Mdot
.15684 .15086 Mdot
.15689 .1512 Mdot
.15694 .15155 Mdot
.15699 .15189 Mdot
.15703 .15224 Mdot
.15708 .15259 Mdot
.15713 .15294 Mdot
.15718 .15328 Mdot
.15722 .15363 Mdot
.15727 .15398 Mdot
.15732 .15433 Mdot
.15737 .15468 Mdot
.15742 .15503 Mdot
.15746 .15539 Mdot
.15751 .15574 Mdot
.15756 .15609 Mdot
.15761 .15645 Mdot
.15765 .1568 Mdot
.1577 .15716 Mdot
.15775 .15751 Mdot
.1578 .15786 Mdot
.15784 .15821 Mdot
.15789 .15856 Mdot
.15794 .15892 Mdot
.15799 .15928 Mdot
.15803 .15963 Mdot
.15808 .15999 Mdot
.15813 .16036 Mdot
.15818 .16072 Mdot
.15822 .16108 Mdot
.15827 .16145 Mdot
.15832 .16181 Mdot
.15837 .16217 Mdot
.15842 .16253 Mdot
.15846 .1629 Mdot
.15851 .16326 Mdot
.15856 .16363 Mdot
.15861 .164 Mdot
.15865 .16437 Mdot
.1587 .16474 Mdot
.15875 .1651 Mdot
.1588 .16547 Mdot
.15884 .16583 Mdot
.15889 .1662 Mdot
.15894 .16656 Mdot
.15899 .16693 Mdot
.15903 .16729 Mdot
.15908 .16765 Mdot
.15913 .16802 Mdot
.15918 .16838 Mdot
.15922 .16875 Mdot
.15927 .16911 Mdot
.15932 .16948 Mdot
.15937 .16985 Mdot
.15942 .17021 Mdot
.15946 .17058 Mdot
.15951 .17095 Mdot
.15956 .17132 Mdot
.15961 .17169 Mdot
.15965 .17205 Mdot
.1597 .17242 Mdot
.15975 .17278 Mdot
.1598 .17315 Mdot
.15984 .17352 Mdot
.15989 .1739 Mdot
.15994 .17427 Mdot
.15999 .17464 Mdot
.16003 .17501 Mdot
.16008 .17537 Mdot
.16013 .17574 Mdot
.16018 .1761 Mdot
.16022 .17647 Mdot
.16027 .17683 Mdot
.16032 .1772 Mdot
.16037 .17756 Mdot
.16041 .17793 Mdot
.16046 .1783 Mdot
.16051 .17866 Mdot
.16056 .17903 Mdot
.16061 .1794 Mdot
.16065 .17977 Mdot
.1607 .18014 Mdot
.16075 .18051 Mdot
.1608 .18087 Mdot
.16084 .18124 Mdot
.16089 .1816 Mdot
.16094 .18197 Mdot
.16099 .18233 Mdot
.16103 .18269 Mdot
.16108 .18306 Mdot
.16113 .18342 Mdot
.16118 .18378 Mdot
.16122 .18415 Mdot
.16127 .18451 Mdot
.16132 .18487 Mdot
.16137 .18524 Mdot
.16141 .1856 Mdot
.16146 .18597 Mdot
.16151 .18633 Mdot
.16156 .1867 Mdot
.16161 .18706 Mdot
.16165 .18743 Mdot
.1617 .18779 Mdot
.16175 .18816 Mdot
.1618 .18852 Mdot
.16184 .18889 Mdot
.16189 .18925 Mdot
.16194 .18962 Mdot
.16199 .18998 Mdot
.16203 .19035 Mdot
.16208 .19072 Mdot
.16213 .19109 Mdot
.16218 .19147 Mdot
.16222 .19184 Mdot
.16227 .19221 Mdot
.16232 .19258 Mdot
.16237 .19296 Mdot
.16241 .19333 Mdot
.16246 .1937 Mdot
.16251 .19407 Mdot
.16256 .19445 Mdot
.16261 .19482 Mdot
.16265 .1952 Mdot
.1627 .19557 Mdot
.16275 .19595 Mdot
.1628 .19632 Mdot
.16284 .19669 Mdot
.16289 .19707 Mdot
.16294 .19745 Mdot
.16299 .19782 Mdot
.16303 .1982 Mdot
.16308 .19857 Mdot
.16313 .19894 Mdot
.16318 .19932 Mdot
.16322 .19969 Mdot
.16327 .20007 Mdot
.16332 .20044 Mdot
.16337 .20082 Mdot
.16341 .2012 Mdot
.16346 .20157 Mdot
.16351 .20194 Mdot
.16356 .20231 Mdot
.16361 .20269 Mdot
.16365 .20307 Mdot
.1637 .20344 Mdot
.16375 .20382 Mdot
.1638 .20419 Mdot
.16384 .20457 Mdot
.16389 .20494 Mdot
.16394 .20532 Mdot
.16399 .20569 Mdot
.16403 .20606 Mdot
.16408 .20644 Mdot
.16413 .20682 Mdot
.16418 .20719 Mdot
.16422 .20757 Mdot
.16427 .20794 Mdot
.16432 .20831 Mdot
.16437 .20869 Mdot
.16441 .20907 Mdot
.16446 .20944 Mdot
.16451 .20982 Mdot
.16456 .2102 Mdot
.1646 .21058 Mdot
.16465 .21096 Mdot
.1647 .21134 Mdot
.16475 .21172 Mdot
.1648 .2121 Mdot
.16484 .21248 Mdot
.16489 .21287 Mdot
.16494 .21325 Mdot
.16499 .21363 Mdot
.16503 .21402 Mdot
.16508 .21441 Mdot
.16513 .2148 Mdot
.16518 .21519 Mdot
.16522 .21558 Mdot
.16527 .21597 Mdot
.16532 .21635 Mdot
.16537 .21674 Mdot
.16541 .21713 Mdot
.16546 .21751 Mdot
.16551 .2179 Mdot
.16556 .21829 Mdot
.1656 .21868 Mdot
.16565 .21907 Mdot
.1657 .21947 Mdot
.16575 .21986 Mdot
.1658 .22025 Mdot
.16584 .22064 Mdot
.16589 .22103 Mdot
.16594 .22143 Mdot
.16599 .22182 Mdot
.16603 .22221 Mdot
.16608 .22261 Mdot
.16613 .223 Mdot
.16618 .2234 Mdot
.16622 .2238 Mdot
.16627 .2242 Mdot
.16632 .22459 Mdot
.16637 .22499 Mdot
.16641 .22539 Mdot
.16646 .22579 Mdot
.16651 .22618 Mdot
.16656 .22658 Mdot
.1666 .22697 Mdot
.16665 .22737 Mdot
.1667 .22776 Mdot
.16675 .22815 Mdot
.1668 .22854 Mdot
.16684 .22893 Mdot
.16689 .22931 Mdot
.16694 .2297 Mdot
.16699 .23009 Mdot
.16703 .23049 Mdot
.16708 .23088 Mdot
.16713 .23127 Mdot
.16718 .23165 Mdot
.16722 .23204 Mdot
.16727 .23243 Mdot
.16732 .23283 Mdot
.16737 .23322 Mdot
.16741 .23361 Mdot
.16746 .23401 Mdot
.16751 .2344 Mdot
.16756 .23479 Mdot
.1676 .23519 Mdot
.16765 .23558 Mdot
.1677 .23598 Mdot
.16775 .23638 Mdot
.1678 .23677 Mdot
.16784 .23717 Mdot
.16789 .23756 Mdot
.16794 .23796 Mdot
.16799 .23835 Mdot
.16803 .23875 Mdot
.16808 .23914 Mdot
.16813 .23954 Mdot
.16818 .23993 Mdot
.16822 .24032 Mdot
.16827 .24072 Mdot
.16832 .24111 Mdot
.16837 .2415 Mdot
.16841 .2419 Mdot
.16846 .2423 Mdot
.16851 .24269 Mdot
.16856 .24308 Mdot
.1686 .24348 Mdot
.16865 .24387 Mdot
.1687 .24426 Mdot
.16875 .24465 Mdot
.1688 .24505 Mdot
.16884 .24544 Mdot
.16889 .24584 Mdot
.16894 .24623 Mdot
.16899 .24662 Mdot
.16903 .24701 Mdot
.16908 .24741 Mdot
.16913 .2478 Mdot
.16918 .24819 Mdot
.16922 .24858 Mdot
.16927 .24897 Mdot
.16932 .24936 Mdot
.16937 .24975 Mdot
.16941 .25014 Mdot
.16946 .25053 Mdot
.16951 .25092 Mdot
.16956 .25131 Mdot
.1696 .2517 Mdot
.16965 .25209 Mdot
.1697 .25248 Mdot
.16975 .25287 Mdot
.16979 .25325 Mdot
.16984 .25364 Mdot
.16989 .25402 Mdot
.16994 .2544 Mdot
.16999 .25478 Mdot
.17003 .25516 Mdot
.17008 .25554 Mdot
.17013 .25592 Mdot
.17018 .25631 Mdot
.17022 .25669 Mdot
.17027 .25707 Mdot
.17032 .25745 Mdot
.17037 .25783 Mdot
.17041 .25821 Mdot
.17046 .25859 Mdot
.17051 .25897 Mdot
.17056 .25935 Mdot
.1706 .25973 Mdot
.17065 .26012 Mdot
.1707 .2605 Mdot
.17075 .26089 Mdot
.17079 .26128 Mdot
.17084 .26166 Mdot
.17089 .26205 Mdot
.17094 .26244 Mdot
.17099 .26282 Mdot
.17103 .26321 Mdot
.17108 .2636 Mdot
.17113 .26398 Mdot
.17118 .26437 Mdot
.17122 .26476 Mdot
.17127 .26515 Mdot
.17132 .26555 Mdot
.17137 .26594 Mdot
.17141 .26634 Mdot
.17146 .26673 Mdot
.17151 .26713 Mdot
.17156 .26753 Mdot
.1716 .26793 Mdot
.17165 .26833 Mdot
.1717 .26873 Mdot
.17175 .26913 Mdot
.17179 .26954 Mdot
.17184 .26994 Mdot
.17189 .27035 Mdot
.17194 .27075 Mdot
.17199 .27116 Mdot
.17203 .27157 Mdot
.17208 .27198 Mdot
.17213 .27238 Mdot
.17218 .2728 Mdot
.17222 .27321 Mdot
.17227 .27361 Mdot
.17232 .27402 Mdot
.17237 .27443 Mdot
.17241 .27484 Mdot
.17246 .27524 Mdot
.17251 .27565 Mdot
.17256 .27606 Mdot
.1726 .27647 Mdot
.17265 .27688 Mdot
.1727 .27729 Mdot
.17275 .27769 Mdot
.17279 .27811 Mdot
.17284 .27852 Mdot
.17289 .27893 Mdot
.17294 .27935 Mdot
.17299 .27976 Mdot
.17303 .28017 Mdot
.17308 .28058 Mdot
.17313 .281 Mdot
.17318 .28141 Mdot
.17322 .28182 Mdot
.17327 .28223 Mdot
.17332 .28265 Mdot
.17337 .28306 Mdot
.17341 .28347 Mdot
.17346 .28388 Mdot
.17351 .28429 Mdot
.17356 .28471 Mdot
.1736 .28512 Mdot
.17365 .28553 Mdot
.1737 .28595 Mdot
.17375 .28637 Mdot
.17379 .28679 Mdot
.17384 .28721 Mdot
.17389 .28763 Mdot
.17394 .28804 Mdot
.17398 .28846 Mdot
.17403 .28888 Mdot
.17408 .28931 Mdot
.17413 .28973 Mdot
.17418 .29016 Mdot
.17422 .29059 Mdot
.17427 .29101 Mdot
.17432 .29144 Mdot
.17437 .29187 Mdot
.17441 .2923 Mdot
.17446 .29272 Mdot
.17451 .29315 Mdot
.17456 .29357 Mdot
.1746 .294 Mdot
.17465 .29442 Mdot
.1747 .29485 Mdot
.17475 .29528 Mdot
.17479 .2957 Mdot
.17484 .29613 Mdot
.17489 .29656 Mdot
.17494 .29699 Mdot
.17498 .29743 Mdot
.17503 .29786 Mdot
.17508 .2983 Mdot
.17513 .29874 Mdot
.17518 .29917 Mdot
.17522 .29961 Mdot
.17527 .30005 Mdot
.17532 .30049 Mdot
.17537 .30093 Mdot
.17541 .30137 Mdot
.17546 .3018 Mdot
.17551 .30224 Mdot
.17556 .30267 Mdot
.1756 .30311 Mdot
.17565 .30354 Mdot
.1757 .30398 Mdot
.17575 .30441 Mdot
.17579 .30485 Mdot
.17584 .30528 Mdot
.17589 .30572 Mdot
.17594 .30616 Mdot
.17598 .30659 Mdot
.17603 .30703 Mdot
.17608 .30746 Mdot
.17613 .30789 Mdot
.17618 .30832 Mdot
.17622 .30876 Mdot
.17627 .30919 Mdot
.17632 .30963 Mdot
.17637 .31006 Mdot
.17641 .31049 Mdot
.17646 .31093 Mdot
.17651 .31136 Mdot
.17656 .3118 Mdot
.1766 .31224 Mdot
.17665 .31267 Mdot
.1767 .31311 Mdot
.17675 .31354 Mdot
.17679 .31398 Mdot
.17684 .31442 Mdot
.17689 .31486 Mdot
.17694 .31529 Mdot
.17698 .31573 Mdot
.17703 .31617 Mdot
.17708 .31661 Mdot
.17713 .31704 Mdot
.17718 .31748 Mdot
.17722 .31792 Mdot
.17727 .31835 Mdot
.17732 .31879 Mdot
.17737 .31923 Mdot
.17741 .31966 Mdot
.17746 .3201 Mdot
.17751 .32053 Mdot
.17756 .32097 Mdot
.1776 .32141 Mdot
.17765 .32185 Mdot
.1777 .32229 Mdot
.17775 .32273 Mdot
.17779 .32317 Mdot
.17784 .32361 Mdot
.17789 .32405 Mdot
.17794 .32449 Mdot
.17798 .32493 Mdot
.17803 .32538 Mdot
.17808 .32582 Mdot
.17813 .32626 Mdot
.17818 .32669 Mdot
.17822 .32713 Mdot
.17827 .32757 Mdot
.17832 .328 Mdot
.17837 .32843 Mdot
.17841 .32887 Mdot
.17846 .32931 Mdot
.17851 .32974 Mdot
.17856 .33017 Mdot
.1786 .3306 Mdot
.17865 .33103 Mdot
.1787 .33146 Mdot
.17875 .33189 Mdot
.17879 .33233 Mdot
.17884 .33275 Mdot
.17889 .33318 Mdot
.17894 .33361 Mdot
.17898 .33404 Mdot
.17903 .33446 Mdot
.17908 .3349 Mdot
.17913 .33532 Mdot
.17917 .33575 Mdot
.17922 .33619 Mdot
.17927 .33662 Mdot
.17932 .33704 Mdot
.17937 .33747 Mdot
.17941 .3379 Mdot
.17946 .33833 Mdot
.17951 .33876 Mdot
.17956 .33919 Mdot
.1796 .33963 Mdot
.17965 .34007 Mdot
.1797 .3405 Mdot
.17975 .34094 Mdot
.17979 .34137 Mdot
.17984 .34181 Mdot
.17989 .34224 Mdot
.17994 .34268 Mdot
.17998 .34312 Mdot
.18003 .34355 Mdot
.18008 .34399 Mdot
.18013 .34443 Mdot
.18017 .34486 Mdot
.18022 .3453 Mdot
.18027 .34573 Mdot
.18032 .34616 Mdot
.18037 .3466 Mdot
.18041 .34703 Mdot
.18046 .34746 Mdot
.18051 .34789 Mdot
.18056 .34832 Mdot
.1806 .34874 Mdot
.18065 .34917 Mdot
.1807 .3496 Mdot
.18075 .35003 Mdot
.18079 .35046 Mdot
.18084 .35089 Mdot
.18089 .35132 Mdot
.18094 .35174 Mdot
.18098 .35216 Mdot
.18103 .35258 Mdot
.18108 .35301 Mdot
.18113 .35343 Mdot
.18117 .35385 Mdot
.18122 .35428 Mdot
.18127 .3547 Mdot
.18132 .35512 Mdot
.18137 .35554 Mdot
.18141 .35597 Mdot
.18146 .35639 Mdot
.18151 .35681 Mdot
.18156 .35724 Mdot
.1816 .35767 Mdot
.18165 .35809 Mdot
.1817 .35851 Mdot
.18175 .35894 Mdot
.18179 .35936 Mdot
.18184 .35979 Mdot
.18189 .36021 Mdot
.18194 .36064 Mdot
.18198 .36106 Mdot
.18203 .36149 Mdot
.18208 .36191 Mdot
.18213 .36233 Mdot
.18217 .36275 Mdot
.18222 .36317 Mdot
.18227 .36359 Mdot
.18232 .36401 Mdot
.18237 .36443 Mdot
.18241 .36485 Mdot
.18246 .36528 Mdot
.18251 .3657 Mdot
.18256 .36613 Mdot
.1826 .36656 Mdot
.18265 .36699 Mdot
.1827 .36742 Mdot
.18275 .36785 Mdot
.18279 .36828 Mdot
.18284 .36872 Mdot
.18289 .36915 Mdot
.18294 .36959 Mdot
.18298 .37003 Mdot
.18303 .37046 Mdot
.18308 .3709 Mdot
.18313 .37134 Mdot
.18317 .37178 Mdot
.18322 .37221 Mdot
.18327 .37264 Mdot
.18332 .37307 Mdot
.18336 .3735 Mdot
.18341 .37393 Mdot
.18346 .37435 Mdot
.18351 .37478 Mdot
.18356 .3752 Mdot
.1836 .37563 Mdot
.18365 .37605 Mdot
.1837 .37648 Mdot
.18375 .37691 Mdot
.18379 .37734 Mdot
.18384 .37777 Mdot
.18389 .37819 Mdot
.18394 .37862 Mdot
.18398 .37905 Mdot
.18403 .37948 Mdot
.18408 .37991 Mdot
.18413 .38034 Mdot
.18417 .38076 Mdot
.18422 .38119 Mdot
.18427 .38162 Mdot
.18432 .38205 Mdot
.18436 .38247 Mdot
.18441 .38289 Mdot
.18446 .38332 Mdot
.18451 .38374 Mdot
.18456 .38417 Mdot
.1846 .3846 Mdot
.18465 .38502 Mdot
.1847 .38545 Mdot
.18475 .38587 Mdot
.18479 .38629 Mdot
.18484 .38671 Mdot
.18489 .38714 Mdot
.18494 .38756 Mdot
.18498 .38798 Mdot
.18503 .38841 Mdot
.18508 .38883 Mdot
.18513 .38925 Mdot
.18517 .38968 Mdot
.18522 .3901 Mdot
.18527 .39053 Mdot
.18532 .39095 Mdot
.18536 .39138 Mdot
.18541 .3918 Mdot
.18546 .39223 Mdot
.18551 .39265 Mdot
.18556 .39308 Mdot
.1856 .3935 Mdot
.18565 .39392 Mdot
.1857 .39434 Mdot
.18575 .39476 Mdot
.18579 .39518 Mdot
.18584 .3956 Mdot
.18589 .39601 Mdot
.18594 .39643 Mdot
.18598 .39684 Mdot
.18603 .39726 Mdot
.18608 .39767 Mdot
.18613 .39809 Mdot
.18617 .3985 Mdot
.18622 .39892 Mdot
.18627 .39934 Mdot
.18632 .39976 Mdot
.18636 .40018 Mdot
.18641 .4006 Mdot
.18646 .40102 Mdot
.18651 .40144 Mdot
.18656 .40185 Mdot
.1866 .40227 Mdot
.18665 .40268 Mdot
.1867 .40309 Mdot
.18675 .40351 Mdot
.18679 .40392 Mdot
.18684 .40433 Mdot
.18689 .40474 Mdot
.18694 .40515 Mdot
.18698 .40556 Mdot
.18703 .40598 Mdot
.18708 .40639 Mdot
.18713 .4068 Mdot
.18717 .40721 Mdot
.18722 .40762 Mdot
.18727 .40803 Mdot
.18732 .40844 Mdot
.18736 .40885 Mdot
.18741 .40925 Mdot
.18746 .40966 Mdot
.18751 .41006 Mdot
.18756 .41046 Mdot
.1876 .41086 Mdot
.18765 .41126 Mdot
.1877 .41166 Mdot
.18775 .41206 Mdot
.18779 .41246 Mdot
.18784 .41287 Mdot
.18789 .41327 Mdot
.18794 .41368 Mdot
.18798 .41408 Mdot
.18803 .41449 Mdot
.18808 .41489 Mdot
.18813 .41529 Mdot
.18817 .41569 Mdot
.18822 .41608 Mdot
.18827 .41648 Mdot
.18832 .41687 Mdot
.18836 .41726 Mdot
.18841 .41765 Mdot
.18846 .41804 Mdot
.18851 .41843 Mdot
.18855 .41882 Mdot
.1886 .41922 Mdot
.18865 .41961 Mdot
.1887 .42001 Mdot
.18875 .4204 Mdot
.18879 .42079 Mdot
.18884 .42117 Mdot
.18889 .42156 Mdot
.18894 .42195 Mdot
.18898 .42233 Mdot
.18903 .42272 Mdot
.18908 .4231 Mdot
.18913 .42348 Mdot
.18917 .42386 Mdot
.18922 .42424 Mdot
.18927 .42463 Mdot
.18932 .42501 Mdot
.18936 .42539 Mdot
.18941 .42577 Mdot
.18946 .42616 Mdot
.18951 .42654 Mdot
.18955 .42692 Mdot
.1896 .4273 Mdot
.18965 .42768 Mdot
.1897 .42806 Mdot
.18975 .42844 Mdot
.18979 .42882 Mdot
.18984 .4292 Mdot
.18989 .42958 Mdot
.18994 .42995 Mdot
.18998 .43032 Mdot
.19003 .4307 Mdot
.19008 .43107 Mdot
.19013 .43143 Mdot
.19017 .4318 Mdot
.19022 .43217 Mdot
.19027 .43253 Mdot
.19032 .43289 Mdot
.19036 .43325 Mdot
.19041 .43361 Mdot
.19046 .43397 Mdot
.19051 .43433 Mdot
.19055 .43469 Mdot
.1906 .43505 Mdot
.19065 .43541 Mdot
.1907 .43577 Mdot
.19075 .43613 Mdot
.19079 .43649 Mdot
.19084 .43685 Mdot
.19089 .4372 Mdot
.19094 .43756 Mdot
.19098 .43792 Mdot
.19103 .43828 Mdot
.19108 .43863 Mdot
.19113 .43898 Mdot
.19117 .43933 Mdot
.19122 .43968 Mdot
.19127 .44003 Mdot
.19132 .44037 Mdot
.19136 .44072 Mdot
.19141 .44107 Mdot
.19146 .44141 Mdot
.19151 .44176 Mdot
.19155 .4421 Mdot
.1916 .44245 Mdot
.19165 .44279 Mdot
.1917 .44312 Mdot
.19175 .44346 Mdot
.19179 .4438 Mdot
.19184 .44413 Mdot
.19189 .44447 Mdot
.19194 .44481 Mdot
.19198 .44515 Mdot
.19203 .44549 Mdot
.19208 .44583 Mdot
.19213 .44617 Mdot
.19217 .44651 Mdot
.19222 .44685 Mdot
.19227 .44719 Mdot
.19232 .44753 Mdot
.19236 .44786 Mdot
.19241 .4482 Mdot
.19246 .44853 Mdot
.19251 .44887 Mdot
.19255 .44921 Mdot
.1926 .44955 Mdot
.19265 .44988 Mdot
.1927 .45022 Mdot
.19275 .45056 Mdot
.19279 .45089 Mdot
.19284 .45123 Mdot
.19289 .45156 Mdot
.19294 .45189 Mdot
.19298 .45223 Mdot
.19303 .45257 Mdot
.19308 .4529 Mdot
.19313 .45324 Mdot
.19317 .45358 Mdot
.19322 .45392 Mdot
.19327 .45426 Mdot
.19332 .45459 Mdot
.19336 .45493 Mdot
.19341 .45526 Mdot
.19346 .45559 Mdot
.19351 .45592 Mdot
.19355 .45624 Mdot
.1936 .45657 Mdot
.19365 .45689 Mdot
.1937 .45722 Mdot
.19374 .45754 Mdot
.19379 .45787 Mdot
.19384 .45819 Mdot
.19389 .45852 Mdot
.19394 .45884 Mdot
.19398 .45916 Mdot
.19403 .45949 Mdot
.19408 .45981 Mdot
.19413 .46013 Mdot
.19417 .46046 Mdot
.19422 .46078 Mdot
.19427 .4611 Mdot
.19432 .46142 Mdot
.19436 .46174 Mdot
.19441 .46206 Mdot
.19446 .46238 Mdot
.19451 .46271 Mdot
.19455 .46304 Mdot
.1946 .46336 Mdot
.19465 .46369 Mdot
.1947 .46401 Mdot
.19474 .46433 Mdot
.19479 .46466 Mdot
.19484 .46498 Mdot
.19489 .4653 Mdot
.19494 .46562 Mdot
.19498 .46594 Mdot
.19503 .46625 Mdot
.19508 .46657 Mdot
.19513 .46689 Mdot
.19517 .4672 Mdot
.19522 .46752 Mdot
.19527 .46783 Mdot
.19532 .46814 Mdot
.19536 .46846 Mdot
.19541 .46878 Mdot
.19546 .46909 Mdot
.19551 .46941 Mdot
.19555 .46972 Mdot
.1956 .47003 Mdot
.19565 .47034 Mdot
.1957 .47065 Mdot
.19574 .47095 Mdot
.19579 .47126 Mdot
.19584 .47156 Mdot
.19589 .47185 Mdot
.19594 .47216 Mdot
.19598 .47246 Mdot
.19603 .47276 Mdot
.19608 .47307 Mdot
.19613 .47337 Mdot
.19617 .47368 Mdot
.19622 .47398 Mdot
.19627 .47428 Mdot
.19632 .47458 Mdot
.19636 .47488 Mdot
.19641 .47518 Mdot
.19646 .47549 Mdot
.19651 .47579 Mdot
.19655 .4761 Mdot
.1966 .4764 Mdot
.19665 .4767 Mdot
.1967 .47701 Mdot
.19674 .47731 Mdot
.19679 .47761 Mdot
.19684 .47791 Mdot
.19689 .47821 Mdot
.19694 .47851 Mdot
.19698 .47881 Mdot
.19703 .4791 Mdot
.19708 .4794 Mdot
.19713 .47969 Mdot
.19717 .47999 Mdot
.19722 .48028 Mdot
.19727 .48057 Mdot
.19732 .48087 Mdot
.19736 .48116 Mdot
.19741 .48145 Mdot
.19746 .48174 Mdot
.19751 .48203 Mdot
.19755 .48232 Mdot
.1976 .48261 Mdot
.19765 .4829 Mdot
.1977 .48319 Mdot
.19774 .48348 Mdot
.19779 .48377 Mdot
.19784 .48406 Mdot
.19789 .48435 Mdot
.19793 .48464 Mdot
.19798 .48493 Mdot
.19803 .48522 Mdot
.19808 .48552 Mdot
.19813 .48581 Mdot
.19817 .48611 Mdot
.19822 .4864 Mdot
.19827 .48669 Mdot
.19832 .48698 Mdot
.19836 .48728 Mdot
.19841 .48757 Mdot
.19846 .48786 Mdot
.19851 .48816 Mdot
.19855 .48845 Mdot
.1986 .48874 Mdot
.19865 .48904 Mdot
.1987 .48933 Mdot
.19874 .48963 Mdot
.19879 .48992 Mdot
.19884 .49022 Mdot
.19889 .49052 Mdot
.19893 .49082 Mdot
.19898 .49112 Mdot
.19903 .49141 Mdot
.19908 .49171 Mdot
.19913 .492 Mdot
.19917 .4923 Mdot
.19922 .49259 Mdot
.19927 .49288 Mdot
.19932 .49317 Mdot
.19936 .49346 Mdot
.19941 .49375 Mdot
.19946 .49404 Mdot
.19951 .49433 Mdot
.19955 .49462 Mdot
.1996 .49491 Mdot
.19965 .49519 Mdot
.1997 .49548 Mdot
.19974 .49577 Mdot
.19979 .49605 Mdot
.19984 .49634 Mdot
.19989 .49663 Mdot
.19993 .49692 Mdot
.19998 .49721 Mdot
.20003 .4975 Mdot
.20008 .49778 Mdot
.20013 .49807 Mdot
.20017 .49835 Mdot
.20022 .49863 Mdot
.20027 .49891 Mdot
.20032 .49919 Mdot
.20036 .49947 Mdot
.20041 .49976 Mdot
.20046 .50004 Mdot
.20051 .50032 Mdot
.20055 .5006 Mdot
.2006 .50088 Mdot
.20065 .50116 Mdot
.2007 .50145 Mdot
.20074 .50173 Mdot
.20079 .50201 Mdot
.20084 .50229 Mdot
.20089 .50256 Mdot
.20093 .50284 Mdot
.20098 .50312 Mdot
.20103 .5034 Mdot
.20108 .50368 Mdot
.20113 .50396 Mdot
.20117 .50424 Mdot
.20122 .50452 Mdot
.20127 .50481 Mdot
.20132 .50509 Mdot
.20136 .50538 Mdot
.20141 .50566 Mdot
.20146 .50594 Mdot
.20151 .50622 Mdot
.20155 .5065 Mdot
.2016 .50678 Mdot
.20165 .50706 Mdot
.2017 .50734 Mdot
.20174 .50762 Mdot
.20179 .5079 Mdot
.20184 .50818 Mdot
.20189 .50846 Mdot
.20193 .50873 Mdot
.20198 .50901 Mdot
.20203 .50928 Mdot
.20208 .50956 Mdot
.20213 .50983 Mdot
.20217 .5101 Mdot
.20222 .51037 Mdot
.20227 .51065 Mdot
.20232 .51091 Mdot
.20236 .51118 Mdot
.20241 .51145 Mdot
.20246 .51171 Mdot
.20251 .51197 Mdot
.20255 .51224 Mdot
.2026 .5125 Mdot
.20265 .51276 Mdot
.2027 .51303 Mdot
.20274 .51329 Mdot
.20279 .51355 Mdot
.20284 .51381 Mdot
.20289 .51407 Mdot
.20293 .51433 Mdot
.20298 .51459 Mdot
.20303 .51485 Mdot
.20308 .51511 Mdot
.20312 .51537 Mdot
.20317 .51563 Mdot
.20322 .5159 Mdot
.20327 .51615 Mdot
.20332 .51641 Mdot
.20336 .51667 Mdot
.20341 .51693 Mdot
.20346 .51719 Mdot
.20351 .51744 Mdot
.20355 .51769 Mdot
.2036 .51795 Mdot
.20365 .51819 Mdot
.2037 .51844 Mdot
.20374 .5187 Mdot
.20379 .51895 Mdot
.20384 .5192 Mdot
.20389 .51946 Mdot
.20393 .51971 Mdot
.20398 .51997 Mdot
.20403 .52022 Mdot
.20408 .52048 Mdot
.20412 .52074 Mdot
.20417 .521 Mdot
.20422 .52126 Mdot
.20427 .52151 Mdot
.20432 .52177 Mdot
.20436 .52203 Mdot
.20441 .52228 Mdot
.20446 .52254 Mdot
.20451 .5228 Mdot
.20455 .52305 Mdot
.2046 .52331 Mdot
.20465 .52356 Mdot
.2047 .52381 Mdot
.20474 .52406 Mdot
.20479 .52432 Mdot
.20484 .52457 Mdot
.20489 .52482 Mdot
.20493 .52507 Mdot
.20498 .52532 Mdot
.20503 .52557 Mdot
.20508 .52582 Mdot
.20512 .52606 Mdot
.20517 .5263 Mdot
.20522 .52655 Mdot
.20527 .52679 Mdot
.20532 .52704 Mdot
.20536 .52728 Mdot
.20541 .52751 Mdot
.20546 .52775 Mdot
.20551 .528 Mdot
.20555 .52824 Mdot
.2056 .52848 Mdot
.20565 .52872 Mdot
.2057 .52896 Mdot
.20574 .5292 Mdot
.20579 .52943 Mdot
.20584 .52967 Mdot
.20589 .5299 Mdot
.20593 .53014 Mdot
.20598 .53037 Mdot
.20603 .5306 Mdot
.20608 .53083 Mdot
.20612 .53106 Mdot
.20617 .53129 Mdot
.20622 .53152 Mdot
.20627 .53175 Mdot
.20632 .53198 Mdot
.20636 .5322 Mdot
.20641 .53243 Mdot
.20646 .53266 Mdot
.20651 .53289 Mdot
.20655 .53311 Mdot
.2066 .53334 Mdot
.20665 .53357 Mdot
.2067 .53379 Mdot
.20674 .53401 Mdot
.20679 .53424 Mdot
.20684 .53446 Mdot
.20689 .53469 Mdot
.20693 .53491 Mdot
.20698 .53513 Mdot
.20703 .53536 Mdot
.20708 .53558 Mdot
.20712 .5358 Mdot
.20717 .53602 Mdot
.20722 .53625 Mdot
.20727 .53647 Mdot
.20731 .53669 Mdot
.20736 .53691 Mdot
.20741 .53713 Mdot
.20746 .53734 Mdot
.20751 .53756 Mdot
.20755 .53778 Mdot
.2076 .538 Mdot
.20765 .53821 Mdot
.2077 .53842 Mdot
.20774 .53863 Mdot
.20779 .53884 Mdot
.20784 .53905 Mdot
.20789 .53925 Mdot
.20793 .53945 Mdot
.20798 .53966 Mdot
.20803 .53986 Mdot
.20808 .54006 Mdot
.20812 .54027 Mdot
.20817 .54047 Mdot
.20822 .54068 Mdot
.20827 .54088 Mdot
.20831 .54108 Mdot
.20836 .54129 Mdot
.20841 .54149 Mdot
.20846 .5417 Mdot
.20851 .5419 Mdot
.20855 .54211 Mdot
.2086 .54231 Mdot
.20865 .54252 Mdot
.2087 .54273 Mdot
.20874 .54293 Mdot
.20879 .54313 Mdot
.20884 .54334 Mdot
.20889 .54354 Mdot
.20893 .54374 Mdot
.20898 .54395 Mdot
.20903 .54414 Mdot
.20908 .54435 Mdot
.20912 .54455 Mdot
.20917 .54475 Mdot
.20922 .54495 Mdot
.20927 .54516 Mdot
.20931 .54536 Mdot
.20936 .54557 Mdot
.20941 .54577 Mdot
.20946 .54597 Mdot
.20951 .54616 Mdot
.20955 .54636 Mdot
.2096 .54657 Mdot
.20965 .54676 Mdot
.2097 .54697 Mdot
.20974 .54717 Mdot
.20979 .54736 Mdot
.20984 .54756 Mdot
.20989 .54776 Mdot
.20993 .54796 Mdot
.20998 .54816 Mdot
.21003 .54836 Mdot
.21008 .54855 Mdot
.21012 .54875 Mdot
.21017 .54895 Mdot
.21022 .54914 Mdot
.21027 .54933 Mdot
.21031 .54953 Mdot
.21036 .54972 Mdot
.21041 .5499 Mdot
.21046 .55009 Mdot
.21051 .55027 Mdot
.21055 .55045 Mdot
.2106 .55063 Mdot
.21065 .55081 Mdot
.2107 .55099 Mdot
.21074 .55117 Mdot
.21079 .55135 Mdot
.21084 .55153 Mdot
.21089 .55171 Mdot
.21093 .55189 Mdot
.21098 .55207 Mdot
.21103 .55225 Mdot
.21108 .55243 Mdot
.21112 .55262 Mdot
.21117 .5528 Mdot
.21122 .55298 Mdot
.21127 .55315 Mdot
.21131 .55333 Mdot
.21136 .55351 Mdot
.21141 .55369 Mdot
.21146 .55387 Mdot
.21151 .55405 Mdot
.21155 .55423 Mdot
.2116 .55441 Mdot
.21165 .55459 Mdot
.2117 .55476 Mdot
.21174 .55494 Mdot
.21179 .55511 Mdot
.21184 .55528 Mdot
.21189 .55545 Mdot
.21193 .55562 Mdot
.21198 .55579 Mdot
.21203 .55596 Mdot
.21208 .55613 Mdot
.21212 .5563 Mdot
.21217 .55647 Mdot
.21222 .55664 Mdot
.21227 .55681 Mdot
.21231 .55698 Mdot
.21236 .55715 Mdot
.21241 .55732 Mdot
.21246 .5575 Mdot
.2125 .55767 Mdot
.21255 .55784 Mdot
.2126 .55801 Mdot
.21265 .55818 Mdot
.2127 .55835 Mdot
.21274 .55852 Mdot
.21279 .55868 Mdot
.21284 .55885 Mdot
.21289 .55902 Mdot
.21293 .55918 Mdot
.21298 .55935 Mdot
.21303 .55952 Mdot
.21308 .55968 Mdot
.21312 .55985 Mdot
.21317 .56001 Mdot
.21322 .56018 Mdot
.21327 .56034 Mdot
.21331 .5605 Mdot
.21336 .56066 Mdot
.21341 .56082 Mdot
.21346 .56098 Mdot
.2135 .56114 Mdot
.21355 .56129 Mdot
.2136 .56145 Mdot
.21365 .56161 Mdot
.2137 .56176 Mdot
.21374 .56192 Mdot
.21379 .56208 Mdot
.21384 .56224 Mdot
.21389 .5624 Mdot
.21393 .56256 Mdot
.21398 .56271 Mdot
.21403 .56287 Mdot
.21408 .56302 Mdot
.21412 .56317 Mdot
.21417 .56332 Mdot
.21422 .56348 Mdot
.21427 .56362 Mdot
.21431 .56377 Mdot
.21436 .56391 Mdot
.21441 .56406 Mdot
.21446 .5642 Mdot
.2145 .56433 Mdot
.21455 .56447 Mdot
.2146 .56461 Mdot
.21465 .56475 Mdot
.2147 .56489 Mdot
.21474 .56503 Mdot
.21479 .56517 Mdot
.21484 .5653 Mdot
.21489 .56544 Mdot
.21493 .56557 Mdot
.21498 .56571 Mdot
.21503 .56585 Mdot
.21508 .56599 Mdot
.21512 .56613 Mdot
.21517 .56626 Mdot
.21522 .5664 Mdot
.21527 .56653 Mdot
.21531 .56667 Mdot
.21536 .56681 Mdot
.21541 .56694 Mdot
.21546 .56707 Mdot
.2155 .56721 Mdot
.21555 .56734 Mdot
.2156 .56748 Mdot
.21565 .56761 Mdot
.2157 .56775 Mdot
.21574 .56788 Mdot
.21579 .56801 Mdot
.21584 .56814 Mdot
.21589 .56827 Mdot
.21593 .56839 Mdot
.21598 .56852 Mdot
.21603 .56864 Mdot
.21608 .56876 Mdot
.21612 .56888 Mdot
.21617 .569 Mdot
.21622 .56913 Mdot
.21627 .56925 Mdot
.21631 .56937 Mdot
.21636 .56949 Mdot
.21641 .5696 Mdot
.21646 .56972 Mdot
.2165 .56983 Mdot
.21655 .56994 Mdot
.2166 .57006 Mdot
.21665 .57017 Mdot
.21669 .57028 Mdot
.21674 .57039 Mdot
.21679 .5705 Mdot
.21684 .5706 Mdot
.21689 .57071 Mdot
.21693 .57082 Mdot
.21698 .57093 Mdot
.21703 .57103 Mdot
.21708 .57114 Mdot
.21712 .57125 Mdot
.21717 .57136 Mdot
.21722 .57147 Mdot
.21727 .57157 Mdot
.21731 .57168 Mdot
.21736 .57178 Mdot
.21741 .57189 Mdot
.21746 .572 Mdot
.2175 .5721 Mdot
.21755 .57221 Mdot
.2176 .57231 Mdot
.21765 .57242 Mdot
.21769 .57252 Mdot
.21774 .57263 Mdot
.21779 .57273 Mdot
.21784 .57284 Mdot
.21789 .57294 Mdot
.21793 .57305 Mdot
.21798 .57316 Mdot
.21803 .57326 Mdot
.21808 .57337 Mdot
.21812 .57347 Mdot
.21817 .57358 Mdot
.21822 .57368 Mdot
.21827 .57378 Mdot
.21831 .57389 Mdot
.21836 .574 Mdot
.21841 .5741 Mdot
.21846 .5742 Mdot
.2185 .5743 Mdot
.21855 .57441 Mdot
.2186 .57451 Mdot
.21865 .57461 Mdot
.21869 .57472 Mdot
.21874 .57482 Mdot
.21879 .57492 Mdot
.21884 .57502 Mdot
.21889 .57511 Mdot
.21893 .57522 Mdot
.21898 .57532 Mdot
.21903 .57542 Mdot
.21908 .57552 Mdot
.21912 .57562 Mdot
.21917 .57572 Mdot
.21922 .57582 Mdot
.21927 .57592 Mdot
.21931 .57602 Mdot
.21936 .57612 Mdot
.21941 .57621 Mdot
.21946 .57631 Mdot
.2195 .5764 Mdot
.21955 .57649 Mdot
.2196 .57659 Mdot
.21965 .57668 Mdot
.21969 .57677 Mdot
.21974 .57686 Mdot
.21979 .57695 Mdot
.21984 .57705 Mdot
.21989 .57713 Mdot
.21993 .57722 Mdot
.21998 .57731 Mdot
.22003 .5774 Mdot
.22008 .57749 Mdot
.22012 .57757 Mdot
.22017 .57765 Mdot
.22022 .57773 Mdot
.22027 .5778 Mdot
.22031 .57788 Mdot
.22036 .57796 Mdot
.22041 .57804 Mdot
.22046 .57811 Mdot
.2205 .57819 Mdot
.22055 .57827 Mdot
.2206 .57834 Mdot
.22065 .57842 Mdot
.22069 .5785 Mdot
.22074 .57857 Mdot
.22079 .57865 Mdot
.22084 .57872 Mdot
.22089 .5788 Mdot
.22093 .57887 Mdot
.22098 .57894 Mdot
.22103 .57901 Mdot
.22108 .57908 Mdot
.22112 .57915 Mdot
.22117 .57921 Mdot
.22122 .57928 Mdot
.22127 .57934 Mdot
.22131 .5794 Mdot
.22136 .57946 Mdot
.22141 .57952 Mdot
.22146 .57958 Mdot
.2215 .57964 Mdot
.22155 .5797 Mdot
.2216 .57975 Mdot
.22165 .57981 Mdot
.22169 .57987 Mdot
.22174 .57993 Mdot
.22179 .57998 Mdot
.22184 .58004 Mdot
.22188 .58009 Mdot
.22193 .58015 Mdot
.22198 .58021 Mdot
.22203 .58027 Mdot
.22208 .58032 Mdot
.22212 .58038 Mdot
.22217 .58044 Mdot
.22222 .5805 Mdot
.22227 .58055 Mdot
.22231 .58061 Mdot
.22236 .58066 Mdot
.22241 .58071 Mdot
.22246 .58076 Mdot
.2225 .58082 Mdot
.22255 .58087 Mdot
.2226 .58093 Mdot
.22265 .58098 Mdot
.22269 .58103 Mdot
.22274 .58109 Mdot
.22279 .58114 Mdot
.22284 .58119 Mdot
.22288 .58125 Mdot
.22293 .5813 Mdot
.22298 .58135 Mdot
.22303 .5814 Mdot
.22308 .58146 Mdot
.22312 .58151 Mdot
.22317 .58155 Mdot
.22322 .5816 Mdot
.22327 .58165 Mdot
.22331 .5817 Mdot
.22336 .58176 Mdot
.22341 .58181 Mdot
.22346 .58186 Mdot
.2235 .58191 Mdot
.22355 .58196 Mdot
.2236 .58201 Mdot
.22365 .58205 Mdot
.22369 .5821 Mdot
.22374 .58216 Mdot
.22379 .58221 Mdot
.22384 .58226 Mdot
.22388 .58231 Mdot
.22393 .58236 Mdot
.22398 .58241 Mdot
.22403 .58246 Mdot
.22408 .58251 Mdot
.22412 .58256 Mdot
.22417 .5826 Mdot
.22422 .58265 Mdot
.22427 .5827 Mdot
.22431 .58275 Mdot
.22436 .5828 Mdot
.22441 .58285 Mdot
.22446 .58291 Mdot
.2245 .58296 Mdot
.22455 .58301 Mdot
.2246 .58306 Mdot
.22465 .58311 Mdot
.22469 .58316 Mdot
.22474 .5832 Mdot
.22479 .58325 Mdot
.22484 .5833 Mdot
.22488 .58335 Mdot
.22493 .58339 Mdot
.22498 .58344 Mdot
.22503 .58349 Mdot
.22508 .58353 Mdot
.22512 .58358 Mdot
.22517 .58363 Mdot
.22522 .58367 Mdot
.22527 .58372 Mdot
.22531 .58376 Mdot
.22536 .58381 Mdot
.22541 .58385 Mdot
.22546 .58389 Mdot
.2255 .58394 Mdot
.22555 .58398 Mdot
.2256 .58403 Mdot
.22565 .58407 Mdot
.22569 .58412 Mdot
.22574 .58416 Mdot
.22579 .58421 Mdot
.22584 .58425 Mdot
.22588 .58429 Mdot
.22593 .58433 Mdot
.22598 .58436 Mdot
.22603 .5844 Mdot
.22608 .58443 Mdot
.22612 .58447 Mdot
.22617 .5845 Mdot
.22622 .58453 Mdot
.22627 .58456 Mdot
.22631 .58459 Mdot
.22636 .58463 Mdot
.22641 .58466 Mdot
.22646 .58469 Mdot
.2265 .58472 Mdot
.22655 .58475 Mdot
.2266 .58478 Mdot
.22665 .58481 Mdot
.22669 .58483 Mdot
.22674 .58485 Mdot
.22679 .58487 Mdot
.22684 .58489 Mdot
.22688 .58491 Mdot
.22693 .58493 Mdot
.22698 .58495 Mdot
.22703 .58497 Mdot
.22707 .58498 Mdot
.22712 .58499 Mdot
.22717 .585 Mdot
.22722 .58501 Mdot
.22727 .58502 Mdot
.22731 .58503 Mdot
.22736 .58504 Mdot
.22741 .58505 Mdot
.22746 .58505 Mdot
.2275 .58506 Mdot
.22755 .58507 Mdot
.2276 .58508 Mdot
.22765 .58509 Mdot
.22769 .5851 Mdot
.22774 .58512 Mdot
.22779 .58513 Mdot
.22784 .58515 Mdot
.22788 .58516 Mdot
.22793 .58517 Mdot
.22798 .58519 Mdot
.22803 .5852 Mdot
.22807 .58521 Mdot
.22812 .58521 Mdot
.22817 .58522 Mdot
.22822 .58523 Mdot
.22827 .58524 Mdot
.22831 .58525 Mdot
.22836 .58525 Mdot
.22841 .58526 Mdot
.22846 .58527 Mdot
.2285 .58527 Mdot
.22855 .58528 Mdot
.2286 .58529 Mdot
.22865 .58529 Mdot
.22869 .58529 Mdot
.22874 .5853 Mdot
.22879 .5853 Mdot
.22884 .58531 Mdot
.22888 .58531 Mdot
.22893 .58531 Mdot
.22898 .58532 Mdot
.22903 .58532 Mdot
.22907 .58531 Mdot
.22912 .58531 Mdot
.22917 .58531 Mdot
.22922 .5853 Mdot
.22927 .58529 Mdot
.22931 .58528 Mdot
.22936 .58528 Mdot
.22941 .58526 Mdot
.22946 .58525 Mdot
.2295 .58524 Mdot
.22955 .58523 Mdot
.2296 .58521 Mdot
.22965 .5852 Mdot
.22969 .58519 Mdot
.22974 .58518 Mdot
.22979 .58517 Mdot
.22984 .58516 Mdot
.22988 .58515 Mdot
.22993 .58513 Mdot
.22998 .58512 Mdot
.23003 .5851 Mdot
.23007 .58508 Mdot
.23012 .58507 Mdot
.23017 .58505 Mdot
.23022 .58504 Mdot
.23027 .58503 Mdot
.23031 .58501 Mdot
.23036 .585 Mdot
.23041 .58498 Mdot
.23046 .58497 Mdot
.2305 .58495 Mdot
.23055 .58493 Mdot
.2306 .58492 Mdot
.23065 .5849 Mdot
.23069 .58489 Mdot
.23074 .58488 Mdot
.23079 .58486 Mdot
.23084 .58485 Mdot
.23088 .58484 Mdot
.23093 .58483 Mdot
.23098 .58482 Mdot
.23103 .58481 Mdot
.23107 .5848 Mdot
.23112 .58479 Mdot
.23117 .58478 Mdot
.23122 .58477 Mdot
.23126 .58476 Mdot
.23131 .58476 Mdot
.23136 .58475 Mdot
.23141 .58474 Mdot
.23146 .58473 Mdot
.2315 .58472 Mdot
.23155 .58471 Mdot
.2316 .5847 Mdot
.23165 .58468 Mdot
.23169 .58467 Mdot
.23174 .58465 Mdot
.23179 .58462 Mdot
.23184 .5846 Mdot
.23188 .58458 Mdot
.23193 .58456 Mdot
.23198 .58453 Mdot
.23203 .58451 Mdot
.23207 .58449 Mdot
.23212 .58447 Mdot
.23217 .58444 Mdot
.23222 .58442 Mdot
.23226 .58441 Mdot
.23231 .58439 Mdot
.23236 .58436 Mdot
.23241 .58434 Mdot
.23246 .58432 Mdot
.2325 .58429 Mdot
.23255 .58427 Mdot
.2326 .58424 Mdot
.23265 .58422 Mdot
.23269 .58419 Mdot
.23274 .58417 Mdot
.23279 .58414 Mdot
.23284 .5841 Mdot
.23288 .58407 Mdot
.23293 .58404 Mdot
.23298 .584 Mdot
.23303 .58397 Mdot
.23307 .58393 Mdot
.23312 .5839 Mdot
.23317 .58387 Mdot
.23322 .58384 Mdot
.23326 .58381 Mdot
.23331 .58378 Mdot
.23336 .58375 Mdot
.23341 .58372 Mdot
.23346 .58368 Mdot
.2335 .58364 Mdot
.23355 .5836 Mdot
.2336 .58357 Mdot
.23365 .58353 Mdot
.23369 .58349 Mdot
.23374 .58345 Mdot
.23379 .58341 Mdot
.23384 .58337 Mdot
.23388 .58333 Mdot
.23393 .5833 Mdot
.23398 .58326 Mdot
.23403 .58322 Mdot
.23407 .58318 Mdot
.23412 .58313 Mdot
.23417 .58309 Mdot
.23422 .58305 Mdot
.23426 .58301 Mdot
.23431 .58296 Mdot
.23436 .58292 Mdot
.23441 .58287 Mdot
.23446 .58283 Mdot
.2345 .58278 Mdot
.23455 .58273 Mdot
.2346 .58268 Mdot
.23465 .58264 Mdot
.23469 .58258 Mdot
.23474 .58254 Mdot
.23479 .58249 Mdot
.23484 .58244 Mdot
.23488 .58239 Mdot
.23493 .58233 Mdot
.23498 .58228 Mdot
.23503 .58222 Mdot
.23507 .58217 Mdot
.23512 .58211 Mdot
.23517 .58206 Mdot
.23522 .582 Mdot
.23526 .58194 Mdot
.23531 .58189 Mdot
.23536 .58184 Mdot
.23541 .58178 Mdot
.23546 .58173 Mdot
.2355 .58167 Mdot
.23555 .58161 Mdot
.2356 .58154 Mdot
.23565 .58148 Mdot
.23569 .58142 Mdot
.23574 .58135 Mdot
.23579 .58128 Mdot
.23584 .58122 Mdot
.23588 .58115 Mdot
.23593 .58108 Mdot
.23598 .58101 Mdot
.23603 .58093 Mdot
.23607 .58086 Mdot
.23612 .58078 Mdot
.23617 .5807 Mdot
.23622 .58062 Mdot
.23626 .58054 Mdot
.23631 .58045 Mdot
.23636 .58037 Mdot
.23641 .58028 Mdot
.23645 .5802 Mdot
.2365 .58011 Mdot
.23655 .58002 Mdot
.2366 .57993 Mdot
.23665 .57984 Mdot
.23669 .57975 Mdot
.23674 .57965 Mdot
.23679 .57956 Mdot
.23684 .57947 Mdot
.23688 .57937 Mdot
.23693 .57928 Mdot
.23698 .57918 Mdot
.23703 .57909 Mdot
.23707 .57899 Mdot
.23712 .5789 Mdot
.23717 .5788 Mdot
.23722 .57871 Mdot
.23726 .57861 Mdot
.23731 .57852 Mdot
.23736 .57842 Mdot
.23741 .57831 Mdot
.23745 .57821 Mdot
.2375 .5781 Mdot
.23755 .578 Mdot
.2376 .5779 Mdot
.23765 .5778 Mdot
.23769 .5777 Mdot
.23774 .5776 Mdot
.23779 .57749 Mdot
.23784 .57739 Mdot
.23788 .57728 Mdot
.23793 .57717 Mdot
.23798 .57706 Mdot
.23803 .57696 Mdot
.23807 .57685 Mdot
.23812 .57674 Mdot
.23817 .57662 Mdot
.23822 .5765 Mdot
.23826 .57638 Mdot
.23831 .57626 Mdot
.23836 .57614 Mdot
.23841 .57602 Mdot
.23845 .57589 Mdot
.2385 .57577 Mdot
.23855 .57564 Mdot
.2386 .57551 Mdot
.23865 .57538 Mdot
.23869 .57525 Mdot
.23874 .57512 Mdot
.23879 .57499 Mdot
.23884 .57486 Mdot
.23888 .57473 Mdot
.23893 .57459 Mdot
.23898 .57446 Mdot
.23903 .57432 Mdot
.23907 .57419 Mdot
.23912 .57405 Mdot
.23917 .57391 Mdot
.23922 .57378 Mdot
.23926 .57364 Mdot
.23931 .5735 Mdot
.23936 .57337 Mdot
.23941 .57323 Mdot
.23945 .57309 Mdot
.2395 .57295 Mdot
.23955 .57281 Mdot
.2396 .57267 Mdot
.23965 .57253 Mdot
.23969 .57239 Mdot
.23974 .57225 Mdot
.23979 .57211 Mdot
.23984 .57197 Mdot
.23988 .57183 Mdot
.23993 .57168 Mdot
.23998 .57154 Mdot
.24003 .5714 Mdot
.24007 .57125 Mdot
.24012 .57111 Mdot
.24017 .57096 Mdot
.24022 .57082 Mdot
.24026 .57067 Mdot
.24031 .57053 Mdot
.24036 .57038 Mdot
.24041 .57023 Mdot
.24045 .57009 Mdot
.2405 .56994 Mdot
.24055 .56979 Mdot
.2406 .56964 Mdot
.24064 .56949 Mdot
.24069 .56934 Mdot
.24074 .56919 Mdot
.24079 .56904 Mdot
.24084 .56888 Mdot
.24088 .56873 Mdot
.24093 .56857 Mdot
.24098 .56842 Mdot
.24103 .56826 Mdot
.24107 .5681 Mdot
.24112 .56794 Mdot
.24117 .56778 Mdot
.24122 .56762 Mdot
.24126 .56746 Mdot
.24131 .5673 Mdot
.24136 .56714 Mdot
.24141 .56698 Mdot
.24145 .56682 Mdot
.2415 .56666 Mdot
.24155 .5665 Mdot
.2416 .56634 Mdot
.24164 .56619 Mdot
.24169 .56602 Mdot
.24174 .56586 Mdot
.24179 .5657 Mdot
.24184 .56554 Mdot
.24188 .56537 Mdot
.24193 .56521 Mdot
.24198 .56505 Mdot
.24203 .56489 Mdot
.24207 .56473 Mdot
.24212 .56457 Mdot
.24217 .56441 Mdot
.24222 .56425 Mdot
.24226 .56409 Mdot
.24231 .56392 Mdot
.24236 .56376 Mdot
.24241 .5636 Mdot
.24245 .56344 Mdot
.2425 .56328 Mdot
.24255 .56312 Mdot
.2426 .56296 Mdot
.24264 .5628 Mdot
.24269 .56264 Mdot
.24274 .56248 Mdot
.24279 .56232 Mdot
.24284 .56216 Mdot
.24288 .562 Mdot
.24293 .56184 Mdot
.24298 .56167 Mdot
.24303 .56151 Mdot
.24307 .56134 Mdot
.24312 .56117 Mdot
.24317 .56101 Mdot
.24322 .56083 Mdot
.24326 .56066 Mdot
.24331 .56049 Mdot
.24336 .56031 Mdot
.24341 .56014 Mdot
.24345 .55997 Mdot
.2435 .55979 Mdot
.24355 .55961 Mdot
.2436 .55943 Mdot
.24364 .55925 Mdot
.24369 .55907 Mdot
.24374 .55889 Mdot
.24379 .5587 Mdot
.24384 .55852 Mdot
.24388 .55834 Mdot
.24393 .55816 Mdot
.24398 .55798 Mdot
.24403 .55779 Mdot
.24407 .55762 Mdot
.24412 .55744 Mdot
.24417 .55725 Mdot
.24422 .55707 Mdot
.24426 .55688 Mdot
.24431 .5567 Mdot
.24436 .55652 Mdot
.24441 .55633 Mdot
.24445 .55614 Mdot
.2445 .55595 Mdot
.24455 .55576 Mdot
.2446 .55556 Mdot
.24464 .55536 Mdot
.24469 .55517 Mdot
.24474 .55497 Mdot
.24479 .55477 Mdot
.24484 .55457 Mdot
.24488 .55437 Mdot
.24493 .55417 Mdot
.24498 .55397 Mdot
.24503 .55376 Mdot
.24507 .55355 Mdot
.24512 .55335 Mdot
.24517 .55314 Mdot
.24522 .55293 Mdot
.24526 .55272 Mdot
.24531 .5525 Mdot
.24536 .55229 Mdot
.24541 .55208 Mdot
.24545 .55186 Mdot
.2455 .55165 Mdot
.24555 .55144 Mdot
.2456 .55122 Mdot
.24564 .55101 Mdot
.24569 .55079 Mdot
.24574 .55057 Mdot
.24579 .55036 Mdot
.24583 .55014 Mdot
.24588 .54991 Mdot
.24593 .54969 Mdot
.24598 .54946 Mdot
.24603 .54923 Mdot
.24607 .549 Mdot
.24612 .54877 Mdot
.24617 .54853 Mdot
.24622 .5483 Mdot
.24626 .54806 Mdot
.24631 .54783 Mdot
.24636 .5476 Mdot
.24641 .54737 Mdot
.24645 .54714 Mdot
.2465 .54691 Mdot
.24655 .54668 Mdot
.2466 .54646 Mdot
.24664 .54623 Mdot
.24669 .54599 Mdot
.24674 .54576 Mdot
.24679 .54553 Mdot
.24683 .54529 Mdot
.24688 .54505 Mdot
.24693 .54481 Mdot
.24698 .54457 Mdot
.24703 .54433 Mdot
.24707 .5441 Mdot
.24712 .54387 Mdot
.24717 .54363 Mdot
.24722 .5434 Mdot
.24726 .54317 Mdot
.24731 .54293 Mdot
.24736 .54269 Mdot
.24741 .54246 Mdot
.24745 .54222 Mdot
.2475 .54198 Mdot
.24755 .54174 Mdot
.2476 .54149 Mdot
.24764 .54125 Mdot
.24769 .541 Mdot
.24774 .54075 Mdot
.24779 .5405 Mdot
.24783 .54025 Mdot
.24788 .54001 Mdot
.24793 .53976 Mdot
.24798 .53951 Mdot
.24803 .53927 Mdot
.24807 .53902 Mdot
.24812 .53878 Mdot
.24817 .53854 Mdot
.24822 .5383 Mdot
.24826 .53806 Mdot
.24831 .53781 Mdot
.24836 .53756 Mdot
.24841 .53732 Mdot
.24845 .53707 Mdot
.2485 .53682 Mdot
.24855 .53657 Mdot
.2486 .53633 Mdot
.24864 .53608 Mdot
.24869 .53583 Mdot
.24874 .53557 Mdot
.24879 .53532 Mdot
.24883 .53506 Mdot
.24888 .53481 Mdot
.24893 .53455 Mdot
.24898 .5343 Mdot
.24903 .53404 Mdot
.24907 .53378 Mdot
.24912 .53353 Mdot
.24917 .53327 Mdot
.24922 .53301 Mdot
.24926 .53275 Mdot
.24931 .53249 Mdot
.24936 .53223 Mdot
.24941 .53197 Mdot
.24945 .5317 Mdot
.2495 .53144 Mdot
.24955 .53118 Mdot
.2496 .53092 Mdot
.24964 .53066 Mdot
.24969 .53039 Mdot
.24974 .53013 Mdot
.24979 .52987 Mdot
.24983 .52961 Mdot
.24988 .52935 Mdot
.24993 .52909 Mdot
.24998 .52883 Mdot
.25002 .52857 Mdot
.25007 .52831 Mdot
.25012 .52806 Mdot
.25017 .5278 Mdot
.25022 .52755 Mdot
.25026 .52729 Mdot
.25031 .52703 Mdot
.25036 .52677 Mdot
.25041 .52651 Mdot
.25045 .52625 Mdot
.2505 .52599 Mdot
.25055 .52573 Mdot
.2506 .52547 Mdot
.25064 .52521 Mdot
.25069 .52495 Mdot
.25074 .52469 Mdot
.25079 .52443 Mdot
.25083 .52416 Mdot
.25088 .5239 Mdot
.25093 .52363 Mdot
.25098 .52337 Mdot
.25102 .52311 Mdot
.25107 .52285 Mdot
.25112 .52258 Mdot
.25117 .52231 Mdot
.25122 .52204 Mdot
.25126 .52176 Mdot
.25131 .52149 Mdot
.25136 .52121 Mdot
.25141 .52094 Mdot
.25145 .52067 Mdot
.2515 .5204 Mdot
.25155 .52012 Mdot
.2516 .51985 Mdot
.25164 .51957 Mdot
.25169 .5193 Mdot
.25174 .51902 Mdot
.25179 .51874 Mdot
.25183 .51845 Mdot
.25188 .51817 Mdot
.25193 .51789 Mdot
.25198 .51761 Mdot
.25202 .51733 Mdot
.25207 .51704 Mdot
.25212 .51676 Mdot
.25217 .51649 Mdot
.25222 .51621 Mdot
.25226 .51593 Mdot
.25231 .51565 Mdot
.25236 .51537 Mdot
.25241 .51509 Mdot
.25245 .51482 Mdot
.2525 .51454 Mdot
.25255 .51426 Mdot
.2526 .51399 Mdot
.25264 .51372 Mdot
.25269 .51344 Mdot
.25274 .51317 Mdot
.25279 .51289 Mdot
.25283 .51262 Mdot
.25288 .51234 Mdot
.25293 .51207 Mdot
.25298 .51179 Mdot
.25302 .51151 Mdot
.25307 .51123 Mdot
.25312 .51096 Mdot
.25317 .51068 Mdot
.25322 .5104 Mdot
.25326 .51012 Mdot
.25331 .50984 Mdot
.25336 .50956 Mdot
.25341 .50928 Mdot
.25345 .509 Mdot
.2535 .50872 Mdot
.25355 .50844 Mdot
.2536 .50816 Mdot
.25364 .50788 Mdot
.25369 .5076 Mdot
.25374 .50731 Mdot
.25379 .50703 Mdot
.25383 .50675 Mdot
.25388 .50647 Mdot
.25393 .50618 Mdot
.25398 .50589 Mdot
.25402 .5056 Mdot
.25407 .50531 Mdot
.25412 .50501 Mdot
.25417 .50471 Mdot
.25422 .50441 Mdot
.25426 .50411 Mdot
.25431 .50381 Mdot
.25436 .50351 Mdot
.25441 .50321 Mdot
.25445 .50291 Mdot
.2545 .50261 Mdot
.25455 .50231 Mdot
.2546 .502 Mdot
.25464 .5017 Mdot
.25469 .5014 Mdot
.25474 .50109 Mdot
.25479 .50079 Mdot
.25483 .50048 Mdot
.25488 .50017 Mdot
.25493 .49987 Mdot
.25498 .49956 Mdot
.25502 .49925 Mdot
.25507 .49895 Mdot
.25512 .49864 Mdot
.25517 .49833 Mdot
.25521 .49802 Mdot
.25526 .4977 Mdot
.25531 .49739 Mdot
.25536 .49707 Mdot
.25541 .49676 Mdot
.25545 .49644 Mdot
.2555 .49612 Mdot
.25555 .49581 Mdot
.2556 .4955 Mdot
.25564 .49518 Mdot
.25569 .49486 Mdot
.25574 .49454 Mdot
.25579 .49422 Mdot
.25583 .49389 Mdot
.25588 .49357 Mdot
.25593 .49325 Mdot
.25598 .49292 Mdot
.25602 .49259 Mdot
.25607 .49226 Mdot
.25612 .49194 Mdot
.25617 .49161 Mdot
.25621 .49128 Mdot
.25626 .49095 Mdot
.25631 .49061 Mdot
.25636 .49027 Mdot
.25641 .48994 Mdot
.25645 .4896 Mdot
.2565 .48926 Mdot
.25655 .48893 Mdot
.2566 .48859 Mdot
.25664 .48826 Mdot
.25669 .48793 Mdot
.25674 .48759 Mdot
.25679 .48725 Mdot
.25683 .48692 Mdot
.25688 .48658 Mdot
.25693 .48625 Mdot
.25698 .48592 Mdot
.25702 .48559 Mdot
.25707 .48526 Mdot
.25712 .48493 Mdot
.25717 .4846 Mdot
.25721 .48426 Mdot
.25726 .48393 Mdot
.25731 .4836 Mdot
.25736 .48326 Mdot
.25741 .48293 Mdot
.25745 .48259 Mdot
.2575 .48225 Mdot
.25755 .48192 Mdot
.2576 .48158 Mdot
.25764 .48124 Mdot
.25769 .4809 Mdot
.25774 .48056 Mdot
.25779 .48023 Mdot
.25783 .47989 Mdot
.25788 .47955 Mdot
.25793 .47921 Mdot
.25798 .47887 Mdot
.25802 .47853 Mdot
.25807 .47819 Mdot
.25812 .47785 Mdot
.25817 .47751 Mdot
.25821 .47718 Mdot
.25826 .47683 Mdot
.25831 .47649 Mdot
.25836 .47615 Mdot
.25841 .47581 Mdot
.25845 .47547 Mdot
.2585 .47513 Mdot
.25855 .47478 Mdot
.2586 .47444 Mdot
.25864 .4741 Mdot
.25869 .47376 Mdot
.25874 .47343 Mdot
.25879 .47309 Mdot
.25883 .47276 Mdot
.25888 .47242 Mdot
.25893 .47208 Mdot
.25898 .47174 Mdot
.25902 .4714 Mdot
.25907 .47105 Mdot
.25912 .47071 Mdot
.25917 .47036 Mdot
.25921 .47001 Mdot
.25926 .46967 Mdot
.25931 .46933 Mdot
.25936 .46898 Mdot
.25941 .46863 Mdot
.25945 .46828 Mdot
.2595 .46793 Mdot
.25955 .46758 Mdot
.2596 .46722 Mdot
.25964 .46687 Mdot
.25969 .46651 Mdot
.25974 .46616 Mdot
.25979 .4658 Mdot
.25983 .46545 Mdot
.25988 .46509 Mdot
.25993 .46473 Mdot
.25998 .46438 Mdot
.26002 .46402 Mdot
.26007 .46367 Mdot
.26012 .46331 Mdot
.26017 .46296 Mdot
.26021 .4626 Mdot
.26026 .46225 Mdot
.26031 .46189 Mdot
.26036 .46153 Mdot
.2604 .46117 Mdot
.26045 .46081 Mdot
.2605 .46046 Mdot
.26055 .4601 Mdot
.2606 .45973 Mdot
.26064 .45937 Mdot
.26069 .459 Mdot
.26074 .45864 Mdot
.26079 .45828 Mdot
.26083 .45792 Mdot
.26088 .45755 Mdot
.26093 .45718 Mdot
.26098 .45682 Mdot
.26102 .45645 Mdot
.26107 .45609 Mdot
.26112 .45572 Mdot
.26117 .45535 Mdot
.26121 .45499 Mdot
.26126 .45462 Mdot
.26131 .45425 Mdot
.26136 .45388 Mdot
.2614 .45351 Mdot
.26145 .45313 Mdot
.2615 .45276 Mdot
.26155 .45239 Mdot
.2616 .45201 Mdot
.26164 .45164 Mdot
.26169 .45127 Mdot
.26174 .4509 Mdot
.26179 .45053 Mdot
.26183 .45015 Mdot
.26188 .44978 Mdot
.26193 .4494 Mdot
.26198 .44902 Mdot
.26202 .44864 Mdot
.26207 .44826 Mdot
.26212 .44788 Mdot
.26217 .4475 Mdot
.26221 .44712 Mdot
.26226 .44674 Mdot
.26231 .44636 Mdot
.26236 .44598 Mdot
.2624 .44559 Mdot
.26245 .44521 Mdot
.2625 .44483 Mdot
.26255 .44445 Mdot
.2626 .44407 Mdot
.26264 .44369 Mdot
.26269 .44332 Mdot
.26274 .44294 Mdot
.26279 .44256 Mdot
.26283 .44218 Mdot
.26288 .44181 Mdot
.26293 .44143 Mdot
.26298 .44105 Mdot
.26302 .44067 Mdot
.26307 .44029 Mdot
.26312 .43991 Mdot
.26317 .43953 Mdot
.26321 .43915 Mdot
.26326 .43876 Mdot
.26331 .43838 Mdot
.26336 .438 Mdot
.2634 .43762 Mdot
.26345 .43724 Mdot
.2635 .43686 Mdot
.26355 .43648 Mdot
.2636 .4361 Mdot
.26364 .43571 Mdot
.26369 .43533 Mdot
.26374 .43494 Mdot
.26379 .43456 Mdot
.26383 .43418 Mdot
.26388 .4338 Mdot
.26393 .43342 Mdot
.26398 .43304 Mdot
.26402 .43266 Mdot
.26407 .43227 Mdot
.26412 .43189 Mdot
.26417 .4315 Mdot
.26421 .43112 Mdot
.26426 .43073 Mdot
.26431 .43035 Mdot
.26436 .42997 Mdot
.2644 .42958 Mdot
.26445 .4292 Mdot
.2645 .42882 Mdot
.26455 .42843 Mdot
.26459 .42805 Mdot
.26464 .42767 Mdot
.26469 .42728 Mdot
.26474 .42689 Mdot
.26479 .42651 Mdot
.26483 .42612 Mdot
.26488 .42574 Mdot
.26493 .42535 Mdot
.26498 .42496 Mdot
.26502 .42457 Mdot
.26507 .42418 Mdot
.26512 .42378 Mdot
.26517 .42339 Mdot
.26521 .42299 Mdot
.26526 .4226 Mdot
.26531 .4222 Mdot
.26536 .4218 Mdot
.2654 .42141 Mdot
.26545 .42101 Mdot
.2655 .42061 Mdot
.26555 .42021 Mdot
.26559 .41981 Mdot
.26564 .41941 Mdot
.26569 .41901 Mdot
.26574 .41861 Mdot
.26579 .41821 Mdot
.26583 .41781 Mdot
.26588 .41741 Mdot
.26593 .41701 Mdot
.26598 .41661 Mdot
.26602 .4162 Mdot
.26607 .4158 Mdot
.26612 .41539 Mdot
.26617 .41499 Mdot
.26621 .41458 Mdot
.26626 .41417 Mdot
.26631 .41376 Mdot
.26636 .41335 Mdot
.2664 .41294 Mdot
.26645 .41252 Mdot
.2665 .41211 Mdot
.26655 .4117 Mdot
.26659 .41128 Mdot
.26664 .41087 Mdot
.26669 .41047 Mdot
.26674 .41006 Mdot
.26679 .40965 Mdot
.26683 .40923 Mdot
.26688 .40882 Mdot
.26693 .40841 Mdot
.26698 .408 Mdot
.26702 .40759 Mdot
.26707 .40718 Mdot
.26712 .40677 Mdot
.26717 .40636 Mdot
.26721 .40595 Mdot
.26726 .40554 Mdot
.26731 .40513 Mdot
.26736 .40472 Mdot
.2674 .40431 Mdot
.26745 .40389 Mdot
.2675 .40348 Mdot
.26755 .40306 Mdot
.26759 .40264 Mdot
.26764 .40223 Mdot
.26769 .40181 Mdot
.26774 .40139 Mdot
.26779 .40097 Mdot
.26783 .40056 Mdot
.26788 .40014 Mdot
.26793 .39971 Mdot
.26798 .39929 Mdot
.26802 .39887 Mdot
.26807 .39845 Mdot
.26812 .39803 Mdot
.26817 .39761 Mdot
.26821 .39719 Mdot
.26826 .39677 Mdot
.26831 .39636 Mdot
.26836 .39594 Mdot
.2684 .39552 Mdot
.26845 .3951 Mdot
.2685 .39468 Mdot
.26855 .39426 Mdot
.26859 .39383 Mdot
.26864 .39341 Mdot
.26869 .39299 Mdot
.26874 .39257 Mdot
.26879 .39215 Mdot
.26883 .39173 Mdot
.26888 .39131 Mdot
.26893 .39088 Mdot
.26898 .39046 Mdot
.26902 .39003 Mdot
.26907 .38961 Mdot
.26912 .38918 Mdot
.26917 .38876 Mdot
.26921 .38833 Mdot
.26926 .3879 Mdot
.26931 .38748 Mdot
.26936 .38705 Mdot
.2694 .38662 Mdot
.26945 .3862 Mdot
.2695 .38577 Mdot
.26955 .38534 Mdot
.26959 .38491 Mdot
.26964 .38448 Mdot
.26969 .38405 Mdot
.26974 .38363 Mdot
.26978 .3832 Mdot
.26983 .38277 Mdot
.26988 .38234 Mdot
.26993 .38191 Mdot
.26998 .38148 Mdot
.27002 .38106 Mdot
.27007 .38063 Mdot
.27012 .38021 Mdot
.27017 .37978 Mdot
.27021 .37935 Mdot
.27026 .37892 Mdot
.27031 .37849 Mdot
.27036 .37805 Mdot
.2704 .37762 Mdot
.27045 .37719 Mdot
.2705 .37676 Mdot
.27055 .37633 Mdot
.27059 .3759 Mdot
.27064 .37546 Mdot
.27069 .37503 Mdot
.27074 .3746 Mdot
.27078 .37417 Mdot
.27083 .37373 Mdot
.27088 .3733 Mdot
.27093 .37287 Mdot
.27098 .37244 Mdot
.27102 .37201 Mdot
.27107 .37157 Mdot
.27112 .37114 Mdot
.27117 .3707 Mdot
.27121 .37027 Mdot
.27126 .36984 Mdot
.27131 .3694 Mdot
.27136 .36897 Mdot
.2714 .36853 Mdot
.27145 .36809 Mdot
.2715 .36765 Mdot
.27155 .36721 Mdot
.27159 .36677 Mdot
.27164 .36632 Mdot
.27169 .36588 Mdot
.27174 .36545 Mdot
.27178 .36501 Mdot
.27183 .36457 Mdot
.27188 .36413 Mdot
.27193 .36369 Mdot
.27198 .36325 Mdot
.27202 .36281 Mdot
.27207 .36237 Mdot
.27212 .36193 Mdot
.27217 .36148 Mdot
.27221 .36104 Mdot
.27226 .3606 Mdot
.27231 .36016 Mdot
.27236 .35972 Mdot
.2724 .35929 Mdot
.27245 .35885 Mdot
.2725 .35842 Mdot
.27255 .358 Mdot
.27259 .35757 Mdot
.27264 .35715 Mdot
.27269 .35672 Mdot
.27274 .35631 Mdot
.27278 .35588 Mdot
.27283 .35547 Mdot
.27288 .35505 Mdot
.27293 .35463 Mdot
.27298 .35421 Mdot
.27302 .35379 Mdot
.27307 .35337 Mdot
.27312 .35296 Mdot
.27317 .35254 Mdot
.27321 .35212 Mdot
.27326 .3517 Mdot
.27331 .35128 Mdot
.27336 .35086 Mdot
.2734 .35044 Mdot
.27345 .35001 Mdot
.2735 .34959 Mdot
.27355 .34917 Mdot
.27359 .34876 Mdot
.27364 .34834 Mdot
.27369 .34792 Mdot
.27374 .3475 Mdot
.27378 .34708 Mdot
.27383 .34667 Mdot
.27388 .34625 Mdot
.27393 .34583 Mdot
.27397 .34542 Mdot
.27402 .34501 Mdot
.27407 .34459 Mdot
.27412 .34418 Mdot
.27417 .34377 Mdot
.27421 .34335 Mdot
.27426 .34294 Mdot
.27431 .34252 Mdot
.27436 .3421 Mdot
.2744 .34169 Mdot
.27445 .34127 Mdot
.2745 .34085 Mdot
.27455 .34043 Mdot
.27459 .34001 Mdot
.27464 .33959 Mdot
.27469 .33917 Mdot
.27474 .33876 Mdot
.27478 .33835 Mdot
.27483 .33794 Mdot
.27488 .33753 Mdot
.27493 .33712 Mdot
.27497 .33671 Mdot
.27502 .3363 Mdot
.27507 .33589 Mdot
.27512 .33548 Mdot
.27517 .33507 Mdot
.27521 .33466 Mdot
.27526 .33425 Mdot
.27531 .33384 Mdot
.27536 .33343 Mdot
.2754 .33302 Mdot
.27545 .33261 Mdot
.2755 .3322 Mdot
.27555 .3318 Mdot
.27559 .33139 Mdot
.27564 .33098 Mdot
.27569 .33057 Mdot
.27574 .33016 Mdot
.27578 .32975 Mdot
.27583 .32934 Mdot
.27588 .32894 Mdot
.27593 .32854 Mdot
.27597 .32813 Mdot
.27602 .32773 Mdot
.27607 .32733 Mdot
.27612 .32693 Mdot
.27617 .32652 Mdot
.27621 .32612 Mdot
.27626 .32572 Mdot
.27631 .32531 Mdot
.27636 .32492 Mdot
.2764 .32452 Mdot
.27645 .32412 Mdot
.2765 .32372 Mdot
.27655 .32331 Mdot
.27659 .32291 Mdot
.27664 .3225 Mdot
.27669 .32209 Mdot
.27674 .32168 Mdot
.27678 .32127 Mdot
.27683 .32086 Mdot
.27688 .32046 Mdot
.27693 .32005 Mdot
.27697 .31964 Mdot
.27702 .31922 Mdot
.27707 .31881 Mdot
.27712 .3184 Mdot
.27717 .31799 Mdot
.27721 .31757 Mdot
.27726 .31716 Mdot
.27731 .31674 Mdot
.27736 .31633 Mdot
.2774 .31591 Mdot
.27745 .31549 Mdot
.2775 .31508 Mdot
.27755 .31466 Mdot
.27759 .31424 Mdot
.27764 .31382 Mdot
.27769 .3134 Mdot
.27774 .31298 Mdot
.27778 .31256 Mdot
.27783 .31214 Mdot
.27788 .31172 Mdot
.27793 .3113 Mdot
.27797 .31087 Mdot
.27802 .31045 Mdot
.27807 .31003 Mdot
.27812 .30961 Mdot
.27817 .30919 Mdot
.27821 .30877 Mdot
.27826 .30834 Mdot
.27831 .30793 Mdot
.27836 .30751 Mdot
.2784 .30709 Mdot
.27845 .30667 Mdot
.2785 .30625 Mdot
.27855 .30583 Mdot
.27859 .3054 Mdot
.27864 .30498 Mdot
.27869 .30456 Mdot
.27874 .30414 Mdot
.27878 .30372 Mdot
.27883 .30329 Mdot
.27888 .30287 Mdot
.27893 .30245 Mdot
.27897 .30203 Mdot
.27902 .30161 Mdot
.27907 .30119 Mdot
.27912 .30076 Mdot
.27916 .30034 Mdot
.27921 .29992 Mdot
.27926 .29949 Mdot
.27931 .29906 Mdot
.27936 .29863 Mdot
.2794 .2982 Mdot
.27945 .29777 Mdot
.2795 .29734 Mdot
.27955 .2969 Mdot
.27959 .29647 Mdot
.27964 .29603 Mdot
.27969 .2956 Mdot
.27974 .29517 Mdot
.27978 .29474 Mdot
.27983 .2943 Mdot
.27988 .29387 Mdot
.27993 .29344 Mdot
.27997 .29301 Mdot
.28002 .29258 Mdot
.28007 .29216 Mdot
.28012 .29174 Mdot
.28016 .29131 Mdot
.28021 .29089 Mdot
.28026 .29047 Mdot
.28031 .29005 Mdot
.28036 .28963 Mdot
.2804 .28922 Mdot
.28045 .2888 Mdot
.2805 .28839 Mdot
.28055 .28798 Mdot
.28059 .28756 Mdot
.28064 .28715 Mdot
.28069 .28674 Mdot
.28074 .28633 Mdot
.28078 .28592 Mdot
.28083 .28551 Mdot
.28088 .28511 Mdot
.28093 .2847 Mdot
.28097 .28429 Mdot
.28102 .28388 Mdot
.28107 .28348 Mdot
.28112 .28307 Mdot
.28116 .28267 Mdot
.28121 .28226 Mdot
.28126 .28186 Mdot
.28131 .28146 Mdot
.28136 .28106 Mdot
.2814 .28066 Mdot
.28145 .28026 Mdot
.2815 .27986 Mdot
.28155 .27946 Mdot
.28159 .27906 Mdot
.28164 .27866 Mdot
.28169 .27827 Mdot
.28174 .27787 Mdot
.28178 .27748 Mdot
.28183 .27708 Mdot
.28188 .27669 Mdot
.28193 .2763 Mdot
.28197 .2759 Mdot
.28202 .27551 Mdot
.28207 .27512 Mdot
.28212 .27473 Mdot
.28216 .27433 Mdot
.28221 .27394 Mdot
.28226 .27355 Mdot
.28231 .27316 Mdot
.28236 .27277 Mdot
.2824 .27237 Mdot
.28245 .27198 Mdot
.2825 .27159 Mdot
.28255 .27119 Mdot
.28259 .27079 Mdot
.28264 .27039 Mdot
.28269 .27 Mdot
.28274 .26959 Mdot
.28278 .26919 Mdot
.28283 .26879 Mdot
.28288 .26839 Mdot
.28293 .26799 Mdot
.28297 .26758 Mdot
.28302 .26718 Mdot
.28307 .26677 Mdot
.28312 .26636 Mdot
.28316 .26596 Mdot
.28321 .26555 Mdot
.28326 .26515 Mdot
.28331 .26474 Mdot
.28335 .26434 Mdot
.2834 .26394 Mdot
.28345 .26355 Mdot
.2835 .26315 Mdot
.28355 .26276 Mdot
.28359 .26237 Mdot
.28364 .26198 Mdot
.28369 .26159 Mdot
.28374 .2612 Mdot
.28378 .2608 Mdot
.28383 .26041 Mdot
.28388 .26001 Mdot
.28393 .25962 Mdot
.28397 .25922 Mdot
.28402 .25882 Mdot
.28407 .25841 Mdot
.28412 .25801 Mdot
.28416 .25761 Mdot
.28421 .25722 Mdot
.28426 .25682 Mdot
.28431 .25642 Mdot
.28435 .25602 Mdot
.2844 .25562 Mdot
.28445 .25522 Mdot
.2845 .25482 Mdot
.28455 .25442 Mdot
.28459 .25402 Mdot
.28464 .25362 Mdot
.28469 .25323 Mdot
.28474 .25283 Mdot
.28478 .25243 Mdot
.28483 .25204 Mdot
.28488 .25164 Mdot
.28493 .25123 Mdot
.28497 .25083 Mdot
.28502 .25043 Mdot
.28507 .25003 Mdot
.28512 .24963 Mdot
.28516 .24922 Mdot
.28521 .24881 Mdot
.28526 .24841 Mdot
.28531 .248 Mdot
.28535 .24759 Mdot
.2854 .24719 Mdot
.28545 .24679 Mdot
.2855 .24639 Mdot
.28555 .24599 Mdot
.28559 .24559 Mdot
.28564 .24519 Mdot
.28569 .24479 Mdot
.28574 .2444 Mdot
.28578 .244 Mdot
.28583 .2436 Mdot
.28588 .24321 Mdot
.28593 .24281 Mdot
.28597 .24242 Mdot
.28602 .24203 Mdot
.28607 .24163 Mdot
.28612 .24124 Mdot
.28616 .24085 Mdot
.28621 .24045 Mdot
.28626 .24006 Mdot
.28631 .23966 Mdot
.28635 .23927 Mdot
.2864 .23887 Mdot
.28645 .23848 Mdot
.2865 .23808 Mdot
.28655 .23769 Mdot
.28659 .2373 Mdot
.28664 .23691 Mdot
.28669 .23652 Mdot
.28674 .23613 Mdot
.28678 .23574 Mdot
.28683 .23535 Mdot
.28688 .23496 Mdot
.28693 .23457 Mdot
.28697 .23419 Mdot
.28702 .2338 Mdot
.28707 .23341 Mdot
.28712 .23302 Mdot
.28716 .23263 Mdot
.28721 .23224 Mdot
.28726 .23186 Mdot
.28731 .23147 Mdot
.28735 .23108 Mdot
.2874 .23069 Mdot
.28745 .2303 Mdot
.2875 .22991 Mdot
.28755 .22952 Mdot
.28759 .22913 Mdot
.28764 .22874 Mdot
.28769 .22834 Mdot
.28774 .22795 Mdot
.28778 .22756 Mdot
.28783 .22716 Mdot
.28788 .22677 Mdot
.28793 .22637 Mdot
.28797 .22598 Mdot
.28802 .22559 Mdot
.28807 .2252 Mdot
.28812 .2248 Mdot
.28816 .22441 Mdot
.28821 .22402 Mdot
.28826 .22363 Mdot
.28831 .22324 Mdot
.28835 .22285 Mdot
.2884 .22246 Mdot
.28845 .22207 Mdot
.2885 .22168 Mdot
.28854 .22129 Mdot
.28859 .22091 Mdot
.28864 .22052 Mdot
.28869 .22013 Mdot
.28874 .21975 Mdot
.28878 .21936 Mdot
.28883 .21898 Mdot
.28888 .2186 Mdot
.28893 .21822 Mdot
.28897 .21784 Mdot
.28902 .21745 Mdot
.28907 .21708 Mdot
.28912 .2167 Mdot
.28916 .21632 Mdot
.28921 .21595 Mdot
.28926 .21558 Mdot
.28931 .2152 Mdot
.28935 .21483 Mdot
.2894 .21445 Mdot
.28945 .21408 Mdot
.2895 .21371 Mdot
.28954 .21333 Mdot
.28959 .21296 Mdot
.28964 .21259 Mdot
.28969 .21221 Mdot
.28974 .21184 Mdot
.28978 .21146 Mdot
.28983 .21108 Mdot
.28988 .2107 Mdot
.28993 .21033 Mdot
.28997 .20995 Mdot
.29002 .20958 Mdot
.29007 .2092 Mdot
.29012 .20882 Mdot
.29016 .20845 Mdot
.29021 .20807 Mdot
.29026 .20769 Mdot
.29031 .20731 Mdot
.29035 .20693 Mdot
.2904 .20655 Mdot
.29045 .20618 Mdot
.2905 .2058 Mdot
.29054 .20543 Mdot
.29059 .20505 Mdot
.29064 .20468 Mdot
.29069 .20432 Mdot
.29074 .20395 Mdot
.29078 .20358 Mdot
.29083 .20322 Mdot
.29088 .20285 Mdot
.29093 .20248 Mdot
.29097 .20212 Mdot
.29102 .20175 Mdot
.29107 .20139 Mdot
.29112 .20102 Mdot
.29116 .20065 Mdot
.29121 .20029 Mdot
.29126 .19992 Mdot
.29131 .19956 Mdot
.29135 .1992 Mdot
.2914 .19883 Mdot
.29145 .19847 Mdot
.2915 .1981 Mdot
.29154 .19773 Mdot
.29159 .19737 Mdot
.29164 .197 Mdot
.29169 .19664 Mdot
.29174 .19627 Mdot
.29178 .19591 Mdot
.29183 .19555 Mdot
.29188 .19519 Mdot
.29193 .19483 Mdot
.29197 .19447 Mdot
.29202 .19411 Mdot
.29207 .19376 Mdot
.29212 .19341 Mdot
.29216 .19305 Mdot
.29221 .1927 Mdot
.29226 .19235 Mdot
.29231 .192 Mdot
.29235 .19165 Mdot
.2924 .1913 Mdot
.29245 .19096 Mdot
.2925 .19062 Mdot
.29254 .19028 Mdot
.29259 .18994 Mdot
.29264 .18961 Mdot
.29269 .18927 Mdot
.29274 .18893 Mdot
.29278 .1886 Mdot
.29283 .18826 Mdot
.29288 .18792 Mdot
.29293 .18759 Mdot
.29297 .18725 Mdot
.29302 .18691 Mdot
.29307 .18658 Mdot
.29312 .18624 Mdot
.29316 .1859 Mdot
.29321 .18556 Mdot
.29326 .18523 Mdot
.29331 .18489 Mdot
.29335 .18455 Mdot
.2934 .18422 Mdot
.29345 .18388 Mdot
.2935 .18355 Mdot
.29354 .18322 Mdot
.29359 .18289 Mdot
.29364 .18256 Mdot
.29369 .18223 Mdot
.29373 .18191 Mdot
.29378 .18158 Mdot
.29383 .18126 Mdot
.29388 .18093 Mdot
.29393 .1806 Mdot
.29397 .18027 Mdot
.29402 .17994 Mdot
.29407 .17962 Mdot
.29412 .17929 Mdot
.29416 .17896 Mdot
.29421 .17864 Mdot
.29426 .17831 Mdot
.29431 .17799 Mdot
.29435 .17766 Mdot
.2944 .17734 Mdot
.29445 .17702 Mdot
.2945 .1767 Mdot
.29454 .17637 Mdot
.29459 .17604 Mdot
.29464 .17571 Mdot
.29469 .17538 Mdot
.29473 .17505 Mdot
.29478 .17472 Mdot
.29483 .17439 Mdot
.29488 .17406 Mdot
.29493 .17374 Mdot
.29497 .17341 Mdot
.29502 .17308 Mdot
.29507 .17276 Mdot
.29512 .17243 Mdot
.29516 .1721 Mdot
.29521 .17178 Mdot
.29526 .17145 Mdot
.29531 .17112 Mdot
.29535 .1708 Mdot
.2954 .17047 Mdot
.29545 .17015 Mdot
.2955 .16982 Mdot
.29554 .1695 Mdot
.29559 .16917 Mdot
.29564 .16885 Mdot
.29569 .16853 Mdot
.29573 .16821 Mdot
.29578 .16788 Mdot
.29583 .16756 Mdot
.29588 .16723 Mdot
.29593 .16691 Mdot
.29597 .16658 Mdot
.29602 .16625 Mdot
.29607 .16593 Mdot
.29612 .1656 Mdot
.29616 .16527 Mdot
.29621 .16494 Mdot
.29626 .16461 Mdot
.29631 .16428 Mdot
.29635 .16395 Mdot
.2964 .16362 Mdot
.29645 .1633 Mdot
.2965 .16297 Mdot
.29654 .16265 Mdot
.29659 .16232 Mdot
.29664 .162 Mdot
.29669 .16167 Mdot
.29673 .16135 Mdot
.29678 .16103 Mdot
.29683 .16071 Mdot
.29688 .16038 Mdot
.29693 .16006 Mdot
.29697 .15974 Mdot
.29702 .15942 Mdot
.29707 .15911 Mdot
.29712 .15879 Mdot
.29716 .15848 Mdot
.29721 .15816 Mdot
.29726 .15784 Mdot
.29731 .15752 Mdot
.29735 .15721 Mdot
.2974 .15689 Mdot
.29745 .15658 Mdot
.2975 .15626 Mdot
.29754 .15594 Mdot
.29759 .15562 Mdot
.29764 .1553 Mdot
.29769 .15498 Mdot
.29773 .15466 Mdot
.29778 .15434 Mdot
.29783 .15403 Mdot
.29788 .15372 Mdot
.29792 .15341 Mdot
.29797 .1531 Mdot
.29802 .15279 Mdot
.29807 .15247 Mdot
.29812 .15216 Mdot
.29816 .15185 Mdot
.29821 .15154 Mdot
.29826 .15123 Mdot
.29831 .15092 Mdot
.29835 .1506 Mdot
.2984 .15029 Mdot
.29845 .14998 Mdot
.2985 .14967 Mdot
.29854 .14936 Mdot
.29859 .14905 Mdot
.29864 .14874 Mdot
.29869 .14843 Mdot
.29873 .14811 Mdot
.29878 .1478 Mdot
.29883 .14749 Mdot
.29888 .14718 Mdot
.29892 .14687 Mdot
.29897 .14656 Mdot
.29902 .14626 Mdot
.29907 .14595 Mdot
.29912 .14565 Mdot
.29916 .14534 Mdot
.29921 .14504 Mdot
.29926 .14474 Mdot
.29931 .14443 Mdot
.29935 .14413 Mdot
.2994 .14383 Mdot
.29945 .14353 Mdot
.2995 .14322 Mdot
.29954 .14292 Mdot
.29959 .14262 Mdot
.29964 .14232 Mdot
.29969 .14202 Mdot
.29973 .14171 Mdot
.29978 .14141 Mdot
.29983 .14111 Mdot
.29988 .14081 Mdot
.29992 .14051 Mdot
.29997 .1402 Mdot
.30002 .1399 Mdot
.30007 .1396 Mdot
.30012 .1393 Mdot
.30016 .139 Mdot
.30021 .13871 Mdot
.30026 .13841 Mdot
.30031 .13811 Mdot
.30035 .13781 Mdot
.3004 .13752 Mdot
.30045 .13723 Mdot
.3005 .13694 Mdot
.30054 .13665 Mdot
.30059 .13636 Mdot
.30064 .13607 Mdot
.30069 .13578 Mdot
.30073 .13549 Mdot
.30078 .13521 Mdot
.30083 .13492 Mdot
.30088 .13463 Mdot
.30092 .13434 Mdot
.30097 .13405 Mdot
.30102 .13376 Mdot
.30107 .13347 Mdot
.30112 .13317 Mdot
.30116 .13288 Mdot
.30121 .13259 Mdot
.30126 .1323 Mdot
.30131 .132 Mdot
.30135 .13171 Mdot
.3014 .13141 Mdot
.30145 .13112 Mdot
.3015 .13082 Mdot
.30154 .13052 Mdot
.30159 .13022 Mdot
.30164 .12993 Mdot
.30169 .12963 Mdot
.30173 .12933 Mdot
.30178 .12904 Mdot
.30183 .12874 Mdot
.30188 .12845 Mdot
.30192 .12816 Mdot
.30197 .12788 Mdot
.30202 .12759 Mdot
.30207 .12731 Mdot
.30212 .12702 Mdot
.30216 .12674 Mdot
.30221 .12646 Mdot
.30226 .12618 Mdot
.30231 .12591 Mdot
.30235 .12563 Mdot
.3024 .12536 Mdot
.30245 .12508 Mdot
.3025 .1248 Mdot
.30254 .12453 Mdot
.30259 .12425 Mdot
.30264 .12398 Mdot
.30269 .1237 Mdot
.30273 .12343 Mdot
.30278 .12316 Mdot
.30283 .12288 Mdot
.30288 .12261 Mdot
.30292 .12234 Mdot
.30297 .12207 Mdot
.30302 .12179 Mdot
.30307 .12152 Mdot
.30311 .12125 Mdot
.30316 .12098 Mdot
.30321 .12071 Mdot
.30326 .12044 Mdot
.30331 .12017 Mdot
.30335 .1199 Mdot
.3034 .11963 Mdot
.30345 .11937 Mdot
.3035 .1191 Mdot
.30354 .11884 Mdot
.30359 .11857 Mdot
.30364 .11831 Mdot
.30369 .11805 Mdot
.30373 .11779 Mdot
.30378 .11753 Mdot
.30383 .11727 Mdot
.30388 .11701 Mdot
.30392 .11675 Mdot
.30397 .11649 Mdot
.30402 .11623 Mdot
.30407 .11597 Mdot
.30411 .11572 Mdot
.30416 .11547 Mdot
.30421 .11522 Mdot
.30426 .11497 Mdot
.30431 .11472 Mdot
.30435 .11446 Mdot
.3044 .11421 Mdot
.30445 .11395 Mdot
.3045 .1137 Mdot
.30454 .11345 Mdot
.30459 .1132 Mdot
.30464 .11295 Mdot
.30469 .1127 Mdot
.30473 .11245 Mdot
.30478 .11221 Mdot
.30483 .11196 Mdot
.30488 .11171 Mdot
.30492 .11146 Mdot
.30497 .11121 Mdot
.30502 .11096 Mdot
.30507 .11071 Mdot
.30511 .11046 Mdot
.30516 .11022 Mdot
.30521 .10997 Mdot
.30526 .10972 Mdot
.30531 .10947 Mdot
.30535 .10922 Mdot
.3054 .10897 Mdot
.30545 .10873 Mdot
.3055 .10848 Mdot
.30554 .10824 Mdot
.30559 .10799 Mdot
.30564 .10774 Mdot
.30569 .1075 Mdot
.30573 .10725 Mdot
.30578 .10701 Mdot
.30583 .10677 Mdot
.30588 .10653 Mdot
.30592 .10629 Mdot
.30597 .10605 Mdot
.30602 .10581 Mdot
.30607 .10556 Mdot
.30611 .10532 Mdot
.30616 .10507 Mdot
.30621 .10483 Mdot
.30626 .10459 Mdot
.30631 .10434 Mdot
.30635 .1041 Mdot
.3064 .10386 Mdot
.30645 .10362 Mdot
.3065 .10339 Mdot
.30654 .10315 Mdot
.30659 .10292 Mdot
.30664 .10269 Mdot
.30669 .10245 Mdot
.30673 .10222 Mdot
.30678 .10198 Mdot
.30683 .10175 Mdot
.30688 .10151 Mdot
.30692 .10128 Mdot
.30697 .10104 Mdot
.30702 .10081 Mdot
.30707 .10058 Mdot
.30711 .10034 Mdot
.30716 .10011 Mdot
.30721 .09987 Mdot
.30726 .09964 Mdot
.3073 .09941 Mdot
.30735 .09918 Mdot
.3074 .09895 Mdot
.30745 .09872 Mdot
.3075 .09848 Mdot
.30754 .09825 Mdot
.30759 .09802 Mdot
.30764 .09779 Mdot
.30769 .09756 Mdot
.30773 .09732 Mdot
.30778 .09709 Mdot
.30783 .09685 Mdot
.30788 .09661 Mdot
.30792 .09638 Mdot
.30797 .09614 Mdot
.30802 .0959 Mdot
.30807 .09567 Mdot
.30811 .09543 Mdot
.30816 .0952 Mdot
.30821 .09496 Mdot
.30826 .09472 Mdot
.3083 .09448 Mdot
.30835 .09424 Mdot
.3084 .09401 Mdot
.30845 .09377 Mdot
.3085 .09353 Mdot
.30854 .09329 Mdot
.30859 .09305 Mdot
.30864 .09282 Mdot
.30869 .09259 Mdot
.30873 .09235 Mdot
.30878 .09212 Mdot
.30883 .09189 Mdot
.30888 .09166 Mdot
.30892 .09143 Mdot
.30897 .0912 Mdot
.30902 .09097 Mdot
.30907 .09075 Mdot
.30911 .09052 Mdot
.30916 .09029 Mdot
.30921 .09006 Mdot
.30926 .08983 Mdot
.3093 .08959 Mdot
.30935 .08936 Mdot
.3094 .08914 Mdot
.30945 .08891 Mdot
.3095 .08868 Mdot
.30954 .08846 Mdot
.30959 .08824 Mdot
.30964 .08801 Mdot
.30969 .08779 Mdot
.30973 .08756 Mdot
.30978 .08734 Mdot
.30983 .08711 Mdot
.30988 .08688 Mdot
.30992 .08666 Mdot
.30997 .08643 Mdot
.31002 .0862 Mdot
.31007 .08596 Mdot
.31011 .08573 Mdot
.31016 .0855 Mdot
.31021 .08527 Mdot
.31026 .08505 Mdot
.3103 .08482 Mdot
.31035 .0846 Mdot
.3104 .08437 Mdot
.31045 .08414 Mdot
.3105 .08392 Mdot
.31054 .08369 Mdot
.31059 .08346 Mdot
.31064 .08324 Mdot
.31069 .08301 Mdot
.31073 .08279 Mdot
.31078 .08256 Mdot
.31083 .08234 Mdot
.31088 .08212 Mdot
.31092 .08189 Mdot
.31097 .08167 Mdot
.31102 .08145 Mdot
.31107 .08123 Mdot
.31111 .08101 Mdot
.31116 .08079 Mdot
.31121 .08057 Mdot
.31126 .08035 Mdot
.3113 .08013 Mdot
.31135 .07991 Mdot
.3114 .0797 Mdot
.31145 .07948 Mdot
.3115 .07926 Mdot
.31154 .07905 Mdot
.31159 .07883 Mdot
.31164 .07861 Mdot
.31169 .07839 Mdot
.31173 .07817 Mdot
.31178 .07795 Mdot
.31183 .07773 Mdot
.31188 .07752 Mdot
.31192 .0773 Mdot
.31197 .07708 Mdot
.31202 .07686 Mdot
.31207 .07664 Mdot
.31211 .07642 Mdot
.31216 .0762 Mdot
.31221 .07599 Mdot
.31226 .07577 Mdot
.3123 .07555 Mdot
.31235 .07534 Mdot
.3124 .07513 Mdot
.31245 .07492 Mdot
.31249 .07471 Mdot
.31254 .0745 Mdot
.31259 .0743 Mdot
.31264 .07409 Mdot
.31269 .07388 Mdot
.31273 .07368 Mdot
.31278 .07348 Mdot
.31283 .07327 Mdot
.31288 .07307 Mdot
.31292 .07286 Mdot
.31297 .07266 Mdot
.31302 .07246 Mdot
.31307 .07226 Mdot
.31311 .07206 Mdot
.31316 .07185 Mdot
.31321 .07165 Mdot
.31326 .07145 Mdot
.3133 .07125 Mdot
.31335 .07105 Mdot
.3134 .07085 Mdot
.31345 .07066 Mdot
.31349 .07046 Mdot
.31354 .07026 Mdot
.31359 .07006 Mdot
.31364 .06987 Mdot
.31369 .06967 Mdot
.31373 .06948 Mdot
.31378 .06929 Mdot
.31383 .0691 Mdot
.31388 .06891 Mdot
.31392 .06872 Mdot
.31397 .06854 Mdot
.31402 .06835 Mdot
.31407 .06816 Mdot
.31411 .06798 Mdot
.31416 .06779 Mdot
.31421 .06761 Mdot
.31426 .06743 Mdot
.3143 .06724 Mdot
.31435 .06706 Mdot
.3144 .06688 Mdot
.31445 .06669 Mdot
.31449 .06651 Mdot
.31454 .06632 Mdot
.31459 .06614 Mdot
.31464 .06595 Mdot
.31469 .06577 Mdot
.31473 .06558 Mdot
.31478 .0654 Mdot
.31483 .06522 Mdot
.31488 .06504 Mdot
.31492 .06487 Mdot
.31497 .06469 Mdot
.31502 .06452 Mdot
.31507 .06434 Mdot
.31511 .06416 Mdot
.31516 .06398 Mdot
.31521 .06381 Mdot
.31526 .06363 Mdot
.3153 .06346 Mdot
.31535 .06328 Mdot
.3154 .06311 Mdot
.31545 .06294 Mdot
.31549 .06277 Mdot
.31554 .0626 Mdot
.31559 .06244 Mdot
.31564 .06227 Mdot
.31569 .0621 Mdot
.31573 .06194 Mdot
.31578 .06178 Mdot
.31583 .06162 Mdot
.31588 .06146 Mdot
.31592 .0613 Mdot
.31597 .06113 Mdot
.31602 .06098 Mdot
.31607 .06082 Mdot
.31611 .06067 Mdot
.31616 .06051 Mdot
.31621 .06036 Mdot
.31626 .06021 Mdot
.3163 .06006 Mdot
.31635 .05992 Mdot
.3164 .05978 Mdot
.31645 .05963 Mdot
.31649 .05949 Mdot
.31654 .05935 Mdot
.31659 .05921 Mdot
.31664 .05907 Mdot
.31668 .05894 Mdot
.31673 .0588 Mdot
.31678 .05867 Mdot
.31683 .05853 Mdot
.31688 .0584 Mdot
.31692 .05827 Mdot
.31697 .05814 Mdot
.31702 .05801 Mdot
.31707 .05788 Mdot
.31711 .05776 Mdot
.31716 .05763 Mdot
.31721 .05751 Mdot
.31726 .05739 Mdot
.3173 .05727 Mdot
.31735 .05715 Mdot
.3174 .05702 Mdot
.31745 .05689 Mdot
.31749 .05676 Mdot
.31754 .05664 Mdot
.31759 .05651 Mdot
.31764 .05638 Mdot
.31768 .05625 Mdot
.31773 .05613 Mdot
.31778 .056 Mdot
.31783 .05588 Mdot
.31788 .05575 Mdot
.31792 .05562 Mdot
.31797 .0555 Mdot
.31802 .05538 Mdot
.31807 .05525 Mdot
.31811 .05512 Mdot
.31816 .055 Mdot
.31821 .05488 Mdot
.31826 .05476 Mdot
.3183 .05464 Mdot
.31835 .05452 Mdot
.3184 .0544 Mdot
.31845 .05428 Mdot
.31849 .05417 Mdot
.31854 .05405 Mdot
.31859 .05394 Mdot
.31864 .05384 Mdot
.31868 .05373 Mdot
.31873 .05362 Mdot
.31878 .05351 Mdot
.31883 .05341 Mdot
.31888 .0533 Mdot
.31892 .05319 Mdot
.31897 .05308 Mdot
.31902 .05297 Mdot
.31907 .05285 Mdot
.31911 .05274 Mdot
.31916 .05263 Mdot
.31921 .05252 Mdot
.31926 .05241 Mdot
.3193 .0523 Mdot
.31935 .0522 Mdot
.3194 .05209 Mdot
.31945 .05198 Mdot
.31949 .05187 Mdot
.31954 .05175 Mdot
.31959 .05164 Mdot
.31964 .05152 Mdot
.31968 .05141 Mdot
.31973 .05129 Mdot
.31978 .05117 Mdot
.31983 .05106 Mdot
.31988 .05094 Mdot
.31992 .05082 Mdot
.31997 .0507 Mdot
.32002 .05059 Mdot
.32007 .05048 Mdot
.32011 .05036 Mdot
.32016 .05024 Mdot
.32021 .05012 Mdot
.32026 .05 Mdot
.3203 .04989 Mdot
.32035 .04978 Mdot
.3204 .04966 Mdot
.32045 .04955 Mdot
.32049 .04944 Mdot
.32054 .04933 Mdot
.32059 .04922 Mdot
.32064 .04911 Mdot
.32068 .049 Mdot
.32073 .04889 Mdot
.32078 .04878 Mdot
.32083 .04867 Mdot
.32088 .04856 Mdot
.32092 .04845 Mdot
.32097 .04834 Mdot
.32102 .04824 Mdot
.32107 .04813 Mdot
.32111 .04802 Mdot
.32116 .04791 Mdot
.32121 .04781 Mdot
.32126 .0477 Mdot
.3213 .04759 Mdot
.32135 .04748 Mdot
.3214 .04738 Mdot
.32145 .04727 Mdot
.32149 .04716 Mdot
.32154 .04705 Mdot
.32159 .04694 Mdot
.32164 .04684 Mdot
.32168 .04674 Mdot
.32173 .04664 Mdot
.32178 .04654 Mdot
.32183 .04644 Mdot
.32187 .04635 Mdot
.32192 .04625 Mdot
.32197 .04616 Mdot
.32202 .04606 Mdot
.32207 .04597 Mdot
.32211 .04588 Mdot
.32216 .04579 Mdot
.32221 .0457 Mdot
.32226 .04562 Mdot
.3223 .04553 Mdot
.32235 .04544 Mdot
.3224 .04536 Mdot
.32245 .04527 Mdot
.32249 .04518 Mdot
.32254 .04509 Mdot
.32259 .04501 Mdot
.32264 .04492 Mdot
.32268 .04483 Mdot
.32273 .04474 Mdot
.32278 .04466 Mdot
.32283 .04458 Mdot
.32287 .0445 Mdot
.32292 .04442 Mdot
.32297 .04434 Mdot
.32302 .04426 Mdot
.32307 .04419 Mdot
.32311 .04411 Mdot
.32316 .04404 Mdot
.32321 .04396 Mdot
.32326 .04388 Mdot
.3233 .0438 Mdot
.32335 .04372 Mdot
.3234 .04364 Mdot
.32345 .04357 Mdot
.32349 .04349 Mdot
.32354 .04341 Mdot
.32359 .04333 Mdot
.32364 .04325 Mdot
.32368 .04317 Mdot
.32373 .0431 Mdot
.32378 .04302 Mdot
.32383 .04295 Mdot
.32387 .04287 Mdot
.32392 .0428 Mdot
.32397 .04272 Mdot
.32402 .04265 Mdot
.32407 .04257 Mdot
.32411 .0425 Mdot
.32416 .04242 Mdot
.32421 .04234 Mdot
.32426 .04227 Mdot
.3243 .04219 Mdot
.32435 .04212 Mdot
.3244 .04205 Mdot
.32445 .04198 Mdot
.32449 .04191 Mdot
.32454 .04184 Mdot
.32459 .04177 Mdot
.32464 .0417 Mdot
.32468 .04164 Mdot
.32473 .04157 Mdot
.32478 .04151 Mdot
.32483 .04145 Mdot
.32487 .04138 Mdot
.32492 .04133 Mdot
.32497 .04127 Mdot
.32502 .04121 Mdot
.32507 .04115 Mdot
.32511 .04109 Mdot
.32516 .04104 Mdot
.32521 .04098 Mdot
.32526 .04092 Mdot
.3253 .04086 Mdot
.32535 .0408 Mdot
.3254 .04074 Mdot
.32545 .04069 Mdot
.32549 .04063 Mdot
.32554 .04057 Mdot
.32559 .04051 Mdot
.32564 .04046 Mdot
.32568 .0404 Mdot
.32573 .04035 Mdot
.32578 .0403 Mdot
.32583 .04025 Mdot
.32587 .0402 Mdot
.32592 .04015 Mdot
.32597 .0401 Mdot
.32602 .04005 Mdot
.32607 .04 Mdot
.32611 .03996 Mdot
.32616 .03991 Mdot
.32621 .03986 Mdot
.32626 .03981 Mdot
.3263 .03977 Mdot
.32635 .03972 Mdot
.3264 .03967 Mdot
.32645 .03963 Mdot
.32649 .03959 Mdot
.32654 .03954 Mdot
.32659 .0395 Mdot
.32664 .03945 Mdot
.32668 .03941 Mdot
.32673 .03937 Mdot
.32678 .03933 Mdot
.32683 .03929 Mdot
.32687 .03925 Mdot
.32692 .03921 Mdot
.32697 .03917 Mdot
.32702 .03913 Mdot
.32706 .03909 Mdot
.32711 .03905 Mdot
.32716 .03901 Mdot
.32721 .03898 Mdot
.32726 .03894 Mdot
.3273 .0389 Mdot
.32735 .03887 Mdot
.3274 .03883 Mdot
.32745 .03879 Mdot
.32749 .03876 Mdot
.32754 .03872 Mdot
.32759 .03869 Mdot
.32764 .03865 Mdot
.32768 .03861 Mdot
.32773 .03858 Mdot
.32778 .03854 Mdot
.32783 .03851 Mdot
.32787 .03848 Mdot
.32792 .03845 Mdot
.32797 .03842 Mdot
.32802 .03839 Mdot
.32806 .03836 Mdot
.32811 .03834 Mdot
.32816 .03831 Mdot
.32821 .03828 Mdot
.32826 .03825 Mdot
.3283 .03823 Mdot
.32835 .0382 Mdot
.3284 .03817 Mdot
.32845 .03815 Mdot
.32849 .03812 Mdot
.32854 .03809 Mdot
.32859 .03807 Mdot
.32864 .03805 Mdot
.32868 .03802 Mdot
.32873 .038 Mdot
.32878 .03798 Mdot
.32883 .03796 Mdot
.32887 .03794 Mdot
.32892 .03791 Mdot
.32897 .03789 Mdot
.32902 .03787 Mdot
.32906 .03786 Mdot
.32911 .03784 Mdot
.32916 .03782 Mdot
.32921 .03781 Mdot
.32926 .03779 Mdot
.3293 .03778 Mdot
.32935 .03776 Mdot
.3294 .03775 Mdot
.32945 .03773 Mdot
.32949 .03772 Mdot
.32954 .03771 Mdot
.32959 .0377 Mdot
.32964 .03769 Mdot
.32968 .03768 Mdot
.32973 .03767 Mdot
.32978 .03766 Mdot
.32983 .03765 Mdot
.32987 .03764 Mdot
.32992 .03764 Mdot
.32997 .03763 Mdot
.33002 .03762 Mdot
.33006 .03761 Mdot
.33011 .03761 Mdot
.33016 .0376 Mdot
.33021 .0376 Mdot
.33026 .03759 Mdot
.3303 .03759 Mdot
.33035 .03758 Mdot
.3304 .03757 Mdot
.33045 .03757 Mdot
.33049 .03756 Mdot
.33054 .03756 Mdot
.33059 .03755 Mdot
.33064 .03755 Mdot
.33068 .03755 Mdot
.33073 .03755 Mdot
.33078 .03755 Mdot
.33083 .03754 Mdot
.33087 .03753 Mdot
.33092 .03753 Mdot
.33097 .03752 Mdot
.33102 .03752 Mdot
.33106 .03751 Mdot
.33111 .03751 Mdot
.33116 .0375 Mdot
.33121 .0375 Mdot
.33125 .0375 Mdot
.3313 .0375 Mdot
.33135 .03749 Mdot
.3314 .03749 Mdot
.33145 .03749 Mdot
.33149 .03748 Mdot
.33154 .03748 Mdot
.33159 .03748 Mdot
.33164 .03748 Mdot
.33168 .03749 Mdot
.33173 .03749 Mdot
.33178 .03749 Mdot
.33183 .0375 Mdot
.33187 .0375 Mdot
.33192 .0375 Mdot
.33197 .0375 Mdot
.33202 .0375 Mdot
.33206 .03751 Mdot
.33211 .03752 Mdot
.33216 .03753 Mdot
.33221 .03755 Mdot
.33225 .03756 Mdot
.3323 .03757 Mdot
.33235 .03758 Mdot
.3324 .03759 Mdot
.33245 .0376 Mdot
.33249 .03761 Mdot
.33254 .03762 Mdot
.33259 .03763 Mdot
.33264 .03764 Mdot
.33268 .03765 Mdot
.33273 .03766 Mdot
.33278 .03768 Mdot
.33283 .03769 Mdot
.33287 .03771 Mdot
.33292 .03772 Mdot
.33297 .03774 Mdot
.33302 .03776 Mdot
.33306 .03778 Mdot
.33311 .0378 Mdot
.33316 .03783 Mdot
.33321 .03785 Mdot
.33325 .03787 Mdot
.3333 .03789 Mdot
.33335 .03791 Mdot
.3334 .03793 Mdot
.33345 .03796 Mdot
.33349 .03798 Mdot
.33354 .03801 Mdot
.33359 .03803 Mdot
.33364 .03806 Mdot
.33368 .03808 Mdot
.33373 .03811 Mdot
.33378 .03813 Mdot
.33383 .03816 Mdot
.33387 .03819 Mdot
.33392 .03823 Mdot
.33397 .03826 Mdot
.33402 .03829 Mdot
.33406 .03833 Mdot
.33411 .03836 Mdot
.33416 .03839 Mdot
.33421 .03842 Mdot
.33425 .03846 Mdot
.3343 .03849 Mdot
.33435 .03852 Mdot
.3344 .03855 Mdot
.33445 .03859 Mdot
.33449 .03862 Mdot
.33454 .03866 Mdot
.33459 .03869 Mdot
.33464 .03873 Mdot
.33468 .03877 Mdot
.33473 .03881 Mdot
.33478 .03885 Mdot
.33483 .03889 Mdot
.33487 .03893 Mdot
.33492 .03898 Mdot
.33497 .03902 Mdot
.33502 .03907 Mdot
.33506 .03912 Mdot
.33511 .03916 Mdot
.33516 .03921 Mdot
.33521 .03926 Mdot
.33525 .03931 Mdot
.3353 .03935 Mdot
.33535 .0394 Mdot
.3354 .03945 Mdot
.33545 .0395 Mdot
.33549 .03955 Mdot
.33554 .0396 Mdot
.33559 .03965 Mdot
.33564 .0397 Mdot
.33568 .03976 Mdot
.33573 .03981 Mdot
.33578 .03987 Mdot
.33583 .03992 Mdot
.33587 .03998 Mdot
.33592 .04003 Mdot
.33597 .04009 Mdot
.33602 .04014 Mdot
.33606 .0402 Mdot
.33611 .04025 Mdot
.33616 .04031 Mdot
.33621 .04036 Mdot
.33625 .04042 Mdot
.3363 .04047 Mdot
.33635 .04052 Mdot
.3364 .04057 Mdot
.33644 .04062 Mdot
.33649 .04068 Mdot
.33654 .04073 Mdot
.33659 .04079 Mdot
.33664 .04084 Mdot
.33668 .0409 Mdot
.33673 .04095 Mdot
.33678 .04101 Mdot
.33683 .04107 Mdot
.33687 .04112 Mdot
.33692 .04118 Mdot
.33697 .04124 Mdot
.33702 .0413 Mdot
.33706 .04135 Mdot
.33711 .0414 Mdot
.33716 .04146 Mdot
.33721 .04151 Mdot
.33725 .04157 Mdot
.3373 .04163 Mdot
.33735 .04168 Mdot
.3374 .04174 Mdot
.33744 .04179 Mdot
.33749 .04185 Mdot
.33754 .0419 Mdot
.33759 .04195 Mdot
.33764 .04201 Mdot
.33768 .04206 Mdot
.33773 .04212 Mdot
.33778 .04218 Mdot
.33783 .04223 Mdot
.33787 .04229 Mdot
.33792 .04235 Mdot
.33797 .0424 Mdot
.33802 .04246 Mdot
.33806 .04252 Mdot
.33811 .04257 Mdot
.33816 .04263 Mdot
.33821 .04268 Mdot
.33825 .04274 Mdot
.3383 .0428 Mdot
.33835 .04287 Mdot
.3384 .04293 Mdot
.33844 .04299 Mdot
.33849 .04306 Mdot
.33854 .04313 Mdot
.33859 .0432 Mdot
.33864 .04327 Mdot
.33868 .04334 Mdot
.33873 .04341 Mdot
.33878 .04349 Mdot
.33883 .04356 Mdot
.33887 .04363 Mdot
.33892 .04371 Mdot
.33897 .04378 Mdot
.33902 .04386 Mdot
.33906 .04393 Mdot
.33911 .044 Mdot
.33916 .04408 Mdot
.33921 .04416 Mdot
.33925 .04423 Mdot
.3393 .0443 Mdot
.33935 .04438 Mdot
.3394 .04445 Mdot
.33944 .04453 Mdot
.33949 .0446 Mdot
.33954 .04468 Mdot
.33959 .04475 Mdot
.33964 .04483 Mdot
.33968 .0449 Mdot
.33973 .04498 Mdot
.33978 .04505 Mdot
.33983 .04513 Mdot
.33987 .04521 Mdot
.33992 .04529 Mdot
.33997 .04537 Mdot
.34002 .04545 Mdot
.34006 .04553 Mdot
.34011 .0456 Mdot
.34016 .04568 Mdot
.34021 .04577 Mdot
.34025 .04585 Mdot
.3403 .04594 Mdot
.34035 .04602 Mdot
.3404 .0461 Mdot
.34044 .04619 Mdot
.34049 .04627 Mdot
.34054 .04636 Mdot
.34059 .04645 Mdot
.34063 .04654 Mdot
.34068 .04662 Mdot
.34073 .0467 Mdot
.34078 .04678 Mdot
.34083 .04687 Mdot
.34087 .04695 Mdot
.34092 .04703 Mdot
.34097 .04712 Mdot
.34102 .0472 Mdot
.34106 .04729 Mdot
.34111 .04738 Mdot
.34116 .04746 Mdot
.34121 .04755 Mdot
.34125 .04764 Mdot
.3413 .04773 Mdot
.34135 .04782 Mdot
.3414 .04791 Mdot
.34144 .04799 Mdot
.34149 .04808 Mdot
.34154 .04817 Mdot
.34159 .04826 Mdot
.34163 .04834 Mdot
.34168 .04843 Mdot
.34173 .04852 Mdot
.34178 .04861 Mdot
.34183 .0487 Mdot
.34187 .04879 Mdot
.34192 .04887 Mdot
.34197 .04896 Mdot
.34202 .04905 Mdot
.34206 .04913 Mdot
.34211 .04923 Mdot
.34216 .04932 Mdot
.34221 .04941 Mdot
.34225 .04951 Mdot
.3423 .0496 Mdot
.34235 .04969 Mdot
.3424 .04979 Mdot
.34244 .04988 Mdot
.34249 .04998 Mdot
.34254 .05007 Mdot
.34259 .05016 Mdot
.34263 .05026 Mdot
.34268 .05035 Mdot
.34273 .05044 Mdot
.34278 .05053 Mdot
.34283 .05063 Mdot
.34287 .05072 Mdot
.34292 .05081 Mdot
.34297 .0509 Mdot
.34302 .05099 Mdot
.34306 .05109 Mdot
.34311 .05119 Mdot
.34316 .05129 Mdot
.34321 .05139 Mdot
.34325 .05149 Mdot
.3433 .05159 Mdot
.34335 .05169 Mdot
.3434 .05179 Mdot
.34344 .0519 Mdot
.34349 .052 Mdot
.34354 .0521 Mdot
.34359 .05221 Mdot
.34363 .05231 Mdot
.34368 .05242 Mdot
.34373 .05252 Mdot
.34378 .05262 Mdot
.34383 .05272 Mdot
.34387 .05282 Mdot
.34392 .05292 Mdot
.34397 .05302 Mdot
.34402 .05312 Mdot
.34406 .05322 Mdot
.34411 .05331 Mdot
.34416 .05341 Mdot
.34421 .05351 Mdot
.34425 .0536 Mdot
.3443 .0537 Mdot
.34435 .0538 Mdot
.3444 .05389 Mdot
.34444 .05399 Mdot
.34449 .05409 Mdot
.34454 .05419 Mdot
.34459 .05428 Mdot
.34463 .05438 Mdot
.34468 .05448 Mdot
.34473 .05458 Mdot
.34478 .05468 Mdot
.34483 .05478 Mdot
.34487 .05487 Mdot
.34492 .05497 Mdot
.34497 .05506 Mdot
.34502 .05515 Mdot
.34506 .05524 Mdot
.34511 .05533 Mdot
.34516 .05543 Mdot
.34521 .05553 Mdot
.34525 .05563 Mdot
.3453 .05572 Mdot
.34535 .05582 Mdot
.3454 .05592 Mdot
.34544 .05601 Mdot
.34549 .05611 Mdot
.34554 .05621 Mdot
.34559 .05631 Mdot
.34563 .05641 Mdot
.34568 .05651 Mdot
.34573 .05662 Mdot
.34578 .05672 Mdot
.34582 .05683 Mdot
.34587 .05693 Mdot
.34592 .05704 Mdot
.34597 .05715 Mdot
.34602 .05726 Mdot
.34606 .05738 Mdot
.34611 .05749 Mdot
.34616 .0576 Mdot
.34621 .05771 Mdot
.34625 .05783 Mdot
.3463 .05794 Mdot
.34635 .05805 Mdot
.3464 .05817 Mdot
.34644 .05828 Mdot
.34649 .0584 Mdot
.34654 .05852 Mdot
.34659 .05864 Mdot
.34663 .05876 Mdot
.34668 .05887 Mdot
.34673 .05899 Mdot
.34678 .05911 Mdot
.34682 .05924 Mdot
.34687 .05936 Mdot
.34692 .05948 Mdot
.34697 .05961 Mdot
.34702 .05973 Mdot
.34706 .05986 Mdot
.34711 .05998 Mdot
.34716 .0601 Mdot
.34721 .06022 Mdot
.34725 .06034 Mdot
.3473 .06046 Mdot
.34735 .06058 Mdot
.3474 .0607 Mdot
.34744 .06082 Mdot
.34749 .06094 Mdot
.34754 .06107 Mdot
.34759 .06119 Mdot
.34763 .06132 Mdot
.34768 .06145 Mdot
.34773 .06158 Mdot
.34778 .0617 Mdot
.34782 .06183 Mdot
.34787 .06196 Mdot
.34792 .06208 Mdot
.34797 .06221 Mdot
.34802 .06234 Mdot
.34806 .06246 Mdot
.34811 .06259 Mdot
.34816 .06272 Mdot
.34821 .06285 Mdot
.34825 .06298 Mdot
.3483 .06311 Mdot
.34835 .06324 Mdot
.3484 .06337 Mdot
.34844 .06351 Mdot
.34849 .06365 Mdot
.34854 .06378 Mdot
.34859 .06391 Mdot
.34863 .06405 Mdot
.34868 .06419 Mdot
.34873 .06433 Mdot
.34878 .06447 Mdot
.34882 .06462 Mdot
.34887 .06476 Mdot
.34892 .0649 Mdot
.34897 .06505 Mdot
.34902 .06519 Mdot
.34906 .06534 Mdot
.34911 .06548 Mdot
.34916 .06563 Mdot
.34921 .06577 Mdot
.34925 .06592 Mdot
.3493 .06607 Mdot
.34935 .06622 Mdot
.3494 .06637 Mdot
.34944 .06652 Mdot
.34949 .06667 Mdot
.34954 .06682 Mdot
.34959 .06697 Mdot
.34963 .06712 Mdot
.34968 .06728 Mdot
.34973 .06743 Mdot
.34978 .06758 Mdot
.34982 .06774 Mdot
.34987 .06789 Mdot
.34992 .06805 Mdot
.34997 .0682 Mdot
.35001 .06836 Mdot
.35006 .06852 Mdot
.35011 .06868 Mdot
.35016 .06884 Mdot
.35021 .069 Mdot
.35025 .06916 Mdot
.3503 .06932 Mdot
.35035 .06947 Mdot
.3504 .06963 Mdot
.35044 .06978 Mdot
.35049 .06994 Mdot
.35054 .07011 Mdot
.35059 .07027 Mdot
.35063 .07043 Mdot
.35068 .07059 Mdot
.35073 .07075 Mdot
.35078 .07091 Mdot
.35082 .07108 Mdot
.35087 .07124 Mdot
.35092 .0714 Mdot
.35097 .07157 Mdot
.35101 .07173 Mdot
.35106 .07189 Mdot
.35111 .07206 Mdot
.35116 .07223 Mdot
.35121 .07239 Mdot
.35125 .07255 Mdot
.3513 .07272 Mdot
.35135 .07288 Mdot
.3514 .07305 Mdot
.35144 .07322 Mdot
.35149 .07338 Mdot
.35154 .07355 Mdot
.35159 .07371 Mdot
.35163 .07388 Mdot
.35168 .07404 Mdot
.35173 .0742 Mdot
.35178 .07437 Mdot
.35182 .07454 Mdot
.35187 .0747 Mdot
.35192 .07487 Mdot
.35197 .07504 Mdot
.35201 .07521 Mdot
.35206 .07538 Mdot
.35211 .07555 Mdot
.35216 .07572 Mdot
.35221 .07588 Mdot
.35225 .07605 Mdot
.3523 .07621 Mdot
.35235 .07638 Mdot
.3524 .07654 Mdot
.35244 .07671 Mdot
.35249 .07688 Mdot
.35254 .07705 Mdot
.35259 .07722 Mdot
.35263 .07739 Mdot
.35268 .07757 Mdot
.35273 .07775 Mdot
.35278 .07792 Mdot
.35282 .07809 Mdot
.35287 .07827 Mdot
.35292 .07844 Mdot
.35297 .07861 Mdot
.35301 .07878 Mdot
.35306 .07896 Mdot
.35311 .07913 Mdot
.35316 .0793 Mdot
.35321 .07947 Mdot
.35325 .07965 Mdot
.3533 .07982 Mdot
.35335 .07999 Mdot
.3534 .08016 Mdot
.35344 .08033 Mdot
.35349 .0805 Mdot
.35354 .08067 Mdot
.35359 .08085 Mdot
.35363 .08103 Mdot
.35368 .08121 Mdot
.35373 .08138 Mdot
.35378 .08156 Mdot
.35382 .08174 Mdot
.35387 .08192 Mdot
.35392 .0821 Mdot
.35397 .08228 Mdot
.35401 .08247 Mdot
.35406 .08265 Mdot
.35411 .08284 Mdot
.35416 .08302 Mdot
.35421 .08321 Mdot
.35425 .0834 Mdot
.3543 .08359 Mdot
.35435 .08378 Mdot
.3544 .08397 Mdot
.35444 .08416 Mdot
.35449 .08435 Mdot
.35454 .08455 Mdot
.35459 .08475 Mdot
.35463 .08495 Mdot
.35468 .08514 Mdot
.35473 .08534 Mdot
.35478 .08553 Mdot
.35482 .08573 Mdot
.35487 .08592 Mdot
.35492 .08612 Mdot
.35497 .08632 Mdot
.35501 .08652 Mdot
.35506 .08672 Mdot
.35511 .08692 Mdot
.35516 .08711 Mdot
.3552 .08731 Mdot
.35525 .08751 Mdot
.3553 .08771 Mdot
.35535 .08791 Mdot
.3554 .0881 Mdot
.35544 .0883 Mdot
.35549 .08849 Mdot
.35554 .08869 Mdot
.35559 .08889 Mdot
.35563 .08908 Mdot
.35568 .08927 Mdot
.35573 .08947 Mdot
.35578 .08967 Mdot
.35582 .08987 Mdot
.35587 .09007 Mdot
.35592 .09027 Mdot
.35597 .09046 Mdot
.35601 .09066 Mdot
.35606 .09086 Mdot
.35611 .09106 Mdot
.35616 .09126 Mdot
.3562 .09146 Mdot
.35625 .09165 Mdot
.3563 .09185 Mdot
.35635 .09204 Mdot
.3564 .09224 Mdot
.35644 .09245 Mdot
.35649 .09265 Mdot
.35654 .09284 Mdot
.35659 .09304 Mdot
.35663 .09325 Mdot
.35668 .09345 Mdot
.35673 .09365 Mdot
.35678 .09386 Mdot
.35682 .09406 Mdot
.35687 .09426 Mdot
.35692 .09447 Mdot
.35697 .09467 Mdot
.35701 .09488 Mdot
.35706 .09508 Mdot
.35711 .09529 Mdot
.35716 .09549 Mdot
.3572 .0957 Mdot
.35725 .09591 Mdot
.3573 .09611 Mdot
.35735 .09632 Mdot
.3574 .09652 Mdot
.35744 .09673 Mdot
.35749 .09693 Mdot
.35754 .09713 Mdot
.35759 .09733 Mdot
.35763 .09753 Mdot
.35768 .09773 Mdot
.35773 .09794 Mdot
.35778 .09815 Mdot
.35782 .09835 Mdot
.35787 .09856 Mdot
.35792 .09877 Mdot
.35797 .09897 Mdot
.35801 .09918 Mdot
.35806 .09938 Mdot
.35811 .09959 Mdot
.35816 .0998 Mdot
.3582 .1 Mdot
.35825 .10021 Mdot
.3583 .10042 Mdot
.35835 .10063 Mdot
.3584 .10084 Mdot
.35844 .10105 Mdot
.35849 .10127 Mdot
.35854 .10148 Mdot
.35859 .10169 Mdot
.35863 .10191 Mdot
.35868 .10212 Mdot
.35873 .10234 Mdot
.35878 .10255 Mdot
.35882 .10276 Mdot
.35887 .10297 Mdot
.35892 .10319 Mdot
.35897 .1034 Mdot
.35901 .10362 Mdot
.35906 .10384 Mdot
.35911 .10406 Mdot
.35916 .10428 Mdot
.3592 .1045 Mdot
.35925 .10472 Mdot
.3593 .10494 Mdot
.35935 .10516 Mdot
.3594 .10538 Mdot
.35944 .1056 Mdot
.35949 .10582 Mdot
.35954 .10604 Mdot
.35959 .10626 Mdot
.35963 .10649 Mdot
.35968 .10671 Mdot
.35973 .10694 Mdot
.35978 .10716 Mdot
.35982 .10738 Mdot
.35987 .10761 Mdot
.35992 .10783 Mdot
.35997 .10806 Mdot
.36001 .10828 Mdot
.36006 .10851 Mdot
.36011 .10873 Mdot
.36016 .10896 Mdot
.3602 .10919 Mdot
.36025 .10941 Mdot
.3603 .10964 Mdot
.36035 .10987 Mdot
.36039 .1101 Mdot
.36044 .11033 Mdot
.36049 .11056 Mdot
.36054 .1108 Mdot
.36059 .11103 Mdot
.36063 .11125 Mdot
.36068 .11148 Mdot
.36073 .11172 Mdot
.36078 .11195 Mdot
.36082 .11218 Mdot
.36087 .11242 Mdot
.36092 .11265 Mdot
.36097 .11289 Mdot
.36101 .11313 Mdot
.36106 .11337 Mdot
.36111 .11361 Mdot
.36116 .11385 Mdot
.3612 .1141 Mdot
.36125 .11434 Mdot
.3613 .11458 Mdot
.36135 .11482 Mdot
.36139 .11506 Mdot
.36144 .1153 Mdot
.36149 .11554 Mdot
.36154 .11579 Mdot
.36159 .11603 Mdot
.36163 .11627 Mdot
.36168 .11651 Mdot
.36173 .11676 Mdot
.36178 .11701 Mdot
.36182 .11725 Mdot
.36187 .11749 Mdot
.36192 .11774 Mdot
.36197 .11798 Mdot
.36201 .11823 Mdot
.36206 .11848 Mdot
.36211 .11873 Mdot
.36216 .11898 Mdot
.3622 .11923 Mdot
.36225 .11949 Mdot
.3623 .11974 Mdot
.36235 .12 Mdot
.36239 .12026 Mdot
.36244 .12051 Mdot
.36249 .12077 Mdot
.36254 .12102 Mdot
.36259 .12128 Mdot
.36263 .12154 Mdot
.36268 .1218 Mdot
.36273 .12206 Mdot
.36278 .12232 Mdot
.36282 .12258 Mdot
.36287 .12284 Mdot
.36292 .1231 Mdot
.36297 .12337 Mdot
.36301 .12363 Mdot
.36306 .12389 Mdot
.36311 .12416 Mdot
.36316 .12442 Mdot
.3632 .12469 Mdot
.36325 .12495 Mdot
.3633 .12522 Mdot
.36335 .12548 Mdot
.36339 .12574 Mdot
.36344 .12601 Mdot
.36349 .12627 Mdot
.36354 .12654 Mdot
.36359 .12681 Mdot
.36363 .12707 Mdot
.36368 .12734 Mdot
.36373 .1276 Mdot
.36378 .12787 Mdot
.36382 .12814 Mdot
.36387 .12841 Mdot
.36392 .12867 Mdot
.36397 .12894 Mdot
.36401 .12921 Mdot
.36406 .12948 Mdot
.36411 .12974 Mdot
.36416 .13001 Mdot
.3642 .13028 Mdot
.36425 .13054 Mdot
.3643 .13081 Mdot
.36435 .13107 Mdot
.36439 .13134 Mdot
.36444 .1316 Mdot
.36449 .13186 Mdot
.36454 .13213 Mdot
.36458 .13239 Mdot
.36463 .13266 Mdot
.36468 .13293 Mdot
.36473 .1332 Mdot
.36478 .13346 Mdot
.36482 .13372 Mdot
.36487 .13398 Mdot
.36492 .13425 Mdot
.36497 .13451 Mdot
.36501 .13477 Mdot
.36506 .13504 Mdot
.36511 .13531 Mdot
.36516 .13557 Mdot
.3652 .13585 Mdot
.36525 .13612 Mdot
.3653 .13639 Mdot
.36535 .13667 Mdot
.36539 .13694 Mdot
.36544 .13722 Mdot
.36549 .1375 Mdot
.36554 .13778 Mdot
.36558 .13806 Mdot
.36563 .13834 Mdot
.36568 .13862 Mdot
.36573 .1389 Mdot
.36578 .13918 Mdot
.36582 .13946 Mdot
.36587 .13975 Mdot
.36592 .14003 Mdot
.36597 .14031 Mdot
.36601 .14059 Mdot
.36606 .14087 Mdot
.36611 .14115 Mdot
.36616 .14143 Mdot
.3662 .14172 Mdot
.36625 .142 Mdot
.3663 .14228 Mdot
.36635 .14256 Mdot
.36639 .14284 Mdot
.36644 .14312 Mdot
.36649 .1434 Mdot
.36654 .14369 Mdot
.36658 .14397 Mdot
.36663 .14425 Mdot
.36668 .14453 Mdot
.36673 .14482 Mdot
.36678 .1451 Mdot
.36682 .14538 Mdot
.36687 .14567 Mdot
.36692 .14595 Mdot
.36697 .14624 Mdot
.36701 .14652 Mdot
.36706 .14681 Mdot
.36711 .1471 Mdot
.36716 .14739 Mdot
.3672 .14767 Mdot
.36725 .14796 Mdot
.3673 .14825 Mdot
.36735 .14854 Mdot
.36739 .14883 Mdot
.36744 .14912 Mdot
.36749 .14941 Mdot
.36754 .1497 Mdot
.36758 .15 Mdot
.36763 .15029 Mdot
.36768 .15058 Mdot
.36773 .15087 Mdot
.36778 .15116 Mdot
.36782 .15145 Mdot
.36787 .15175 Mdot
.36792 .15205 Mdot
.36797 .15234 Mdot
.36801 .15264 Mdot
.36806 .15293 Mdot
.36811 .15323 Mdot
.36816 .15353 Mdot
.3682 .15383 Mdot
.36825 .15413 Mdot
.3683 .15444 Mdot
.36835 .15475 Mdot
.36839 .15505 Mdot
.36844 .15536 Mdot
.36849 .15566 Mdot
.36854 .15597 Mdot
.36858 .15627 Mdot
.36863 .15657 Mdot
.36868 .15687 Mdot
.36873 .15718 Mdot
.36878 .15748 Mdot
.36882 .15779 Mdot
.36887 .15809 Mdot
.36892 .1584 Mdot
.36897 .1587 Mdot
.36901 .15901 Mdot
.36906 .15932 Mdot
.36911 .15963 Mdot
.36916 .15993 Mdot
.3692 .16024 Mdot
.36925 .16055 Mdot
.3693 .16086 Mdot
.36935 .16117 Mdot
.36939 .16148 Mdot
.36944 .16179 Mdot
.36949 .1621 Mdot
.36954 .16241 Mdot
.36958 .16272 Mdot
.36963 .16302 Mdot
.36968 .16333 Mdot
.36973 .16365 Mdot
.36977 .16396 Mdot
.36982 .16427 Mdot
.36987 .16459 Mdot
.36992 .1649 Mdot
.36997 .16521 Mdot
.37001 .16552 Mdot
.37006 .16583 Mdot
.37011 .16614 Mdot
.37016 .16645 Mdot
.3702 .16676 Mdot
.37025 .16707 Mdot
.3703 .16739 Mdot
.37035 .1677 Mdot
.37039 .16801 Mdot
.37044 .16833 Mdot
.37049 .16864 Mdot
.37054 .16895 Mdot
.37058 .16926 Mdot
.37063 .16957 Mdot
.37068 .16988 Mdot
.37073 .1702 Mdot
.37077 .17051 Mdot
.37082 .17082 Mdot
.37087 .17114 Mdot
.37092 .17146 Mdot
.37097 .17177 Mdot
.37101 .17208 Mdot
.37106 .1724 Mdot
.37111 .17271 Mdot
.37116 .17303 Mdot
.3712 .17335 Mdot
.37125 .17367 Mdot
.3713 .17398 Mdot
.37135 .1743 Mdot
.37139 .17463 Mdot
.37144 .17495 Mdot
.37149 .17528 Mdot
.37154 .1756 Mdot
.37158 .17593 Mdot
.37163 .17625 Mdot
.37168 .17658 Mdot
.37173 .17691 Mdot
.37177 .17724 Mdot
.37182 .17758 Mdot
.37187 .17792 Mdot
.37192 .17826 Mdot
.37197 .17859 Mdot
.37201 .17894 Mdot
.37206 .17928 Mdot
.37211 .17962 Mdot
.37216 .17997 Mdot
.3722 .18031 Mdot
.37225 .18065 Mdot
.3723 .181 Mdot
.37235 .18134 Mdot
.37239 .18168 Mdot
.37244 .18203 Mdot
.37249 .18237 Mdot
.37254 .18271 Mdot
.37258 .18306 Mdot
.37263 .1834 Mdot
.37268 .18375 Mdot
.37273 .18409 Mdot
.37277 .18444 Mdot
.37282 .18479 Mdot
.37287 .18513 Mdot
.37292 .18548 Mdot
.37297 .18584 Mdot
.37301 .18619 Mdot
.37306 .18654 Mdot
.37311 .1869 Mdot
.37316 .18725 Mdot
.3732 .18761 Mdot
.37325 .18796 Mdot
.3733 .18831 Mdot
.37335 .18867 Mdot
.37339 .18902 Mdot
.37344 .18938 Mdot
.37349 .18973 Mdot
.37354 .19009 Mdot
.37358 .19044 Mdot
.37363 .19079 Mdot
.37368 .19114 Mdot
.37373 .19149 Mdot
.37377 .19183 Mdot
.37382 .19218 Mdot
.37387 .19253 Mdot
.37392 .19288 Mdot
.37396 .19322 Mdot
.37401 .19356 Mdot
.37406 .1939 Mdot
.37411 .19424 Mdot
.37416 .19458 Mdot
.3742 .19492 Mdot
.37425 .19526 Mdot
.3743 .19559 Mdot
.37435 .19593 Mdot
.37439 .19626 Mdot
.37444 .19659 Mdot
.37449 .19692 Mdot
.37454 .19725 Mdot
.37458 .19758 Mdot
.37463 .19791 Mdot
.37468 .19824 Mdot
.37473 .19857 Mdot
.37477 .1989 Mdot
.37482 .19923 Mdot
.37487 .19956 Mdot
.37492 .19989 Mdot
.37496 .20021 Mdot
.37501 .20054 Mdot
.37506 .20087 Mdot
.37511 .2012 Mdot
.37516 .20154 Mdot
.3752 .20187 Mdot
.37525 .2022 Mdot
.3753 .20253 Mdot
.37535 .20286 Mdot
.37539 .20319 Mdot
.37544 .20352 Mdot
.37549 .20385 Mdot
.37554 .20419 Mdot
.37558 .20452 Mdot
.37563 .20486 Mdot
.37568 .20519 Mdot
.37573 .20553 Mdot
.37577 .20587 Mdot
.37582 .20622 Mdot
.37587 .20656 Mdot
.37592 .2069 Mdot
.37596 .20724 Mdot
.37601 .20757 Mdot
.37606 .20791 Mdot
.37611 .20825 Mdot
.37616 .20859 Mdot
.3762 .20893 Mdot
.37625 .20927 Mdot
.3763 .20961 Mdot
.37635 .20996 Mdot
.37639 .2103 Mdot
.37644 .21064 Mdot
.37649 .21098 Mdot
.37654 .21133 Mdot
.37658 .21167 Mdot
.37663 .21202 Mdot
.37668 .21237 Mdot
.37673 .21272 Mdot
.37677 .21307 Mdot
.37682 .21341 Mdot
.37687 .21375 Mdot
.37692 .2141 Mdot
.37696 .21444 Mdot
.37701 .21479 Mdot
.37706 .21513 Mdot
.37711 .21547 Mdot
.37716 .21581 Mdot
.3772 .21615 Mdot
.37725 .21649 Mdot
.3773 .21682 Mdot
.37735 .21716 Mdot
.37739 .2175 Mdot
.37744 .21783 Mdot
.37749 .21817 Mdot
.37754 .21851 Mdot
.37758 .21884 Mdot
.37763 .21918 Mdot
.37768 .21952 Mdot
.37773 .21985 Mdot
.37777 .22019 Mdot
.37782 .22053 Mdot
.37787 .22086 Mdot
.37792 .2212 Mdot
.37796 .22154 Mdot
.37801 .22187 Mdot
.37806 .22221 Mdot
.37811 .22255 Mdot
.37816 .22289 Mdot
.3782 .22322 Mdot
.37825 .22356 Mdot
.3783 .2239 Mdot
.37835 .22424 Mdot
.37839 .22458 Mdot
.37844 .22492 Mdot
.37849 .22526 Mdot
.37854 .2256 Mdot
.37858 .22595 Mdot
.37863 .22629 Mdot
.37868 .22663 Mdot
.37873 .22697 Mdot
.37877 .22732 Mdot
.37882 .22766 Mdot
.37887 .228 Mdot
.37892 .22835 Mdot
.37896 .22869 Mdot
.37901 .22903 Mdot
.37906 .22937 Mdot
.37911 .22972 Mdot
.37915 .23006 Mdot
.3792 .2304 Mdot
.37925 .23075 Mdot
.3793 .23109 Mdot
.37935 .23143 Mdot
.37939 .23177 Mdot
.37944 .23212 Mdot
.37949 .23246 Mdot
.37954 .23281 Mdot
.37958 .23316 Mdot
.37963 .23351 Mdot
.37968 .23385 Mdot
.37973 .2342 Mdot
.37977 .23455 Mdot
.37982 .2349 Mdot
.37987 .23525 Mdot
.37992 .2356 Mdot
.37996 .23595 Mdot
.38001 .23629 Mdot
.38006 .23664 Mdot
.38011 .23698 Mdot
.38015 .23733 Mdot
.3802 .23768 Mdot
.38025 .23803 Mdot
.3803 .23838 Mdot
.38035 .23873 Mdot
.38039 .23908 Mdot
.38044 .23943 Mdot
.38049 .23978 Mdot
.38054 .24013 Mdot
.38058 .24048 Mdot
.38063 .24082 Mdot
.38068 .24117 Mdot
.38073 .24153 Mdot
.38077 .24188 Mdot
.38082 .24223 Mdot
.38087 .24259 Mdot
.38092 .24294 Mdot
.38096 .2433 Mdot
.38101 .24365 Mdot
.38106 .24401 Mdot
.38111 .24437 Mdot
.38115 .24473 Mdot
.3812 .24509 Mdot
.38125 .24545 Mdot
.3813 .2458 Mdot
.38135 .24616 Mdot
.38139 .24651 Mdot
.38144 .24686 Mdot
.38149 .24722 Mdot
.38154 .24757 Mdot
.38158 .24792 Mdot
.38163 .24827 Mdot
.38168 .24862 Mdot
.38173 .24897 Mdot
.38177 .24931 Mdot
.38182 .24966 Mdot
.38187 .25001 Mdot
.38192 .25035 Mdot
.38196 .25069 Mdot
.38201 .25104 Mdot
.38206 .25138 Mdot
.38211 .25172 Mdot
.38215 .25207 Mdot
.3822 .25241 Mdot
.38225 .25276 Mdot
.3823 .25311 Mdot
.38235 .25346 Mdot
.38239 .25381 Mdot
.38244 .25416 Mdot
.38249 .25452 Mdot
.38254 .25488 Mdot
.38258 .25523 Mdot
.38263 .25559 Mdot
.38268 .25595 Mdot
.38273 .2563 Mdot
.38277 .25666 Mdot
.38282 .25702 Mdot
.38287 .25737 Mdot
.38292 .25773 Mdot
.38296 .25809 Mdot
.38301 .25845 Mdot
.38306 .25881 Mdot
.38311 .25917 Mdot
.38315 .25952 Mdot
.3832 .25988 Mdot
.38325 .26024 Mdot
.3833 .26059 Mdot
.38334 .26095 Mdot
.38339 .26131 Mdot
.38344 .26168 Mdot
.38349 .26204 Mdot
.38354 .26241 Mdot
.38358 .26278 Mdot
.38363 .26314 Mdot
.38368 .26351 Mdot
.38373 .26387 Mdot
.38377 .26424 Mdot
.38382 .2646 Mdot
.38387 .26496 Mdot
.38392 .26532 Mdot
.38396 .26568 Mdot
.38401 .26604 Mdot
.38406 .26641 Mdot
.38411 .26677 Mdot
.38415 .26713 Mdot
.3842 .2675 Mdot
.38425 .26786 Mdot
.3843 .26822 Mdot
.38434 .26858 Mdot
.38439 .26894 Mdot
.38444 .2693 Mdot
.38449 .26967 Mdot
.38454 .27003 Mdot
.38458 .2704 Mdot
.38463 .27076 Mdot
.38468 .27113 Mdot
.38473 .27149 Mdot
.38477 .27186 Mdot
.38482 .27223 Mdot
.38487 .2726 Mdot
.38492 .27297 Mdot
.38496 .27333 Mdot
.38501 .2737 Mdot
.38506 .27407 Mdot
.38511 .27444 Mdot
.38515 .2748 Mdot
.3852 .27517 Mdot
.38525 .27553 Mdot
.3853 .2759 Mdot
.38534 .27627 Mdot
.38539 .27663 Mdot
.38544 .277 Mdot
.38549 .27737 Mdot
.38554 .27773 Mdot
.38558 .2781 Mdot
.38563 .27846 Mdot
.38568 .27883 Mdot
.38573 .2792 Mdot
.38577 .27957 Mdot
.38582 .27993 Mdot
.38587 .2803 Mdot
.38592 .28067 Mdot
.38596 .28104 Mdot
.38601 .28141 Mdot
.38606 .28179 Mdot
.38611 .28216 Mdot
.38615 .28254 Mdot
.3862 .28291 Mdot
.38625 .28329 Mdot
.3863 .28367 Mdot
.38634 .28404 Mdot
.38639 .28442 Mdot
.38644 .2848 Mdot
.38649 .28517 Mdot
.38654 .28555 Mdot
.38658 .28592 Mdot
.38663 .28629 Mdot
.38668 .28667 Mdot
.38673 .28705 Mdot
.38677 .28742 Mdot
.38682 .2878 Mdot
.38687 .28818 Mdot
.38692 .28855 Mdot
.38696 .28892 Mdot
.38701 .28929 Mdot
.38706 .28966 Mdot
.38711 .29003 Mdot
.38715 .29039 Mdot
.3872 .29076 Mdot
.38725 .29113 Mdot
.3873 .29149 Mdot
.38734 .29186 Mdot
.38739 .29223 Mdot
.38744 .2926 Mdot
.38749 .29297 Mdot
.38754 .29334 Mdot
.38758 .2937 Mdot
.38763 .29408 Mdot
.38768 .29444 Mdot
.38773 .29481 Mdot
.38777 .29518 Mdot
.38782 .29554 Mdot
.38787 .29591 Mdot
.38792 .29628 Mdot
.38796 .29664 Mdot
.38801 .29701 Mdot
.38806 .29737 Mdot
.38811 .29773 Mdot
.38815 .2981 Mdot
.3882 .29847 Mdot
.38825 .29883 Mdot
.3883 .2992 Mdot
.38834 .29957 Mdot
.38839 .29993 Mdot
.38844 .3003 Mdot
.38849 .30067 Mdot
.38853 .30103 Mdot
.38858 .3014 Mdot
.38863 .30177 Mdot
.38868 .30214 Mdot
.38873 .30252 Mdot
.38877 .30288 Mdot
.38882 .30326 Mdot
.38887 .30363 Mdot
.38892 .304 Mdot
.38896 .30437 Mdot
.38901 .30475 Mdot
.38906 .30512 Mdot
.38911 .3055 Mdot
.38915 .30588 Mdot
.3892 .30626 Mdot
.38925 .30664 Mdot
.3893 .30701 Mdot
.38934 .30739 Mdot
.38939 .30776 Mdot
.38944 .30814 Mdot
.38949 .30852 Mdot
.38953 .3089 Mdot
.38958 .30928 Mdot
.38963 .30966 Mdot
.38968 .31004 Mdot
.38973 .31041 Mdot
.38977 .31079 Mdot
.38982 .31117 Mdot
.38987 .31154 Mdot
.38992 .31192 Mdot
.38996 .31231 Mdot
.39001 .31269 Mdot
.39006 .31307 Mdot
.39011 .31345 Mdot
.39015 .31384 Mdot
.3902 .31422 Mdot
.39025 .31461 Mdot
.3903 .31499 Mdot
.39034 .31537 Mdot
.39039 .31576 Mdot
.39044 .31614 Mdot
.39049 .31653 Mdot
.39053 .31691 Mdot
.39058 .31729 Mdot
.39063 .31767 Mdot
.39068 .31806 Mdot
.39073 .31844 Mdot
.39077 .31882 Mdot
.39082 .3192 Mdot
.39087 .31958 Mdot
.39092 .31997 Mdot
.39096 .32035 Mdot
.39101 .32073 Mdot
.39106 .32111 Mdot
.39111 .32149 Mdot
.39115 .32188 Mdot
.3912 .32226 Mdot
.39125 .32264 Mdot
.3913 .32302 Mdot
.39134 .3234 Mdot
.39139 .32378 Mdot
.39144 .32416 Mdot
.39149 .32454 Mdot
.39153 .32492 Mdot
.39158 .32529 Mdot
.39163 .32567 Mdot
.39168 .32605 Mdot
.39173 .32643 Mdot
.39177 .32681 Mdot
.39182 .32719 Mdot
.39187 .32757 Mdot
.39192 .32794 Mdot
.39196 .32832 Mdot
.39201 .3287 Mdot
.39206 .32908 Mdot
.39211 .32946 Mdot
.39215 .32984 Mdot
.3922 .33022 Mdot
.39225 .33059 Mdot
.3923 .33097 Mdot
.39234 .33135 Mdot
.39239 .33173 Mdot
.39244 .33211 Mdot
.39249 .33249 Mdot
.39253 .33287 Mdot
.39258 .33325 Mdot
.39263 .33363 Mdot
.39268 .33401 Mdot
.39273 .33439 Mdot
.39277 .33477 Mdot
.39282 .33514 Mdot
.39287 .33552 Mdot
.39292 .33589 Mdot
.39296 .33626 Mdot
.39301 .33663 Mdot
.39306 .337 Mdot
.39311 .33737 Mdot
.39315 .33774 Mdot
.3932 .3381 Mdot
.39325 .33848 Mdot
.3933 .33885 Mdot
.39334 .33922 Mdot
.39339 .33959 Mdot
.39344 .33995 Mdot
.39349 .34032 Mdot
.39353 .3407 Mdot
.39358 .34107 Mdot
.39363 .34145 Mdot
.39368 .34182 Mdot
.39372 .34219 Mdot
.39377 .34257 Mdot
.39382 .34295 Mdot
.39387 .34333 Mdot
.39392 .3437 Mdot
.39396 .34408 Mdot
.39401 .34446 Mdot
.39406 .34484 Mdot
.39411 .34522 Mdot
.39415 .34559 Mdot
.3942 .34597 Mdot
.39425 .34635 Mdot
.3943 .34673 Mdot
.39434 .34711 Mdot
.39439 .34748 Mdot
.39444 .34785 Mdot
.39449 .34823 Mdot
.39453 .34859 Mdot
.39458 .34896 Mdot
.39463 .34933 Mdot
.39468 .3497 Mdot
.39472 .35006 Mdot
.39477 .35043 Mdot
.39482 .35079 Mdot
.39487 .35116 Mdot
.39492 .35152 Mdot
.39496 .35189 Mdot
.39501 .35225 Mdot
.39506 .35262 Mdot
.39511 .35299 Mdot
.39515 .35335 Mdot
.3952 .35372 Mdot
.39525 .35408 Mdot
.3953 .35444 Mdot
.39534 .35481 Mdot
.39539 .35517 Mdot
.39544 .35553 Mdot
.39549 .3559 Mdot
.39553 .35626 Mdot
.39558 .35663 Mdot
.39563 .35699 Mdot
.39568 .35736 Mdot
.39572 .35772 Mdot
.39577 .35809 Mdot
.39582 .35846 Mdot
.39587 .35883 Mdot
.39592 .3592 Mdot
.39596 .35957 Mdot
.39601 .35994 Mdot
.39606 .36031 Mdot
.39611 .36069 Mdot
.39615 .36105 Mdot
.3962 .36142 Mdot
.39625 .36179 Mdot
.3963 .36216 Mdot
.39634 .36253 Mdot
.39639 .3629 Mdot
.39644 .36327 Mdot
.39649 .36364 Mdot
.39653 .364 Mdot
.39658 .36436 Mdot
.39663 .36472 Mdot
.39668 .36508 Mdot
.39672 .36544 Mdot
.39677 .3658 Mdot
.39682 .36615 Mdot
.39687 .36651 Mdot
.39692 .36687 Mdot
.39696 .36723 Mdot
.39701 .36759 Mdot
.39706 .36795 Mdot
.39711 .36831 Mdot
.39715 .36868 Mdot
.3972 .36904 Mdot
.39725 .36941 Mdot
.3973 .36978 Mdot
.39734 .37014 Mdot
.39739 .37051 Mdot
.39744 .37088 Mdot
.39749 .37125 Mdot
.39753 .37161 Mdot
.39758 .37198 Mdot
.39763 .37235 Mdot
.39768 .37272 Mdot
.39772 .37309 Mdot
.39777 .37346 Mdot
.39782 .37383 Mdot
.39787 .37419 Mdot
.39791 .37456 Mdot
.39796 .37493 Mdot
.39801 .3753 Mdot
.39806 .37567 Mdot
.39811 .37604 Mdot
.39815 .37641 Mdot
.3982 .37678 Mdot
.39825 .37715 Mdot
.3983 .37751 Mdot
.39834 .37787 Mdot
.39839 .37824 Mdot
.39844 .3786 Mdot
.39849 .37897 Mdot
.39853 .37933 Mdot
.39858 .37969 Mdot
.39863 .38006 Mdot
.39868 .38042 Mdot
.39872 .38078 Mdot
.39877 .38114 Mdot
.39882 .38149 Mdot
.39887 .38185 Mdot
.39891 .3822 Mdot
.39896 .38256 Mdot
.39901 .38292 Mdot
.39906 .38327 Mdot
.39911 .38362 Mdot
.39915 .38397 Mdot
.3992 .38431 Mdot
.39925 .38466 Mdot
.3993 .38501 Mdot
.39934 .38536 Mdot
.39939 .38571 Mdot
.39944 .38606 Mdot
.39949 .38641 Mdot
.39953 .38676 Mdot
.39958 .38711 Mdot
.39963 .38747 Mdot
.39968 .38782 Mdot
.39972 .38818 Mdot
.39977 .38853 Mdot
.39982 .38889 Mdot
.39987 .38924 Mdot
.39991 .38959 Mdot
.39996 .38994 Mdot
.40001 .39029 Mdot
.40006 .39064 Mdot
.40011 .39099 Mdot
.40015 .39134 Mdot
.4002 .39168 Mdot
.40025 .39203 Mdot
.4003 .39238 Mdot
.40034 .39273 Mdot
.40039 .39308 Mdot
.40044 .39343 Mdot
.40049 .39378 Mdot
.40053 .39413 Mdot
.40058 .39447 Mdot
.40063 .39482 Mdot
.40068 .39517 Mdot
.40072 .39551 Mdot
.40077 .39586 Mdot
.40082 .3962 Mdot
.40087 .39655 Mdot
.40091 .3969 Mdot
.40096 .39725 Mdot
.40101 .3976 Mdot
.40106 .39795 Mdot
.40111 .3983 Mdot
.40115 .39864 Mdot
.4012 .39899 Mdot
.40125 .39934 Mdot
.4013 .39969 Mdot
.40134 .40003 Mdot
.40139 .40038 Mdot
.40144 .40072 Mdot
.40149 .40107 Mdot
.40153 .40141 Mdot
.40158 .40176 Mdot
.40163 .4021 Mdot
.40168 .40245 Mdot
.40172 .40279 Mdot
.40177 .40314 Mdot
.40182 .40348 Mdot
.40187 .40383 Mdot
.40191 .40418 Mdot
.40196 .40453 Mdot
.40201 .40488 Mdot
.40206 .40523 Mdot
.40211 .40558 Mdot
.40215 .40593 Mdot
.4022 .40628 Mdot
.40225 .40663 Mdot
.4023 .40698 Mdot
.40234 .40733 Mdot
.40239 .40768 Mdot
.40244 .40803 Mdot
.40249 .40838 Mdot
.40253 .40872 Mdot
.40258 .40907 Mdot
.40263 .40942 Mdot
.40268 .40977 Mdot
.40272 .41012 Mdot
.40277 .41047 Mdot
.40282 .41082 Mdot
.40287 .41116 Mdot
.40291 .41151 Mdot
.40296 .41185 Mdot
.40301 .4122 Mdot
.40306 .41254 Mdot
.4031 .41288 Mdot
.40315 .41322 Mdot
.4032 .41357 Mdot
.40325 .41391 Mdot
.4033 .41424 Mdot
.40334 .41458 Mdot
.40339 .41492 Mdot
.40344 .41526 Mdot
.40349 .4156 Mdot
.40353 .41594 Mdot
.40358 .41628 Mdot
.40363 .41662 Mdot
.40368 .41696 Mdot
.40372 .4173 Mdot
.40377 .41764 Mdot
.40382 .41799 Mdot
.40387 .41833 Mdot
.40391 .41867 Mdot
.40396 .41901 Mdot
.40401 .41935 Mdot
.40406 .41969 Mdot
.4041 .42003 Mdot
.40415 .42037 Mdot
.4042 .42071 Mdot
.40425 .42104 Mdot
.4043 .42138 Mdot
.40434 .42172 Mdot
.40439 .42206 Mdot
.40444 .4224 Mdot
.40449 .42273 Mdot
.40453 .42307 Mdot
.40458 .42341 Mdot
.40463 .42374 Mdot
.40468 .42408 Mdot
.40472 .42441 Mdot
.40477 .42475 Mdot
.40482 .42509 Mdot
.40487 .42543 Mdot
.40491 .42577 Mdot
.40496 .42611 Mdot
.40501 .42645 Mdot
.40506 .42679 Mdot
.4051 .42714 Mdot
.40515 .42748 Mdot
.4052 .42782 Mdot
.40525 .42816 Mdot
.4053 .4285 Mdot
.40534 .42884 Mdot
.40539 .42918 Mdot
.40544 .42952 Mdot
.40549 .42985 Mdot
.40553 .43019 Mdot
.40558 .43053 Mdot
.40563 .43087 Mdot
.40568 .4312 Mdot
.40572 .43153 Mdot
.40577 .43187 Mdot
.40582 .4322 Mdot
.40587 .43253 Mdot
.40591 .43286 Mdot
.40596 .43319 Mdot
.40601 .43352 Mdot
.40606 .43386 Mdot
.4061 .43419 Mdot
.40615 .43452 Mdot
.4062 .43486 Mdot
.40625 .43519 Mdot
.4063 .43553 Mdot
.40634 .43586 Mdot
.40639 .43619 Mdot
.40644 .43653 Mdot
.40649 .43686 Mdot
.40653 .43719 Mdot
.40658 .43752 Mdot
.40663 .43785 Mdot
.40668 .43818 Mdot
.40672 .43852 Mdot
.40677 .43885 Mdot
.40682 .43919 Mdot
.40687 .43952 Mdot
.40691 .43986 Mdot
.40696 .44019 Mdot
.40701 .44052 Mdot
.40706 .44086 Mdot
.4071 .44119 Mdot
.40715 .44152 Mdot
.4072 .44186 Mdot
.40725 .44219 Mdot
.40729 .44253 Mdot
.40734 .44287 Mdot
.40739 .4432 Mdot
.40744 .44354 Mdot
.40749 .44388 Mdot
.40753 .44421 Mdot
.40758 .44455 Mdot
.40763 .44489 Mdot
.40768 .44522 Mdot
.40772 .44556 Mdot
.40777 .4459 Mdot
.40782 .44623 Mdot
.40787 .44657 Mdot
.40791 .44691 Mdot
.40796 .44725 Mdot
.40801 .44758 Mdot
.40806 .44792 Mdot
.4081 .44826 Mdot
.40815 .44859 Mdot
.4082 .44893 Mdot
.40825 .44928 Mdot
.40829 .44962 Mdot
.40834 .44996 Mdot
.40839 .4503 Mdot
.40844 .45065 Mdot
.40849 .45099 Mdot
.40853 .45133 Mdot
.40858 .45167 Mdot
.40863 .45201 Mdot
.40868 .45235 Mdot
.40872 .45268 Mdot
.40877 .45301 Mdot
.40882 .45334 Mdot
.40887 .45367 Mdot
.40891 .454 Mdot
.40896 .45433 Mdot
.40901 .45467 Mdot
.40906 .455 Mdot
.4091 .45533 Mdot
.40915 .45566 Mdot
.4092 .45599 Mdot
.40925 .45631 Mdot
.40929 .45664 Mdot
.40934 .45697 Mdot
.40939 .45729 Mdot
.40944 .45761 Mdot
.40949 .45793 Mdot
.40953 .45825 Mdot
.40958 .45857 Mdot
.40963 .45889 Mdot
.40968 .45921 Mdot
.40972 .45953 Mdot
.40977 .45985 Mdot
.40982 .46018 Mdot
.40987 .46051 Mdot
.40991 .46083 Mdot
.40996 .46116 Mdot
.41001 .46149 Mdot
.41006 .46181 Mdot
.4101 .46214 Mdot
.41015 .46247 Mdot
.4102 .46279 Mdot
.41025 .46312 Mdot
.41029 .46344 Mdot
.41034 .46377 Mdot
.41039 .46409 Mdot
.41044 .46441 Mdot
.41049 .46474 Mdot
.41053 .46506 Mdot
.41058 .46538 Mdot
.41063 .4657 Mdot
.41068 .46602 Mdot
.41072 .46633 Mdot
.41077 .46665 Mdot
.41082 .46696 Mdot
.41087 .46727 Mdot
.41091 .46759 Mdot
.41096 .4679 Mdot
.41101 .46822 Mdot
.41106 .46853 Mdot
.4111 .46884 Mdot
.41115 .46915 Mdot
.4112 .46947 Mdot
.41125 .46978 Mdot
.41129 .4701 Mdot
.41134 .47042 Mdot
.41139 .47073 Mdot
.41144 .47105 Mdot
.41149 .47137 Mdot
.41153 .47168 Mdot
.41158 .472 Mdot
.41163 .47232 Mdot
.41168 .47263 Mdot
.41172 .47295 Mdot
.41177 .47326 Mdot
.41182 .47357 Mdot
.41187 .47388 Mdot
.41191 .47419 Mdot
.41196 .4745 Mdot
.41201 .47482 Mdot
.41206 .47513 Mdot
.4121 .47544 Mdot
.41215 .47575 Mdot
.4122 .47606 Mdot
.41225 .47637 Mdot
.41229 .47668 Mdot
.41234 .47699 Mdot
.41239 .4773 Mdot
.41244 .47761 Mdot
.41248 .47791 Mdot
.41253 .47822 Mdot
.41258 .47852 Mdot
.41263 .47883 Mdot
.41268 .47913 Mdot
.41272 .47943 Mdot
.41277 .47973 Mdot
.41282 .48004 Mdot
.41287 .48034 Mdot
.41291 .48065 Mdot
.41296 .48096 Mdot
.41301 .48127 Mdot
.41306 .48157 Mdot
.4131 .48188 Mdot
.41315 .48219 Mdot
.4132 .48249 Mdot
.41325 .48281 Mdot
.41329 .48312 Mdot
.41334 .48343 Mdot
.41339 .48374 Mdot
.41344 .48405 Mdot
.41348 .48436 Mdot
.41353 .48467 Mdot
.41358 .48498 Mdot
.41363 .48529 Mdot
.41368 .4856 Mdot
.41372 .48591 Mdot
.41377 .48622 Mdot
.41382 .48654 Mdot
.41387 .48685 Mdot
.41391 .48717 Mdot
.41396 .48748 Mdot
.41401 .4878 Mdot
.41406 .48812 Mdot
.4141 .48843 Mdot
.41415 .48875 Mdot
.4142 .48907 Mdot
.41425 .48939 Mdot
.41429 .48971 Mdot
.41434 .49002 Mdot
.41439 .49034 Mdot
.41444 .49066 Mdot
.41448 .49098 Mdot
.41453 .49129 Mdot
.41458 .4916 Mdot
.41463 .49192 Mdot
.41468 .49223 Mdot
.41472 .49253 Mdot
.41477 .49284 Mdot
.41482 .49315 Mdot
.41487 .49346 Mdot
.41491 .49376 Mdot
.41496 .49407 Mdot
.41501 .49438 Mdot
.41506 .49469 Mdot
.4151 .495 Mdot
.41515 .4953 Mdot
.4152 .49561 Mdot
.41525 .49591 Mdot
.41529 .49622 Mdot
.41534 .49652 Mdot
.41539 .49682 Mdot
.41544 .49713 Mdot
.41548 .49742 Mdot
.41553 .49773 Mdot
.41558 .49803 Mdot
.41563 .49833 Mdot
.41568 .49863 Mdot
.41572 .49893 Mdot
.41577 .49923 Mdot
.41582 .49953 Mdot
.41587 .49984 Mdot
.41591 .50013 Mdot
.41596 .50043 Mdot
.41601 .50073 Mdot
.41606 .50103 Mdot
.4161 .50132 Mdot
.41615 .50162 Mdot
.4162 .50192 Mdot
.41625 .50221 Mdot
.41629 .50251 Mdot
.41634 .50281 Mdot
.41639 .50311 Mdot
.41644 .50341 Mdot
.41648 .50371 Mdot
.41653 .50402 Mdot
.41658 .50432 Mdot
.41663 .50463 Mdot
.41667 .50493 Mdot
.41672 .50523 Mdot
.41677 .50554 Mdot
.41682 .50584 Mdot
.41687 .50615 Mdot
.41691 .50645 Mdot
.41696 .50675 Mdot
.41701 .50706 Mdot
.41706 .50736 Mdot
.4171 .50766 Mdot
.41715 .50796 Mdot
.4172 .50826 Mdot
.41725 .50856 Mdot
.41729 .50885 Mdot
.41734 .50915 Mdot
.41739 .50944 Mdot
.41744 .50974 Mdot
.41748 .51003 Mdot
.41753 .51033 Mdot
.41758 .51062 Mdot
.41763 .51091 Mdot
.41767 .5112 Mdot
.41772 .51149 Mdot
.41777 .51177 Mdot
.41782 .51206 Mdot
.41787 .51234 Mdot
.41791 .51262 Mdot
.41796 .5129 Mdot
.41801 .51318 Mdot
.41806 .51346 Mdot
.4181 .51374 Mdot
.41815 .51402 Mdot
.4182 .5143 Mdot
.41825 .51458 Mdot
.41829 .51486 Mdot
.41834 .51514 Mdot
.41839 .51543 Mdot
.41844 .51571 Mdot
.41848 .51599 Mdot
.41853 .51627 Mdot
.41858 .51654 Mdot
.41863 .51682 Mdot
.41867 .5171 Mdot
.41872 .51738 Mdot
.41877 .51766 Mdot
.41882 .51794 Mdot
.41887 .51822 Mdot
.41891 .5185 Mdot
.41896 .51878 Mdot
.41901 .51906 Mdot
.41906 .51934 Mdot
.4191 .51961 Mdot
.41915 .51988 Mdot
.4192 .52016 Mdot
.41925 .52043 Mdot
.41929 .52071 Mdot
.41934 .52097 Mdot
.41939 .52124 Mdot
.41944 .52151 Mdot
.41948 .52178 Mdot
.41953 .52204 Mdot
.41958 .52231 Mdot
.41963 .52258 Mdot
.41967 .52284 Mdot
.41972 .52311 Mdot
.41977 .52338 Mdot
.41982 .52365 Mdot
.41987 .52393 Mdot
.41991 .5242 Mdot
.41996 .52447 Mdot
.42001 .52474 Mdot
.42006 .52501 Mdot
.4201 .52528 Mdot
.42015 .52555 Mdot
.4202 .52581 Mdot
.42025 .52607 Mdot
.42029 .52633 Mdot
.42034 .52659 Mdot
.42039 .52684 Mdot
.42044 .5271 Mdot
.42048 .52736 Mdot
.42053 .52761 Mdot
.42058 .52786 Mdot
.42063 .52812 Mdot
.42067 .52838 Mdot
.42072 .52864 Mdot
.42077 .52889 Mdot
.42082 .52915 Mdot
.42087 .5294 Mdot
.42091 .52965 Mdot
.42096 .5299 Mdot
.42101 .53015 Mdot
.42106 .5304 Mdot
.4211 .53064 Mdot
.42115 .53088 Mdot
.4212 .53113 Mdot
.42125 .53137 Mdot
.42129 .53161 Mdot
.42134 .53185 Mdot
.42139 .53209 Mdot
.42144 .53233 Mdot
.42148 .53257 Mdot
.42153 .53281 Mdot
.42158 .53305 Mdot
.42163 .53329 Mdot
.42167 .53353 Mdot
.42172 .53377 Mdot
.42177 .53401 Mdot
.42182 .53425 Mdot
.42186 .53449 Mdot
.42191 .53473 Mdot
.42196 .53497 Mdot
.42201 .53521 Mdot
.42206 .53545 Mdot
.4221 .5357 Mdot
.42215 .53594 Mdot
.4222 .53617 Mdot
.42225 .53641 Mdot
.42229 .53665 Mdot
.42234 .53689 Mdot
.42239 .53713 Mdot
.42244 .53737 Mdot
.42248 .53761 Mdot
.42253 .53785 Mdot
.42258 .53809 Mdot
.42263 .53833 Mdot
.42267 .53857 Mdot
.42272 .53881 Mdot
.42277 .53905 Mdot
.42282 .53929 Mdot
.42286 .53952 Mdot
.42291 .53975 Mdot
.42296 .53997 Mdot
.42301 .5402 Mdot
.42306 .54043 Mdot
.4231 .54066 Mdot
.42315 .54088 Mdot
.4232 .54111 Mdot
.42325 .54133 Mdot
.42329 .54156 Mdot
.42334 .54178 Mdot
.42339 .54201 Mdot
.42344 .54223 Mdot
.42348 .54246 Mdot
.42353 .54268 Mdot
.42358 .5429 Mdot
.42363 .54312 Mdot
.42367 .54334 Mdot
.42372 .54355 Mdot
.42377 .54377 Mdot
.42382 .54399 Mdot
.42386 .54421 Mdot
.42391 .54443 Mdot
.42396 .54465 Mdot
.42401 .54487 Mdot
.42406 .54509 Mdot
.4241 .5453 Mdot
.42415 .54552 Mdot
.4242 .54574 Mdot
.42425 .54596 Mdot
.42429 .54618 Mdot
.42434 .5464 Mdot
.42439 .54662 Mdot
.42444 .54684 Mdot
.42448 .54705 Mdot
.42453 .54727 Mdot
.42458 .54749 Mdot
.42463 .54771 Mdot
.42467 .54793 Mdot
.42472 .54815 Mdot
.42477 .54837 Mdot
.42482 .54859 Mdot
.42486 .5488 Mdot
.42491 .54902 Mdot
.42496 .54923 Mdot
.42501 .54945 Mdot
.42506 .54967 Mdot
.4251 .54988 Mdot
.42515 .5501 Mdot
.4252 .55032 Mdot
.42525 .55053 Mdot
.42529 .55074 Mdot
.42534 .55096 Mdot
.42539 .55117 Mdot
.42544 .55138 Mdot
.42548 .55159 Mdot
.42553 .5518 Mdot
.42558 .55201 Mdot
.42563 .55222 Mdot
.42567 .55243 Mdot
.42572 .55264 Mdot
.42577 .55284 Mdot
.42582 .55304 Mdot
.42586 .55324 Mdot
.42591 .55344 Mdot
.42596 .55364 Mdot
.42601 .55383 Mdot
.42606 .55403 Mdot
.4261 .55422 Mdot
.42615 .55442 Mdot
.4262 .55461 Mdot
.42625 .5548 Mdot
.42629 .55499 Mdot
.42634 .55518 Mdot
.42639 .55536 Mdot
.42644 .55555 Mdot
.42648 .55574 Mdot
.42653 .55593 Mdot
.42658 .55611 Mdot
.42663 .5563 Mdot
.42667 .55648 Mdot
.42672 .55666 Mdot
.42677 .55684 Mdot
.42682 .55702 Mdot
.42686 .5572 Mdot
.42691 .55738 Mdot
.42696 .55755 Mdot
.42701 .55773 Mdot
.42705 .5579 Mdot
.4271 .55807 Mdot
.42715 .55824 Mdot
.4272 .55841 Mdot
.42725 .55858 Mdot
.42729 .55875 Mdot
.42734 .55892 Mdot
.42739 .55909 Mdot
.42744 .55926 Mdot
.42748 .55942 Mdot
.42753 .55959 Mdot
.42758 .55975 Mdot
.42763 .55992 Mdot
.42767 .56008 Mdot
.42772 .56025 Mdot
.42777 .56042 Mdot
.42782 .56058 Mdot
.42786 .56074 Mdot
.42791 .5609 Mdot
.42796 .56107 Mdot
.42801 .56123 Mdot
.42805 .56139 Mdot
.4281 .56155 Mdot
.42815 .56171 Mdot
.4282 .56186 Mdot
.42825 .56201 Mdot
.42829 .56216 Mdot
.42834 .56231 Mdot
.42839 .56245 Mdot
.42844 .5626 Mdot
.42848 .56275 Mdot
.42853 .5629 Mdot
.42858 .56305 Mdot
.42863 .5632 Mdot
.42867 .56334 Mdot
.42872 .56349 Mdot
.42877 .56364 Mdot
.42882 .56379 Mdot
.42886 .56395 Mdot
.42891 .56409 Mdot
.42896 .56424 Mdot
.42901 .56439 Mdot
.42905 .56454 Mdot
.4291 .56468 Mdot
.42915 .56482 Mdot
.4292 .56496 Mdot
.42925 .5651 Mdot
.42929 .56523 Mdot
.42934 .56537 Mdot
.42939 .5655 Mdot
.42944 .56562 Mdot
.42948 .56575 Mdot
.42953 .56588 Mdot
.42958 .566 Mdot
.42963 .56612 Mdot
.42967 .56624 Mdot
.42972 .56636 Mdot
.42977 .56648 Mdot
.42982 .56659 Mdot
.42986 .56671 Mdot
.42991 .56682 Mdot
.42996 .56694 Mdot
.43001 .56705 Mdot
.43005 .56716 Mdot
.4301 .56727 Mdot
.43015 .56738 Mdot
.4302 .56749 Mdot
.43025 .5676 Mdot
.43029 .5677 Mdot
.43034 .5678 Mdot
.43039 .56791 Mdot
.43044 .56801 Mdot
.43048 .56812 Mdot
.43053 .56822 Mdot
.43058 .56832 Mdot
.43063 .56842 Mdot
.43067 .56852 Mdot
.43072 .56861 Mdot
.43077 .56871 Mdot
.43082 .5688 Mdot
.43086 .56889 Mdot
.43091 .56898 Mdot
.43096 .56907 Mdot
.43101 .56915 Mdot
.43105 .56924 Mdot
.4311 .56933 Mdot
.43115 .56942 Mdot
.4312 .56951 Mdot
.43124 .5696 Mdot
.43129 .56968 Mdot
.43134 .56977 Mdot
.43139 .56986 Mdot
.43144 .56995 Mdot
.43148 .57004 Mdot
.43153 .57012 Mdot
.43158 .57021 Mdot
.43163 .57029 Mdot
.43167 .57038 Mdot
.43172 .57046 Mdot
.43177 .57054 Mdot
.43182 .57063 Mdot
.43186 .57071 Mdot
.43191 .5708 Mdot
.43196 .57088 Mdot
.43201 .57097 Mdot
.43205 .57105 Mdot
.4321 .57113 Mdot
.43215 .57121 Mdot
.4322 .57129 Mdot
.43224 .57138 Mdot
.43229 .57146 Mdot
.43234 .57154 Mdot
.43239 .57162 Mdot
.43244 .5717 Mdot
.43248 .57178 Mdot
.43253 .57186 Mdot
.43258 .57194 Mdot
.43263 .57201 Mdot
.43267 .57209 Mdot
.43272 .57216 Mdot
.43277 .57223 Mdot
.43282 .57231 Mdot
.43286 .57238 Mdot
.43291 .57246 Mdot
.43296 .57253 Mdot
.43301 .5726 Mdot
.43305 .57267 Mdot
.4331 .57274 Mdot
.43315 .57282 Mdot
.4332 .57289 Mdot
.43324 .57296 Mdot
.43329 .57303 Mdot
.43334 .5731 Mdot
.43339 .57316 Mdot
.43344 .57323 Mdot
.43348 .5733 Mdot
.43353 .57337 Mdot
.43358 .57344 Mdot
.43363 .5735 Mdot
.43367 .57357 Mdot
.43372 .57363 Mdot
.43377 .57369 Mdot
.43382 .57375 Mdot
.43386 .57381 Mdot
.43391 .57387 Mdot
.43396 .57392 Mdot
.43401 .57398 Mdot
.43405 .57404 Mdot
.4341 .57409 Mdot
.43415 .57415 Mdot
.4342 .5742 Mdot
.43424 .57425 Mdot
.43429 .5743 Mdot
.43434 .57435 Mdot
.43439 .5744 Mdot
.43444 .57444 Mdot
.43448 .57449 Mdot
.43453 .57454 Mdot
.43458 .57458 Mdot
.43463 .57462 Mdot
.43467 .57467 Mdot
.43472 .57471 Mdot
.43477 .57476 Mdot
.43482 .57481 Mdot
.43486 .57485 Mdot
.43491 .5749 Mdot
.43496 .57494 Mdot
.43501 .57499 Mdot
.43505 .57502 Mdot
.4351 .57506 Mdot
.43515 .5751 Mdot
.4352 .57514 Mdot
.43524 .57518 Mdot
.43529 .57521 Mdot
.43534 .57524 Mdot
.43539 .57527 Mdot
.43544 .57529 Mdot
.43548 .57531 Mdot
.43553 .57534 Mdot
.43558 .57536 Mdot
.43563 .57538 Mdot
.43567 .5754 Mdot
.43572 .57541 Mdot
.43577 .57543 Mdot
.43582 .57545 Mdot
.43586 .57546 Mdot
.43591 .57548 Mdot
.43596 .57549 Mdot
.43601 .5755 Mdot
.43605 .57551 Mdot
.4361 .57552 Mdot
.43615 .57553 Mdot
.4362 .57554 Mdot
.43624 .57554 Mdot
.43629 .57554 Mdot
.43634 .57554 Mdot
.43639 .57555 Mdot
.43643 .57554 Mdot
.43648 .57555 Mdot
.43653 .57555 Mdot
.43658 .57555 Mdot
.43663 .57555 Mdot
.43667 .57556 Mdot
.43672 .57555 Mdot
.43677 .57555 Mdot
.43682 .57555 Mdot
.43686 .57556 Mdot
.43691 .57556 Mdot
.43696 .57556 Mdot
.43701 .57556 Mdot
.43705 .57556 Mdot
.4371 .57556 Mdot
.43715 .57556 Mdot
.4372 .57556 Mdot
.43724 .57556 Mdot
.43729 .57556 Mdot
.43734 .57555 Mdot
.43739 .57555 Mdot
.43743 .57555 Mdot
.43748 .57554 Mdot
.43753 .57554 Mdot
.43758 .57553 Mdot
.43763 .57553 Mdot
.43767 .57553 Mdot
.43772 .57552 Mdot
.43777 .57551 Mdot
.43782 .5755 Mdot
.43786 .57549 Mdot
.43791 .57548 Mdot
.43796 .57547 Mdot
.43801 .57546 Mdot
.43805 .57545 Mdot
.4381 .57544 Mdot
.43815 .57543 Mdot
.4382 .57541 Mdot
.43824 .5754 Mdot
.43829 .57538 Mdot
.43834 .57537 Mdot
.43839 .57535 Mdot
.43843 .57534 Mdot
.43848 .57532 Mdot
.43853 .5753 Mdot
.43858 .57529 Mdot
.43863 .57527 Mdot
.43867 .57525 Mdot
.43872 .57524 Mdot
.43877 .57522 Mdot
.43882 .57521 Mdot
.43886 .57519 Mdot
.43891 .57517 Mdot
.43896 .57514 Mdot
.43901 .57512 Mdot
.43905 .5751 Mdot
.4391 .57508 Mdot
.43915 .57506 Mdot
.4392 .57504 Mdot
.43924 .57502 Mdot
.43929 .575 Mdot
.43934 .57498 Mdot
.43939 .57496 Mdot
.43943 .57494 Mdot
.43948 .57492 Mdot
.43953 .57489 Mdot
.43958 .57487 Mdot
.43963 .57484 Mdot
.43967 .57481 Mdot
.43972 .57479 Mdot
.43977 .57476 Mdot
.43982 .57474 Mdot
.43986 .57471 Mdot
.43991 .57469 Mdot
.43996 .57467 Mdot
.44001 .57465 Mdot
.44005 .57463 Mdot
.4401 .57461 Mdot
.44015 .57458 Mdot
.4402 .57456 Mdot
.44024 .57455 Mdot
.44029 .57453 Mdot
.44034 .57451 Mdot
.44039 .57448 Mdot
.44043 .57446 Mdot
.44048 .57444 Mdot
.44053 .57441 Mdot
.44058 .57439 Mdot
.44062 .57437 Mdot
.44067 .57435 Mdot
.44072 .57432 Mdot
.44077 .5743 Mdot
.44082 .57427 Mdot
.44086 .57424 Mdot
.44091 .57421 Mdot
.44096 .57418 Mdot
.44101 .57415 Mdot
.44105 .57412 Mdot
.4411 .57408 Mdot
.44115 .57405 Mdot
.4412 .57402 Mdot
.44124 .57398 Mdot
.44129 .57394 Mdot
.44134 .57391 Mdot
.44139 .57387 Mdot
.44143 .57382 Mdot
.44148 .57378 Mdot
.44153 .57374 Mdot
.44158 .57369 Mdot
.44162 .57365 Mdot
.44167 .57361 Mdot
.44172 .57357 Mdot
.44177 .57354 Mdot
.44182 .5735 Mdot
.44186 .57346 Mdot
.44191 .57342 Mdot
.44196 .57338 Mdot
.44201 .57334 Mdot
.44205 .5733 Mdot
.4421 .57326 Mdot
.44215 .57322 Mdot
.4422 .57318 Mdot
.44224 .57314 Mdot
.44229 .5731 Mdot
.44234 .57306 Mdot
.44239 .57302 Mdot
.44243 .57297 Mdot
.44248 .57293 Mdot
.44253 .57289 Mdot
.44258 .57284 Mdot
.44262 .5728 Mdot
.44267 .57276 Mdot
.44272 .57271 Mdot
.44277 .57267 Mdot
.44282 .57262 Mdot
.44286 .57257 Mdot
.44291 .57252 Mdot
.44296 .57247 Mdot
.44301 .57242 Mdot
.44305 .57237 Mdot
.4431 .57232 Mdot
.44315 .57227 Mdot
.4432 .57222 Mdot
.44324 .57217 Mdot
.44329 .57212 Mdot
.44334 .57207 Mdot
.44339 .57202 Mdot
.44343 .57197 Mdot
.44348 .57192 Mdot
.44353 .57187 Mdot
.44358 .57182 Mdot
.44362 .57177 Mdot
.44367 .57172 Mdot
.44372 .57167 Mdot
.44377 .57161 Mdot
.44382 .57156 Mdot
.44386 .5715 Mdot
.44391 .57145 Mdot
.44396 .57139 Mdot
.44401 .57134 Mdot
.44405 .57129 Mdot
.4441 .57123 Mdot
.44415 .57118 Mdot
.4442 .57112 Mdot
.44424 .57106 Mdot
.44429 .571 Mdot
.44434 .57095 Mdot
.44439 .57089 Mdot
.44443 .57084 Mdot
.44448 .57078 Mdot
.44453 .57073 Mdot
.44458 .57067 Mdot
.44462 .57062 Mdot
.44467 .57057 Mdot
.44472 .57052 Mdot
.44477 .57047 Mdot
.44482 .57042 Mdot
.44486 .57037 Mdot
.44491 .57032 Mdot
.44496 .57027 Mdot
.44501 .57022 Mdot
.44505 .57017 Mdot
.4451 .57011 Mdot
.44515 .57006 Mdot
.4452 .57001 Mdot
.44524 .56995 Mdot
.44529 .56989 Mdot
.44534 .56984 Mdot
.44539 .56978 Mdot
.44543 .56973 Mdot
.44548 .56967 Mdot
.44553 .56961 Mdot
.44558 .56956 Mdot
.44562 .5695 Mdot
.44567 .56945 Mdot
.44572 .56939 Mdot
.44577 .56933 Mdot
.44581 .56928 Mdot
.44586 .56922 Mdot
.44591 .56917 Mdot
.44596 .56911 Mdot
.44601 .56906 Mdot
.44605 .569 Mdot
.4461 .56895 Mdot
.44615 .56889 Mdot
.4462 .56883 Mdot
.44624 .56877 Mdot
.44629 .56871 Mdot
.44634 .56866 Mdot
.44639 .5686 Mdot
.44643 .56854 Mdot
.44648 .56849 Mdot
.44653 .56843 Mdot
.44658 .56838 Mdot
.44662 .56833 Mdot
.44667 .56828 Mdot
.44672 .56822 Mdot
.44677 .56817 Mdot
.44681 .56812 Mdot
.44686 .56807 Mdot
.44691 .56802 Mdot
.44696 .56797 Mdot
.44701 .56792 Mdot
.44705 .56788 Mdot
.4471 .56783 Mdot
.44715 .56778 Mdot
.4472 .56773 Mdot
.44724 .56768 Mdot
.44729 .56763 Mdot
.44734 .56758 Mdot
.44739 .56752 Mdot
.44743 .56747 Mdot
.44748 .56742 Mdot
.44753 .56736 Mdot
.44758 .5673 Mdot
.44762 .56725 Mdot
.44767 .56718 Mdot
.44772 .56713 Mdot
.44777 .56707 Mdot
.44781 .56701 Mdot
.44786 .56694 Mdot
.44791 .56688 Mdot
.44796 .56681 Mdot
.44801 .56675 Mdot
.44805 .56669 Mdot
.4481 .56662 Mdot
.44815 .56656 Mdot
.4482 .5665 Mdot
.44824 .56643 Mdot
.44829 .56636 Mdot
.44834 .5663 Mdot
.44839 .56623 Mdot
.44843 .56615 Mdot
.44848 .56608 Mdot
.44853 .56601 Mdot
.44858 .56594 Mdot
.44862 .56587 Mdot
.44867 .56579 Mdot
.44872 .56572 Mdot
.44877 .56564 Mdot
.44881 .56556 Mdot
.44886 .56549 Mdot
.44891 .56541 Mdot
.44896 .56533 Mdot
.44901 .56525 Mdot
.44905 .56516 Mdot
.4491 .56508 Mdot
.44915 .565 Mdot
.4492 .56492 Mdot
.44924 .56483 Mdot
.44929 .56475 Mdot
.44934 .56466 Mdot
.44939 .56457 Mdot
.44943 .56449 Mdot
.44948 .5644 Mdot
.44953 .56431 Mdot
.44958 .56423 Mdot
.44962 .56415 Mdot
.44967 .56407 Mdot
.44972 .56398 Mdot
.44977 .56389 Mdot
.44981 .56381 Mdot
.44986 .56373 Mdot
.44991 .56364 Mdot
.44996 .56356 Mdot
.45 .56347 Mdot
.45005 .56338 Mdot
.4501 .56329 Mdot
.45015 .5632 Mdot
.4502 .56311 Mdot
.45024 .56301 Mdot
.45029 .56291 Mdot
.45034 .56282 Mdot
.45039 .56272 Mdot
.45043 .56262 Mdot
.45048 .56251 Mdot
.45053 .56241 Mdot
.45058 .56231 Mdot
.45062 .56221 Mdot
.45067 .56211 Mdot
.45072 .56202 Mdot
.45077 .56192 Mdot
.45081 .56182 Mdot
.45086 .56172 Mdot
.45091 .56162 Mdot
.45096 .56152 Mdot
.451 .56142 Mdot
.45105 .56131 Mdot
.4511 .5612 Mdot
.45115 .56109 Mdot
.4512 .56099 Mdot
.45124 .56088 Mdot
.45129 .56077 Mdot
.45134 .56066 Mdot
.45139 .56055 Mdot
.45143 .56044 Mdot
.45148 .56034 Mdot
.45153 .56023 Mdot
.45158 .56012 Mdot
.45162 .56001 Mdot
.45167 .5599 Mdot
.45172 .5598 Mdot
.45177 .55969 Mdot
.45181 .55958 Mdot
.45186 .55947 Mdot
.45191 .55936 Mdot
.45196 .55926 Mdot
.452 .55915 Mdot
.45205 .55905 Mdot
.4521 .55894 Mdot
.45215 .55884 Mdot
.4522 .55873 Mdot
.45224 .55863 Mdot
.45229 .55853 Mdot
.45234 .55842 Mdot
.45239 .55832 Mdot
.45243 .55822 Mdot
.45248 .55812 Mdot
.45253 .55802 Mdot
.45258 .55792 Mdot
.45262 .55781 Mdot
.45267 .55771 Mdot
.45272 .5576 Mdot
.45277 .55749 Mdot
.45281 .55738 Mdot
.45286 .55728 Mdot
.45291 .55717 Mdot
.45296 .55706 Mdot
.453 .55695 Mdot
.45305 .55685 Mdot
.4531 .55674 Mdot
.45315 .55663 Mdot
.4532 .55651 Mdot
.45324 .5564 Mdot
.45329 .55628 Mdot
.45334 .55616 Mdot
.45339 .55604 Mdot
.45343 .55592 Mdot
.45348 .55579 Mdot
.45353 .55567 Mdot
.45358 .55554 Mdot
.45362 .55542 Mdot
.45367 .55529 Mdot
.45372 .55517 Mdot
.45377 .55504 Mdot
.45381 .55491 Mdot
.45386 .55478 Mdot
.45391 .55465 Mdot
.45396 .55453 Mdot
.454 .5544 Mdot
.45405 .55427 Mdot
.4541 .55414 Mdot
.45415 .55401 Mdot
.4542 .55387 Mdot
.45424 .55374 Mdot
.45429 .5536 Mdot
.45434 .55347 Mdot
.45439 .55334 Mdot
.45443 .55321 Mdot
.45448 .55308 Mdot
.45453 .55295 Mdot
.45458 .55281 Mdot
.45462 .55268 Mdot
.45467 .55255 Mdot
.45472 .55241 Mdot
.45477 .55228 Mdot
.45481 .55215 Mdot
.45486 .55201 Mdot
.45491 .55188 Mdot
.45496 .55175 Mdot
.455 .55162 Mdot
.45505 .55149 Mdot
.4551 .55137 Mdot
.45515 .55124 Mdot
.45519 .55111 Mdot
.45524 .55098 Mdot
.45529 .55085 Mdot
.45534 .55072 Mdot
.45539 .55059 Mdot
.45543 .55046 Mdot
.45548 .55033 Mdot
.45553 .5502 Mdot
.45558 .55007 Mdot
.45562 .54994 Mdot
.45567 .5498 Mdot
.45572 .54967 Mdot
.45577 .54953 Mdot
.45581 .54939 Mdot
.45586 .54926 Mdot
.45591 .54912 Mdot
.45596 .54898 Mdot
.456 .54883 Mdot
.45605 .54869 Mdot
.4561 .54854 Mdot
.45615 .5484 Mdot
.45619 .54826 Mdot
.45624 .54811 Mdot
.45629 .54796 Mdot
.45634 .54781 Mdot
.45639 .54766 Mdot
.45643 .54751 Mdot
.45648 .54735 Mdot
.45653 .54719 Mdot
.45658 .54704 Mdot
.45662 .54688 Mdot
.45667 .54672 Mdot
.45672 .54656 Mdot
.45677 .5464 Mdot
.45681 .54624 Mdot
.45686 .54608 Mdot
.45691 .54592 Mdot
.45696 .54576 Mdot
.457 .5456 Mdot
.45705 .54543 Mdot
.4571 .54526 Mdot
.45715 .5451 Mdot
.45719 .54493 Mdot
.45724 .54476 Mdot
.45729 .54459 Mdot
.45734 .54442 Mdot
.45739 .54425 Mdot
.45743 .54408 Mdot
.45748 .54391 Mdot
.45753 .54374 Mdot
.45758 .54356 Mdot
.45762 .54339 Mdot
.45767 .54322 Mdot
.45772 .54304 Mdot
.45777 .54287 Mdot
.45781 .5427 Mdot
.45786 .54253 Mdot
.45791 .54235 Mdot
.45796 .54218 Mdot
.458 .54201 Mdot
.45805 .54183 Mdot
.4581 .54165 Mdot
.45815 .54148 Mdot
.45819 .5413 Mdot
.45824 .54112 Mdot
.45829 .54095 Mdot
.45834 .54077 Mdot
.45839 .5406 Mdot
.45843 .54043 Mdot
.45848 .54026 Mdot
.45853 .54008 Mdot
.45858 .53991 Mdot
.45862 .53973 Mdot
.45867 .53956 Mdot
.45872 .53938 Mdot
.45877 .53921 Mdot
.45881 .53903 Mdot
.45886 .53885 Mdot
.45891 .53867 Mdot
.45896 .5385 Mdot
.459 .53832 Mdot
.45905 .53814 Mdot
.4591 .53796 Mdot
.45915 .53778 Mdot
.45919 .53761 Mdot
.45924 .53743 Mdot
.45929 .53725 Mdot
.45934 .53707 Mdot
.45939 .5369 Mdot
.45943 .53672 Mdot
.45948 .53655 Mdot
.45953 .53637 Mdot
.45958 .5362 Mdot
.45962 .53603 Mdot
.45967 .53585 Mdot
.45972 .53567 Mdot
.45977 .53549 Mdot
.45981 .53532 Mdot
.45986 .53514 Mdot
.45991 .53497 Mdot
.45996 .53479 Mdot
.46 .53462 Mdot
.46005 .53444 Mdot
.4601 .53426 Mdot
.46015 .53408 Mdot
.46019 .5339 Mdot
.46024 .53373 Mdot
.46029 .53354 Mdot
.46034 .53336 Mdot
.46038 .53317 Mdot
.46043 .53299 Mdot
.46048 .53281 Mdot
.46053 .53262 Mdot
.46058 .53244 Mdot
.46062 .53225 Mdot
.46067 .53207 Mdot
.46072 .53188 Mdot
.46077 .53169 Mdot
.46081 .5315 Mdot
.46086 .53131 Mdot
.46091 .53112 Mdot
.46096 .53093 Mdot
.461 .53075 Mdot
.46105 .53056 Mdot
.4611 .53036 Mdot
.46115 .53017 Mdot
.46119 .52998 Mdot
.46124 .52978 Mdot
.46129 .52958 Mdot
.46134 .52939 Mdot
.46138 .52919 Mdot
.46143 .52899 Mdot
.46148 .52879 Mdot
.46153 .52859 Mdot
.46158 .5284 Mdot
.46162 .5282 Mdot
.46167 .528 Mdot
.46172 .5278 Mdot
.46177 .5276 Mdot
.46181 .52739 Mdot
.46186 .52719 Mdot
.46191 .52698 Mdot
.46196 .52678 Mdot
.462 .52658 Mdot
.46205 .52638 Mdot
.4621 .52618 Mdot
.46215 .52598 Mdot
.46219 .52578 Mdot
.46224 .52558 Mdot
.46229 .52538 Mdot
.46234 .52517 Mdot
.46238 .52497 Mdot
.46243 .52477 Mdot
.46248 .52458 Mdot
.46253 .52438 Mdot
.46258 .52419 Mdot
.46262 .52399 Mdot
.46267 .52379 Mdot
.46272 .52359 Mdot
.46277 .52339 Mdot
.46281 .52319 Mdot
.46286 .52299 Mdot
.46291 .5228 Mdot
.46296 .5226 Mdot
.463 .5224 Mdot
.46305 .5222 Mdot
.4631 .522 Mdot
.46315 .52181 Mdot
.46319 .52161 Mdot
.46324 .52142 Mdot
.46329 .52122 Mdot
.46334 .52102 Mdot
.46338 .52083 Mdot
.46343 .52064 Mdot
.46348 .52044 Mdot
.46353 .52024 Mdot
.46358 .52005 Mdot
.46362 .51986 Mdot
.46367 .51966 Mdot
.46372 .51947 Mdot
.46377 .51928 Mdot
.46381 .51908 Mdot
.46386 .51888 Mdot
.46391 .51869 Mdot
.46396 .51849 Mdot
.464 .51828 Mdot
.46405 .51808 Mdot
.4641 .51788 Mdot
.46415 .51768 Mdot
.46419 .51747 Mdot
.46424 .51726 Mdot
.46429 .51706 Mdot
.46434 .51686 Mdot
.46438 .51665 Mdot
.46443 .51645 Mdot
.46448 .51625 Mdot
.46453 .51605 Mdot
.46457 .51585 Mdot
.46462 .51565 Mdot
.46467 .51545 Mdot
.46472 .51525 Mdot
.46477 .51505 Mdot
.46481 .51485 Mdot
.46486 .51466 Mdot
.46491 .51446 Mdot
.46496 .51426 Mdot
.465 .51406 Mdot
.46505 .51387 Mdot
.4651 .51367 Mdot
.46515 .51348 Mdot
.46519 .51329 Mdot
.46524 .51309 Mdot
.46529 .5129 Mdot
.46534 .5127 Mdot
.46538 .51251 Mdot
.46543 .51232 Mdot
.46548 .51213 Mdot
.46553 .51194 Mdot
.46557 .51174 Mdot
.46562 .51155 Mdot
.46567 .51136 Mdot
.46572 .51117 Mdot
.46577 .51097 Mdot
.46581 .51078 Mdot
.46586 .51058 Mdot
.46591 .51038 Mdot
.46596 .51018 Mdot
.466 .50998 Mdot
.46605 .50979 Mdot
.4661 .50959 Mdot
.46615 .50939 Mdot
.46619 .50919 Mdot
.46624 .50898 Mdot
.46629 .50878 Mdot
.46634 .50858 Mdot
.46638 .50837 Mdot
.46643 .50816 Mdot
.46648 .50795 Mdot
.46653 .50775 Mdot
.46657 .50754 Mdot
.46662 .50733 Mdot
.46667 .50712 Mdot
.46672 .5069 Mdot
.46677 .50669 Mdot
.46681 .50647 Mdot
.46686 .50625 Mdot
.46691 .50603 Mdot
.46696 .50581 Mdot
.467 .50559 Mdot
.46705 .50537 Mdot
.4671 .50515 Mdot
.46715 .50493 Mdot
.46719 .50471 Mdot
.46724 .50449 Mdot
.46729 .50427 Mdot
.46734 .50405 Mdot
.46738 .50384 Mdot
.46743 .50362 Mdot
.46748 .50341 Mdot
.46753 .50319 Mdot
.46757 .50298 Mdot
.46762 .50276 Mdot
.46767 .50254 Mdot
.46772 .50233 Mdot
.46777 .50211 Mdot
.46781 .50189 Mdot
.46786 .50168 Mdot
.46791 .50147 Mdot
.46796 .50125 Mdot
.468 .50104 Mdot
.46805 .50082 Mdot
.4681 .50061 Mdot
.46815 .50039 Mdot
.46819 .50018 Mdot
.46824 .49996 Mdot
.46829 .49975 Mdot
.46834 .49953 Mdot
.46838 .49932 Mdot
.46843 .49911 Mdot
.46848 .49889 Mdot
.46853 .49868 Mdot
.46857 .49847 Mdot
.46862 .49825 Mdot
.46867 .49804 Mdot
.46872 .49782 Mdot
.46877 .49761 Mdot
.46881 .4974 Mdot
.46886 .49718 Mdot
.46891 .49697 Mdot
.46896 .49676 Mdot
.469 .49654 Mdot
.46905 .49633 Mdot
.4691 .49611 Mdot
.46915 .4959 Mdot
.46919 .49568 Mdot
.46924 .49547 Mdot
.46929 .49525 Mdot
.46934 .49503 Mdot
.46938 .4948 Mdot
.46943 .49458 Mdot
.46948 .49436 Mdot
.46953 .49414 Mdot
.46957 .49392 Mdot
.46962 .4937 Mdot
.46967 .49347 Mdot
.46972 .49325 Mdot
.46976 .49302 Mdot
.46981 .49279 Mdot
.46986 .49256 Mdot
.46991 .49233 Mdot
.46996 .4921 Mdot
.47 .49186 Mdot
.47005 .49163 Mdot
.4701 .4914 Mdot
.47015 .49117 Mdot
.47019 .49094 Mdot
.47024 .49071 Mdot
.47029 .49048 Mdot
.47034 .49025 Mdot
.47038 .49002 Mdot
.47043 .48979 Mdot
.47048 .48955 Mdot
.47053 .48931 Mdot
.47057 .48907 Mdot
.47062 .48883 Mdot
.47067 .48859 Mdot
.47072 .48836 Mdot
.47076 .48812 Mdot
.47081 .48788 Mdot
.47086 .48764 Mdot
.47091 .48739 Mdot
.47096 .48715 Mdot
.471 .48691 Mdot
.47105 .48667 Mdot
.4711 .48643 Mdot
.47115 .4862 Mdot
.47119 .48596 Mdot
.47124 .48572 Mdot
.47129 .48548 Mdot
.47134 .48524 Mdot
.47138 .485 Mdot
.47143 .48476 Mdot
.47148 .48451 Mdot
.47153 .48426 Mdot
.47157 .48401 Mdot
.47162 .48375 Mdot
.47167 .4835 Mdot
.47172 .48325 Mdot
.47176 .483 Mdot
.47181 .48274 Mdot
.47186 .48249 Mdot
.47191 .48224 Mdot
.47196 .48199 Mdot
.472 .48174 Mdot
.47205 .48149 Mdot
.4721 .48123 Mdot
.47215 .48098 Mdot
.47219 .48073 Mdot
.47224 .48048 Mdot
.47229 .48023 Mdot
.47234 .47998 Mdot
.47238 .47972 Mdot
.47243 .47947 Mdot
.47248 .47922 Mdot
.47253 .47897 Mdot
.47257 .47871 Mdot
.47262 .47846 Mdot
.47267 .47821 Mdot
.47272 .47796 Mdot
.47276 .47771 Mdot
.47281 .47745 Mdot
.47286 .4772 Mdot
.47291 .47694 Mdot
.47296 .47669 Mdot
.473 .47643 Mdot
.47305 .47617 Mdot
.4731 .47591 Mdot
.47315 .47564 Mdot
.47319 .47538 Mdot
.47324 .47512 Mdot
.47329 .47485 Mdot
.47334 .47458 Mdot
.47338 .47432 Mdot
.47343 .47405 Mdot
.47348 .47379 Mdot
.47353 .47352 Mdot
.47357 .47325 Mdot
.47362 .47298 Mdot
.47367 .47272 Mdot
.47372 .47245 Mdot
.47376 .47219 Mdot
.47381 .47192 Mdot
.47386 .47166 Mdot
.47391 .47139 Mdot
.47395 .47112 Mdot
.474 .47085 Mdot
.47405 .47059 Mdot
.4741 .47032 Mdot
.47415 .47005 Mdot
.47419 .46979 Mdot
.47424 .46952 Mdot
.47429 .46926 Mdot
.47434 .46899 Mdot
.47438 .46873 Mdot
.47443 .46846 Mdot
.47448 .4682 Mdot
.47453 .46794 Mdot
.47457 .46767 Mdot
.47462 .46741 Mdot
.47467 .46714 Mdot
.47472 .46688 Mdot
.47476 .46661 Mdot
.47481 .46634 Mdot
.47486 .46607 Mdot
.47491 .46581 Mdot
.47495 .46554 Mdot
.475 .46528 Mdot
.47505 .46501 Mdot
.4751 .46474 Mdot
.47515 .46447 Mdot
.47519 .4642 Mdot
.47524 .46393 Mdot
.47529 .46365 Mdot
.47534 .46338 Mdot
.47538 .4631 Mdot
.47543 .46282 Mdot
.47548 .46255 Mdot
.47553 .46227 Mdot
.47557 .462 Mdot
.47562 .46172 Mdot
.47567 .46145 Mdot
.47572 .46118 Mdot
.47576 .4609 Mdot
.47581 .46063 Mdot
.47586 .46036 Mdot
.47591 .46009 Mdot
.47595 .45981 Mdot
.476 .45954 Mdot
.47605 .45926 Mdot
.4761 .45898 Mdot
.47615 .45871 Mdot
.47619 .45844 Mdot
.47624 .45817 Mdot
.47629 .4579 Mdot
.47634 .45763 Mdot
.47638 .45736 Mdot
.47643 .45709 Mdot
.47648 .45682 Mdot
.47653 .45655 Mdot
.47657 .45628 Mdot
.47662 .45601 Mdot
.47667 .45574 Mdot
.47672 .45548 Mdot
.47676 .45521 Mdot
.47681 .45495 Mdot
.47686 .45468 Mdot
.47691 .45441 Mdot
.47695 .45414 Mdot
.477 .45387 Mdot
.47705 .4536 Mdot
.4771 .45332 Mdot
.47715 .45304 Mdot
.47719 .45277 Mdot
.47724 .45249 Mdot
.47729 .45221 Mdot
.47734 .45192 Mdot
.47738 .45164 Mdot
.47743 .45136 Mdot
.47748 .45107 Mdot
.47753 .45079 Mdot
.47757 .4505 Mdot
.47762 .45021 Mdot
.47767 .44993 Mdot
.47772 .44964 Mdot
.47776 .44935 Mdot
.47781 .44906 Mdot
.47786 .44877 Mdot
.47791 .44848 Mdot
.47795 .44819 Mdot
.478 .44789 Mdot
.47805 .4476 Mdot
.4781 .4473 Mdot
.47815 .447 Mdot
.47819 .44671 Mdot
.47824 .44641 Mdot
.47829 .4461 Mdot
.47834 .4458 Mdot
.47838 .44549 Mdot
.47843 .44518 Mdot
.47848 .44488 Mdot
.47853 .44457 Mdot
.47857 .44427 Mdot
.47862 .44396 Mdot
.47867 .44365 Mdot
.47872 .44335 Mdot
.47876 .44304 Mdot
.47881 .44273 Mdot
.47886 .44243 Mdot
.47891 .44212 Mdot
.47895 .44181 Mdot
.479 .44151 Mdot
.47905 .4412 Mdot
.4791 .4409 Mdot
.47914 .44059 Mdot
.47919 .44029 Mdot
.47924 .43998 Mdot
.47929 .43968 Mdot
.47934 .43937 Mdot
.47938 .43906 Mdot
.47943 .43875 Mdot
.47948 .43844 Mdot
.47953 .43813 Mdot
.47957 .43782 Mdot
.47962 .43751 Mdot
.47967 .4372 Mdot
.47972 .43689 Mdot
.47976 .43659 Mdot
.47981 .43628 Mdot
.47986 .43597 Mdot
.47991 .43566 Mdot
.47995 .43535 Mdot
.48 .43504 Mdot
.48005 .43472 Mdot
.4801 .4344 Mdot
.48014 .43409 Mdot
.48019 .43377 Mdot
.48024 .43345 Mdot
.48029 .43313 Mdot
.48034 .43281 Mdot
.48038 .43249 Mdot
.48043 .43217 Mdot
.48048 .43185 Mdot
.48053 .43153 Mdot
.48057 .43121 Mdot
.48062 .43089 Mdot
.48067 .43057 Mdot
.48072 .43025 Mdot
.48076 .42994 Mdot
.48081 .42962 Mdot
.48086 .4293 Mdot
.48091 .42898 Mdot
.48095 .42866 Mdot
.481 .42833 Mdot
.48105 .42801 Mdot
.4811 .42768 Mdot
.48114 .42736 Mdot
.48119 .42703 Mdot
.48124 .4267 Mdot
.48129 .42637 Mdot
.48134 .42604 Mdot
.48138 .42572 Mdot
.48143 .42539 Mdot
.48148 .42507 Mdot
.48153 .42474 Mdot
.48157 .42442 Mdot
.48162 .42409 Mdot
.48167 .42377 Mdot
.48172 .42344 Mdot
.48176 .42312 Mdot
.48181 .42279 Mdot
.48186 .42246 Mdot
.48191 .42213 Mdot
.48195 .42179 Mdot
.482 .42146 Mdot
.48205 .42112 Mdot
.4821 .42078 Mdot
.48214 .42045 Mdot
.48219 .42011 Mdot
.48224 .41977 Mdot
.48229 .41943 Mdot
.48234 .4191 Mdot
.48238 .41876 Mdot
.48243 .41842 Mdot
.48248 .41808 Mdot
.48253 .41774 Mdot
.48257 .4174 Mdot
.48262 .41706 Mdot
.48267 .41672 Mdot
.48272 .41638 Mdot
.48276 .41604 Mdot
.48281 .41571 Mdot
.48286 .41537 Mdot
.48291 .41503 Mdot
.48295 .4147 Mdot
.483 .41436 Mdot
.48305 .41402 Mdot
.4831 .41368 Mdot
.48314 .41334 Mdot
.48319 .413 Mdot
.48324 .41266 Mdot
.48329 .41232 Mdot
.48333 .41198 Mdot
.48338 .41163 Mdot
.48343 .41128 Mdot
.48348 .41093 Mdot
.48353 .41059 Mdot
.48357 .41024 Mdot
.48362 .40989 Mdot
.48367 .40954 Mdot
.48372 .40919 Mdot
.48376 .40884 Mdot
.48381 .40848 Mdot
.48386 .40813 Mdot
.48391 .40778 Mdot
.48395 .40743 Mdot
.484 .40707 Mdot
.48405 .40672 Mdot
.4841 .40637 Mdot
.48414 .40601 Mdot
.48419 .40565 Mdot
.48424 .4053 Mdot
.48429 .40494 Mdot
.48433 .40459 Mdot
.48438 .40423 Mdot
.48443 .40387 Mdot
.48448 .40351 Mdot
.48453 .40315 Mdot
.48457 .40279 Mdot
.48462 .40242 Mdot
.48467 .40206 Mdot
.48472 .40169 Mdot
.48476 .40133 Mdot
.48481 .40097 Mdot
.48486 .40061 Mdot
.48491 .40025 Mdot
.48495 .39988 Mdot
.485 .39951 Mdot
.48505 .39915 Mdot
.4851 .39878 Mdot
.48514 .39842 Mdot
.48519 .39806 Mdot
.48524 .39769 Mdot
.48529 .39732 Mdot
.48533 .39696 Mdot
.48538 .39659 Mdot
.48543 .39622 Mdot
.48548 .39584 Mdot
.48553 .39547 Mdot
.48557 .3951 Mdot
.48562 .39472 Mdot
.48567 .39434 Mdot
.48572 .39396 Mdot
.48576 .39358 Mdot
.48581 .39321 Mdot
.48586 .39283 Mdot
.48591 .39245 Mdot
.48595 .39207 Mdot
.486 .39169 Mdot
.48605 .39131 Mdot
.4861 .39094 Mdot
.48614 .39056 Mdot
.48619 .39018 Mdot
.48624 .3898 Mdot
.48629 .38942 Mdot
.48633 .38903 Mdot
.48638 .38865 Mdot
.48643 .38827 Mdot
.48648 .38789 Mdot
.48653 .3875 Mdot
.48657 .38712 Mdot
.48662 .38674 Mdot
.48667 .38635 Mdot
.48672 .38597 Mdot
.48676 .38558 Mdot
.48681 .38519 Mdot
.48686 .3848 Mdot
.48691 .38441 Mdot
.48695 .38402 Mdot
.487 .38363 Mdot
.48705 .38324 Mdot
.4871 .38284 Mdot
.48714 .38245 Mdot
.48719 .38206 Mdot
.48724 .38166 Mdot
.48729 .38127 Mdot
.48733 .38089 Mdot
.48738 .3805 Mdot
.48743 .38011 Mdot
.48748 .37972 Mdot
.48753 .37934 Mdot
.48757 .37895 Mdot
.48762 .37857 Mdot
.48767 .37819 Mdot
.48772 .3778 Mdot
.48776 .37741 Mdot
.48781 .37702 Mdot
.48786 .37663 Mdot
.48791 .37624 Mdot
.48795 .37585 Mdot
.488 .37546 Mdot
.48805 .37508 Mdot
.4881 .3747 Mdot
.48814 .37431 Mdot
.48819 .37393 Mdot
.48824 .37354 Mdot
.48829 .37316 Mdot
.48833 .37278 Mdot
.48838 .37239 Mdot
.48843 .37201 Mdot
.48848 .37163 Mdot
.48852 .37125 Mdot
.48857 .37087 Mdot
.48862 .37048 Mdot
.48867 .3701 Mdot
.48872 .36972 Mdot
.48876 .36934 Mdot
.48881 .36896 Mdot
.48886 .36857 Mdot
.48891 .36819 Mdot
.48895 .3678 Mdot
.489 .36742 Mdot
.48905 .36704 Mdot
.4891 .36666 Mdot
.48914 .36628 Mdot
.48919 .36589 Mdot
.48924 .36551 Mdot
.48929 .36512 Mdot
.48933 .36473 Mdot
.48938 .36435 Mdot
.48943 .36396 Mdot
.48948 .36357 Mdot
.48952 .36319 Mdot
.48957 .3628 Mdot
.48962 .36241 Mdot
.48967 .36203 Mdot
.48972 .36164 Mdot
.48976 .36125 Mdot
.48981 .36086 Mdot
.48986 .36046 Mdot
.48991 .36007 Mdot
.48995 .35968 Mdot
.49 .3593 Mdot
.49005 .35891 Mdot
.4901 .35852 Mdot
.49014 .35813 Mdot
.49019 .35775 Mdot
.49024 .35736 Mdot
.49029 .35697 Mdot
.49033 .35658 Mdot
.49038 .35618 Mdot
.49043 .3558 Mdot
.49048 .3554 Mdot
.49052 .35502 Mdot
.49057 .35462 Mdot
.49062 .35423 Mdot
.49067 .35383 Mdot
.49072 .35344 Mdot
.49076 .35304 Mdot
.49081 .35264 Mdot
.49086 .35224 Mdot
.49091 .35184 Mdot
.49095 .35144 Mdot
.491 .35104 Mdot
.49105 .35064 Mdot
.4911 .35023 Mdot
.49114 .34982 Mdot
.49119 .34942 Mdot
.49124 .34901 Mdot
.49129 .3486 Mdot
.49133 .34819 Mdot
.49138 .34778 Mdot
.49143 .34737 Mdot
.49148 .34696 Mdot
.49152 .34655 Mdot
.49157 .34613 Mdot
.49162 .34572 Mdot
.49167 .3453 Mdot
.49172 .34489 Mdot
.49176 .34447 Mdot
.49181 .34405 Mdot
.49186 .34363 Mdot
.49191 .3432 Mdot
.49195 .34278 Mdot
.492 .34235 Mdot
.49205 .34193 Mdot
.4921 .34151 Mdot
.49214 .34108 Mdot
.49219 .34065 Mdot
.49224 .34022 Mdot
.49229 .33979 Mdot
.49233 .33937 Mdot
.49238 .33894 Mdot
.49243 .33852 Mdot
.49248 .33809 Mdot
.49252 .33766 Mdot
.49257 .33723 Mdot
.49262 .3368 Mdot
.49267 .33637 Mdot
.49272 .33594 Mdot
.49276 .3355 Mdot
.49281 .33508 Mdot
.49286 .33465 Mdot
.49291 .33423 Mdot
.49295 .3338 Mdot
.493 .33337 Mdot
.49305 .33295 Mdot
.4931 .33252 Mdot
.49314 .3321 Mdot
.49319 .33167 Mdot
.49324 .33125 Mdot
.49329 .33082 Mdot
.49333 .3304 Mdot
.49338 .32998 Mdot
.49343 .32956 Mdot
.49348 .32913 Mdot
.49352 .32871 Mdot
.49357 .32828 Mdot
.49362 .32786 Mdot
.49367 .32744 Mdot
.49371 .32701 Mdot
.49376 .32659 Mdot
.49381 .32617 Mdot
.49386 .32574 Mdot
.49391 .32532 Mdot
.49395 .3249 Mdot
.494 .32447 Mdot
.49405 .32405 Mdot
.4941 .32363 Mdot
.49414 .32321 Mdot
.49419 .32279 Mdot
.49424 .32238 Mdot
.49429 .32196 Mdot
.49433 .32155 Mdot
.49438 .32113 Mdot
.49443 .32072 Mdot
.49448 .3203 Mdot
.49452 .31989 Mdot
.49457 .31947 Mdot
.49462 .31905 Mdot
.49467 .31863 Mdot
.49471 .31821 Mdot
.49476 .31779 Mdot
.49481 .31737 Mdot
.49486 .31695 Mdot
.49491 .31652 Mdot
.49495 .3161 Mdot
.495 .31567 Mdot
.49505 .31524 Mdot
.4951 .31482 Mdot
.49514 .31439 Mdot
.49519 .31396 Mdot
.49524 .31354 Mdot
.49529 .31312 Mdot
.49533 .31269 Mdot
.49538 .31227 Mdot
.49543 .31184 Mdot
.49548 .31141 Mdot
.49552 .31099 Mdot
.49557 .31057 Mdot
.49562 .31015 Mdot
.49567 .30973 Mdot
.49571 .30931 Mdot
.49576 .3089 Mdot
.49581 .30848 Mdot
.49586 .30806 Mdot
.49591 .30764 Mdot
.49595 .30722 Mdot
.496 .3068 Mdot
.49605 .30638 Mdot
.4961 .30597 Mdot
.49614 .30555 Mdot
.49619 .30513 Mdot
.49624 .30471 Mdot
.49629 .30429 Mdot
.49633 .30386 Mdot
.49638 .30344 Mdot
.49643 .30302 Mdot
.49648 .3026 Mdot
.49652 .30218 Mdot
.49657 .30176 Mdot
.49662 .30135 Mdot
.49667 .30093 Mdot
.49671 .30051 Mdot
.49676 .30009 Mdot
.49681 .29967 Mdot
.49686 .29925 Mdot
.49691 .29883 Mdot
.49695 .29841 Mdot
.497 .29799 Mdot
.49705 .29757 Mdot
.4971 .29715 Mdot
.49714 .29672 Mdot
.49719 .2963 Mdot
.49724 .29589 Mdot
.49729 .29547 Mdot
.49733 .29505 Mdot
.49738 .29463 Mdot
.49743 .29422 Mdot
.49748 .2938 Mdot
.49752 .29338 Mdot
.49757 .29296 Mdot
.49762 .29254 Mdot
.49767 .29212 Mdot
.49771 .29169 Mdot
.49776 .29127 Mdot
.49781 .29085 Mdot
.49786 .29043 Mdot
.4979 .29002 Mdot
.49795 .2896 Mdot
.498 .28919 Mdot
.49805 .28877 Mdot
.4981 .28835 Mdot
.49814 .28794 Mdot
.49819 .28752 Mdot
.49824 .2871 Mdot
.49829 .28669 Mdot
.49833 .28628 Mdot
.49838 .28586 Mdot
.49843 .28545 Mdot
.49848 .28503 Mdot
.49852 .28461 Mdot
.49857 .28419 Mdot
.49862 .28377 Mdot
.49867 .28335 Mdot
.49871 .28293 Mdot
.49876 .28251 Mdot
.49881 .28209 Mdot
.49886 .28167 Mdot
.4989 .28126 Mdot
.49895 .28084 Mdot
.499 .28042 Mdot
.49905 .28001 Mdot
.4991 .27959 Mdot
.49914 .27917 Mdot
.49919 .27875 Mdot
.49924 .27834 Mdot
.49929 .27792 Mdot
.49933 .2775 Mdot
.49938 .27708 Mdot
.49943 .27666 Mdot
.49948 .27624 Mdot
.49952 .27581 Mdot
.49957 .27539 Mdot
.49962 .27497 Mdot
.49967 .27454 Mdot
.49971 .27412 Mdot
.49976 .2737 Mdot
.49981 .27327 Mdot
.49986 .27284 Mdot
.4999 .27242 Mdot
.49995 .27199 Mdot
.5 .27156 Mdot
.50005 .27114 Mdot
.5001 .27071 Mdot
.50014 .27029 Mdot
.50019 .26986 Mdot
.50024 .26944 Mdot
.50029 .26902 Mdot
.50033 .2686 Mdot
.50038 .26817 Mdot
.50043 .26774 Mdot
.50048 .26732 Mdot
.50052 .2669 Mdot
.50057 .26647 Mdot
.50062 .26605 Mdot
.50067 .26563 Mdot
.50071 .26521 Mdot
.50076 .26479 Mdot
.50081 .26437 Mdot
.50086 .26395 Mdot
.5009 .26353 Mdot
.50095 .26311 Mdot
.501 .26269 Mdot
.50105 .26227 Mdot
.5011 .26185 Mdot
.50114 .26143 Mdot
.50119 .26102 Mdot
.50124 .2606 Mdot
.50129 .26019 Mdot
.50133 .25978 Mdot
.50138 .25936 Mdot
.50143 .25895 Mdot
.50148 .25854 Mdot
.50152 .25813 Mdot
.50157 .25773 Mdot
.50162 .25732 Mdot
.50167 .25691 Mdot
.50171 .25651 Mdot
.50176 .2561 Mdot
.50181 .2557 Mdot
.50186 .25529 Mdot
.5019 .25489 Mdot
.50195 .25449 Mdot
.502 .25409 Mdot
.50205 .25368 Mdot
.5021 .25328 Mdot
.50214 .25288 Mdot
.50219 .25247 Mdot
.50224 .25207 Mdot
.50229 .25167 Mdot
.50233 .25127 Mdot
.50238 .25086 Mdot
.50243 .25046 Mdot
.50248 .25005 Mdot
.50252 .24964 Mdot
.50257 .24924 Mdot
.50262 .24883 Mdot
.50267 .24842 Mdot
.50271 .24802 Mdot
.50276 .24761 Mdot
.50281 .2472 Mdot
.50286 .24679 Mdot
.5029 .24638 Mdot
.50295 .24596 Mdot
.503 .24555 Mdot
.50305 .24514 Mdot
.50309 .24472 Mdot
.50314 .24431 Mdot
.50319 .24389 Mdot
.50324 .24348 Mdot
.50329 .24306 Mdot
.50333 .24264 Mdot
.50338 .24223 Mdot
.50343 .24181 Mdot
.50348 .24139 Mdot
.50352 .24098 Mdot
.50357 .24057 Mdot
.50362 .24016 Mdot
.50367 .23975 Mdot
.50371 .23933 Mdot
.50376 .23892 Mdot
.50381 .23851 Mdot
.50386 .23809 Mdot
.5039 .23768 Mdot
.50395 .23726 Mdot
.504 .23685 Mdot
.50405 .23643 Mdot
.50409 .23601 Mdot
.50414 .23559 Mdot
.50419 .23518 Mdot
.50424 .23477 Mdot
.50429 .23436 Mdot
.50433 .23395 Mdot
.50438 .23354 Mdot
.50443 .23313 Mdot
.50448 .23272 Mdot
.50452 .23231 Mdot
.50457 .2319 Mdot
.50462 .23149 Mdot
.50467 .23108 Mdot
.50471 .23068 Mdot
.50476 .23027 Mdot
.50481 .22987 Mdot
.50486 .22946 Mdot
.5049 .22906 Mdot
.50495 .22865 Mdot
.505 .22824 Mdot
.50505 .22783 Mdot
.50509 .22742 Mdot
.50514 .22701 Mdot
.50519 .22661 Mdot
.50524 .2262 Mdot
.50529 .22579 Mdot
.50533 .22538 Mdot
.50538 .22497 Mdot
.50543 .22456 Mdot
.50548 .22415 Mdot
.50552 .22374 Mdot
.50557 .22334 Mdot
.50562 .22293 Mdot
.50567 .22252 Mdot
.50571 .22211 Mdot
.50576 .2217 Mdot
.50581 .22129 Mdot
.50586 .22088 Mdot
.5059 .22048 Mdot
.50595 .22008 Mdot
.506 .21968 Mdot
.50605 .21928 Mdot
.50609 .21888 Mdot
.50614 .21849 Mdot
.50619 .21809 Mdot
.50624 .2177 Mdot
.50629 .21731 Mdot
.50633 .21692 Mdot
.50638 .21653 Mdot
.50643 .21615 Mdot
.50648 .21576 Mdot
.50652 .21537 Mdot
.50657 .21498 Mdot
.50662 .21459 Mdot
.50667 .21421 Mdot
.50671 .21382 Mdot
.50676 .21343 Mdot
.50681 .21304 Mdot
.50686 .21265 Mdot
.5069 .21226 Mdot
.50695 .21187 Mdot
.507 .21148 Mdot
.50705 .21109 Mdot
.50709 .21071 Mdot
.50714 .21032 Mdot
.50719 .20993 Mdot
.50724 .20955 Mdot
.50728 .20916 Mdot
.50733 .20877 Mdot
.50738 .20838 Mdot
.50743 .208 Mdot
.50748 .20761 Mdot
.50752 .20722 Mdot
.50757 .20683 Mdot
.50762 .20644 Mdot
.50767 .20605 Mdot
.50771 .20566 Mdot
.50776 .20527 Mdot
.50781 .20488 Mdot
.50786 .20449 Mdot
.5079 .2041 Mdot
.50795 .20371 Mdot
.508 .20332 Mdot
.50805 .20293 Mdot
.50809 .20254 Mdot
.50814 .20215 Mdot
.50819 .20176 Mdot
.50824 .20136 Mdot
.50828 .20097 Mdot
.50833 .20058 Mdot
.50838 .20018 Mdot
.50843 .19979 Mdot
.50848 .19939 Mdot
.50852 .199 Mdot
.50857 .1986 Mdot
.50862 .19821 Mdot
.50867 .19782 Mdot
.50871 .19743 Mdot
.50876 .19704 Mdot
.50881 .19666 Mdot
.50886 .19627 Mdot
.5089 .19588 Mdot
.50895 .19549 Mdot
.509 .1951 Mdot
.50905 .19471 Mdot
.50909 .19433 Mdot
.50914 .19395 Mdot
.50919 .19356 Mdot
.50924 .19318 Mdot
.50928 .1928 Mdot
.50933 .19242 Mdot
.50938 .19204 Mdot
.50943 .19167 Mdot
.50948 .19129 Mdot
.50952 .19092 Mdot
.50957 .19054 Mdot
.50962 .19017 Mdot
.50967 .1898 Mdot
.50971 .18943 Mdot
.50976 .18906 Mdot
.50981 .18869 Mdot
.50986 .18831 Mdot
.5099 .18794 Mdot
.50995 .18757 Mdot
.51 .1872 Mdot
.51005 .18683 Mdot
.51009 .18646 Mdot
.51014 .1861 Mdot
.51019 .18573 Mdot
.51024 .18537 Mdot
.51028 .185 Mdot
.51033 .18463 Mdot
.51038 .18426 Mdot
.51043 .1839 Mdot
.51048 .18353 Mdot
.51052 .18317 Mdot
.51057 .1828 Mdot
.51062 .18244 Mdot
.51067 .18208 Mdot
.51071 .18172 Mdot
.51076 .18136 Mdot
.51081 .181 Mdot
.51086 .18064 Mdot
.5109 .18028 Mdot
.51095 .17993 Mdot
.511 .17958 Mdot
.51105 .17922 Mdot
.51109 .17887 Mdot
.51114 .17851 Mdot
.51119 .17815 Mdot
.51124 .17779 Mdot
.51128 .17743 Mdot
.51133 .17707 Mdot
.51138 .17671 Mdot
.51143 .17635 Mdot
.51148 .17599 Mdot
.51152 .17563 Mdot
.51157 .17527 Mdot
.51162 .17491 Mdot
.51167 .17455 Mdot
.51171 .17419 Mdot
.51176 .17384 Mdot
.51181 .17348 Mdot
.51186 .17312 Mdot
.5119 .17276 Mdot
.51195 .17241 Mdot
.512 .17205 Mdot
.51205 .17169 Mdot
.51209 .17134 Mdot
.51214 .17098 Mdot
.51219 .17062 Mdot
.51224 .17026 Mdot
.51228 .1699 Mdot
.51233 .16955 Mdot
.51238 .16919 Mdot
.51243 .16882 Mdot
.51247 .16846 Mdot
.51252 .16809 Mdot
.51257 .16773 Mdot
.51262 .16736 Mdot
.51267 .16699 Mdot
.51271 .16662 Mdot
.51276 .16624 Mdot
.51281 .16587 Mdot
.51286 .1655 Mdot
.5129 .16513 Mdot
.51295 .16476 Mdot
.513 .16439 Mdot
.51305 .16402 Mdot
.51309 .16365 Mdot
.51314 .16328 Mdot
.51319 .16292 Mdot
.51324 .16255 Mdot
.51328 .16218 Mdot
.51333 .16181 Mdot
.51338 .16144 Mdot
.51343 .16108 Mdot
.51347 .16071 Mdot
.51352 .16034 Mdot
.51357 .15998 Mdot
.51362 .15961 Mdot
.51367 .15925 Mdot
.51371 .15888 Mdot
.51376 .15852 Mdot
.51381 .15816 Mdot
.51386 .15779 Mdot
.5139 .15743 Mdot
.51395 .15707 Mdot
.514 .1567 Mdot
.51405 .15634 Mdot
.51409 .15597 Mdot
.51414 .1556 Mdot
.51419 .15524 Mdot
.51424 .15488 Mdot
.51428 .15451 Mdot
.51433 .15415 Mdot
.51438 .15378 Mdot
.51443 .15341 Mdot
.51447 .15305 Mdot
.51452 .15268 Mdot
.51457 .15231 Mdot
.51462 .15194 Mdot
.51467 .15158 Mdot
.51471 .15121 Mdot
.51476 .15085 Mdot
.51481 .15048 Mdot
.51486 .15012 Mdot
.5149 .14976 Mdot
.51495 .14939 Mdot
.515 .14903 Mdot
.51505 .14866 Mdot
.51509 .1483 Mdot
.51514 .14793 Mdot
.51519 .14756 Mdot
.51524 .1472 Mdot
.51528 .14683 Mdot
.51533 .14647 Mdot
.51538 .14611 Mdot
.51543 .14575 Mdot
.51547 .14539 Mdot
.51552 .14503 Mdot
.51557 .14467 Mdot
.51562 .14431 Mdot
.51567 .14395 Mdot
.51571 .14359 Mdot
.51576 .14323 Mdot
.51581 .14287 Mdot
.51586 .14251 Mdot
.5159 .14215 Mdot
.51595 .1418 Mdot
.516 .14144 Mdot
.51605 .14109 Mdot
.51609 .14074 Mdot
.51614 .14038 Mdot
.51619 .14003 Mdot
.51624 .13969 Mdot
.51628 .13934 Mdot
.51633 .13899 Mdot
.51638 .13865 Mdot
.51643 .13831 Mdot
.51647 .13797 Mdot
.51652 .13763 Mdot
.51657 .13728 Mdot
.51662 .13694 Mdot
.51667 .13659 Mdot
.51671 .13625 Mdot
.51676 .13591 Mdot
.51681 .13557 Mdot
.51686 .13523 Mdot
.5169 .13489 Mdot
.51695 .13455 Mdot
.517 .13421 Mdot
.51705 .13386 Mdot
.51709 .13352 Mdot
.51714 .13318 Mdot
.51719 .13283 Mdot
.51724 .1325 Mdot
.51728 .13216 Mdot
.51733 .13182 Mdot
.51738 .13148 Mdot
.51743 .13114 Mdot
.51747 .13081 Mdot
.51752 .13047 Mdot
.51757 .13013 Mdot
.51762 .1298 Mdot
.51766 .12946 Mdot
.51771 .12913 Mdot
.51776 .1288 Mdot
.51781 .12847 Mdot
.51786 .12813 Mdot
.5179 .12781 Mdot
.51795 .12748 Mdot
.518 .12715 Mdot
.51805 .12682 Mdot
.51809 .1265 Mdot
.51814 .12617 Mdot
.51819 .12585 Mdot
.51824 .12553 Mdot
.51828 .12522 Mdot
.51833 .1249 Mdot
.51838 .12458 Mdot
.51843 .12427 Mdot
.51847 .12395 Mdot
.51852 .12364 Mdot
.51857 .12332 Mdot
.51862 .12301 Mdot
.51866 .12269 Mdot
.51871 .12238 Mdot
.51876 .12207 Mdot
.51881 .12176 Mdot
.51886 .12145 Mdot
.5189 .12114 Mdot
.51895 .12082 Mdot
.519 .12051 Mdot
.51905 .1202 Mdot
.51909 .11988 Mdot
.51914 .11957 Mdot
.51919 .11926 Mdot
.51924 .11894 Mdot
.51928 .11864 Mdot
.51933 .11832 Mdot
.51938 .11801 Mdot
.51943 .1177 Mdot
.51947 .11739 Mdot
.51952 .11708 Mdot
.51957 .11676 Mdot
.51962 .11644 Mdot
.51966 .11613 Mdot
.51971 .11581 Mdot
.51976 .1155 Mdot
.51981 .11519 Mdot
.51986 .11489 Mdot
.5199 .11458 Mdot
.51995 .11428 Mdot
.52 .11398 Mdot
.52005 .11368 Mdot
.52009 .11338 Mdot
.52014 .11308 Mdot
.52019 .11279 Mdot
.52024 .11249 Mdot
.52028 .11219 Mdot
.52033 .11189 Mdot
.52038 .11159 Mdot
.52043 .11129 Mdot
.52047 .11099 Mdot
.52052 .11068 Mdot
.52057 .11038 Mdot
.52062 .11007 Mdot
.52066 .10977 Mdot
.52071 .10946 Mdot
.52076 .10915 Mdot
.52081 .10885 Mdot
.52086 .10854 Mdot
.5209 .10824 Mdot
.52095 .10794 Mdot
.521 .10763 Mdot
.52105 .10733 Mdot
.52109 .10703 Mdot
.52114 .10673 Mdot
.52119 .10643 Mdot
.52124 .10613 Mdot
.52128 .10583 Mdot
.52133 .10553 Mdot
.52138 .10523 Mdot
.52143 .10492 Mdot
.52147 .10462 Mdot
.52152 .10432 Mdot
.52157 .10402 Mdot
.52162 .10372 Mdot
.52166 .10342 Mdot
.52171 .10312 Mdot
.52176 .10283 Mdot
.52181 .10253 Mdot
.52185 .10223 Mdot
.5219 .10194 Mdot
.52195 .10165 Mdot
.522 .10136 Mdot
.52205 .10107 Mdot
.52209 .10078 Mdot
.52214 .10049 Mdot
.52219 .10019 Mdot
.52224 .0999 Mdot
.52228 .09961 Mdot
.52233 .09931 Mdot
.52238 .09902 Mdot
.52243 .09873 Mdot
.52247 .09844 Mdot
.52252 .09814 Mdot
.52257 .09785 Mdot
.52262 .09756 Mdot
.52266 .09726 Mdot
.52271 .09696 Mdot
.52276 .09667 Mdot
.52281 .09638 Mdot
.52285 .09608 Mdot
.5229 .09579 Mdot
.52295 .0955 Mdot
.523 .0952 Mdot
.52305 .09491 Mdot
.52309 .09461 Mdot
.52314 .09432 Mdot
.52319 .09402 Mdot
.52324 .09372 Mdot
.52328 .09342 Mdot
.52333 .09312 Mdot
.52338 .09282 Mdot
.52343 .09253 Mdot
.52347 .09223 Mdot
.52352 .09194 Mdot
.52357 .09165 Mdot
.52362 .09136 Mdot
.52366 .09107 Mdot
.52371 .09078 Mdot
.52376 .09049 Mdot
.52381 .09021 Mdot
.52385 .08992 Mdot
.5239 .08963 Mdot
.52395 .08935 Mdot
.524 .08907 Mdot
.52405 .08878 Mdot
.52409 .0885 Mdot
.52414 .08821 Mdot
.52419 .08793 Mdot
.52424 .08765 Mdot
.52428 .08737 Mdot
.52433 .08709 Mdot
.52438 .08681 Mdot
.52443 .08653 Mdot
.52447 .08625 Mdot
.52452 .08598 Mdot
.52457 .08571 Mdot
.52462 .08544 Mdot
.52466 .08517 Mdot
.52471 .0849 Mdot
.52476 .08463 Mdot
.52481 .08436 Mdot
.52485 .08409 Mdot
.5249 .08382 Mdot
.52495 .08356 Mdot
.525 .08329 Mdot
.52505 .08302 Mdot
.52509 .08275 Mdot
.52514 .08248 Mdot
.52519 .08221 Mdot
.52524 .08194 Mdot
.52528 .08167 Mdot
.52533 .0814 Mdot
.52538 .08114 Mdot
.52543 .08087 Mdot
.52547 .0806 Mdot
.52552 .08034 Mdot
.52557 .08007 Mdot
.52562 .0798 Mdot
.52566 .07953 Mdot
.52571 .07927 Mdot
.52576 .079 Mdot
.52581 .07873 Mdot
.52585 .07846 Mdot
.5259 .07819 Mdot
.52595 .07792 Mdot
.526 .07766 Mdot
.52605 .07739 Mdot
.52609 .07713 Mdot
.52614 .07686 Mdot
.52619 .0766 Mdot
.52624 .07634 Mdot
.52628 .07608 Mdot
.52633 .07582 Mdot
.52638 .07556 Mdot
.52643 .0753 Mdot
.52647 .07504 Mdot
.52652 .07479 Mdot
.52657 .07453 Mdot
.52662 .07427 Mdot
.52666 .07402 Mdot
.52671 .07376 Mdot
.52676 .07351 Mdot
.52681 .07326 Mdot
.52685 .07301 Mdot
.5269 .07276 Mdot
.52695 .0725 Mdot
.527 .07225 Mdot
.52704 .07199 Mdot
.52709 .07174 Mdot
.52714 .07148 Mdot
.52719 .07122 Mdot
.52724 .07097 Mdot
.52728 .07071 Mdot
.52733 .07045 Mdot
.52738 .0702 Mdot
.52743 .06994 Mdot
.52747 .06969 Mdot
.52752 .06943 Mdot
.52757 .06918 Mdot
.52762 .06893 Mdot
.52766 .06868 Mdot
.52771 .06843 Mdot
.52776 .06818 Mdot
.52781 .06794 Mdot
.52785 .06769 Mdot
.5279 .06745 Mdot
.52795 .0672 Mdot
.528 .06695 Mdot
.52804 .06671 Mdot
.52809 .06647 Mdot
.52814 .06623 Mdot
.52819 .06599 Mdot
.52824 .06574 Mdot
.52828 .0655 Mdot
.52833 .06526 Mdot
.52838 .06503 Mdot
.52843 .06479 Mdot
.52847 .06455 Mdot
.52852 .06432 Mdot
.52857 .06409 Mdot
.52862 .06386 Mdot
.52866 .06363 Mdot
.52871 .0634 Mdot
.52876 .06318 Mdot
.52881 .06295 Mdot
.52885 .06273 Mdot
.5289 .06252 Mdot
.52895 .0623 Mdot
.529 .06209 Mdot
.52904 .06188 Mdot
.52909 .06167 Mdot
.52914 .06146 Mdot
.52919 .06125 Mdot
.52924 .06104 Mdot
.52928 .06083 Mdot
.52933 .06062 Mdot
.52938 .06041 Mdot
.52943 .0602 Mdot
.52947 .05998 Mdot
.52952 .05977 Mdot
.52957 .05957 Mdot
.52962 .05936 Mdot
.52966 .05915 Mdot
.52971 .05894 Mdot
.52976 .05873 Mdot
.52981 .05851 Mdot
.52985 .0583 Mdot
.5299 .05809 Mdot
.52995 .05788 Mdot
.53 .05768 Mdot
.53004 .05747 Mdot
.53009 .05726 Mdot
.53014 .05706 Mdot
.53019 .05686 Mdot
.53024 .05665 Mdot
.53028 .05644 Mdot
.53033 .05623 Mdot
.53038 .05602 Mdot
.53043 .05582 Mdot
.53047 .05561 Mdot
.53052 .05541 Mdot
.53057 .0552 Mdot
.53062 .05499 Mdot
.53066 .05478 Mdot
.53071 .05457 Mdot
.53076 .05436 Mdot
.53081 .05416 Mdot
.53085 .05396 Mdot
.5309 .05375 Mdot
.53095 .05355 Mdot
.531 .05335 Mdot
.53104 .05314 Mdot
.53109 .05294 Mdot
.53114 .05274 Mdot
.53119 .05254 Mdot
.53123 .05235 Mdot
.53128 .05215 Mdot
.53133 .05196 Mdot
.53138 .05177 Mdot
.53143 .05158 Mdot
.53147 .05139 Mdot
.53152 .0512 Mdot
.53157 .05101 Mdot
.53162 .05083 Mdot
.53166 .05064 Mdot
.53171 .05045 Mdot
.53176 .05027 Mdot
.53181 .05008 Mdot
.53185 .04989 Mdot
.5319 .0497 Mdot
.53195 .04952 Mdot
.532 .04933 Mdot
.53204 .04915 Mdot
.53209 .04896 Mdot
.53214 .04878 Mdot
.53219 .0486 Mdot
.53223 .04842 Mdot
.53228 .04824 Mdot
.53233 .04806 Mdot
.53238 .04788 Mdot
.53243 .0477 Mdot
.53247 .04752 Mdot
.53252 .04734 Mdot
.53257 .04716 Mdot
.53262 .04698 Mdot
.53266 .0468 Mdot
.53271 .04662 Mdot
.53276 .04644 Mdot
.53281 .04626 Mdot
.53285 .04609 Mdot
.5329 .04592 Mdot
.53295 .04574 Mdot
.533 .04557 Mdot
.53304 .0454 Mdot
.53309 .04523 Mdot
.53314 .04506 Mdot
.53319 .04489 Mdot
.53323 .04472 Mdot
.53328 .04456 Mdot
.53333 .0444 Mdot
.53338 .04424 Mdot
.53343 .04408 Mdot
.53347 .04392 Mdot
.53352 .04376 Mdot
.53357 .04361 Mdot
.53362 .04346 Mdot
.53366 .04331 Mdot
.53371 .04316 Mdot
.53376 .04301 Mdot
.53381 .04286 Mdot
.53385 .04271 Mdot
.5339 .04257 Mdot
.53395 .04242 Mdot
.534 .04228 Mdot
.53404 .04213 Mdot
.53409 .04199 Mdot
.53414 .04185 Mdot
.53419 .04171 Mdot
.53423 .04157 Mdot
.53428 .04143 Mdot
.53433 .0413 Mdot
.53438 .04116 Mdot
.53443 .04102 Mdot
.53447 .04088 Mdot
.53452 .04074 Mdot
.53457 .0406 Mdot
.53462 .04046 Mdot
.53466 .04033 Mdot
.53471 .04019 Mdot
.53476 .04005 Mdot
.53481 .03991 Mdot
.53485 .03977 Mdot
.5349 .03964 Mdot
.53495 .03949 Mdot
.535 .03935 Mdot
.53504 .03921 Mdot
.53509 .03907 Mdot
.53514 .03893 Mdot
.53519 .03879 Mdot
.53523 .03865 Mdot
.53528 .0385 Mdot
.53533 .03836 Mdot
.53538 .03822 Mdot
.53543 .03808 Mdot
.53547 .03794 Mdot
.53552 .03781 Mdot
.53557 .03767 Mdot
.53562 .03754 Mdot
.53566 .0374 Mdot
.53571 .03727 Mdot
.53576 .03713 Mdot
.53581 .037 Mdot
.53585 .03687 Mdot
.5359 .03673 Mdot
.53595 .0366 Mdot
.536 .03647 Mdot
.53604 .03634 Mdot
.53609 .03621 Mdot
.53614 .03608 Mdot
.53619 .03595 Mdot
.53623 .03582 Mdot
.53628 .03569 Mdot
.53633 .03556 Mdot
.53638 .03543 Mdot
.53642 .0353 Mdot
.53647 .03517 Mdot
.53652 .03504 Mdot
.53657 .03491 Mdot
.53662 .03478 Mdot
.53666 .03465 Mdot
.53671 .03451 Mdot
.53676 .03438 Mdot
.53681 .03424 Mdot
.53685 .03411 Mdot
.5369 .03397 Mdot
.53695 .03384 Mdot
.537 .0337 Mdot
.53704 .03356 Mdot
.53709 .03342 Mdot
.53714 .03328 Mdot
.53719 .03315 Mdot
.53723 .03302 Mdot
.53728 .03288 Mdot
.53733 .03275 Mdot
.53738 .03263 Mdot
.53742 .0325 Mdot
.53747 .03236 Mdot
.53752 .03223 Mdot
.53757 .03211 Mdot
.53762 .03198 Mdot
.53766 .03185 Mdot
.53771 .03172 Mdot
.53776 .03158 Mdot
.53781 .03146 Mdot
.53785 .03133 Mdot
.5379 .03121 Mdot
.53795 .03108 Mdot
.538 .03096 Mdot
.53804 .03083 Mdot
.53809 .03071 Mdot
.53814 .03059 Mdot
.53819 .03047 Mdot
.53823 .03034 Mdot
.53828 .03022 Mdot
.53833 .0301 Mdot
.53838 .02998 Mdot
.53842 .02986 Mdot
.53847 .02974 Mdot
.53852 .02963 Mdot
.53857 .02951 Mdot
.53862 .0294 Mdot
.53866 .02929 Mdot
.53871 .02918 Mdot
.53876 .02907 Mdot
.53881 .02896 Mdot
.53885 .02886 Mdot
.5389 .02875 Mdot
.53895 .02865 Mdot
.539 .02854 Mdot
.53904 .02844 Mdot
.53909 .02833 Mdot
.53914 .02822 Mdot
.53919 .02812 Mdot
.53923 .02801 Mdot
.53928 .0279 Mdot
.53933 .0278 Mdot
.53938 .02769 Mdot
.53942 .02758 Mdot
.53947 .02748 Mdot
.53952 .02737 Mdot
.53957 .02727 Mdot
.53962 .02716 Mdot
.53966 .02706 Mdot
.53971 .02696 Mdot
.53976 .02686 Mdot
.53981 .02676 Mdot
.53985 .02666 Mdot
.5399 .02656 Mdot
.53995 .02647 Mdot
.54 .02638 Mdot
.54004 .02629 Mdot
.54009 .02619 Mdot
.54014 .0261 Mdot
.54019 .02601 Mdot
.54023 .02592 Mdot
.54028 .02583 Mdot
.54033 .02574 Mdot
.54038 .02565 Mdot
.54042 .02556 Mdot
.54047 .02547 Mdot
.54052 .02538 Mdot
.54057 .0253 Mdot
.54061 .02521 Mdot
.54066 .02512 Mdot
.54071 .02503 Mdot
.54076 .02494 Mdot
.54081 .02485 Mdot
.54085 .02477 Mdot
.5409 .02468 Mdot
.54095 .0246 Mdot
.541 .02452 Mdot
.54104 .02443 Mdot
.54109 .02435 Mdot
.54114 .02426 Mdot
.54119 .02418 Mdot
.54123 .0241 Mdot
.54128 .02401 Mdot
.54133 .02393 Mdot
.54138 .02385 Mdot
.54142 .02377 Mdot
.54147 .02369 Mdot
.54152 .0236 Mdot
.54157 .02352 Mdot
.54161 .02344 Mdot
.54166 .02336 Mdot
.54171 .02327 Mdot
.54176 .02319 Mdot
.54181 .0231 Mdot
.54185 .02301 Mdot
.5419 .02293 Mdot
.54195 .02284 Mdot
.542 .02276 Mdot
.54204 .02267 Mdot
.54209 .02259 Mdot
.54214 .0225 Mdot
.54219 .02241 Mdot
.54223 .02232 Mdot
.54228 .02223 Mdot
.54233 .02215 Mdot
.54238 .02206 Mdot
.54242 .02197 Mdot
.54247 .02188 Mdot
.54252 .02179 Mdot
.54257 .0217 Mdot
.54261 .02162 Mdot
.54266 .02153 Mdot
.54271 .02145 Mdot
.54276 .02136 Mdot
.54281 .02128 Mdot
.54285 .0212 Mdot
.5429 .02112 Mdot
.54295 .02103 Mdot
.543 .02095 Mdot
.54304 .02087 Mdot
.54309 .02078 Mdot
.54314 .0207 Mdot
.54319 .02061 Mdot
.54323 .02053 Mdot
.54328 .02045 Mdot
.54333 .02037 Mdot
.54338 .02029 Mdot
.54342 .02022 Mdot
.54347 .02014 Mdot
.54352 .02006 Mdot
.54357 .01999 Mdot
.54361 .01991 Mdot
.54366 .01984 Mdot
.54371 .01976 Mdot
.54376 .01969 Mdot
.54381 .01962 Mdot
.54385 .01954 Mdot
.5439 .01947 Mdot
.54395 .0194 Mdot
.544 .01932 Mdot
.54404 .01925 Mdot
.54409 .01917 Mdot
.54414 .0191 Mdot
.54419 .01903 Mdot
.54423 .01897 Mdot
.54428 .0189 Mdot
.54433 .01883 Mdot
.54438 .01876 Mdot
.54442 .0187 Mdot
.54447 .01864 Mdot
.54452 .01857 Mdot
.54457 .01851 Mdot
.54461 .01844 Mdot
.54466 .01838 Mdot
.54471 .01832 Mdot
.54476 .01826 Mdot
.54481 .0182 Mdot
.54485 .01814 Mdot
.5449 .01808 Mdot
.54495 .01802 Mdot
.545 .01796 Mdot
.54504 .0179 Mdot
.54509 .01784 Mdot
.54514 .01778 Mdot
.54519 .01771 Mdot
.54523 .01765 Mdot
.54528 .01759 Mdot
.54533 .01753 Mdot
.54538 .01746 Mdot
.54542 .0174 Mdot
.54547 .01734 Mdot
.54552 .01728 Mdot
.54557 .01722 Mdot
.54561 .01717 Mdot
.54566 .01711 Mdot
.54571 .01705 Mdot
.54576 .017 Mdot
.5458 .01695 Mdot
.54585 .0169 Mdot
.5459 .01685 Mdot
.54595 .0168 Mdot
.546 .01676 Mdot
.54604 .01671 Mdot
.54609 .01666 Mdot
.54614 .01661 Mdot
.54619 .01657 Mdot
.54623 .01652 Mdot
.54628 .01647 Mdot
.54633 .01643 Mdot
.54638 .01638 Mdot
.54642 .01633 Mdot
.54647 .01629 Mdot
.54652 .01624 Mdot
.54657 .01619 Mdot
.54661 .01615 Mdot
.54666 .0161 Mdot
.54671 .01606 Mdot
.54676 .01601 Mdot
.5468 .01597 Mdot
.54685 .01593 Mdot
.5469 .01589 Mdot
.54695 .01585 Mdot
.547 .01582 Mdot
.54704 .01578 Mdot
.54709 .01575 Mdot
.54714 .01571 Mdot
.54719 .01568 Mdot
.54723 .01565 Mdot
.54728 .01562 Mdot
.54733 .01559 Mdot
.54738 .01557 Mdot
.54742 .01554 Mdot
.54747 .01552 Mdot
.54752 .0155 Mdot
.54757 .01547 Mdot
.54761 .01544 Mdot
.54766 .01542 Mdot
.54771 .0154 Mdot
.54776 .01538 Mdot
.5478 .01536 Mdot
.54785 .01534 Mdot
.5479 .01532 Mdot
.54795 .0153 Mdot
.548 .01528 Mdot
.54804 .01526 Mdot
.54809 .01524 Mdot
.54814 .01522 Mdot
.54819 .01519 Mdot
.54823 .01517 Mdot
.54828 .01515 Mdot
.54833 .01513 Mdot
.54838 .0151 Mdot
.54842 .01508 Mdot
.54847 .01506 Mdot
.54852 .01504 Mdot
.54857 .01502 Mdot
.54861 .01501 Mdot
.54866 .01499 Mdot
.54871 .01498 Mdot
.54876 .01496 Mdot
.5488 .01495 Mdot
.54885 .01493 Mdot
.5489 .01492 Mdot
.54895 .0149 Mdot
.549 .01489 Mdot
.54904 .01487 Mdot
.54909 .01486 Mdot
.54914 .01485 Mdot
.54919 .01484 Mdot
.54923 .01483 Mdot
.54928 .01482 Mdot
.54933 .01481 Mdot
.54938 .0148 Mdot
.54942 .01479 Mdot
.54947 .01478 Mdot
.54952 .01478 Mdot
.54957 .01477 Mdot
.54961 .01476 Mdot
.54966 .01475 Mdot
.54971 .01474 Mdot
.54976 .01474 Mdot
.5498 .01474 Mdot
.54985 .01473 Mdot
.5499 .01473 Mdot
.54995 .01473 Mdot
.55 .01473 Mdot
.55004 .01473 Mdot
.55009 .01473 Mdot
.55014 .01473 Mdot
.55019 .01472 Mdot
.55023 .01472 Mdot
.55028 .01472 Mdot
.55033 .01472 Mdot
.55038 .01472 Mdot
.55042 .01472 Mdot
.55047 .01472 Mdot
.55052 .01472 Mdot
.55057 .01472 Mdot
.55061 .01472 Mdot
.55066 .01472 Mdot
.55071 .01472 Mdot
.55076 .01472 Mdot
.5508 .01472 Mdot
.55085 .01472 Mdot
.5509 .01473 Mdot
.55095 .01473 Mdot
.55099 .01474 Mdot
.55104 .01474 Mdot
.55109 .01475 Mdot
.55114 .01477 Mdot
.55119 .01478 Mdot
.55123 .0148 Mdot
.55128 .01481 Mdot
.55133 .01483 Mdot
.55138 .01485 Mdot
.55142 .01487 Mdot
.55147 .01488 Mdot
.55152 .0149 Mdot
.55157 .01492 Mdot
.55161 .01493 Mdot
.55166 .01495 Mdot
.55171 .01496 Mdot
.55176 .01498 Mdot
.5518 .015 Mdot
.55185 .01502 Mdot
.5519 .01504 Mdot
.55195 .01506 Mdot
.55199 .01507 Mdot
.55204 .01509 Mdot
.55209 .01511 Mdot
.55214 .01513 Mdot
.55219 .01516 Mdot
.55223 .01518 Mdot
.55228 .0152 Mdot
.55233 .01523 Mdot
.55238 .01525 Mdot
.55242 .01528 Mdot
.55247 .0153 Mdot
.55252 .01533 Mdot
.55257 .01536 Mdot
.55261 .01539 Mdot
.55266 .01543 Mdot
.55271 .01546 Mdot
.55276 .01549 Mdot
.5528 .01553 Mdot
.55285 .01556 Mdot
.5529 .0156 Mdot
.55295 .01564 Mdot
.55299 .01568 Mdot
.55304 .01571 Mdot
.55309 .01576 Mdot
.55314 .01579 Mdot
.55319 .01583 Mdot
.55323 .01587 Mdot
.55328 .01591 Mdot
.55333 .01594 Mdot
.55338 .01598 Mdot
.55342 .01601 Mdot
.55347 .01604 Mdot
.55352 .01607 Mdot
.55357 .01611 Mdot
.55361 .01614 Mdot
.55366 .01618 Mdot
.55371 .01621 Mdot
.55376 .01625 Mdot
.5538 .01628 Mdot
.55385 .01632 Mdot
.5539 .01636 Mdot
.55395 .01641 Mdot
.55399 .01645 Mdot
.55404 .01649 Mdot
.55409 .01653 Mdot
.55414 .01657 Mdot
.55419 .0166 Mdot
.55423 .01664 Mdot
.55428 .01667 Mdot
.55433 .01671 Mdot
.55438 .01674 Mdot
.55442 .01678 Mdot
.55447 .01682 Mdot
.55452 .01686 Mdot
.55457 .01691 Mdot
.55461 .01696 Mdot
.55466 .017 Mdot
.55471 .01704 Mdot
.55476 .01709 Mdot
.5548 .01713 Mdot
.55485 .01717 Mdot
.5549 .01722 Mdot
.55495 .01727 Mdot
.55499 .01732 Mdot
.55504 .01737 Mdot
.55509 .01742 Mdot
.55514 .01746 Mdot
.55518 .01751 Mdot
.55523 .01756 Mdot
.55528 .01761 Mdot
.55533 .01765 Mdot
.55538 .01769 Mdot
.55542 .01774 Mdot
.55547 .01778 Mdot
.55552 .01783 Mdot
.55557 .01787 Mdot
.55561 .01792 Mdot
.55566 .01796 Mdot
.55571 .01801 Mdot
.55576 .01805 Mdot
.5558 .0181 Mdot
.55585 .01815 Mdot
.5559 .0182 Mdot
.55595 .01825 Mdot
.55599 .0183 Mdot
.55604 .01835 Mdot
.55609 .0184 Mdot
.55614 .01844 Mdot
.55618 .01849 Mdot
.55623 .01854 Mdot
.55628 .0186 Mdot
.55633 .01865 Mdot
.55638 .0187 Mdot
.55642 .01876 Mdot
.55647 .01881 Mdot
.55652 .01886 Mdot
.55657 .01892 Mdot
.55661 .01898 Mdot
.55666 .01904 Mdot
.55671 .0191 Mdot
.55676 .01917 Mdot
.5568 .01923 Mdot
.55685 .01929 Mdot
.5569 .01934 Mdot
.55695 .0194 Mdot
.55699 .01946 Mdot
.55704 .01952 Mdot
.55709 .01958 Mdot
.55714 .01964 Mdot
.55718 .0197 Mdot
.55723 .01976 Mdot
.55728 .01981 Mdot
.55733 .01987 Mdot
.55738 .01993 Mdot
.55742 .01999 Mdot
.55747 .02005 Mdot
.55752 .02011 Mdot
.55757 .02017 Mdot
.55761 .02023 Mdot
.55766 .0203 Mdot
.55771 .02036 Mdot
.55776 .02043 Mdot
.5578 .02049 Mdot
.55785 .02056 Mdot
.5579 .02063 Mdot
.55795 .0207 Mdot
.55799 .02078 Mdot
.55804 .02085 Mdot
.55809 .02092 Mdot
.55814 .021 Mdot
.55818 .02108 Mdot
.55823 .02116 Mdot
.55828 .02124 Mdot
.55833 .02132 Mdot
.55838 .02141 Mdot
.55842 .0215 Mdot
.55847 .02158 Mdot
.55852 .02167 Mdot
.55857 .02176 Mdot
.55861 .02185 Mdot
.55866 .02194 Mdot
.55871 .02203 Mdot
.55876 .02212 Mdot
.5588 .02222 Mdot
.55885 .02231 Mdot
.5589 .0224 Mdot
.55895 .02249 Mdot
.55899 .02258 Mdot
.55904 .02267 Mdot
.55909 .02276 Mdot
.55914 .02285 Mdot
.55918 .02295 Mdot
.55923 .02304 Mdot
.55928 .02314 Mdot
.55933 .02324 Mdot
.55938 .02334 Mdot
.55942 .02344 Mdot
.55947 .02355 Mdot
.55952 .02365 Mdot
.55957 .02376 Mdot
.55961 .02386 Mdot
.55966 .02397 Mdot
.55971 .02408 Mdot
.55976 .02419 Mdot
.5598 .0243 Mdot
.55985 .0244 Mdot
.5599 .02451 Mdot
.55995 .02462 Mdot
.55999 .02473 Mdot
.56004 .02485 Mdot
.56009 .02496 Mdot
.56014 .02507 Mdot
.56018 .02518 Mdot
.56023 .02529 Mdot
.56028 .02541 Mdot
.56033 .02552 Mdot
.56037 .02564 Mdot
.56042 .02575 Mdot
.56047 .02587 Mdot
.56052 .02598 Mdot
.56057 .0261 Mdot
.56061 .02622 Mdot
.56066 .02635 Mdot
.56071 .02647 Mdot
.56076 .0266 Mdot
.5608 .02672 Mdot
.56085 .02685 Mdot
.5609 .02697 Mdot
.56095 .02709 Mdot
.56099 .02722 Mdot
.56104 .02734 Mdot
.56109 .02747 Mdot
.56114 .02759 Mdot
.56118 .02772 Mdot
.56123 .02784 Mdot
.56128 .02797 Mdot
.56133 .02809 Mdot
.56137 .02822 Mdot
.56142 .02835 Mdot
.56147 .02849 Mdot
.56152 .02862 Mdot
.56157 .02876 Mdot
.56161 .0289 Mdot
.56166 .02905 Mdot
.56171 .02919 Mdot
.56176 .02933 Mdot
.5618 .02948 Mdot
.56185 .02962 Mdot
.5619 .02976 Mdot
.56195 .0299 Mdot
.56199 .03005 Mdot
.56204 .03019 Mdot
.56209 .03034 Mdot
.56214 .0305 Mdot
.56218 .03065 Mdot
.56223 .03081 Mdot
.56228 .03097 Mdot
.56233 .03113 Mdot
.56237 .03128 Mdot
.56242 .03144 Mdot
.56247 .0316 Mdot
.56252 .03175 Mdot
.56257 .0319 Mdot
.56261 .03206 Mdot
.56266 .03221 Mdot
.56271 .03236 Mdot
.56276 .03251 Mdot
.5628 .03266 Mdot
.56285 .03281 Mdot
.5629 .03297 Mdot
.56295 .03312 Mdot
.56299 .03327 Mdot
.56304 .03342 Mdot
.56309 .03358 Mdot
.56314 .03374 Mdot
.56318 .0339 Mdot
.56323 .03406 Mdot
.56328 .03422 Mdot
.56333 .03438 Mdot
.56337 .03454 Mdot
.56342 .0347 Mdot
.56347 .03486 Mdot
.56352 .03502 Mdot
.56357 .03518 Mdot
.56361 .03534 Mdot
.56366 .0355 Mdot
.56371 .03566 Mdot
.56376 .03582 Mdot
.5638 .03598 Mdot
.56385 .03614 Mdot
.5639 .0363 Mdot
.56395 .03646 Mdot
.56399 .03662 Mdot
.56404 .03678 Mdot
.56409 .03693 Mdot
.56414 .03709 Mdot
.56418 .03725 Mdot
.56423 .03741 Mdot
.56428 .03757 Mdot
.56433 .03773 Mdot
.56437 .0379 Mdot
.56442 .03806 Mdot
.56447 .03823 Mdot
.56452 .03839 Mdot
.56456 .03856 Mdot
.56461 .03873 Mdot
.56466 .0389 Mdot
.56471 .03907 Mdot
.56476 .03924 Mdot
.5648 .03941 Mdot
.56485 .03959 Mdot
.5649 .03976 Mdot
.56495 .03994 Mdot
.56499 .04011 Mdot
.56504 .04029 Mdot
.56509 .04046 Mdot
.56514 .04064 Mdot
.56518 .04082 Mdot
.56523 .041 Mdot
.56528 .04118 Mdot
.56533 .04137 Mdot
.56537 .04155 Mdot
.56542 .04173 Mdot
.56547 .04192 Mdot
.56552 .0421 Mdot
.56556 .04229 Mdot
.56561 .04248 Mdot
.56566 .04266 Mdot
.56571 .04285 Mdot
.56576 .04303 Mdot
.5658 .04321 Mdot
.56585 .0434 Mdot
.5659 .04359 Mdot
.56595 .04377 Mdot
.56599 .04396 Mdot
.56604 .04415 Mdot
.56609 .04434 Mdot
.56614 .04453 Mdot
.56618 .04471 Mdot
.56623 .0449 Mdot
.56628 .04509 Mdot
.56633 .04528 Mdot
.56637 .04547 Mdot
.56642 .04567 Mdot
.56647 .04586 Mdot
.56652 .04605 Mdot
.56656 .04624 Mdot
.56661 .04643 Mdot
.56666 .04663 Mdot
.56671 .04682 Mdot
.56676 .04701 Mdot
.5668 .04721 Mdot
.56685 .0474 Mdot
.5669 .0476 Mdot
.56695 .04779 Mdot
.56699 .04799 Mdot
.56704 .04818 Mdot
.56709 .04838 Mdot
.56714 .04857 Mdot
.56718 .04877 Mdot
.56723 .04896 Mdot
.56728 .04916 Mdot
.56733 .04935 Mdot
.56737 .04954 Mdot
.56742 .04973 Mdot
.56747 .04992 Mdot
.56752 .05011 Mdot
.56756 .05031 Mdot
.56761 .0505 Mdot
.56766 .0507 Mdot
.56771 .05089 Mdot
.56776 .05108 Mdot
.5678 .05128 Mdot
.56785 .05147 Mdot
.5679 .05167 Mdot
.56795 .05187 Mdot
.56799 .05206 Mdot
.56804 .05226 Mdot
.56809 .05246 Mdot
.56814 .05266 Mdot
.56818 .05285 Mdot
.56823 .05305 Mdot
.56828 .05324 Mdot
.56833 .05344 Mdot
.56837 .05364 Mdot
.56842 .05385 Mdot
.56847 .05405 Mdot
.56852 .05425 Mdot
.56856 .05445 Mdot
.56861 .05465 Mdot
.56866 .05486 Mdot
.56871 .05507 Mdot
.56876 .05528 Mdot
.5688 .05549 Mdot
.56885 .0557 Mdot
.5689 .05591 Mdot
.56895 .05613 Mdot
.56899 .05635 Mdot
.56904 .05656 Mdot
.56909 .05678 Mdot
.56914 .057 Mdot
.56918 .05721 Mdot
.56923 .05743 Mdot
.56928 .05765 Mdot
.56933 .05786 Mdot
.56937 .05809 Mdot
.56942 .05831 Mdot
.56947 .05853 Mdot
.56952 .05875 Mdot
.56956 .05898 Mdot
.56961 .0592 Mdot
.56966 .05943 Mdot
.56971 .05965 Mdot
.56975 .05988 Mdot
.5698 .06011 Mdot
.56985 .06033 Mdot
.5699 .06057 Mdot
.56995 .0608 Mdot
.56999 .06103 Mdot
.57004 .06126 Mdot
.57009 .06149 Mdot
.57014 .06172 Mdot
.57018 .06195 Mdot
.57023 .06218 Mdot
.57028 .06241 Mdot
.57033 .06265 Mdot
.57037 .06288 Mdot
.57042 .06311 Mdot
.57047 .06335 Mdot
.57052 .06358 Mdot
.57056 .06381 Mdot
.57061 .06405 Mdot
.57066 .06429 Mdot
.57071 .06452 Mdot
.57075 .06476 Mdot
.5708 .065 Mdot
.57085 .06524 Mdot
.5709 .06547 Mdot
.57095 .06571 Mdot
.57099 .06595 Mdot
.57104 .06618 Mdot
.57109 .06641 Mdot
.57114 .06665 Mdot
.57118 .06688 Mdot
.57123 .06711 Mdot
.57128 .06735 Mdot
.57133 .06758 Mdot
.57137 .06782 Mdot
.57142 .06806 Mdot
.57147 .0683 Mdot
.57152 .06854 Mdot
.57156 .06878 Mdot
.57161 .06903 Mdot
.57166 .06927 Mdot
.57171 .06952 Mdot
.57175 .06977 Mdot
.5718 .07001 Mdot
.57185 .07026 Mdot
.5719 .07051 Mdot
.57195 .07075 Mdot
.57199 .071 Mdot
.57204 .07124 Mdot
.57209 .07149 Mdot
.57214 .07173 Mdot
.57218 .07197 Mdot
.57223 .07222 Mdot
.57228 .07246 Mdot
.57233 .0727 Mdot
.57237 .07295 Mdot
.57242 .07319 Mdot
.57247 .07343 Mdot
.57252 .07368 Mdot
.57256 .07392 Mdot
.57261 .07416 Mdot
.57266 .0744 Mdot
.57271 .07464 Mdot
.57275 .07488 Mdot
.5728 .07512 Mdot
.57285 .07536 Mdot
.5729 .0756 Mdot
.57295 .07584 Mdot
.57299 .07608 Mdot
.57304 .07632 Mdot
.57309 .07657 Mdot
.57314 .07681 Mdot
.57318 .07705 Mdot
.57323 .0773 Mdot
.57328 .07755 Mdot
.57333 .0778 Mdot
.57337 .07805 Mdot
.57342 .0783 Mdot
.57347 .07856 Mdot
.57352 .07881 Mdot
.57356 .07907 Mdot
.57361 .07933 Mdot
.57366 .07958 Mdot
.57371 .07984 Mdot
.57375 .0801 Mdot
.5738 .08036 Mdot
.57385 .08062 Mdot
.5739 .08087 Mdot
.57394 .08113 Mdot
.57399 .08139 Mdot
.57404 .08165 Mdot
.57409 .08192 Mdot
.57414 .08218 Mdot
.57418 .08245 Mdot
.57423 .08272 Mdot
.57428 .08299 Mdot
.57433 .08325 Mdot
.57437 .08352 Mdot
.57442 .08379 Mdot
.57447 .08406 Mdot
.57452 .08433 Mdot
.57456 .0846 Mdot
.57461 .08487 Mdot
.57466 .08513 Mdot
.57471 .0854 Mdot
.57475 .08566 Mdot
.5748 .08593 Mdot
.57485 .0862 Mdot
.5749 .08646 Mdot
.57494 .08673 Mdot
.57499 .087 Mdot
.57504 .08726 Mdot
.57509 .08753 Mdot
.57514 .0878 Mdot
.57518 .08807 Mdot
.57523 .08834 Mdot
.57528 .08862 Mdot
.57533 .08889 Mdot
.57537 .08916 Mdot
.57542 .08944 Mdot
.57547 .08971 Mdot
.57552 .08999 Mdot
.57556 .09027 Mdot
.57561 .09054 Mdot
.57566 .09082 Mdot
.57571 .0911 Mdot
.57575 .09138 Mdot
.5758 .09166 Mdot
.57585 .09194 Mdot
.5759 .09223 Mdot
.57594 .09251 Mdot
.57599 .09279 Mdot
.57604 .09308 Mdot
.57609 .09336 Mdot
.57614 .09364 Mdot
.57618 .09393 Mdot
.57623 .09421 Mdot
.57628 .0945 Mdot
.57633 .09478 Mdot
.57637 .09507 Mdot
.57642 .09535 Mdot
.57647 .09564 Mdot
.57652 .09593 Mdot
.57656 .09622 Mdot
.57661 .09651 Mdot
.57666 .09679 Mdot
.57671 .09708 Mdot
.57675 .09737 Mdot
.5768 .09766 Mdot
.57685 .09796 Mdot
.5769 .09825 Mdot
.57694 .09855 Mdot
.57699 .09884 Mdot
.57704 .09913 Mdot
.57709 .09943 Mdot
.57714 .09972 Mdot
.57718 .10002 Mdot
.57723 .10031 Mdot
.57728 .10061 Mdot
.57733 .1009 Mdot
.57737 .1012 Mdot
.57742 .10149 Mdot
.57747 .10179 Mdot
.57752 .10209 Mdot
.57756 .10239 Mdot
.57761 .10269 Mdot
.57766 .10298 Mdot
.57771 .10328 Mdot
.57775 .10358 Mdot
.5778 .10388 Mdot
.57785 .10418 Mdot
.5779 .10448 Mdot
.57794 .10477 Mdot
.57799 .10507 Mdot
.57804 .10538 Mdot
.57809 .10568 Mdot
.57814 .10598 Mdot
.57818 .10628 Mdot
.57823 .10658 Mdot
.57828 .10688 Mdot
.57833 .10718 Mdot
.57837 .10747 Mdot
.57842 .10776 Mdot
.57847 .10806 Mdot
.57852 .10835 Mdot
.57856 .10865 Mdot
.57861 .10895 Mdot
.57866 .10924 Mdot
.57871 .10954 Mdot
.57875 .10984 Mdot
.5788 .11014 Mdot
.57885 .11044 Mdot
.5789 .11073 Mdot
.57894 .11103 Mdot
.57899 .11133 Mdot
.57904 .11163 Mdot
.57909 .11193 Mdot
.57913 .11223 Mdot
.57918 .11253 Mdot
.57923 .11283 Mdot
.57928 .11313 Mdot
.57933 .11343 Mdot
.57937 .11372 Mdot
.57942 .11402 Mdot
.57947 .11431 Mdot
.57952 .11461 Mdot
.57956 .11491 Mdot
.57961 .1152 Mdot
.57966 .1155 Mdot
.57971 .1158 Mdot
.57975 .1161 Mdot
.5798 .1164 Mdot
.57985 .1167 Mdot
.5799 .11701 Mdot
.57994 .11731 Mdot
.57999 .11761 Mdot
.58004 .11791 Mdot
.58009 .11821 Mdot
.58013 .11851 Mdot
.58018 .11881 Mdot
.58023 .1191 Mdot
.58028 .1194 Mdot
.58033 .1197 Mdot
.58037 .11999 Mdot
.58042 .12029 Mdot
.58047 .12058 Mdot
.58052 .12088 Mdot
.58056 .12118 Mdot
.58061 .12149 Mdot
.58066 .12179 Mdot
.58071 .1221 Mdot
.58075 .12241 Mdot
.5808 .12272 Mdot
.58085 .12303 Mdot
.5809 .12334 Mdot
.58094 .12365 Mdot
.58099 .12397 Mdot
.58104 .12428 Mdot
.58109 .1246 Mdot
.58113 .12492 Mdot
.58118 .12523 Mdot
.58123 .12555 Mdot
.58128 .12587 Mdot
.58133 .12619 Mdot
.58137 .1265 Mdot
.58142 .12682 Mdot
.58147 .12714 Mdot
.58152 .12745 Mdot
.58156 .12777 Mdot
.58161 .12808 Mdot
.58166 .1284 Mdot
.58171 .12871 Mdot
.58175 .12903 Mdot
.5818 .12934 Mdot
.58185 .12966 Mdot
.5819 .12998 Mdot
.58194 .1303 Mdot
.58199 .13063 Mdot
.58204 .13095 Mdot
.58209 .13127 Mdot
.58213 .1316 Mdot
.58218 .13192 Mdot
.58223 .13225 Mdot
.58228 .13257 Mdot
.58233 .1329 Mdot
.58237 .13323 Mdot
.58242 .13356 Mdot
.58247 .13388 Mdot
.58252 .13421 Mdot
.58256 .13454 Mdot
.58261 .13487 Mdot
.58266 .1352 Mdot
.58271 .13553 Mdot
.58275 .13586 Mdot
.5828 .13619 Mdot
.58285 .13652 Mdot
.5829 .13685 Mdot
.58294 .13718 Mdot
.58299 .13751 Mdot
.58304 .13784 Mdot
.58309 .13818 Mdot
.58313 .13851 Mdot
.58318 .13884 Mdot
.58323 .13917 Mdot
.58328 .13951 Mdot
.58333 .13984 Mdot
.58337 .14017 Mdot
.58342 .14051 Mdot
.58347 .14085 Mdot
.58352 .14119 Mdot
.58356 .14153 Mdot
.58361 .14187 Mdot
.58366 .14221 Mdot
.58371 .14255 Mdot
.58375 .1429 Mdot
.5838 .14324 Mdot
.58385 .14359 Mdot
.5839 .14394 Mdot
.58394 .14429 Mdot
.58399 .14463 Mdot
.58404 .14499 Mdot
.58409 .14534 Mdot
.58413 .14569 Mdot
.58418 .14604 Mdot
.58423 .14639 Mdot
.58428 .14674 Mdot
.58432 .1471 Mdot
.58437 .14745 Mdot
.58442 .1478 Mdot
.58447 .14816 Mdot
.58452 .14851 Mdot
.58456 .14887 Mdot
.58461 .14922 Mdot
.58466 .14957 Mdot
.58471 .14993 Mdot
.58475 .15029 Mdot
.5848 .15064 Mdot
.58485 .151 Mdot
.5849 .15136 Mdot
.58494 .15172 Mdot
.58499 .15208 Mdot
.58504 .15245 Mdot
.58509 .15281 Mdot
.58513 .15317 Mdot
.58518 .15354 Mdot
.58523 .15391 Mdot
.58528 .15428 Mdot
.58532 .15465 Mdot
.58537 .15503 Mdot
.58542 .1554 Mdot
.58547 .15578 Mdot
.58552 .15616 Mdot
.58556 .15654 Mdot
.58561 .15692 Mdot
.58566 .1573 Mdot
.58571 .15769 Mdot
.58575 .15807 Mdot
.5858 .15846 Mdot
.58585 .15884 Mdot
.5859 .15923 Mdot
.58594 .15961 Mdot
.58599 .15999 Mdot
.58604 .16037 Mdot
.58609 .16075 Mdot
.58613 .16112 Mdot
.58618 .1615 Mdot
.58623 .16188 Mdot
.58628 .16226 Mdot
.58632 .16263 Mdot
.58637 .16301 Mdot
.58642 .16339 Mdot
.58647 .16377 Mdot
.58652 .16415 Mdot
.58656 .16453 Mdot
.58661 .16492 Mdot
.58666 .1653 Mdot
.58671 .16569 Mdot
.58675 .16607 Mdot
.5868 .16646 Mdot
.58685 .16684 Mdot
.5869 .16723 Mdot
.58694 .16762 Mdot
.58699 .16801 Mdot
.58704 .1684 Mdot
.58709 .16879 Mdot
.58713 .16918 Mdot
.58718 .16956 Mdot
.58723 .16995 Mdot
.58728 .17034 Mdot
.58732 .17072 Mdot
.58737 .17111 Mdot
.58742 .17149 Mdot
.58747 .17188 Mdot
.58752 .17227 Mdot
.58756 .17266 Mdot
.58761 .17305 Mdot
.58766 .17344 Mdot
.58771 .17384 Mdot
.58775 .17423 Mdot
.5878 .17463 Mdot
.58785 .17502 Mdot
.5879 .17541 Mdot
.58794 .17581 Mdot
.58799 .17621 Mdot
.58804 .1766 Mdot
.58809 .177 Mdot
.58813 .17739 Mdot
.58818 .17779 Mdot
.58823 .17819 Mdot
.58828 .17858 Mdot
.58832 .17897 Mdot
.58837 .17937 Mdot
.58842 .17976 Mdot
.58847 .18015 Mdot
.58851 .18054 Mdot
.58856 .18094 Mdot
.58861 .18133 Mdot
.58866 .18172 Mdot
.58871 .18212 Mdot
.58875 .18251 Mdot
.5888 .1829 Mdot
.58885 .1833 Mdot
.5889 .18369 Mdot
.58894 .18408 Mdot
.58899 .18448 Mdot
.58904 .18487 Mdot
.58909 .18527 Mdot
.58913 .18566 Mdot
.58918 .18606 Mdot
.58923 .18646 Mdot
.58928 .18686 Mdot
.58932 .18726 Mdot
.58937 .18766 Mdot
.58942 .18806 Mdot
.58947 .18846 Mdot
.58951 .18887 Mdot
.58956 .18927 Mdot
.58961 .18967 Mdot
.58966 .19008 Mdot
.58971 .19048 Mdot
.58975 .19088 Mdot
.5898 .19129 Mdot
.58985 .19169 Mdot
.5899 .19209 Mdot
.58994 .19249 Mdot
.58999 .19289 Mdot
.59004 .19329 Mdot
.59009 .19369 Mdot
.59013 .1941 Mdot
.59018 .1945 Mdot
.59023 .1949 Mdot
.59028 .19531 Mdot
.59032 .19571 Mdot
.59037 .19611 Mdot
.59042 .19652 Mdot
.59047 .19692 Mdot
.59051 .19732 Mdot
.59056 .19772 Mdot
.59061 .19812 Mdot
.59066 .19852 Mdot
.59071 .19892 Mdot
.59075 .19933 Mdot
.5908 .19973 Mdot
.59085 .20013 Mdot
.5909 .20054 Mdot
.59094 .20094 Mdot
.59099 .20134 Mdot
.59104 .20175 Mdot
.59109 .20215 Mdot
.59113 .20256 Mdot
.59118 .20296 Mdot
.59123 .20337 Mdot
.59128 .20378 Mdot
.59132 .20419 Mdot
.59137 .2046 Mdot
.59142 .20501 Mdot
.59147 .20542 Mdot
.59151 .20583 Mdot
.59156 .20625 Mdot
.59161 .20666 Mdot
.59166 .20708 Mdot
.59171 .2075 Mdot
.59175 .20791 Mdot
.5918 .20833 Mdot
.59185 .20875 Mdot
.5919 .20917 Mdot
.59194 .20959 Mdot
.59199 .21002 Mdot
.59204 .21044 Mdot
.59209 .21086 Mdot
.59213 .21129 Mdot
.59218 .21171 Mdot
.59223 .21213 Mdot
.59228 .21255 Mdot
.59232 .21297 Mdot
.59237 .21339 Mdot
.59242 .2138 Mdot
.59247 .21423 Mdot
.59251 .21465 Mdot
.59256 .21507 Mdot
.59261 .21549 Mdot
.59266 .21592 Mdot
.59271 .21635 Mdot
.59275 .21677 Mdot
.5928 .2172 Mdot
.59285 .21763 Mdot
.5929 .21806 Mdot
.59294 .2185 Mdot
.59299 .21893 Mdot
.59304 .21936 Mdot
.59309 .2198 Mdot
.59313 .22023 Mdot
.59318 .22066 Mdot
.59323 .2211 Mdot
.59328 .22153 Mdot
.59332 .22196 Mdot
.59337 .22239 Mdot
.59342 .22282 Mdot
.59347 .22325 Mdot
.59351 .22369 Mdot
.59356 .22413 Mdot
.59361 .22456 Mdot
.59366 .225 Mdot
.5937 .22544 Mdot
.59375 .22587 Mdot
.5938 .22631 Mdot
.59385 .22675 Mdot
.5939 .2272 Mdot
.59394 .22764 Mdot
.59399 .22808 Mdot
.59404 .22852 Mdot
.59409 .22897 Mdot
.59413 .22941 Mdot
.59418 .22986 Mdot
.59423 .23031 Mdot
.59428 .23076 Mdot
.59432 .23121 Mdot
.59437 .23165 Mdot
.59442 .2321 Mdot
.59447 .23255 Mdot
.59451 .233 Mdot
.59456 .23344 Mdot
.59461 .23389 Mdot
.59466 .23433 Mdot
.5947 .23478 Mdot
.59475 .23523 Mdot
.5948 .23568 Mdot
.59485 .23613 Mdot
.5949 .23658 Mdot
.59494 .23703 Mdot
.59499 .23748 Mdot
.59504 .23793 Mdot
.59509 .23838 Mdot
.59513 .23883 Mdot
.59518 .23928 Mdot
.59523 .23973 Mdot
.59528 .24019 Mdot
.59532 .24064 Mdot
.59537 .24109 Mdot
.59542 .24154 Mdot
.59547 .24199 Mdot
.59551 .24245 Mdot
.59556 .24291 Mdot
.59561 .24336 Mdot
.59566 .24382 Mdot
.5957 .24428 Mdot
.59575 .24473 Mdot
.5958 .24519 Mdot
.59585 .24564 Mdot
.5959 .2461 Mdot
.59594 .24656 Mdot
.59599 .24701 Mdot
.59604 .24747 Mdot
.59609 .24792 Mdot
.59613 .24838 Mdot
.59618 .24884 Mdot
.59623 .24929 Mdot
.59628 .24975 Mdot
.59632 .2502 Mdot
.59637 .25066 Mdot
.59642 .25111 Mdot
.59647 .25157 Mdot
.59651 .25202 Mdot
.59656 .25248 Mdot
.59661 .25293 Mdot
.59666 .25339 Mdot
.5967 .25384 Mdot
.59675 .25429 Mdot
.5968 .25474 Mdot
.59685 .25519 Mdot
.5969 .25564 Mdot
.59694 .2561 Mdot
.59699 .25656 Mdot
.59704 .25702 Mdot
.59709 .25748 Mdot
.59713 .25794 Mdot
.59718 .2584 Mdot
.59723 .25886 Mdot
.59728 .25932 Mdot
.59732 .25977 Mdot
.59737 .26023 Mdot
.59742 .26069 Mdot
.59747 .26115 Mdot
.59751 .26161 Mdot
.59756 .26206 Mdot
.59761 .26252 Mdot
.59766 .26298 Mdot
.5977 .26343 Mdot
.59775 .26388 Mdot
.5978 .26434 Mdot
.59785 .26479 Mdot
.59789 .26525 Mdot
.59794 .2657 Mdot
.59799 .26615 Mdot
.59804 .2666 Mdot
.59809 .26705 Mdot
.59813 .26749 Mdot
.59818 .26794 Mdot
.59823 .26839 Mdot
.59828 .26885 Mdot
.59832 .2693 Mdot
.59837 .26975 Mdot
.59842 .2702 Mdot
.59847 .27064 Mdot
.59851 .27109 Mdot
.59856 .27154 Mdot
.59861 .27199 Mdot
.59866 .27244 Mdot
.5987 .27289 Mdot
.59875 .27334 Mdot
.5988 .27379 Mdot
.59885 .27424 Mdot
.59889 .27469 Mdot
.59894 .27514 Mdot
.59899 .2756 Mdot
.59904 .27605 Mdot
.59909 .27651 Mdot
.59913 .27696 Mdot
.59918 .27741 Mdot
.59923 .27787 Mdot
.59928 .27832 Mdot
.59932 .27878 Mdot
.59937 .27923 Mdot
.59942 .27969 Mdot
.59947 .28014 Mdot
.59951 .2806 Mdot
.59956 .28105 Mdot
.59961 .2815 Mdot
.59966 .28195 Mdot
.5997 .28241 Mdot
.59975 .28286 Mdot
.5998 .28331 Mdot
.59985 .28377 Mdot
.59989 .28422 Mdot
.59994 .28467 Mdot
.59999 .28513 Mdot
.60004 .28558 Mdot
.60009 .28604 Mdot
.60013 .28649 Mdot
.60018 .28695 Mdot
.60023 .28741 Mdot
.60028 .28787 Mdot
.60032 .28833 Mdot
.60037 .28879 Mdot
.60042 .28925 Mdot
.60047 .2897 Mdot
.60051 .29016 Mdot
.60056 .29062 Mdot
.60061 .29107 Mdot
.60066 .29152 Mdot
.6007 .29198 Mdot
.60075 .29243 Mdot
.6008 .29289 Mdot
.60085 .29334 Mdot
.60089 .29379 Mdot
.60094 .29424 Mdot
.60099 .29469 Mdot
.60104 .29514 Mdot
.60109 .29559 Mdot
.60113 .29604 Mdot
.60118 .29649 Mdot
.60123 .29694 Mdot
.60128 .2974 Mdot
.60132 .29785 Mdot
.60137 .2983 Mdot
.60142 .29874 Mdot
.60147 .29919 Mdot
.60151 .29964 Mdot
.60156 .30009 Mdot
.60161 .30054 Mdot
.60166 .30099 Mdot
.6017 .30144 Mdot
.60175 .30189 Mdot
.6018 .30234 Mdot
.60185 .30279 Mdot
.60189 .30324 Mdot
.60194 .30369 Mdot
.60199 .30414 Mdot
.60204 .30459 Mdot
.60209 .30504 Mdot
.60213 .3055 Mdot
.60218 .30595 Mdot
.60223 .3064 Mdot
.60228 .30686 Mdot
.60232 .30731 Mdot
.60237 .30776 Mdot
.60242 .30821 Mdot
.60247 .30867 Mdot
.60251 .30912 Mdot
.60256 .30957 Mdot
.60261 .31002 Mdot
.60266 .31047 Mdot
.6027 .31093 Mdot
.60275 .31138 Mdot
.6028 .31183 Mdot
.60285 .31228 Mdot
.60289 .31273 Mdot
.60294 .31318 Mdot
.60299 .31363 Mdot
.60304 .31408 Mdot
.60308 .31453 Mdot
.60313 .31498 Mdot
.60318 .31543 Mdot
.60323 .31588 Mdot
.60328 .31633 Mdot
.60332 .31677 Mdot
.60337 .31722 Mdot
.60342 .31766 Mdot
.60347 .3181 Mdot
.60351 .31855 Mdot
.60356 .31899 Mdot
.60361 .31943 Mdot
.60366 .31987 Mdot
.6037 .32031 Mdot
.60375 .32075 Mdot
.6038 .32118 Mdot
.60385 .32162 Mdot
.60389 .32206 Mdot
.60394 .32249 Mdot
.60399 .32293 Mdot
.60404 .32337 Mdot
.60408 .3238 Mdot
.60413 .32424 Mdot
.60418 .32468 Mdot
.60423 .32511 Mdot
.60428 .32555 Mdot
.60432 .32599 Mdot
.60437 .32643 Mdot
.60442 .32687 Mdot
.60447 .32731 Mdot
.60451 .32774 Mdot
.60456 .32818 Mdot
.60461 .32862 Mdot
.60466 .32906 Mdot
.6047 .3295 Mdot
.60475 .32994 Mdot
.6048 .33039 Mdot
.60485 .33084 Mdot
.60489 .33128 Mdot
.60494 .33173 Mdot
.60499 .33217 Mdot
.60504 .33262 Mdot
.60508 .33306 Mdot
.60513 .33351 Mdot
.60518 .33396 Mdot
.60523 .33441 Mdot
.60528 .33486 Mdot
.60532 .33531 Mdot
.60537 .33576 Mdot
.60542 .33621 Mdot
.60547 .33665 Mdot
.60551 .3371 Mdot
.60556 .33755 Mdot
.60561 .33799 Mdot
.60566 .33844 Mdot
.6057 .3389 Mdot
.60575 .33935 Mdot
.6058 .3398 Mdot
.60585 .34025 Mdot
.60589 .3407 Mdot
.60594 .34115 Mdot
.60599 .3416 Mdot
.60604 .34205 Mdot
.60608 .3425 Mdot
.60613 .34295 Mdot
.60618 .34339 Mdot
.60623 .34384 Mdot
.60628 .34428 Mdot
.60632 .34473 Mdot
.60637 .34517 Mdot
.60642 .34562 Mdot
.60647 .34606 Mdot
.60651 .3465 Mdot
.60656 .34695 Mdot
.60661 .34739 Mdot
.60666 .34784 Mdot
.6067 .34829 Mdot
.60675 .34874 Mdot
.6068 .34919 Mdot
.60685 .34964 Mdot
.60689 .3501 Mdot
.60694 .35055 Mdot
.60699 .351 Mdot
.60704 .35146 Mdot
.60708 .35192 Mdot
.60713 .35237 Mdot
.60718 .35283 Mdot
.60723 .35328 Mdot
.60727 .35374 Mdot
.60732 .35419 Mdot
.60737 .35464 Mdot
.60742 .35509 Mdot
.60747 .35554 Mdot
.60751 .35599 Mdot
.60756 .35644 Mdot
.60761 .35688 Mdot
.60766 .35733 Mdot
.6077 .35778 Mdot
.60775 .35822 Mdot
.6078 .35866 Mdot
.60785 .3591 Mdot
.60789 .35954 Mdot
.60794 .35998 Mdot
.60799 .36042 Mdot
.60804 .36087 Mdot
.60808 .36131 Mdot
.60813 .36176 Mdot
.60818 .3622 Mdot
.60823 .36264 Mdot
.60827 .36308 Mdot
.60832 .36352 Mdot
.60837 .36396 Mdot
.60842 .36439 Mdot
.60847 .36483 Mdot
.60851 .36527 Mdot
.60856 .36571 Mdot
.60861 .36615 Mdot
.60866 .36659 Mdot
.6087 .36703 Mdot
.60875 .36747 Mdot
.6088 .36792 Mdot
.60885 .36836 Mdot
.60889 .36879 Mdot
.60894 .36923 Mdot
.60899 .36966 Mdot
.60904 .3701 Mdot
.60908 .37053 Mdot
.60913 .37096 Mdot
.60918 .37139 Mdot
.60923 .37182 Mdot
.60927 .37225 Mdot
.60932 .37268 Mdot
.60937 .3731 Mdot
.60942 .37353 Mdot
.60947 .37395 Mdot
.60951 .37437 Mdot
.60956 .37479 Mdot
.60961 .37521 Mdot
.60966 .37564 Mdot
.6097 .37606 Mdot
.60975 .37647 Mdot
.6098 .37689 Mdot
.60985 .3773 Mdot
.60989 .37772 Mdot
.60994 .37813 Mdot
.60999 .37855 Mdot
.61004 .37896 Mdot
.61008 .37938 Mdot
.61013 .37979 Mdot
.61018 .3802 Mdot
.61023 .38061 Mdot
.61027 .38103 Mdot
.61032 .38144 Mdot
.61037 .38185 Mdot
.61042 .38225 Mdot
.61047 .38266 Mdot
.61051 .38307 Mdot
.61056 .38347 Mdot
.61061 .38388 Mdot
.61066 .38429 Mdot
.6107 .3847 Mdot
.61075 .38511 Mdot
.6108 .38552 Mdot
.61085 .38593 Mdot
.61089 .38634 Mdot
.61094 .38675 Mdot
.61099 .38716 Mdot
.61104 .38756 Mdot
.61108 .38797 Mdot
.61113 .38838 Mdot
.61118 .38879 Mdot
.61123 .3892 Mdot
.61127 .38961 Mdot
.61132 .39002 Mdot
.61137 .39042 Mdot
.61142 .39083 Mdot
.61147 .39124 Mdot
.61151 .39164 Mdot
.61156 .39205 Mdot
.61161 .39246 Mdot
.61166 .39286 Mdot
.6117 .39327 Mdot
.61175 .39367 Mdot
.6118 .39407 Mdot
.61185 .39447 Mdot
.61189 .39487 Mdot
.61194 .39527 Mdot
.61199 .39567 Mdot
.61204 .39606 Mdot
.61208 .39646 Mdot
.61213 .39685 Mdot
.61218 .39725 Mdot
.61223 .39764 Mdot
.61227 .39803 Mdot
.61232 .39842 Mdot
.61237 .39881 Mdot
.61242 .3992 Mdot
.61246 .39959 Mdot
.61251 .39998 Mdot
.61256 .40037 Mdot
.61261 .40076 Mdot
.61266 .40115 Mdot
.6127 .40154 Mdot
.61275 .40192 Mdot
.6128 .40231 Mdot
.61285 .4027 Mdot
.61289 .40308 Mdot
.61294 .40347 Mdot
.61299 .40386 Mdot
.61304 .40425 Mdot
.61308 .40463 Mdot
.61313 .40502 Mdot
.61318 .4054 Mdot
.61323 .40579 Mdot
.61327 .40617 Mdot
.61332 .40656 Mdot
.61337 .40695 Mdot
.61342 .40733 Mdot
.61346 .40771 Mdot
.61351 .4081 Mdot
.61356 .40848 Mdot
.61361 .40887 Mdot
.61366 .40925 Mdot
.6137 .40963 Mdot
.61375 .41001 Mdot
.6138 .41039 Mdot
.61385 .41077 Mdot
.61389 .41116 Mdot
.61394 .41154 Mdot
.61399 .41192 Mdot
.61404 .41231 Mdot
.61408 .41269 Mdot
.61413 .41308 Mdot
.61418 .41346 Mdot
.61423 .41384 Mdot
.61427 .41423 Mdot
.61432 .41461 Mdot
.61437 .415 Mdot
.61442 .41538 Mdot
.61446 .41577 Mdot
.61451 .41616 Mdot
.61456 .41655 Mdot
.61461 .41694 Mdot
.61466 .41732 Mdot
.6147 .4177 Mdot
.61475 .41809 Mdot
.6148 .41847 Mdot
.61485 .41886 Mdot
.61489 .41924 Mdot
.61494 .41963 Mdot
.61499 .42002 Mdot
.61504 .4204 Mdot
.61508 .42079 Mdot
.61513 .42118 Mdot
.61518 .42156 Mdot
.61523 .42195 Mdot
.61527 .42234 Mdot
.61532 .42272 Mdot
.61537 .4231 Mdot
.61542 .42349 Mdot
.61546 .42387 Mdot
.61551 .42425 Mdot
.61556 .42463 Mdot
.61561 .42502 Mdot
.61566 .4254 Mdot
.6157 .42579 Mdot
.61575 .42617 Mdot
.6158 .42655 Mdot
.61585 .42693 Mdot
.61589 .42731 Mdot
.61594 .42769 Mdot
.61599 .42807 Mdot
.61604 .42845 Mdot
.61608 .42883 Mdot
.61613 .42921 Mdot
.61618 .42959 Mdot
.61623 .42996 Mdot
.61627 .43034 Mdot
.61632 .43072 Mdot
.61637 .4311 Mdot
.61642 .43147 Mdot
.61646 .43184 Mdot
.61651 .43222 Mdot
.61656 .4326 Mdot
.61661 .43297 Mdot
.61666 .43335 Mdot
.6167 .43372 Mdot
.61675 .4341 Mdot
.6168 .43447 Mdot
.61685 .43485 Mdot
.61689 .43523 Mdot
.61694 .43561 Mdot
.61699 .43598 Mdot
.61704 .43636 Mdot
.61708 .43674 Mdot
.61713 .43712 Mdot
.61718 .4375 Mdot
.61723 .43788 Mdot
.61727 .43825 Mdot
.61732 .43863 Mdot
.61737 .439 Mdot
.61742 .43938 Mdot
.61746 .43975 Mdot
.61751 .44013 Mdot
.61756 .44051 Mdot
.61761 .44088 Mdot
.61765 .44126 Mdot
.6177 .44164 Mdot
.61775 .44202 Mdot
.6178 .4424 Mdot
.61785 .44278 Mdot
.61789 .44315 Mdot
.61794 .44353 Mdot
.61799 .44391 Mdot
.61804 .44428 Mdot
.61808 .44466 Mdot
.61813 .44504 Mdot
.61818 .44541 Mdot
.61823 .44579 Mdot
.61827 .44617 Mdot
.61832 .44654 Mdot
.61837 .44692 Mdot
.61842 .4473 Mdot
.61846 .44768 Mdot
.61851 .44806 Mdot
.61856 .44844 Mdot
.61861 .44883 Mdot
.61865 .4492 Mdot
.6187 .44958 Mdot
.61875 .44996 Mdot
.6188 .45034 Mdot
.61885 .45072 Mdot
.61889 .45109 Mdot
.61894 .45147 Mdot
.61899 .45185 Mdot
.61904 .45222 Mdot
.61908 .4526 Mdot
.61913 .45297 Mdot
.61918 .45335 Mdot
.61923 .45372 Mdot
.61927 .45409 Mdot
.61932 .45447 Mdot
.61937 .45484 Mdot
.61942 .45522 Mdot
.61946 .45559 Mdot
.61951 .45596 Mdot
.61956 .45633 Mdot
.61961 .45671 Mdot
.61965 .45708 Mdot
.6197 .45746 Mdot
.61975 .45783 Mdot
.6198 .4582 Mdot
.61985 .45858 Mdot
.61989 .45895 Mdot
.61994 .45932 Mdot
.61999 .45969 Mdot
.62004 .46006 Mdot
.62008 .46042 Mdot
.62013 .46079 Mdot
.62018 .46116 Mdot
.62023 .46152 Mdot
.62027 .46189 Mdot
.62032 .46225 Mdot
.62037 .46262 Mdot
.62042 .46298 Mdot
.62046 .46334 Mdot
.62051 .4637 Mdot
.62056 .46406 Mdot
.62061 .46442 Mdot
.62065 .46478 Mdot
.6207 .46514 Mdot
.62075 .4655 Mdot
.6208 .46586 Mdot
.62085 .46622 Mdot
.62089 .46658 Mdot
.62094 .46693 Mdot
.62099 .46729 Mdot
.62104 .46765 Mdot
.62108 .46801 Mdot
.62113 .46837 Mdot
.62118 .46873 Mdot
.62123 .46909 Mdot
.62127 .46945 Mdot
.62132 .46981 Mdot
.62137 .47016 Mdot
.62142 .47052 Mdot
.62146 .47087 Mdot
.62151 .47122 Mdot
.62156 .47157 Mdot
.62161 .47192 Mdot
.62165 .47227 Mdot
.6217 .47262 Mdot
.62175 .47297 Mdot
.6218 .47332 Mdot
.62184 .47367 Mdot
.62189 .47403 Mdot
.62194 .47438 Mdot
.62199 .47473 Mdot
.62204 .47507 Mdot
.62208 .47542 Mdot
.62213 .47577 Mdot
.62218 .47612 Mdot
.62223 .47647 Mdot
.62227 .47682 Mdot
.62232 .47716 Mdot
.62237 .47751 Mdot
.62242 .47785 Mdot
.62246 .4782 Mdot
.62251 .47854 Mdot
.62256 .47889 Mdot
.62261 .47923 Mdot
.62265 .47957 Mdot
.6227 .47992 Mdot
.62275 .48026 Mdot
.6228 .48061 Mdot
.62284 .48095 Mdot
.62289 .48129 Mdot
.62294 .48164 Mdot
.62299 .48198 Mdot
.62304 .48232 Mdot
.62308 .48266 Mdot
.62313 .48301 Mdot
.62318 .48335 Mdot
.62323 .48369 Mdot
.62327 .48402 Mdot
.62332 .48437 Mdot
.62337 .48471 Mdot
.62342 .48504 Mdot
.62346 .48538 Mdot
.62351 .48572 Mdot
.62356 .48606 Mdot
.62361 .48639 Mdot
.62365 .48672 Mdot
.6237 .48705 Mdot
.62375 .48738 Mdot
.6238 .48771 Mdot
.62384 .48804 Mdot
.62389 .48837 Mdot
.62394 .4887 Mdot
.62399 .48903 Mdot
.62404 .48935 Mdot
.62408 .48968 Mdot
.62413 .49 Mdot
.62418 .49033 Mdot
.62423 .49066 Mdot
.62427 .49099 Mdot
.62432 .49131 Mdot
.62437 .49164 Mdot
.62442 .49197 Mdot
.62446 .4923 Mdot
.62451 .49262 Mdot
.62456 .49295 Mdot
.62461 .49327 Mdot
.62465 .4936 Mdot
.6247 .49392 Mdot
.62475 .49424 Mdot
.6248 .49456 Mdot
.62484 .49489 Mdot
.62489 .49521 Mdot
.62494 .49553 Mdot
.62499 .49585 Mdot
.62504 .49617 Mdot
.62508 .49649 Mdot
.62513 .4968 Mdot
.62518 .49712 Mdot
.62523 .49744 Mdot
.62527 .49776 Mdot
.62532 .49808 Mdot
.62537 .4984 Mdot
.62542 .49871 Mdot
.62546 .49902 Mdot
.62551 .49934 Mdot
.62556 .49965 Mdot
.62561 .49996 Mdot
.62565 .50027 Mdot
.6257 .50058 Mdot
.62575 .50089 Mdot
.6258 .50119 Mdot
.62584 .5015 Mdot
.62589 .5018 Mdot
.62594 .5021 Mdot
.62599 .5024 Mdot
.62604 .5027 Mdot
.62608 .503 Mdot
.62613 .50329 Mdot
.62618 .50359 Mdot
.62623 .50389 Mdot
.62627 .50418 Mdot
.62632 .50447 Mdot
.62637 .50477 Mdot
.62642 .50506 Mdot
.62646 .50535 Mdot
.62651 .50565 Mdot
.62656 .50594 Mdot
.62661 .50624 Mdot
.62665 .50653 Mdot
.6267 .50682 Mdot
.62675 .5071 Mdot
.6268 .50739 Mdot
.62684 .50768 Mdot
.62689 .50797 Mdot
.62694 .50826 Mdot
.62699 .50854 Mdot
.62703 .50884 Mdot
.62708 .50913 Mdot
.62713 .50942 Mdot
.62718 .50971 Mdot
.62723 .50999 Mdot
.62727 .51028 Mdot
.62732 .51057 Mdot
.62737 .51086 Mdot
.62742 .51115 Mdot
.62746 .51143 Mdot
.62751 .51171 Mdot
.62756 .512 Mdot
.62761 .51228 Mdot
.62765 .51256 Mdot
.6277 .51284 Mdot
.62775 .51313 Mdot
.6278 .51341 Mdot
.62784 .51369 Mdot
.62789 .51398 Mdot
.62794 .51426 Mdot
.62799 .51455 Mdot
.62803 .51483 Mdot
.62808 .51512 Mdot
.62813 .51541 Mdot
.62818 .5157 Mdot
.62823 .51598 Mdot
.62827 .51627 Mdot
.62832 .51655 Mdot
.62837 .51684 Mdot
.62842 .51712 Mdot
.62846 .5174 Mdot
.62851 .51769 Mdot
.62856 .51797 Mdot
.62861 .51825 Mdot
.62865 .51853 Mdot
.6287 .51881 Mdot
.62875 .51908 Mdot
.6288 .51937 Mdot
.62884 .51964 Mdot
.62889 .51992 Mdot
.62894 .5202 Mdot
.62899 .52048 Mdot
.62903 .52076 Mdot
.62908 .52104 Mdot
.62913 .52132 Mdot
.62918 .5216 Mdot
.62923 .52188 Mdot
.62927 .52216 Mdot
.62932 .52244 Mdot
.62937 .52272 Mdot
.62942 .52299 Mdot
.62946 .52327 Mdot
.62951 .52354 Mdot
.62956 .52382 Mdot
.62961 .52409 Mdot
.62965 .52436 Mdot
.6297 .52464 Mdot
.62975 .52491 Mdot
.6298 .52518 Mdot
.62984 .52545 Mdot
.62989 .52572 Mdot
.62994 .52599 Mdot
.62999 .52625 Mdot
.63003 .52652 Mdot
.63008 .52678 Mdot
.63013 .52705 Mdot
.63018 .52732 Mdot
.63023 .52759 Mdot
.63027 .52786 Mdot
.63032 .52813 Mdot
.63037 .52839 Mdot
.63042 .52865 Mdot
.63046 .52891 Mdot
.63051 .52917 Mdot
.63056 .52943 Mdot
.63061 .52969 Mdot
.63065 .52995 Mdot
.6307 .53021 Mdot
.63075 .53048 Mdot
.6308 .53074 Mdot
.63084 .531 Mdot
.63089 .53126 Mdot
.63094 .53153 Mdot
.63099 .53179 Mdot
.63103 .53205 Mdot
.63108 .53231 Mdot
.63113 .53257 Mdot
.63118 .53283 Mdot
.63122 .5331 Mdot
.63127 .53336 Mdot
.63132 .53362 Mdot
.63137 .53388 Mdot
.63142 .53415 Mdot
.63146 .53441 Mdot
.63151 .53467 Mdot
.63156 .53494 Mdot
.63161 .53521 Mdot
.63165 .53548 Mdot
.6317 .53574 Mdot
.63175 .536 Mdot
.6318 .53627 Mdot
.63184 .53654 Mdot
.63189 .5368 Mdot
.63194 .53707 Mdot
.63199 .53734 Mdot
.63203 .5376 Mdot
.63208 .53787 Mdot
.63213 .53813 Mdot
.63218 .5384 Mdot
.63222 .53867 Mdot
.63227 .53893 Mdot
.63232 .53919 Mdot
.63237 .53946 Mdot
.63242 .53972 Mdot
.63246 .53998 Mdot
.63251 .54024 Mdot
.63256 .5405 Mdot
.63261 .54077 Mdot
.63265 .54103 Mdot
.6327 .5413 Mdot
.63275 .54156 Mdot
.6328 .54182 Mdot
.63284 .54208 Mdot
.63289 .54234 Mdot
.63294 .54259 Mdot
.63299 .54285 Mdot
.63303 .54311 Mdot
.63308 .54336 Mdot
.63313 .54362 Mdot
.63318 .54387 Mdot
.63322 .54412 Mdot
.63327 .54436 Mdot
.63332 .54461 Mdot
.63337 .54485 Mdot
.63342 .54509 Mdot
.63346 .54533 Mdot
.63351 .54557 Mdot
.63356 .54581 Mdot
.63361 .54605 Mdot
.63365 .54629 Mdot
.6337 .54654 Mdot
.63375 .54678 Mdot
.6338 .54702 Mdot
.63384 .54726 Mdot
.63389 .54751 Mdot
.63394 .54775 Mdot
.63399 .54799 Mdot
.63403 .54823 Mdot
.63408 .54847 Mdot
.63413 .54871 Mdot
.63418 .54895 Mdot
.63422 .54919 Mdot
.63427 .54943 Mdot
.63432 .54967 Mdot
.63437 .5499 Mdot
.63442 .55014 Mdot
.63446 .55037 Mdot
.63451 .55061 Mdot
.63456 .55083 Mdot
.63461 .55106 Mdot
.63465 .55128 Mdot
.6347 .5515 Mdot
.63475 .55172 Mdot
.6348 .55194 Mdot
.63484 .55216 Mdot
.63489 .55238 Mdot
.63494 .55261 Mdot
.63499 .55283 Mdot
.63503 .55305 Mdot
.63508 .55327 Mdot
.63513 .5535 Mdot
.63518 .55372 Mdot
.63522 .55395 Mdot
.63527 .55417 Mdot
.63532 .5544 Mdot
.63537 .55462 Mdot
.63542 .55485 Mdot
.63546 .55507 Mdot
.63551 .5553 Mdot
.63556 .55552 Mdot
.63561 .55574 Mdot
.63565 .55597 Mdot
.6357 .55619 Mdot
.63575 .55641 Mdot
.6358 .55663 Mdot
.63584 .55685 Mdot
.63589 .55706 Mdot
.63594 .55728 Mdot
.63599 .55749 Mdot
.63603 .5577 Mdot
.63608 .55792 Mdot
.63613 .55813 Mdot
.63618 .55834 Mdot
.63622 .55854 Mdot
.63627 .55874 Mdot
.63632 .55894 Mdot
.63637 .55914 Mdot
.63641 .55934 Mdot
.63646 .55954 Mdot
.63651 .55974 Mdot
.63656 .55993 Mdot
.63661 .56013 Mdot
.63665 .56032 Mdot
.6367 .56051 Mdot
.63675 .5607 Mdot
.6368 .56089 Mdot
.63684 .56108 Mdot
.63689 .56128 Mdot
.63694 .56147 Mdot
.63699 .56166 Mdot
.63703 .56185 Mdot
.63708 .56203 Mdot
.63713 .56222 Mdot
.63718 .5624 Mdot
.63722 .56258 Mdot
.63727 .56276 Mdot
.63732 .56293 Mdot
.63737 .5631 Mdot
.63741 .56327 Mdot
.63746 .56344 Mdot
.63751 .56361 Mdot
.63756 .56377 Mdot
.63761 .56394 Mdot
.63765 .56411 Mdot
.6377 .56428 Mdot
.63775 .56444 Mdot
.6378 .56461 Mdot
.63784 .56477 Mdot
.63789 .56493 Mdot
.63794 .5651 Mdot
.63799 .56526 Mdot
.63803 .56542 Mdot
.63808 .56558 Mdot
.63813 .56575 Mdot
.63818 .56591 Mdot
.63822 .56608 Mdot
.63827 .56624 Mdot
.63832 .56641 Mdot
.63837 .56657 Mdot
.63841 .56674 Mdot
.63846 .5669 Mdot
.63851 .56706 Mdot
.63856 .56723 Mdot
.63861 .56739 Mdot
.63865 .56756 Mdot
.6387 .56773 Mdot
.63875 .56789 Mdot
.6388 .56805 Mdot
.63884 .56822 Mdot
.63889 .56838 Mdot
.63894 .56854 Mdot
.63899 .5687 Mdot
.63903 .56885 Mdot
.63908 .56901 Mdot
.63913 .56917 Mdot
.63918 .56933 Mdot
.63922 .56948 Mdot
.63927 .56964 Mdot
.63932 .5698 Mdot
.63937 .56996 Mdot
.63941 .57012 Mdot
.63946 .57027 Mdot
.63951 .57043 Mdot
.63956 .57059 Mdot
.63961 .57075 Mdot
.63965 .57091 Mdot
.6397 .57106 Mdot
.63975 .57122 Mdot
.6398 .57138 Mdot
.63984 .57153 Mdot
.63989 .57169 Mdot
.63994 .57185 Mdot
.63999 .572 Mdot
.64003 .57216 Mdot
.64008 .57232 Mdot
.64013 .57247 Mdot
.64018 .57263 Mdot
.64022 .57279 Mdot
.64027 .57295 Mdot
.64032 .57311 Mdot
.64037 .57326 Mdot
.64041 .57342 Mdot
.64046 .57357 Mdot
.64051 .57372 Mdot
.64056 .57387 Mdot
.6406 .57402 Mdot
.64065 .57417 Mdot
.6407 .57432 Mdot
.64075 .57447 Mdot
.6408 .57461 Mdot
.64084 .57476 Mdot
.64089 .57491 Mdot
.64094 .57505 Mdot
.64099 .5752 Mdot
.64103 .57534 Mdot
.64108 .57548 Mdot
.64113 .57562 Mdot
.64118 .57576 Mdot
.64122 .57589 Mdot
.64127 .57603 Mdot
.64132 .57617 Mdot
.64137 .57631 Mdot
.64141 .57645 Mdot
.64146 .57658 Mdot
.64151 .57671 Mdot
.64156 .57684 Mdot
.6416 .57698 Mdot
.64165 .57711 Mdot
.6417 .57724 Mdot
.64175 .57737 Mdot
.6418 .5775 Mdot
.64184 .57762 Mdot
.64189 .57775 Mdot
.64194 .57787 Mdot
.64199 .578 Mdot
.64203 .57813 Mdot
.64208 .57825 Mdot
.64213 .57837 Mdot
.64218 .57849 Mdot
.64222 .57861 Mdot
.64227 .57873 Mdot
.64232 .57885 Mdot
.64237 .57897 Mdot
.64241 .5791 Mdot
.64246 .57922 Mdot
.64251 .57934 Mdot
.64256 .57945 Mdot
.6426 .57957 Mdot
.64265 .57969 Mdot
.6427 .57981 Mdot
.64275 .57992 Mdot
.6428 .58004 Mdot
.64284 .58016 Mdot
.64289 .58027 Mdot
.64294 .58039 Mdot
.64299 .5805 Mdot
.64303 .58062 Mdot
.64308 .58074 Mdot
.64313 .58085 Mdot
.64318 .58096 Mdot
.64322 .58108 Mdot
.64327 .5812 Mdot
.64332 .58132 Mdot
.64337 .58144 Mdot
.64341 .58156 Mdot
.64346 .58168 Mdot
.64351 .5818 Mdot
.64356 .58192 Mdot
.6436 .58204 Mdot
.64365 .58216 Mdot
.6437 .58227 Mdot
.64375 .58239 Mdot
.6438 .58251 Mdot
.64384 .58262 Mdot
.64389 .58274 Mdot
.64394 .58284 Mdot
.64399 .58295 Mdot
.64403 .58306 Mdot
.64408 .58318 Mdot
.64413 .58329 Mdot
.64418 .5834 Mdot
.64422 .58351 Mdot
.64427 .58363 Mdot
.64432 .58374 Mdot
.64437 .58385 Mdot
.64441 .58396 Mdot
.64446 .58407 Mdot
.64451 .58418 Mdot
.64456 .58429 Mdot
.6446 .58439 Mdot
.64465 .5845 Mdot
.6447 .5846 Mdot
.64475 .5847 Mdot
.6448 .5848 Mdot
.64484 .5849 Mdot
.64489 .585 Mdot
.64494 .5851 Mdot
.64499 .5852 Mdot
.64503 .5853 Mdot
.64508 .5854 Mdot
.64513 .5855 Mdot
.64518 .5856 Mdot
.64522 .5857 Mdot
.64527 .5858 Mdot
.64532 .5859 Mdot
.64537 .586 Mdot
.64541 .5861 Mdot
.64546 .58619 Mdot
.64551 .58629 Mdot
.64556 .58638 Mdot
.6456 .58648 Mdot
.64565 .58657 Mdot
.6457 .58667 Mdot
.64575 .58676 Mdot
.64579 .58686 Mdot
.64584 .58695 Mdot
.64589 .58704 Mdot
.64594 .58713 Mdot
.64599 .58722 Mdot
.64603 .58731 Mdot
.64608 .58739 Mdot
.64613 .58748 Mdot
.64618 .58757 Mdot
.64622 .58765 Mdot
.64627 .58774 Mdot
.64632 .58783 Mdot
.64637 .58791 Mdot
.64641 .58799 Mdot
.64646 .58807 Mdot
.64651 .58815 Mdot
.64656 .58824 Mdot
.6466 .58832 Mdot
.64665 .5884 Mdot
.6467 .58848 Mdot
.64675 .58856 Mdot
.64679 .58864 Mdot
.64684 .58872 Mdot
.64689 .58881 Mdot
.64694 .58889 Mdot
.64699 .58897 Mdot
.64703 .58904 Mdot
.64708 .58912 Mdot
.64713 .58919 Mdot
.64718 .58927 Mdot
.64722 .58934 Mdot
.64727 .58942 Mdot
.64732 .58949 Mdot
.64737 .58957 Mdot
.64741 .58964 Mdot
.64746 .58972 Mdot
.64751 .58979 Mdot
.64756 .58986 Mdot
.6476 .58994 Mdot
.64765 .59001 Mdot
.6477 .59008 Mdot
.64775 .59015 Mdot
.64779 .59022 Mdot
.64784 .59029 Mdot
.64789 .59035 Mdot
.64794 .59042 Mdot
.64799 .59048 Mdot
.64803 .59054 Mdot
.64808 .5906 Mdot
.64813 .59066 Mdot
.64818 .59072 Mdot
.64822 .59078 Mdot
.64827 .59084 Mdot
.64832 .5909 Mdot
.64837 .59095 Mdot
.64841 .591 Mdot
.64846 .59106 Mdot
.64851 .59111 Mdot
.64856 .59116 Mdot
.6486 .59121 Mdot
.64865 .59126 Mdot
.6487 .59131 Mdot
.64875 .59135 Mdot
.64879 .5914 Mdot
.64884 .59145 Mdot
.64889 .59149 Mdot
.64894 .59154 Mdot
.64899 .59158 Mdot
.64903 .59162 Mdot
.64908 .59167 Mdot
.64913 .59172 Mdot
.64918 .59176 Mdot
.64922 .59181 Mdot
.64927 .59185 Mdot
.64932 .5919 Mdot
.64937 .59194 Mdot
.64941 .59198 Mdot
.64946 .59202 Mdot
.64951 .59205 Mdot
.64956 .5921 Mdot
.6496 .59214 Mdot
.64965 .59218 Mdot
.6497 .59222 Mdot
.64975 .59226 Mdot
.64979 .5923 Mdot
.64984 .59233 Mdot
.64989 .59237 Mdot
.64994 .59241 Mdot
.64999 .59245 Mdot
.65003 .59248 Mdot
.65008 .59251 Mdot
.65013 .59254 Mdot
.65018 .59256 Mdot
.65022 .59259 Mdot
.65027 .59261 Mdot
.65032 .59264 Mdot
.65037 .59266 Mdot
.65041 .59269 Mdot
.65046 .59271 Mdot
.65051 .59274 Mdot
.65056 .59276 Mdot
.6506 .59278 Mdot
.65065 .5928 Mdot
.6507 .59282 Mdot
.65075 .59285 Mdot
.65079 .59287 Mdot
.65084 .59289 Mdot
.65089 .59291 Mdot
.65094 .59293 Mdot
.65098 .59294 Mdot
.65103 .59296 Mdot
.65108 .59298 Mdot
.65113 .593 Mdot
.65118 .59302 Mdot
.65122 .59304 Mdot
.65127 .59306 Mdot
.65132 .59307 Mdot
.65137 .59309 Mdot
.65141 .5931 Mdot
.65146 .59312 Mdot
.65151 .59313 Mdot
.65156 .59314 Mdot
.6516 .59316 Mdot
.65165 .59317 Mdot
.6517 .59317 Mdot
.65175 .59318 Mdot
.65179 .59318 Mdot
.65184 .59318 Mdot
.65189 .59318 Mdot
.65194 .59318 Mdot
.65198 .59318 Mdot
.65203 .59318 Mdot
.65208 .59318 Mdot
.65213 .59317 Mdot
.65218 .59316 Mdot
.65222 .59316 Mdot
.65227 .59314 Mdot
.65232 .59314 Mdot
.65237 .59313 Mdot
.65241 .59312 Mdot
.65246 .59311 Mdot
.65251 .59309 Mdot
.65256 .59308 Mdot
.6526 .59307 Mdot
.65265 .59307 Mdot
.6527 .59306 Mdot
.65275 .59305 Mdot
.65279 .59304 Mdot
.65284 .59303 Mdot
.65289 .59302 Mdot
.65294 .59302 Mdot
.65298 .593 Mdot
.65303 .59299 Mdot
.65308 .59298 Mdot
.65313 .59297 Mdot
.65318 .59295 Mdot
.65322 .59294 Mdot
.65327 .59293 Mdot
.65332 .59291 Mdot
.65337 .5929 Mdot
.65341 .59288 Mdot
.65346 .59285 Mdot
.65351 .59283 Mdot
.65356 .59281 Mdot
.6536 .59278 Mdot
.65365 .59275 Mdot
.6537 .59273 Mdot
.65375 .5927 Mdot
.65379 .59268 Mdot
.65384 .59265 Mdot
.65389 .59263 Mdot
.65394 .59261 Mdot
.65398 .59258 Mdot
.65403 .59256 Mdot
.65408 .59253 Mdot
.65413 .5925 Mdot
.65418 .59247 Mdot
.65422 .59244 Mdot
.65427 .59242 Mdot
.65432 .59239 Mdot
.65437 .59236 Mdot
.65441 .59233 Mdot
.65446 .59229 Mdot
.65451 .59226 Mdot
.65456 .59223 Mdot
.6546 .5922 Mdot
.65465 .59217 Mdot
.6547 .59214 Mdot
.65475 .59211 Mdot
.65479 .59208 Mdot
.65484 .59204 Mdot
.65489 .59201 Mdot
.65494 .59198 Mdot
.65498 .59194 Mdot
.65503 .59191 Mdot
.65508 .59187 Mdot
.65513 .59183 Mdot
.65517 .59179 Mdot
.65522 .59176 Mdot
.65527 .59172 Mdot
.65532 .59168 Mdot
.65537 .59164 Mdot
.65541 .5916 Mdot
.65546 .59156 Mdot
.65551 .59152 Mdot
.65556 .59147 Mdot
.6556 .59143 Mdot
.65565 .59139 Mdot
.6557 .59135 Mdot
.65575 .5913 Mdot
.65579 .59126 Mdot
.65584 .59122 Mdot
.65589 .59118 Mdot
.65594 .59113 Mdot
.65598 .59109 Mdot
.65603 .59105 Mdot
.65608 .59101 Mdot
.65613 .59097 Mdot
.65617 .59093 Mdot
.65622 .59089 Mdot
.65627 .59085 Mdot
.65632 .59081 Mdot
.65637 .59077 Mdot
.65641 .59072 Mdot
.65646 .59067 Mdot
.65651 .59062 Mdot
.65656 .59057 Mdot
.6566 .59051 Mdot
.65665 .59046 Mdot
.6567 .59041 Mdot
.65675 .59036 Mdot
.65679 .59031 Mdot
.65684 .59025 Mdot
.65689 .5902 Mdot
.65694 .59014 Mdot
.65698 .59008 Mdot
.65703 .59003 Mdot
.65708 .58998 Mdot
.65713 .58992 Mdot
.65717 .58988 Mdot
.65722 .58983 Mdot
.65727 .58978 Mdot
.65732 .58973 Mdot
.65737 .58968 Mdot
.65741 .58963 Mdot
.65746 .58958 Mdot
.65751 .58953 Mdot
.65756 .58948 Mdot
.6576 .58943 Mdot
.65765 .58938 Mdot
.6577 .58934 Mdot
.65775 .58929 Mdot
.65779 .58924 Mdot
.65784 .58918 Mdot
.65789 .58913 Mdot
.65794 .58907 Mdot
.65798 .58902 Mdot
.65803 .58897 Mdot
.65808 .58891 Mdot
.65813 .58886 Mdot
.65817 .58881 Mdot
.65822 .58877 Mdot
.65827 .58872 Mdot
.65832 .58867 Mdot
.65837 .58862 Mdot
.65841 .58858 Mdot
.65846 .58853 Mdot
.65851 .58848 Mdot
.65856 .58842 Mdot
.6586 .58837 Mdot
.65865 .58832 Mdot
.6587 .58827 Mdot
.65875 .58822 Mdot
.65879 .58817 Mdot
.65884 .58812 Mdot
.65889 .58806 Mdot
.65894 .588 Mdot
.65898 .58795 Mdot
.65903 .58789 Mdot
.65908 .58784 Mdot
.65913 .58779 Mdot
.65917 .58773 Mdot
.65922 .58767 Mdot
.65927 .58761 Mdot
.65932 .58755 Mdot
.65937 .58749 Mdot
.65941 .58742 Mdot
.65946 .58735 Mdot
.65951 .58729 Mdot
.65956 .58722 Mdot
.6596 .58715 Mdot
.65965 .58708 Mdot
.6597 .587 Mdot
.65975 .58692 Mdot
.65979 .58685 Mdot
.65984 .58677 Mdot
.65989 .58669 Mdot
.65994 .58661 Mdot
.65998 .58652 Mdot
.66003 .58645 Mdot
.66008 .58637 Mdot
.66013 .58629 Mdot
.66017 .58621 Mdot
.66022 .58613 Mdot
.66027 .58605 Mdot
.66032 .58597 Mdot
.66036 .58589 Mdot
.66041 .5858 Mdot
.66046 .58571 Mdot
.66051 .58562 Mdot
.66056 .58553 Mdot
.6606 .58545 Mdot
.66065 .58536 Mdot
.6607 .58527 Mdot
.66075 .58518 Mdot
.66079 .58509 Mdot
.66084 .58501 Mdot
.66089 .58492 Mdot
.66094 .58483 Mdot
.66098 .58474 Mdot
.66103 .58465 Mdot
.66108 .58456 Mdot
.66113 .58447 Mdot
.66117 .58438 Mdot
.66122 .58429 Mdot
.66127 .5842 Mdot
.66132 .58412 Mdot
.66136 .58403 Mdot
.66141 .58394 Mdot
.66146 .58385 Mdot
.66151 .58375 Mdot
.66156 .58366 Mdot
.6616 .58357 Mdot
.66165 .58348 Mdot
.6617 .58339 Mdot
.66175 .5833 Mdot
.66179 .5832 Mdot
.66184 .58311 Mdot
.66189 .58301 Mdot
.66194 .58292 Mdot
.66198 .58282 Mdot
.66203 .58273 Mdot
.66208 .58263 Mdot
.66213 .58254 Mdot
.66217 .58244 Mdot
.66222 .58235 Mdot
.66227 .58225 Mdot
.66232 .58216 Mdot
.66236 .58206 Mdot
.66241 .58196 Mdot
.66246 .58187 Mdot
.66251 .58177 Mdot
.66256 .58167 Mdot
.6626 .58157 Mdot
.66265 .58147 Mdot
.6627 .58137 Mdot
.66275 .58126 Mdot
.66279 .58116 Mdot
.66284 .58105 Mdot
.66289 .58094 Mdot
.66294 .58084 Mdot
.66298 .58073 Mdot
.66303 .58062 Mdot
.66308 .58052 Mdot
.66313 .58042 Mdot
.66317 .58031 Mdot
.66322 .58021 Mdot
.66327 .58011 Mdot
.66332 .58001 Mdot
.66336 .57991 Mdot
.66341 .57982 Mdot
.66346 .57972 Mdot
.66351 .57962 Mdot
.66356 .57952 Mdot
.6636 .57943 Mdot
.66365 .57933 Mdot
.6637 .57923 Mdot
.66375 .57913 Mdot
.66379 .57903 Mdot
.66384 .57893 Mdot
.66389 .57883 Mdot
.66394 .57873 Mdot
.66398 .57863 Mdot
.66403 .57852 Mdot
.66408 .57842 Mdot
.66413 .57832 Mdot
.66417 .57822 Mdot
.66422 .57812 Mdot
.66427 .57802 Mdot
.66432 .57792 Mdot
.66436 .57782 Mdot
.66441 .57772 Mdot
.66446 .57762 Mdot
.66451 .57752 Mdot
.66455 .57742 Mdot
.6646 .57731 Mdot
.66465 .57721 Mdot
.6647 .5771 Mdot
.66475 .57699 Mdot
.66479 .57688 Mdot
.66484 .57678 Mdot
.66489 .57667 Mdot
.66494 .57657 Mdot
.66498 .57647 Mdot
.66503 .57636 Mdot
.66508 .57625 Mdot
.66513 .57614 Mdot
.66517 .57603 Mdot
.66522 .57592 Mdot
.66527 .57582 Mdot
.66532 .57571 Mdot
.66536 .5756 Mdot
.66541 .5755 Mdot
.66546 .57539 Mdot
.66551 .57529 Mdot
.66555 .57518 Mdot
.6656 .57508 Mdot
.66565 .57497 Mdot
.6657 .57486 Mdot
.66575 .57475 Mdot
.66579 .57464 Mdot
.66584 .57453 Mdot
.66589 .57442 Mdot
.66594 .5743 Mdot
.66598 .57418 Mdot
.66603 .57407 Mdot
.66608 .57395 Mdot
.66613 .57383 Mdot
.66617 .57371 Mdot
.66622 .57359 Mdot
.66627 .57347 Mdot
.66632 .57335 Mdot
.66636 .57322 Mdot
.66641 .5731 Mdot
.66646 .57297 Mdot
.66651 .57285 Mdot
.66655 .57272 Mdot
.6666 .57259 Mdot
.66665 .57247 Mdot
.6667 .57234 Mdot
.66675 .57221 Mdot
.66679 .57207 Mdot
.66684 .57194 Mdot
.66689 .57181 Mdot
.66694 .57168 Mdot
.66698 .57155 Mdot
.66703 .57143 Mdot
.66708 .5713 Mdot
.66713 .57117 Mdot
.66717 .57104 Mdot
.66722 .57091 Mdot
.66727 .57078 Mdot
.66732 .57065 Mdot
.66736 .57052 Mdot
.66741 .57039 Mdot
.66746 .57025 Mdot
.66751 .57012 Mdot
.66755 .56998 Mdot
.6676 .56985 Mdot
.66765 .5697 Mdot
.6677 .56956 Mdot
.66775 .56943 Mdot
.66779 .56929 Mdot
.66784 .56915 Mdot
.66789 .569 Mdot
.66794 .56886 Mdot
.66798 .56872 Mdot
.66803 .56857 Mdot
.66808 .56843 Mdot
.66813 .56829 Mdot
.66817 .56814 Mdot
.66822 .56799 Mdot
.66827 .56785 Mdot
.66832 .5677 Mdot
.66836 .56755 Mdot
.66841 .5674 Mdot
.66846 .56725 Mdot
.66851 .5671 Mdot
.66855 .56695 Mdot
.6686 .5668 Mdot
.66865 .56664 Mdot
.6687 .56649 Mdot
.66875 .56634 Mdot
.66879 .56619 Mdot
.66884 .56604 Mdot
.66889 .56589 Mdot
.66894 .56573 Mdot
.66898 .56558 Mdot
.66903 .56542 Mdot
.66908 .56527 Mdot
.66913 .56512 Mdot
.66917 .56496 Mdot
.66922 .56481 Mdot
.66927 .56466 Mdot
.66932 .5645 Mdot
.66936 .56435 Mdot
.66941 .5642 Mdot
.66946 .56405 Mdot
.66951 .56389 Mdot
.66955 .56374 Mdot
.6696 .56358 Mdot
.66965 .56343 Mdot
.6697 .56328 Mdot
.66974 .56312 Mdot
.66979 .56297 Mdot
.66984 .56281 Mdot
.66989 .56266 Mdot
.66994 .56251 Mdot
.66998 .56236 Mdot
.67003 .56221 Mdot
.67008 .56206 Mdot
.67013 .5619 Mdot
.67017 .56175 Mdot
.67022 .56159 Mdot
.67027 .56143 Mdot
.67032 .56127 Mdot
.67036 .56111 Mdot
.67041 .56095 Mdot
.67046 .5608 Mdot
.67051 .56064 Mdot
.67055 .56048 Mdot
.6706 .56033 Mdot
.67065 .56017 Mdot
.6707 .56002 Mdot
.67074 .55986 Mdot
.67079 .5597 Mdot
.67084 .55954 Mdot
.67089 .55937 Mdot
.67094 .55921 Mdot
.67098 .55904 Mdot
.67103 .55887 Mdot
.67108 .55871 Mdot
.67113 .55854 Mdot
.67117 .55837 Mdot
.67122 .55819 Mdot
.67127 .55801 Mdot
.67132 .55783 Mdot
.67136 .55765 Mdot
.67141 .55747 Mdot
.67146 .55729 Mdot
.67151 .5571 Mdot
.67155 .55692 Mdot
.6716 .55674 Mdot
.67165 .55655 Mdot
.6717 .55637 Mdot
.67174 .55618 Mdot
.67179 .55599 Mdot
.67184 .5558 Mdot
.67189 .55562 Mdot
.67194 .55542 Mdot
.67198 .55523 Mdot
.67203 .55504 Mdot
.67208 .55485 Mdot
.67213 .55465 Mdot
.67217 .55446 Mdot
.67222 .55426 Mdot
.67227 .55407 Mdot
.67232 .55387 Mdot
.67236 .55368 Mdot
.67241 .55348 Mdot
.67246 .55329 Mdot
.67251 .5531 Mdot
.67255 .5529 Mdot
.6726 .55271 Mdot
.67265 .55251 Mdot
.6727 .55232 Mdot
.67274 .55212 Mdot
.67279 .55192 Mdot
.67284 .55172 Mdot
.67289 .55151 Mdot
.67294 .55131 Mdot
.67298 .5511 Mdot
.67303 .55089 Mdot
.67308 .55068 Mdot
.67313 .55046 Mdot
.67317 .55025 Mdot
.67322 .55004 Mdot
.67327 .54983 Mdot
.67332 .54962 Mdot
.67336 .54941 Mdot
.67341 .5492 Mdot
.67346 .54899 Mdot
.67351 .54878 Mdot
.67355 .54857 Mdot
.6736 .54836 Mdot
.67365 .54816 Mdot
.6737 .54795 Mdot
.67374 .54774 Mdot
.67379 .54753 Mdot
.67384 .54732 Mdot
.67389 .54711 Mdot
.67393 .5469 Mdot
.67398 .54669 Mdot
.67403 .54648 Mdot
.67408 .54626 Mdot
.67413 .54605 Mdot
.67417 .54584 Mdot
.67422 .54562 Mdot
.67427 .54541 Mdot
.67432 .54519 Mdot
.67436 .54498 Mdot
.67441 .54477 Mdot
.67446 .54455 Mdot
.67451 .54434 Mdot
.67455 .54413 Mdot
.6746 .54392 Mdot
.67465 .54371 Mdot
.6747 .5435 Mdot
.67474 .54329 Mdot
.67479 .54309 Mdot
.67484 .54288 Mdot
.67489 .54268 Mdot
.67493 .54247 Mdot
.67498 .54227 Mdot
.67503 .54206 Mdot
.67508 .54186 Mdot
.67513 .54165 Mdot
.67517 .54145 Mdot
.67522 .54124 Mdot
.67527 .54103 Mdot
.67532 .54083 Mdot
.67536 .54062 Mdot
.67541 .54042 Mdot
.67546 .54021 Mdot
.67551 .54 Mdot
.67555 .5398 Mdot
.6756 .53959 Mdot
.67565 .53938 Mdot
.6757 .53917 Mdot
.67574 .53896 Mdot
.67579 .53875 Mdot
.67584 .53854 Mdot
.67589 .53833 Mdot
.67593 .53812 Mdot
.67598 .5379 Mdot
.67603 .53769 Mdot
.67608 .53748 Mdot
.67613 .53726 Mdot
.67617 .53704 Mdot
.67622 .53682 Mdot
.67627 .53661 Mdot
.67632 .53639 Mdot
.67636 .53617 Mdot
.67641 .53595 Mdot
.67646 .53574 Mdot
.67651 .53552 Mdot
.67655 .5353 Mdot
.6766 .53507 Mdot
.67665 .53486 Mdot
.6767 .53463 Mdot
.67674 .53441 Mdot
.67679 .53419 Mdot
.67684 .53397 Mdot
.67689 .53375 Mdot
.67693 .53352 Mdot
.67698 .53329 Mdot
.67703 .53306 Mdot
.67708 .53283 Mdot
.67713 .5326 Mdot
.67717 .53237 Mdot
.67722 .53214 Mdot
.67727 .53191 Mdot
.67732 .53167 Mdot
.67736 .53143 Mdot
.67741 .53119 Mdot
.67746 .53096 Mdot
.67751 .53072 Mdot
.67755 .53048 Mdot
.6776 .53024 Mdot
.67765 .53 Mdot
.6777 .52976 Mdot
.67774 .52951 Mdot
.67779 .52927 Mdot
.67784 .52902 Mdot
.67789 .52877 Mdot
.67793 .52852 Mdot
.67798 .52828 Mdot
.67803 .52803 Mdot
.67808 .52778 Mdot
.67813 .52754 Mdot
.67817 .52729 Mdot
.67822 .52704 Mdot
.67827 .52679 Mdot
.67832 .52654 Mdot
.67836 .52629 Mdot
.67841 .52604 Mdot
.67846 .52579 Mdot
.67851 .52554 Mdot
.67855 .5253 Mdot
.6786 .52505 Mdot
.67865 .5248 Mdot
.6787 .52455 Mdot
.67874 .5243 Mdot
.67879 .52405 Mdot
.67884 .5238 Mdot
.67889 .52354 Mdot
.67893 .52328 Mdot
.67898 .52302 Mdot
.67903 .52276 Mdot
.67908 .52249 Mdot
.67912 .52223 Mdot
.67917 .52197 Mdot
.67922 .5217 Mdot
.67927 .52144 Mdot
.67932 .52118 Mdot
.67936 .52091 Mdot
.67941 .52065 Mdot
.67946 .52039 Mdot
.67951 .52012 Mdot
.67955 .51986 Mdot
.6796 .51959 Mdot
.67965 .51933 Mdot
.6797 .51907 Mdot
.67974 .51881 Mdot
.67979 .51854 Mdot
.67984 .51829 Mdot
.67989 .51803 Mdot
.67993 .51777 Mdot
.67998 .51751 Mdot
.68003 .51725 Mdot
.68008 .51699 Mdot
.68012 .51672 Mdot
.68017 .51646 Mdot
.68022 .51619 Mdot
.68027 .51592 Mdot
.68032 .51565 Mdot
.68036 .51538 Mdot
.68041 .51511 Mdot
.68046 .51483 Mdot
.68051 .51456 Mdot
.68055 .51429 Mdot
.6806 .51402 Mdot
.68065 .51374 Mdot
.6807 .51347 Mdot
.68074 .51319 Mdot
.68079 .51292 Mdot
.68084 .51264 Mdot
.68089 .51237 Mdot
.68093 .5121 Mdot
.68098 .51182 Mdot
.68103 .51155 Mdot
.68108 .51128 Mdot
.68112 .511 Mdot
.68117 .51073 Mdot
.68122 .51046 Mdot
.68127 .51019 Mdot
.68132 .50992 Mdot
.68136 .50964 Mdot
.68141 .50937 Mdot
.68146 .50909 Mdot
.68151 .50882 Mdot
.68155 .50854 Mdot
.6816 .50826 Mdot
.68165 .50798 Mdot
.6817 .5077 Mdot
.68174 .50742 Mdot
.68179 .50714 Mdot
.68184 .50685 Mdot
.68189 .50656 Mdot
.68193 .50627 Mdot
.68198 .50598 Mdot
.68203 .50568 Mdot
.68208 .50539 Mdot
.68212 .5051 Mdot
.68217 .50481 Mdot
.68222 .50451 Mdot
.68227 .50422 Mdot
.68232 .50392 Mdot
.68236 .50362 Mdot
.68241 .50332 Mdot
.68246 .50302 Mdot
.68251 .50272 Mdot
.68255 .50242 Mdot
.6826 .50213 Mdot
.68265 .50183 Mdot
.6827 .50153 Mdot
.68274 .50123 Mdot
.68279 .50093 Mdot
.68284 .50062 Mdot
.68289 .50032 Mdot
.68293 .50001 Mdot
.68298 .4997 Mdot
.68303 .4994 Mdot
.68308 .49909 Mdot
.68312 .49878 Mdot
.68317 .49848 Mdot
.68322 .49817 Mdot
.68327 .49786 Mdot
.68332 .49756 Mdot
.68336 .49725 Mdot
.68341 .49695 Mdot
.68346 .49665 Mdot
.68351 .49635 Mdot
.68355 .49605 Mdot
.6836 .49575 Mdot
.68365 .49546 Mdot
.6837 .49516 Mdot
.68374 .49486 Mdot
.68379 .49457 Mdot
.68384 .49427 Mdot
.68389 .49398 Mdot
.68393 .49368 Mdot
.68398 .49339 Mdot
.68403 .49309 Mdot
.68408 .4928 Mdot
.68412 .4925 Mdot
.68417 .49221 Mdot
.68422 .49191 Mdot
.68427 .49162 Mdot
.68431 .49132 Mdot
.68436 .49102 Mdot
.68441 .49073 Mdot
.68446 .49043 Mdot
.68451 .49013 Mdot
.68455 .48983 Mdot
.6846 .48953 Mdot
.68465 .48923 Mdot
.6847 .48893 Mdot
.68474 .48863 Mdot
.68479 .48834 Mdot
.68484 .48805 Mdot
.68489 .48775 Mdot
.68493 .48745 Mdot
.68498 .48715 Mdot
.68503 .48685 Mdot
.68508 .48655 Mdot
.68512 .48625 Mdot
.68517 .48595 Mdot
.68522 .48565 Mdot
.68527 .48535 Mdot
.68531 .48505 Mdot
.68536 .48474 Mdot
.68541 .48444 Mdot
.68546 .48414 Mdot
.68551 .48383 Mdot
.68555 .48353 Mdot
.6856 .48322 Mdot
.68565 .48291 Mdot
.6857 .4826 Mdot
.68574 .48229 Mdot
.68579 .48198 Mdot
.68584 .48166 Mdot
.68589 .48135 Mdot
.68593 .48103 Mdot
.68598 .48071 Mdot
.68603 .48039 Mdot
.68608 .48007 Mdot
.68612 .47975 Mdot
.68617 .47942 Mdot
.68622 .4791 Mdot
.68627 .47877 Mdot
.68631 .47845 Mdot
.68636 .47812 Mdot
.68641 .47779 Mdot
.68646 .47746 Mdot
.68651 .47713 Mdot
.68655 .4768 Mdot
.6866 .47647 Mdot
.68665 .47615 Mdot
.6867 .47582 Mdot
.68674 .47549 Mdot
.68679 .47517 Mdot
.68684 .47484 Mdot
.68689 .47452 Mdot
.68693 .47419 Mdot
.68698 .47387 Mdot
.68703 .47354 Mdot
.68708 .47321 Mdot
.68712 .47289 Mdot
.68717 .47256 Mdot
.68722 .47224 Mdot
.68727 .47192 Mdot
.68731 .4716 Mdot
.68736 .47127 Mdot
.68741 .47095 Mdot
.68746 .47063 Mdot
.68751 .47031 Mdot
.68755 .46998 Mdot
.6876 .46966 Mdot
.68765 .46933 Mdot
.6877 .46901 Mdot
.68774 .46868 Mdot
.68779 .46836 Mdot
.68784 .46803 Mdot
.68789 .4677 Mdot
.68793 .46738 Mdot
.68798 .46705 Mdot
.68803 .46672 Mdot
.68808 .46639 Mdot
.68812 .46605 Mdot
.68817 .46572 Mdot
.68822 .46539 Mdot
.68827 .46505 Mdot
.68831 .46472 Mdot
.68836 .46439 Mdot
.68841 .46405 Mdot
.68846 .46371 Mdot
.6885 .46337 Mdot
.68855 .46303 Mdot
.6886 .46268 Mdot
.68865 .46234 Mdot
.6887 .462 Mdot
.68874 .46166 Mdot
.68879 .46132 Mdot
.68884 .46098 Mdot
.68889 .46064 Mdot
.68893 .4603 Mdot
.68898 .45996 Mdot
.68903 .45961 Mdot
.68908 .45927 Mdot
.68912 .45893 Mdot
.68917 .45859 Mdot
.68922 .45825 Mdot
.68927 .45791 Mdot
.68931 .45757 Mdot
.68936 .45722 Mdot
.68941 .45688 Mdot
.68946 .45653 Mdot
.6895 .45619 Mdot
.68955 .45584 Mdot
.6896 .4555 Mdot
.68965 .45515 Mdot
.6897 .4548 Mdot
.68974 .45446 Mdot
.68979 .45411 Mdot
.68984 .45377 Mdot
.68989 .45343 Mdot
.68993 .45308 Mdot
.68998 .45273 Mdot
.69003 .45239 Mdot
.69008 .45204 Mdot
.69012 .45169 Mdot
.69017 .45133 Mdot
.69022 .45098 Mdot
.69027 .45062 Mdot
.69031 .45026 Mdot
.69036 .4499 Mdot
.69041 .44954 Mdot
.69046 .44918 Mdot
.6905 .44882 Mdot
.69055 .44846 Mdot
.6906 .44809 Mdot
.69065 .44773 Mdot
.6907 .44737 Mdot
.69074 .447 Mdot
.69079 .44664 Mdot
.69084 .44628 Mdot
.69089 .44591 Mdot
.69093 .44554 Mdot
.69098 .44517 Mdot
.69103 .4448 Mdot
.69108 .44442 Mdot
.69112 .44405 Mdot
.69117 .44367 Mdot
.69122 .44329 Mdot
.69127 .44291 Mdot
.69131 .44254 Mdot
.69136 .44216 Mdot
.69141 .44179 Mdot
.69146 .44141 Mdot
.6915 .44103 Mdot
.69155 .44066 Mdot
.6916 .44028 Mdot
.69165 .4399 Mdot
.6917 .43953 Mdot
.69174 .43915 Mdot
.69179 .43877 Mdot
.69184 .4384 Mdot
.69189 .43802 Mdot
.69193 .43765 Mdot
.69198 .43727 Mdot
.69203 .43689 Mdot
.69208 .43651 Mdot
.69212 .43613 Mdot
.69217 .43575 Mdot
.69222 .43538 Mdot
.69227 .43499 Mdot
.69231 .43461 Mdot
.69236 .43423 Mdot
.69241 .43385 Mdot
.69246 .43347 Mdot
.6925 .43308 Mdot
.69255 .4327 Mdot
.6926 .43231 Mdot
.69265 .43192 Mdot
.6927 .43154 Mdot
.69274 .43115 Mdot
.69279 .43076 Mdot
.69284 .43038 Mdot
.69289 .42999 Mdot
.69293 .42961 Mdot
.69298 .42922 Mdot
.69303 .42884 Mdot
.69308 .42845 Mdot
.69312 .42806 Mdot
.69317 .42768 Mdot
.69322 .42729 Mdot
.69327 .4269 Mdot
.69331 .42651 Mdot
.69336 .42613 Mdot
.69341 .42574 Mdot
.69346 .42536 Mdot
.6935 .42497 Mdot
.69355 .42458 Mdot
.6936 .42419 Mdot
.69365 .4238 Mdot
.69369 .42341 Mdot
.69374 .42303 Mdot
.69379 .42264 Mdot
.69384 .42225 Mdot
.69389 .42186 Mdot
.69393 .42147 Mdot
.69398 .42108 Mdot
.69403 .42069 Mdot
.69408 .4203 Mdot
.69412 .41991 Mdot
.69417 .41953 Mdot
.69422 .41914 Mdot
.69427 .41875 Mdot
.69431 .41836 Mdot
.69436 .41797 Mdot
.69441 .41758 Mdot
.69446 .41719 Mdot
.6945 .4168 Mdot
.69455 .41642 Mdot
.6946 .41603 Mdot
.69465 .41565 Mdot
.69469 .41526 Mdot
.69474 .41488 Mdot
.69479 .4145 Mdot
.69484 .41412 Mdot
.69489 .41374 Mdot
.69493 .41335 Mdot
.69498 .41297 Mdot
.69503 .41259 Mdot
.69508 .41221 Mdot
.69512 .41183 Mdot
.69517 .41145 Mdot
.69522 .41107 Mdot
.69527 .41069 Mdot
.69531 .41031 Mdot
.69536 .40993 Mdot
.69541 .40955 Mdot
.69546 .40917 Mdot
.6955 .40879 Mdot
.69555 .40841 Mdot
.6956 .40803 Mdot
.69565 .40765 Mdot
.69569 .40727 Mdot
.69574 .40689 Mdot
.69579 .4065 Mdot
.69584 .40613 Mdot
.69589 .40574 Mdot
.69593 .40536 Mdot
.69598 .40497 Mdot
.69603 .40459 Mdot
.69608 .4042 Mdot
.69612 .40381 Mdot
.69617 .40343 Mdot
.69622 .40304 Mdot
.69627 .40266 Mdot
.69631 .40227 Mdot
.69636 .40188 Mdot
.69641 .40149 Mdot
.69646 .4011 Mdot
.6965 .40071 Mdot
.69655 .40032 Mdot
.6966 .39993 Mdot
.69665 .39954 Mdot
.69669 .39915 Mdot
.69674 .39876 Mdot
.69679 .39836 Mdot
.69684 .39798 Mdot
.69689 .39759 Mdot
.69693 .3972 Mdot
.69698 .39681 Mdot
.69703 .39643 Mdot
.69708 .39604 Mdot
.69712 .39565 Mdot
.69717 .39527 Mdot
.69722 .39488 Mdot
.69727 .39449 Mdot
.69731 .3941 Mdot
.69736 .39371 Mdot
.69741 .39333 Mdot
.69746 .39294 Mdot
.6975 .39255 Mdot
.69755 .39217 Mdot
.6976 .39178 Mdot
.69765 .39139 Mdot
.69769 .39101 Mdot
.69774 .39063 Mdot
.69779 .39024 Mdot
.69784 .38986 Mdot
.69788 .38947 Mdot
.69793 .38909 Mdot
.69798 .3887 Mdot
.69803 .38832 Mdot
.69808 .38794 Mdot
.69812 .38756 Mdot
.69817 .38719 Mdot
.69822 .38681 Mdot
.69827 .38644 Mdot
.69831 .38606 Mdot
.69836 .38568 Mdot
.69841 .38531 Mdot
.69846 .38493 Mdot
.6985 .38455 Mdot
.69855 .38417 Mdot
.6986 .38379 Mdot
.69865 .38341 Mdot
.69869 .38303 Mdot
.69874 .38265 Mdot
.69879 .38227 Mdot
.69884 .38189 Mdot
.69888 .38151 Mdot
.69893 .38114 Mdot
.69898 .38076 Mdot
.69903 .38039 Mdot
.69908 .38001 Mdot
.69912 .37963 Mdot
.69917 .37925 Mdot
.69922 .37888 Mdot
.69927 .3785 Mdot
.69931 .37812 Mdot
.69936 .37774 Mdot
.69941 .37737 Mdot
.69946 .37699 Mdot
.6995 .37661 Mdot
.69955 .37623 Mdot
.6996 .37586 Mdot
.69965 .37548 Mdot
.69969 .3751 Mdot
.69974 .37472 Mdot
.69979 .37433 Mdot
.69984 .37395 Mdot
.69988 .37357 Mdot
.69993 .37318 Mdot
.69998 .3728 Mdot
.70003 .37241 Mdot
.70008 .37203 Mdot
.70012 .37164 Mdot
.70017 .37126 Mdot
.70022 .37087 Mdot
.70027 .37049 Mdot
.70031 .3701 Mdot
.70036 .36971 Mdot
.70041 .36932 Mdot
.70046 .36893 Mdot
.7005 .36855 Mdot
.70055 .36817 Mdot
.7006 .36778 Mdot
.70065 .36739 Mdot
.70069 .367 Mdot
.70074 .36661 Mdot
.70079 .36623 Mdot
.70084 .36584 Mdot
.70088 .36545 Mdot
.70093 .36505 Mdot
.70098 .36466 Mdot
.70103 .36427 Mdot
.70108 .36388 Mdot
.70112 .36349 Mdot
.70117 .3631 Mdot
.70122 .36271 Mdot
.70127 .36232 Mdot
.70131 .36193 Mdot
.70136 .36153 Mdot
.70141 .36114 Mdot
.70146 .36075 Mdot
.7015 .36036 Mdot
.70155 .35997 Mdot
.7016 .35958 Mdot
.70165 .35919 Mdot
.70169 .3588 Mdot
.70174 .35841 Mdot
.70179 .35802 Mdot
.70184 .35763 Mdot
.70188 .35724 Mdot
.70193 .35685 Mdot
.70198 .35646 Mdot
.70203 .35607 Mdot
.70208 .35568 Mdot
.70212 .3553 Mdot
.70217 .35491 Mdot
.70222 .35452 Mdot
.70227 .35412 Mdot
.70231 .35373 Mdot
.70236 .35334 Mdot
.70241 .35294 Mdot
.70246 .35255 Mdot
.7025 .35216 Mdot
.70255 .35176 Mdot
.7026 .35136 Mdot
.70265 .35096 Mdot
.70269 .35056 Mdot
.70274 .35016 Mdot
.70279 .34976 Mdot
.70284 .34936 Mdot
.70288 .34896 Mdot
.70293 .34855 Mdot
.70298 .34815 Mdot
.70303 .34775 Mdot
.70307 .34734 Mdot
.70312 .34694 Mdot
.70317 .34653 Mdot
.70322 .34613 Mdot
.70327 .34572 Mdot
.70331 .34531 Mdot
.70336 .3449 Mdot
.70341 .34449 Mdot
.70346 .34408 Mdot
.7035 .34367 Mdot
.70355 .34326 Mdot
.7036 .34286 Mdot
.70365 .34245 Mdot
.70369 .34205 Mdot
.70374 .34164 Mdot
.70379 .34124 Mdot
.70384 .34084 Mdot
.70388 .34044 Mdot
.70393 .34003 Mdot
.70398 .33963 Mdot
.70403 .33922 Mdot
.70407 .33882 Mdot
.70412 .33842 Mdot
.70417 .33803 Mdot
.70422 .33763 Mdot
.70427 .33723 Mdot
.70431 .33684 Mdot
.70436 .33644 Mdot
.70441 .33604 Mdot
.70446 .33565 Mdot
.7045 .33525 Mdot
.70455 .33485 Mdot
.7046 .33446 Mdot
.70465 .33405 Mdot
.70469 .33365 Mdot
.70474 .33325 Mdot
.70479 .33285 Mdot
.70484 .33244 Mdot
.70488 .33204 Mdot
.70493 .33163 Mdot
.70498 .33123 Mdot
.70503 .33082 Mdot
.70507 .33042 Mdot
.70512 .33002 Mdot
.70517 .32961 Mdot
.70522 .3292 Mdot
.70527 .3288 Mdot
.70531 .3284 Mdot
.70536 .32799 Mdot
.70541 .32759 Mdot
.70546 .32718 Mdot
.7055 .32678 Mdot
.70555 .32637 Mdot
.7056 .32597 Mdot
.70565 .32556 Mdot
.70569 .32515 Mdot
.70574 .32474 Mdot
.70579 .32433 Mdot
.70584 .32392 Mdot
.70588 .32351 Mdot
.70593 .3231 Mdot
.70598 .32269 Mdot
.70603 .32228 Mdot
.70607 .32187 Mdot
.70612 .32145 Mdot
.70617 .32103 Mdot
.70622 .32062 Mdot
.70627 .32021 Mdot
.70631 .3198 Mdot
.70636 .31939 Mdot
.70641 .31898 Mdot
.70646 .31858 Mdot
.7065 .31817 Mdot
.70655 .31776 Mdot
.7066 .31736 Mdot
.70665 .31695 Mdot
.70669 .31654 Mdot
.70674 .31613 Mdot
.70679 .31572 Mdot
.70684 .31531 Mdot
.70688 .31491 Mdot
.70693 .3145 Mdot
.70698 .31409 Mdot
.70703 .31368 Mdot
.70707 .31327 Mdot
.70712 .31286 Mdot
.70717 .31245 Mdot
.70722 .31204 Mdot
.70726 .31163 Mdot
.70731 .31122 Mdot
.70736 .31081 Mdot
.70741 .31041 Mdot
.70746 .31 Mdot
.7075 .30959 Mdot
.70755 .30918 Mdot
.7076 .30877 Mdot
.70765 .30836 Mdot
.70769 .30795 Mdot
.70774 .30753 Mdot
.70779 .30712 Mdot
.70784 .30671 Mdot
.70788 .3063 Mdot
.70793 .30589 Mdot
.70798 .30548 Mdot
.70803 .30508 Mdot
.70807 .30467 Mdot
.70812 .30427 Mdot
.70817 .30387 Mdot
.70822 .30347 Mdot
.70826 .30306 Mdot
.70831 .30266 Mdot
.70836 .30226 Mdot
.70841 .30187 Mdot
.70846 .30147 Mdot
.7085 .30108 Mdot
.70855 .30068 Mdot
.7086 .30028 Mdot
.70865 .29989 Mdot
.70869 .29949 Mdot
.70874 .29909 Mdot
.70879 .2987 Mdot
.70884 .29831 Mdot
.70888 .29791 Mdot
.70893 .29752 Mdot
.70898 .29712 Mdot
.70903 .29672 Mdot
.70907 .29633 Mdot
.70912 .29593 Mdot
.70917 .29553 Mdot
.70922 .29513 Mdot
.70926 .29473 Mdot
.70931 .29433 Mdot
.70936 .29393 Mdot
.70941 .29353 Mdot
.70946 .29312 Mdot
.7095 .29272 Mdot
.70955 .29231 Mdot
.7096 .29191 Mdot
.70965 .2915 Mdot
.70969 .29109 Mdot
.70974 .29068 Mdot
.70979 .29027 Mdot
.70984 .28987 Mdot
.70988 .28946 Mdot
.70993 .28906 Mdot
.70998 .28866 Mdot
.71003 .28825 Mdot
.71007 .28785 Mdot
.71012 .28745 Mdot
.71017 .28704 Mdot
.71022 .28664 Mdot
.71026 .28623 Mdot
.71031 .28583 Mdot
.71036 .28542 Mdot
.71041 .28502 Mdot
.71046 .28461 Mdot
.7105 .28421 Mdot
.71055 .2838 Mdot
.7106 .28339 Mdot
.71065 .28299 Mdot
.71069 .28258 Mdot
.71074 .28218 Mdot
.71079 .28178 Mdot
.71084 .28138 Mdot
.71088 .28098 Mdot
.71093 .28057 Mdot
.71098 .28018 Mdot
.71103 .27978 Mdot
.71107 .27938 Mdot
.71112 .27898 Mdot
.71117 .27858 Mdot
.71122 .27818 Mdot
.71126 .27779 Mdot
.71131 .27739 Mdot
.71136 .27699 Mdot
.71141 .2766 Mdot
.71146 .27621 Mdot
.7115 .27582 Mdot
.71155 .27543 Mdot
.7116 .27503 Mdot
.71165 .27464 Mdot
.71169 .27425 Mdot
.71174 .27386 Mdot
.71179 .27347 Mdot
.71184 .27308 Mdot
.71188 .27269 Mdot
.71193 .2723 Mdot
.71198 .27191 Mdot
.71203 .27152 Mdot
.71207 .27113 Mdot
.71212 .27075 Mdot
.71217 .27036 Mdot
.71222 .26998 Mdot
.71226 .2696 Mdot
.71231 .26921 Mdot
.71236 .26884 Mdot
.71241 .26845 Mdot
.71245 .26807 Mdot
.7125 .26769 Mdot
.71255 .26731 Mdot
.7126 .26692 Mdot
.71265 .26654 Mdot
.71269 .26616 Mdot
.71274 .26577 Mdot
.71279 .26539 Mdot
.71284 .26501 Mdot
.71288 .26463 Mdot
.71293 .26424 Mdot
.71298 .26386 Mdot
.71303 .26347 Mdot
.71307 .26307 Mdot
.71312 .26268 Mdot
.71317 .26229 Mdot
.71322 .2619 Mdot
.71326 .26151 Mdot
.71331 .26111 Mdot
.71336 .26073 Mdot
.71341 .26034 Mdot
.71345 .25995 Mdot
.7135 .25957 Mdot
.71355 .25919 Mdot
.7136 .25881 Mdot
.71365 .25843 Mdot
.71369 .25805 Mdot
.71374 .25767 Mdot
.71379 .25729 Mdot
.71384 .25691 Mdot
.71388 .25653 Mdot
.71393 .25615 Mdot
.71398 .25577 Mdot
.71403 .25539 Mdot
.71407 .25501 Mdot
.71412 .25464 Mdot
.71417 .25426 Mdot
.71422 .25389 Mdot
.71426 .25351 Mdot
.71431 .25314 Mdot
.71436 .25277 Mdot
.71441 .2524 Mdot
.71445 .25203 Mdot
.7145 .25166 Mdot
.71455 .25129 Mdot
.7146 .25092 Mdot
.71465 .25055 Mdot
.71469 .25018 Mdot
.71474 .24982 Mdot
.71479 .24945 Mdot
.71484 .24908 Mdot
.71488 .24872 Mdot
.71493 .24835 Mdot
.71498 .24799 Mdot
.71503 .24762 Mdot
.71507 .24726 Mdot
.71512 .24689 Mdot
.71517 .24652 Mdot
.71522 .24615 Mdot
.71526 .24578 Mdot
.71531 .24541 Mdot
.71536 .24503 Mdot
.71541 .24466 Mdot
.71545 .24429 Mdot
.7155 .24391 Mdot
.71555 .24353 Mdot
.7156 .24316 Mdot
.71565 .24278 Mdot
.71569 .2424 Mdot
.71574 .24202 Mdot
.71579 .24164 Mdot
.71584 .24126 Mdot
.71588 .24088 Mdot
.71593 .2405 Mdot
.71598 .24012 Mdot
.71603 .23974 Mdot
.71607 .23936 Mdot
.71612 .23898 Mdot
.71617 .23861 Mdot
.71622 .23823 Mdot
.71626 .23786 Mdot
.71631 .23749 Mdot
.71636 .23712 Mdot
.71641 .23675 Mdot
.71645 .23638 Mdot
.7165 .23601 Mdot
.71655 .23564 Mdot
.7166 .23527 Mdot
.71665 .2349 Mdot
.71669 .23453 Mdot
.71674 .23416 Mdot
.71679 .23378 Mdot
.71684 .23342 Mdot
.71688 .23305 Mdot
.71693 .23268 Mdot
.71698 .23231 Mdot
.71703 .23195 Mdot
.71707 .23158 Mdot
.71712 .23122 Mdot
.71717 .23085 Mdot
.71722 .23049 Mdot
.71726 .23013 Mdot
.71731 .22976 Mdot
.71736 .2294 Mdot
.71741 .22903 Mdot
.71745 .22866 Mdot
.7175 .2283 Mdot
.71755 .22793 Mdot
.7176 .22757 Mdot
.71764 .2272 Mdot
.71769 .22684 Mdot
.71774 .22647 Mdot
.71779 .22611 Mdot
.71784 .22575 Mdot
.71788 .22539 Mdot
.71793 .22502 Mdot
.71798 .22466 Mdot
.71803 .2243 Mdot
.71807 .22394 Mdot
.71812 .22358 Mdot
.71817 .22322 Mdot
.71822 .22285 Mdot
.71826 .22249 Mdot
.71831 .22213 Mdot
.71836 .22177 Mdot
.71841 .22141 Mdot
.71845 .22105 Mdot
.7185 .2207 Mdot
.71855 .22034 Mdot
.7186 .21998 Mdot
.71864 .21963 Mdot
.71869 .21928 Mdot
.71874 .21893 Mdot
.71879 .21857 Mdot
.71884 .21822 Mdot
.71888 .21786 Mdot
.71893 .21751 Mdot
.71898 .21716 Mdot
.71903 .2168 Mdot
.71907 .21645 Mdot
.71912 .2161 Mdot
.71917 .21575 Mdot
.71922 .21539 Mdot
.71926 .21504 Mdot
.71931 .21469 Mdot
.71936 .21433 Mdot
.71941 .21398 Mdot
.71945 .21363 Mdot
.7195 .21327 Mdot
.71955 .21292 Mdot
.7196 .21256 Mdot
.71964 .21221 Mdot
.71969 .21186 Mdot
.71974 .2115 Mdot
.71979 .21114 Mdot
.71984 .21079 Mdot
.71988 .21043 Mdot
.71993 .21006 Mdot
.71998 .2097 Mdot
.72003 .20933 Mdot
.72007 .20897 Mdot
.72012 .2086 Mdot
.72017 .20823 Mdot
.72022 .20786 Mdot
.72026 .20749 Mdot
.72031 .20713 Mdot
.72036 .20676 Mdot
.72041 .2064 Mdot
.72045 .20603 Mdot
.7205 .20567 Mdot
.72055 .2053 Mdot
.7206 .20494 Mdot
.72064 .20457 Mdot
.72069 .20421 Mdot
.72074 .20384 Mdot
.72079 .20347 Mdot
.72084 .2031 Mdot
.72088 .20273 Mdot
.72093 .20236 Mdot
.72098 .20198 Mdot
.72103 .20161 Mdot
.72107 .20123 Mdot
.72112 .20086 Mdot
.72117 .20048 Mdot
.72122 .2001 Mdot
.72126 .19973 Mdot
.72131 .19935 Mdot
.72136 .19897 Mdot
.72141 .1986 Mdot
.72145 .19822 Mdot
.7215 .19785 Mdot
.72155 .19747 Mdot
.7216 .1971 Mdot
.72164 .19673 Mdot
.72169 .19636 Mdot
.72174 .19599 Mdot
.72179 .19563 Mdot
.72183 .19526 Mdot
.72188 .19489 Mdot
.72193 .19453 Mdot
.72198 .19416 Mdot
.72203 .19379 Mdot
.72207 .19342 Mdot
.72212 .19305 Mdot
.72217 .19268 Mdot
.72222 .19232 Mdot
.72226 .19196 Mdot
.72231 .19159 Mdot
.72236 .19123 Mdot
.72241 .19087 Mdot
.72245 .19051 Mdot
.7225 .19015 Mdot
.72255 .18979 Mdot
.7226 .18943 Mdot
.72264 .18907 Mdot
.72269 .18871 Mdot
.72274 .18835 Mdot
.72279 .18799 Mdot
.72283 .18763 Mdot
.72288 .18727 Mdot
.72293 .18692 Mdot
.72298 .18656 Mdot
.72303 .1862 Mdot
.72307 .18584 Mdot
.72312 .18548 Mdot
.72317 .18512 Mdot
.72322 .18476 Mdot
.72326 .1844 Mdot
.72331 .18404 Mdot
.72336 .18367 Mdot
.72341 .18332 Mdot
.72345 .18296 Mdot
.7235 .1826 Mdot
.72355 .18224 Mdot
.7236 .18188 Mdot
.72364 .18152 Mdot
.72369 .18116 Mdot
.72374 .1808 Mdot
.72379 .18044 Mdot
.72383 .18008 Mdot
.72388 .17973 Mdot
.72393 .17937 Mdot
.72398 .17902 Mdot
.72403 .17866 Mdot
.72407 .17831 Mdot
.72412 .17795 Mdot
.72417 .17759 Mdot
.72422 .17723 Mdot
.72426 .17687 Mdot
.72431 .17651 Mdot
.72436 .17615 Mdot
.72441 .17578 Mdot
.72445 .17542 Mdot
.7245 .17506 Mdot
.72455 .1747 Mdot
.7246 .17435 Mdot
.72464 .17399 Mdot
.72469 .17363 Mdot
.72474 .17327 Mdot
.72479 .17292 Mdot
.72483 .17256 Mdot
.72488 .17221 Mdot
.72493 .17186 Mdot
.72498 .1715 Mdot
.72503 .17115 Mdot
.72507 .17079 Mdot
.72512 .17044 Mdot
.72517 .17009 Mdot
.72522 .16974 Mdot
.72526 .16939 Mdot
.72531 .16904 Mdot
.72536 .16869 Mdot
.72541 .16835 Mdot
.72545 .16801 Mdot
.7255 .16766 Mdot
.72555 .16732 Mdot
.7256 .16697 Mdot
.72564 .16663 Mdot
.72569 .16629 Mdot
.72574 .16595 Mdot
.72579 .16561 Mdot
.72583 .16527 Mdot
.72588 .16493 Mdot
.72593 .1646 Mdot
.72598 .16426 Mdot
.72603 .16392 Mdot
.72607 .16359 Mdot
.72612 .16325 Mdot
.72617 .16291 Mdot
.72622 .16257 Mdot
.72626 .16224 Mdot
.72631 .1619 Mdot
.72636 .16157 Mdot
.72641 .16124 Mdot
.72645 .1609 Mdot
.7265 .16057 Mdot
.72655 .16023 Mdot
.7266 .1599 Mdot
.72664 .15956 Mdot
.72669 .15922 Mdot
.72674 .15888 Mdot
.72679 .15855 Mdot
.72683 .15822 Mdot
.72688 .15789 Mdot
.72693 .15756 Mdot
.72698 .15723 Mdot
.72702 .1569 Mdot
.72707 .15657 Mdot
.72712 .15624 Mdot
.72717 .15591 Mdot
.72722 .15559 Mdot
.72726 .15526 Mdot
.72731 .15493 Mdot
.72736 .1546 Mdot
.72741 .15428 Mdot
.72745 .15396 Mdot
.7275 .15364 Mdot
.72755 .15332 Mdot
.7276 .153 Mdot
.72764 .15268 Mdot
.72769 .15236 Mdot
.72774 .15204 Mdot
.72779 .15173 Mdot
.72783 .15141 Mdot
.72788 .15108 Mdot
.72793 .15076 Mdot
.72798 .15044 Mdot
.72802 .15012 Mdot
.72807 .1498 Mdot
.72812 .14948 Mdot
.72817 .14917 Mdot
.72822 .14885 Mdot
.72826 .14854 Mdot
.72831 .14822 Mdot
.72836 .1479 Mdot
.72841 .14757 Mdot
.72845 .14725 Mdot
.7285 .14693 Mdot
.72855 .14661 Mdot
.7286 .14628 Mdot
.72864 .14596 Mdot
.72869 .14564 Mdot
.72874 .14532 Mdot
.72879 .145 Mdot
.72883 .14468 Mdot
.72888 .14436 Mdot
.72893 .14405 Mdot
.72898 .14373 Mdot
.72902 .14342 Mdot
.72907 .14311 Mdot
.72912 .1428 Mdot
.72917 .14249 Mdot
.72922 .14217 Mdot
.72926 .14186 Mdot
.72931 .14155 Mdot
.72936 .14124 Mdot
.72941 .14093 Mdot
.72945 .14062 Mdot
.7295 .14031 Mdot
.72955 .14 Mdot
.7296 .13968 Mdot
.72964 .13937 Mdot
.72969 .13906 Mdot
.72974 .13875 Mdot
.72979 .13845 Mdot
.72983 .13814 Mdot
.72988 .13784 Mdot
.72993 .13753 Mdot
.72998 .13722 Mdot
.73002 .13692 Mdot
.73007 .13661 Mdot
.73012 .13631 Mdot
.73017 .136 Mdot
.73022 .1357 Mdot
.73026 .13541 Mdot
.73031 .13511 Mdot
.73036 .13481 Mdot
.73041 .13452 Mdot
.73045 .13422 Mdot
.7305 .13393 Mdot
.73055 .13364 Mdot
.7306 .13334 Mdot
.73064 .13305 Mdot
.73069 .13276 Mdot
.73074 .13247 Mdot
.73079 .13218 Mdot
.73083 .13189 Mdot
.73088 .1316 Mdot
.73093 .13131 Mdot
.73098 .13102 Mdot
.73102 .13073 Mdot
.73107 .13044 Mdot
.73112 .13015 Mdot
.73117 .12986 Mdot
.73121 .12957 Mdot
.73126 .12928 Mdot
.73131 .12899 Mdot
.73136 .12871 Mdot
.73141 .12842 Mdot
.73145 .12814 Mdot
.7315 .12785 Mdot
.73155 .12757 Mdot
.7316 .12728 Mdot
.73164 .12699 Mdot
.73169 .12671 Mdot
.73174 .12643 Mdot
.73179 .12615 Mdot
.73183 .12587 Mdot
.73188 .12558 Mdot
.73193 .1253 Mdot
.73198 .12501 Mdot
.73202 .12472 Mdot
.73207 .12443 Mdot
.73212 .12415 Mdot
.73217 .12386 Mdot
.73221 .12357 Mdot
.73226 .12328 Mdot
.73231 .12299 Mdot
.73236 .1227 Mdot
.73241 .12241 Mdot
.73245 .12212 Mdot
.7325 .12183 Mdot
.73255 .12154 Mdot
.7326 .12125 Mdot
.73264 .12096 Mdot
.73269 .12068 Mdot
.73274 .1204 Mdot
.73279 .12011 Mdot
.73283 .11983 Mdot
.73288 .11954 Mdot
.73293 .11926 Mdot
.73298 .11898 Mdot
.73302 .11869 Mdot
.73307 .11841 Mdot
.73312 .11813 Mdot
.73317 .11784 Mdot
.73321 .11756 Mdot
.73326 .11728 Mdot
.73331 .11699 Mdot
.73336 .11671 Mdot
.73341 .11643 Mdot
.73345 .11614 Mdot
.7335 .11586 Mdot
.73355 .11557 Mdot
.7336 .11528 Mdot
.73364 .115 Mdot
.73369 .11472 Mdot
.73374 .11444 Mdot
.73379 .11417 Mdot
.73383 .11389 Mdot
.73388 .11361 Mdot
.73393 .11334 Mdot
.73398 .11307 Mdot
.73402 .1128 Mdot
.73407 .11252 Mdot
.73412 .11225 Mdot
.73417 .11197 Mdot
.73421 .1117 Mdot
.73426 .11143 Mdot
.73431 .11115 Mdot
.73436 .11088 Mdot
.73441 .11061 Mdot
.73445 .11033 Mdot
.7345 .11005 Mdot
.73455 .10978 Mdot
.7346 .1095 Mdot
.73464 .10922 Mdot
.73469 .10894 Mdot
.73474 .10867 Mdot
.73479 .1084 Mdot
.73483 .10812 Mdot
.73488 .10785 Mdot
.73493 .10757 Mdot
.73498 .1073 Mdot
.73502 .10703 Mdot
.73507 .10676 Mdot
.73512 .10648 Mdot
.73517 .10621 Mdot
.73521 .10593 Mdot
.73526 .10565 Mdot
.73531 .10538 Mdot
.73536 .1051 Mdot
.73541 .10483 Mdot
.73545 .10455 Mdot
.7355 .10427 Mdot
.73555 .104 Mdot
.7356 .10373 Mdot
.73564 .10345 Mdot
.73569 .10318 Mdot
.73574 .10291 Mdot
.73579 .10264 Mdot
.73583 .10237 Mdot
.73588 .1021 Mdot
.73593 .10183 Mdot
.73598 .10156 Mdot
.73602 .1013 Mdot
.73607 .10104 Mdot
.73612 .10078 Mdot
.73617 .10052 Mdot
.73621 .10025 Mdot
.73626 .09999 Mdot
.73631 .09973 Mdot
.73636 .09946 Mdot
.7364 .0992 Mdot
.73645 .09893 Mdot
.7365 .09867 Mdot
.73655 .0984 Mdot
.7366 .09814 Mdot
.73664 .09787 Mdot
.73669 .09761 Mdot
.73674 .09735 Mdot
.73679 .09709 Mdot
.73683 .09682 Mdot
.73688 .09656 Mdot
.73693 .09629 Mdot
.73698 .09603 Mdot
.73702 .09576 Mdot
.73707 .0955 Mdot
.73712 .09524 Mdot
.73717 .09498 Mdot
.73721 .09472 Mdot
.73726 .09447 Mdot
.73731 .09421 Mdot
.73736 .09396 Mdot
.7374 .0937 Mdot
.73745 .09345 Mdot
.7375 .0932 Mdot
.73755 .09294 Mdot
.7376 .09269 Mdot
.73764 .09243 Mdot
.73769 .09218 Mdot
.73774 .09193 Mdot
.73779 .09168 Mdot
.73783 .09143 Mdot
.73788 .09118 Mdot
.73793 .09094 Mdot
.73798 .09069 Mdot
.73802 .09044 Mdot
.73807 .0902 Mdot
.73812 .08995 Mdot
.73817 .08971 Mdot
.73821 .08947 Mdot
.73826 .08922 Mdot
.73831 .08898 Mdot
.73836 .08873 Mdot
.7384 .08848 Mdot
.73845 .08823 Mdot
.7385 .08799 Mdot
.73855 .08774 Mdot
.7386 .08749 Mdot
.73864 .08724 Mdot
.73869 .087 Mdot
.73874 .08675 Mdot
.73879 .0865 Mdot
.73883 .08625 Mdot
.73888 .086 Mdot
.73893 .08576 Mdot
.73898 .08552 Mdot
.73902 .08528 Mdot
.73907 .08504 Mdot
.73912 .08479 Mdot
.73917 .08455 Mdot
.73921 .08431 Mdot
.73926 .08407 Mdot
.73931 .08382 Mdot
.73936 .08358 Mdot
.7394 .08334 Mdot
.73945 .0831 Mdot
.7395 .08285 Mdot
.73955 .08261 Mdot
.7396 .08237 Mdot
.73964 .08213 Mdot
.73969 .08189 Mdot
.73974 .08165 Mdot
.73979 .0814 Mdot
.73983 .08116 Mdot
.73988 .08092 Mdot
.73993 .08068 Mdot
.73998 .08044 Mdot
.74002 .0802 Mdot
.74007 .07996 Mdot
.74012 .07973 Mdot
.74017 .07949 Mdot
.74021 .07926 Mdot
.74026 .07902 Mdot
.74031 .07879 Mdot
.74036 .07855 Mdot
.7404 .07832 Mdot
.74045 .07808 Mdot
.7405 .07785 Mdot
.74055 .07761 Mdot
.74059 .07738 Mdot
.74064 .07715 Mdot
.74069 .07692 Mdot
.74074 .07669 Mdot
.74079 .07647 Mdot
.74083 .07624 Mdot
.74088 .07602 Mdot
.74093 .0758 Mdot
.74098 .07557 Mdot
.74102 .07534 Mdot
.74107 .07512 Mdot
.74112 .07489 Mdot
.74117 .07467 Mdot
.74121 .07445 Mdot
.74126 .07424 Mdot
.74131 .07402 Mdot
.74136 .07381 Mdot
.7414 .07359 Mdot
.74145 .07338 Mdot
.7415 .07317 Mdot
.74155 .07296 Mdot
.74159 .07275 Mdot
.74164 .07254 Mdot
.74169 .07233 Mdot
.74174 .07212 Mdot
.74179 .07191 Mdot
.74183 .07171 Mdot
.74188 .0715 Mdot
.74193 .0713 Mdot
.74198 .0711 Mdot
.74202 .0709 Mdot
.74207 .0707 Mdot
.74212 .0705 Mdot
.74217 .0703 Mdot
.74221 .07011 Mdot
.74226 .06992 Mdot
.74231 .06973 Mdot
.74236 .06954 Mdot
.7424 .06936 Mdot
.74245 .06918 Mdot
.7425 .06899 Mdot
.74255 .06881 Mdot
.74259 .06862 Mdot
.74264 .06844 Mdot
.74269 .06826 Mdot
.74274 .06808 Mdot
.74279 .06789 Mdot
.74283 .06771 Mdot
.74288 .06753 Mdot
.74293 .06736 Mdot
.74298 .06718 Mdot
.74302 .067 Mdot
.74307 .06683 Mdot
.74312 .06666 Mdot
.74317 .06648 Mdot
.74321 .06631 Mdot
.74326 .06613 Mdot
.74331 .06596 Mdot
.74336 .06579 Mdot
.7434 .06562 Mdot
.74345 .06545 Mdot
.7435 .06528 Mdot
.74355 .06511 Mdot
.74359 .06494 Mdot
.74364 .06477 Mdot
.74369 .0646 Mdot
.74374 .06443 Mdot
.74379 .06426 Mdot
.74383 .0641 Mdot
.74388 .06393 Mdot
.74393 .06377 Mdot
.74398 .0636 Mdot
.74402 .06343 Mdot
.74407 .06326 Mdot
.74412 .06309 Mdot
.74417 .06292 Mdot
.74421 .06274 Mdot
.74426 .06257 Mdot
.74431 .0624 Mdot
.74436 .06224 Mdot
.7444 .06207 Mdot
.74445 .0619 Mdot
.7445 .06173 Mdot
.74455 .06157 Mdot
.74459 .0614 Mdot
.74464 .06123 Mdot
.74469 .06107 Mdot
.74474 .0609 Mdot
.74479 .06074 Mdot
.74483 .06058 Mdot
.74488 .06042 Mdot
.74493 .06026 Mdot
.74498 .0601 Mdot
.74502 .05994 Mdot
.74507 .05978 Mdot
.74512 .05962 Mdot
.74517 .05946 Mdot
.74521 .0593 Mdot
.74526 .05914 Mdot
.74531 .05898 Mdot
.74536 .05882 Mdot
.7454 .05866 Mdot
.74545 .0585 Mdot
.7455 .05835 Mdot
.74555 .05819 Mdot
.74559 .05804 Mdot
.74564 .0579 Mdot
.74569 .05775 Mdot
.74574 .0576 Mdot
.74578 .05746 Mdot
.74583 .05731 Mdot
.74588 .05717 Mdot
.74593 .05702 Mdot
.74598 .05688 Mdot
.74602 .05673 Mdot
.74607 .05659 Mdot
.74612 .05645 Mdot
.74617 .0563 Mdot
.74621 .05616 Mdot
.74626 .05601 Mdot
.74631 .05586 Mdot
.74636 .05572 Mdot
.7464 .05557 Mdot
.74645 .05543 Mdot
.7465 .05529 Mdot
.74655 .05515 Mdot
.74659 .055 Mdot
.74664 .05486 Mdot
.74669 .05472 Mdot
.74674 .05458 Mdot
.74678 .05445 Mdot
.74683 .05431 Mdot
.74688 .05417 Mdot
.74693 .05404 Mdot
.74698 .0539 Mdot
.74702 .05377 Mdot
.74707 .05363 Mdot
.74712 .05349 Mdot
.74717 .05336 Mdot
.74721 .05322 Mdot
.74726 .05308 Mdot
.74731 .05294 Mdot
.74736 .05281 Mdot
.7474 .05268 Mdot
.74745 .05254 Mdot
.7475 .05241 Mdot
.74755 .05228 Mdot
.74759 .05214 Mdot
.74764 .05201 Mdot
.74769 .05188 Mdot
.74774 .05176 Mdot
.74778 .05163 Mdot
.74783 .05151 Mdot
.74788 .05138 Mdot
.74793 .05125 Mdot
.74798 .05113 Mdot
.74802 .051 Mdot
.74807 .05088 Mdot
.74812 .05076 Mdot
.74817 .05063 Mdot
.74821 .05051 Mdot
.74826 .05039 Mdot
.74831 .05027 Mdot
.74836 .05015 Mdot
.7484 .05003 Mdot
.74845 .04991 Mdot
.7485 .04979 Mdot
.74855 .04967 Mdot
.74859 .04955 Mdot
.74864 .04943 Mdot
.74869 .04931 Mdot
.74874 .04919 Mdot
.74878 .04907 Mdot
.74883 .04895 Mdot
.74888 .04883 Mdot
.74893 .04871 Mdot
.74898 .0486 Mdot
.74902 .04848 Mdot
.74907 .04837 Mdot
.74912 .04825 Mdot
.74917 .04814 Mdot
.74921 .04802 Mdot
.74926 .04791 Mdot
.74931 .04779 Mdot
.74936 .04767 Mdot
.7494 .04756 Mdot
.74945 .04745 Mdot
.7495 .04734 Mdot
.74955 .04723 Mdot
.74959 .04712 Mdot
.74964 .04701 Mdot
.74969 .0469 Mdot
.74974 .04679 Mdot
.74978 .04668 Mdot
.74983 .04657 Mdot
.74988 .04646 Mdot
.74993 .04635 Mdot
.74998 .04624 Mdot
.75002 .04613 Mdot
.75007 .04602 Mdot
.75012 .04591 Mdot
.75017 .0458 Mdot
.75021 .04569 Mdot
.75026 .04558 Mdot
.75031 .04547 Mdot
.75036 .04535 Mdot
.7504 .04523 Mdot
.75045 .04511 Mdot
.7505 .04499 Mdot
.75055 .04487 Mdot
.75059 .04475 Mdot
.75064 .04463 Mdot
.75069 .04451 Mdot
.75074 .04439 Mdot
.75078 .04428 Mdot
.75083 .04417 Mdot
.75088 .04405 Mdot
.75093 .04394 Mdot
.75097 .04383 Mdot
.75102 .04371 Mdot
.75107 .0436 Mdot
.75112 .04349 Mdot
.75117 .04338 Mdot
.75121 .04327 Mdot
.75126 .04316 Mdot
.75131 .04306 Mdot
.75136 .04295 Mdot
.7514 .04284 Mdot
.75145 .04274 Mdot
.7515 .04263 Mdot
.75155 .04253 Mdot
.75159 .04242 Mdot
.75164 .04232 Mdot
.75169 .04221 Mdot
.75174 .04211 Mdot
.75178 .042 Mdot
.75183 .04189 Mdot
.75188 .04178 Mdot
.75193 .04167 Mdot
.75197 .04156 Mdot
.75202 .04144 Mdot
.75207 .04133 Mdot
.75212 .04121 Mdot
.75217 .0411 Mdot
.75221 .04098 Mdot
.75226 .04087 Mdot
.75231 .04075 Mdot
.75236 .04063 Mdot
.7524 .04052 Mdot
.75245 .0404 Mdot
.7525 .04029 Mdot
.75255 .04017 Mdot
.75259 .04006 Mdot
.75264 .03994 Mdot
.75269 .03983 Mdot
.75274 .03971 Mdot
.75278 .0396 Mdot
.75283 .03948 Mdot
.75288 .03936 Mdot
.75293 .03925 Mdot
.75297 .03913 Mdot
.75302 .03902 Mdot
.75307 .03891 Mdot
.75312 .0388 Mdot
.75317 .03869 Mdot
.75321 .03859 Mdot
.75326 .03848 Mdot
.75331 .03838 Mdot
.75336 .03827 Mdot
.7534 .03817 Mdot
.75345 .03806 Mdot
.7535 .03796 Mdot
.75355 .03786 Mdot
.75359 .03776 Mdot
.75364 .03766 Mdot
.75369 .03755 Mdot
.75374 .03746 Mdot
.75378 .03736 Mdot
.75383 .03726 Mdot
.75388 .03716 Mdot
.75393 .03706 Mdot
.75397 .03697 Mdot
.75402 .03687 Mdot
.75407 .03678 Mdot
.75412 .03668 Mdot
.75417 .03659 Mdot
.75421 .03649 Mdot
.75426 .03639 Mdot
.75431 .0363 Mdot
.75436 .0362 Mdot
.7544 .0361 Mdot
.75445 .03601 Mdot
.7545 .03591 Mdot
.75455 .03582 Mdot
.75459 .03573 Mdot
.75464 .03564 Mdot
.75469 .03555 Mdot
.75474 .03546 Mdot
.75478 .03536 Mdot
.75483 .03527 Mdot
.75488 .03518 Mdot
.75493 .03509 Mdot
.75497 .03501 Mdot
.75502 .03492 Mdot
.75507 .03483 Mdot
.75512 .03475 Mdot
.75516 .03466 Mdot
.75521 .03458 Mdot
.75526 .03449 Mdot
.75531 .03439 Mdot
.75536 .0343 Mdot
.7554 .03422 Mdot
.75545 .03413 Mdot
.7555 .03405 Mdot
.75555 .03397 Mdot
.75559 .03389 Mdot
.75564 .03381 Mdot
.75569 .03373 Mdot
.75574 .03365 Mdot
.75578 .03358 Mdot
.75583 .0335 Mdot
.75588 .03342 Mdot
.75593 .03335 Mdot
.75597 .03328 Mdot
.75602 .03321 Mdot
.75607 .03314 Mdot
.75612 .03307 Mdot
.75616 .033 Mdot
.75621 .03293 Mdot
.75626 .03286 Mdot
.75631 .03279 Mdot
.75636 .03273 Mdot
.7564 .03266 Mdot
.75645 .03259 Mdot
.7565 .03252 Mdot
.75655 .03245 Mdot
.75659 .03239 Mdot
.75664 .03232 Mdot
.75669 .03225 Mdot
.75674 .03218 Mdot
.75678 .03212 Mdot
.75683 .03206 Mdot
.75688 .03199 Mdot
.75693 .03193 Mdot
.75697 .03187 Mdot
.75702 .03181 Mdot
.75707 .03174 Mdot
.75712 .03168 Mdot
.75716 .03162 Mdot
.75721 .03155 Mdot
.75726 .03149 Mdot
.75731 .03143 Mdot
.75736 .03137 Mdot
.7574 .03131 Mdot
.75745 .03125 Mdot
.7575 .0312 Mdot
.75755 .03114 Mdot
.75759 .03108 Mdot
.75764 .03103 Mdot
.75769 .03098 Mdot
.75774 .03093 Mdot
.75778 .03088 Mdot
.75783 .03083 Mdot
.75788 .03077 Mdot
.75793 .03072 Mdot
.75797 .03067 Mdot
.75802 .03061 Mdot
.75807 .03056 Mdot
.75812 .0305 Mdot
.75816 .03045 Mdot
.75821 .0304 Mdot
.75826 .03034 Mdot
.75831 .03029 Mdot
.75836 .03024 Mdot
.7584 .03019 Mdot
.75845 .03014 Mdot
.7585 .03009 Mdot
.75855 .03004 Mdot
.75859 .02999 Mdot
.75864 .02994 Mdot
.75869 .02989 Mdot
.75874 .02985 Mdot
.75878 .0298 Mdot
.75883 .02975 Mdot
.75888 .0297 Mdot
.75893 .02965 Mdot
.75897 .0296 Mdot
.75902 .02956 Mdot
.75907 .02951 Mdot
.75912 .02947 Mdot
.75916 .02942 Mdot
.75921 .02938 Mdot
.75926 .02934 Mdot
.75931 .0293 Mdot
.75936 .02926 Mdot
.7594 .02922 Mdot
.75945 .02918 Mdot
.7595 .02914 Mdot
.75955 .0291 Mdot
.75959 .02906 Mdot
.75964 .02902 Mdot
.75969 .02898 Mdot
.75974 .02894 Mdot
.75978 .0289 Mdot
.75983 .02886 Mdot
.75988 .02881 Mdot
.75993 .02878 Mdot
.75997 .02873 Mdot
.76002 .02869 Mdot
.76007 .02865 Mdot
.76012 .02861 Mdot
.76016 .02857 Mdot
.76021 .02853 Mdot
.76026 .02849 Mdot
.76031 .02845 Mdot
.76035 .02841 Mdot
.7604 .02836 Mdot
.76045 .02833 Mdot
.7605 .02829 Mdot
.76055 .02826 Mdot
.76059 .02822 Mdot
.76064 .02819 Mdot
.76069 .02816 Mdot
.76074 .02812 Mdot
.76078 .02809 Mdot
.76083 .02806 Mdot
.76088 .02803 Mdot
.76093 .028 Mdot
.76097 .02797 Mdot
.76102 .02795 Mdot
.76107 .02792 Mdot
.76112 .02789 Mdot
.76116 .02786 Mdot
.76121 .02784 Mdot
.76126 .02781 Mdot
.76131 .02778 Mdot
.76135 .02775 Mdot
.7614 .02773 Mdot
.76145 .0277 Mdot
.7615 .02768 Mdot
.76155 .02765 Mdot
.76159 .02763 Mdot
.76164 .02761 Mdot
.76169 .02759 Mdot
.76174 .02757 Mdot
.76178 .02755 Mdot
.76183 .02754 Mdot
.76188 .02752 Mdot
.76193 .02751 Mdot
.76197 .0275 Mdot
.76202 .02749 Mdot
.76207 .02748 Mdot
.76212 .02748 Mdot
.76216 .02747 Mdot
.76221 .02746 Mdot
.76226 .02746 Mdot
.76231 .02746 Mdot
.76235 .02746 Mdot
.7624 .02745 Mdot
.76245 .02745 Mdot
.7625 .02745 Mdot
.76255 .02746 Mdot
.76259 .02746 Mdot
.76264 .02746 Mdot
.76269 .02747 Mdot
.76274 .02747 Mdot
.76278 .02748 Mdot
.76283 .02748 Mdot
.76288 .02749 Mdot
.76293 .02749 Mdot
.76297 .0275 Mdot
.76302 .02751 Mdot
.76307 .02751 Mdot
.76312 .02752 Mdot
.76316 .02753 Mdot
.76321 .02755 Mdot
.76326 .02756 Mdot
.76331 .02757 Mdot
.76335 .02759 Mdot
.7634 .02761 Mdot
.76345 .02763 Mdot
.7635 .02765 Mdot
.76355 .02768 Mdot
.76359 .02769 Mdot
.76364 .02772 Mdot
.76369 .02774 Mdot
.76374 .02777 Mdot
.76378 .02779 Mdot
.76383 .02781 Mdot
.76388 .02783 Mdot
.76393 .02785 Mdot
.76397 .02787 Mdot
.76402 .02788 Mdot
.76407 .0279 Mdot
.76412 .02792 Mdot
.76416 .02794 Mdot
.76421 .02796 Mdot
.76426 .02798 Mdot
.76431 .028 Mdot
.76435 .02802 Mdot
.7644 .02805 Mdot
.76445 .02807 Mdot
.7645 .02809 Mdot
.76454 .02811 Mdot
.76459 .02813 Mdot
.76464 .02815 Mdot
.76469 .02817 Mdot
.76474 .02818 Mdot
.76478 .0282 Mdot
.76483 .02822 Mdot
.76488 .02823 Mdot
.76493 .02825 Mdot
.76497 .02826 Mdot
.76502 .02827 Mdot
.76507 .02828 Mdot
.76512 .02829 Mdot
.76516 .0283 Mdot
.76521 .02831 Mdot
.76526 .02832 Mdot
.76531 .02833 Mdot
.76535 .02834 Mdot
.7654 .02836 Mdot
.76545 .02837 Mdot
.7655 .02839 Mdot
.76554 .02841 Mdot
.76559 .02843 Mdot
.76564 .02845 Mdot
.76569 .02847 Mdot
.76574 .0285 Mdot
.76578 .02853 Mdot
.76583 .02856 Mdot
.76588 .0286 Mdot
.76593 .02863 Mdot
.76597 .02867 Mdot
.76602 .02871 Mdot
.76607 .02875 Mdot
.76612 .02879 Mdot
.76616 .02884 Mdot
.76621 .02888 Mdot
.76626 .02892 Mdot
.76631 .02896 Mdot
.76635 .029 Mdot
.7664 .02904 Mdot
.76645 .02908 Mdot
.7665 .02912 Mdot
.76654 .02916 Mdot
.76659 .0292 Mdot
.76664 .02924 Mdot
.76669 .02928 Mdot
.76674 .02933 Mdot
.76678 .02937 Mdot
.76683 .02941 Mdot
.76688 .02945 Mdot
.76693 .02949 Mdot
.76697 .02954 Mdot
.76702 .02958 Mdot
.76707 .02963 Mdot
.76712 .02967 Mdot
.76716 .02972 Mdot
.76721 .02976 Mdot
.76726 .02981 Mdot
.76731 .02986 Mdot
.76735 .02991 Mdot
.7674 .02996 Mdot
.76745 .03 Mdot
.7675 .03005 Mdot
.76754 .03009 Mdot
.76759 .03014 Mdot
.76764 .03019 Mdot
.76769 .03023 Mdot
.76774 .03027 Mdot
.76778 .03031 Mdot
.76783 .03035 Mdot
.76788 .03039 Mdot
.76793 .03043 Mdot
.76797 .03047 Mdot
.76802 .03052 Mdot
.76807 .03056 Mdot
.76812 .0306 Mdot
.76816 .03065 Mdot
.76821 .03069 Mdot
.76826 .03073 Mdot
.76831 .03077 Mdot
.76835 .03081 Mdot
.7684 .03085 Mdot
.76845 .03089 Mdot
.7685 .03093 Mdot
.76854 .03098 Mdot
.76859 .03102 Mdot
.76864 .03107 Mdot
.76869 .03111 Mdot
.76874 .03116 Mdot
.76878 .0312 Mdot
.76883 .03125 Mdot
.76888 .03129 Mdot
.76893 .03134 Mdot
.76897 .03139 Mdot
.76902 .03143 Mdot
.76907 .03148 Mdot
.76912 .03153 Mdot
.76916 .03158 Mdot
.76921 .03163 Mdot
.76926 .03168 Mdot
.76931 .03173 Mdot
.76935 .03178 Mdot
.7694 .03184 Mdot
.76945 .03189 Mdot
.7695 .03195 Mdot
.76954 .03201 Mdot
.76959 .03207 Mdot
.76964 .03213 Mdot
.76969 .03219 Mdot
.76973 .03225 Mdot
.76978 .03231 Mdot
.76983 .03238 Mdot
.76988 .03244 Mdot
.76993 .03251 Mdot
.76997 .03258 Mdot
.77002 .03265 Mdot
.77007 .03272 Mdot
.77012 .03278 Mdot
.77016 .03285 Mdot
.77021 .03292 Mdot
.77026 .033 Mdot
.77031 .03307 Mdot
.77035 .03314 Mdot
.7704 .03322 Mdot
.77045 .03329 Mdot
.7705 .03337 Mdot
.77054 .03345 Mdot
.77059 .03352 Mdot
.77064 .0336 Mdot
.77069 .03367 Mdot
.77073 .03375 Mdot
.77078 .03382 Mdot
.77083 .0339 Mdot
.77088 .03397 Mdot
.77093 .03405 Mdot
.77097 .03412 Mdot
.77102 .03419 Mdot
.77107 .03427 Mdot
.77112 .03434 Mdot
.77116 .03442 Mdot
.77121 .03449 Mdot
.77126 .03456 Mdot
.77131 .03464 Mdot
.77135 .03471 Mdot
.7714 .03479 Mdot
.77145 .03487 Mdot
.7715 .03495 Mdot
.77154 .03503 Mdot
.77159 .03512 Mdot
.77164 .0352 Mdot
.77169 .03528 Mdot
.77173 .03537 Mdot
.77178 .03545 Mdot
.77183 .03554 Mdot
.77188 .03563 Mdot
.77193 .03572 Mdot
.77197 .03581 Mdot
.77202 .0359 Mdot
.77207 .03599 Mdot
.77212 .03608 Mdot
.77216 .03618 Mdot
.77221 .03627 Mdot
.77226 .03637 Mdot
.77231 .03647 Mdot
.77235 .03656 Mdot
.7724 .03666 Mdot
.77245 .03676 Mdot
.7725 .03685 Mdot
.77254 .03695 Mdot
.77259 .03706 Mdot
.77264 .03716 Mdot
.77269 .03726 Mdot
.77273 .03737 Mdot
.77278 .03748 Mdot
.77283 .03759 Mdot
.77288 .03769 Mdot
.77293 .0378 Mdot
.77297 .03791 Mdot
.77302 .03801 Mdot
.77307 .03811 Mdot
.77312 .03822 Mdot
.77316 .03833 Mdot
.77321 .03843 Mdot
.77326 .03854 Mdot
.77331 .03866 Mdot
.77335 .03877 Mdot
.7734 .03888 Mdot
.77345 .03899 Mdot
.7735 .0391 Mdot
.77354 .03921 Mdot
.77359 .03932 Mdot
.77364 .03943 Mdot
.77369 .03955 Mdot
.77373 .03966 Mdot
.77378 .03977 Mdot
.77383 .03988 Mdot
.77388 .03999 Mdot
.77392 .0401 Mdot
.77397 .04021 Mdot
.77402 .04032 Mdot
.77407 .04044 Mdot
.77412 .04055 Mdot
.77416 .04067 Mdot
.77421 .04078 Mdot
.77426 .0409 Mdot
.77431 .04101 Mdot
.77435 .04112 Mdot
.7744 .04124 Mdot
.77445 .04136 Mdot
.7745 .04148 Mdot
.77454 .0416 Mdot
.77459 .04172 Mdot
.77464 .04184 Mdot
.77469 .04196 Mdot
.77473 .04208 Mdot
.77478 .0422 Mdot
.77483 .04232 Mdot
.77488 .04244 Mdot
.77492 .04256 Mdot
.77497 .04269 Mdot
.77502 .04281 Mdot
.77507 .04293 Mdot
.77512 .04306 Mdot
.77516 .04319 Mdot
.77521 .04332 Mdot
.77526 .04346 Mdot
.77531 .04359 Mdot
.77535 .04372 Mdot
.7754 .04385 Mdot
.77545 .04398 Mdot
.7755 .04411 Mdot
.77554 .04423 Mdot
.77559 .04436 Mdot
.77564 .04448 Mdot
.77569 .0446 Mdot
.77573 .04473 Mdot
.77578 .04486 Mdot
.77583 .04499 Mdot
.77588 .04512 Mdot
.77592 .04525 Mdot
.77597 .04538 Mdot
.77602 .0455 Mdot
.77607 .04563 Mdot
.77612 .04575 Mdot
.77616 .04588 Mdot
.77621 .04601 Mdot
.77626 .04614 Mdot
.77631 .04627 Mdot
.77635 .0464 Mdot
.7764 .04653 Mdot
.77645 .04666 Mdot
.7765 .04679 Mdot
.77654 .04693 Mdot
.77659 .04706 Mdot
.77664 .04719 Mdot
.77669 .04732 Mdot
.77673 .04745 Mdot
.77678 .04758 Mdot
.77683 .04772 Mdot
.77688 .04785 Mdot
.77692 .04798 Mdot
.77697 .04811 Mdot
.77702 .04825 Mdot
.77707 .04838 Mdot
.77712 .04851 Mdot
.77716 .04864 Mdot
.77721 .04877 Mdot
.77726 .0489 Mdot
.77731 .04903 Mdot
.77735 .04916 Mdot
.7774 .04929 Mdot
.77745 .04942 Mdot
.7775 .04955 Mdot
.77754 .04968 Mdot
.77759 .04982 Mdot
.77764 .04995 Mdot
.77769 .05009 Mdot
.77773 .05023 Mdot
.77778 .05036 Mdot
.77783 .05049 Mdot
.77788 .05063 Mdot
.77792 .05076 Mdot
.77797 .0509 Mdot
.77802 .05103 Mdot
.77807 .05116 Mdot
.77812 .05129 Mdot
.77816 .05142 Mdot
.77821 .05156 Mdot
.77826 .05169 Mdot
.77831 .05182 Mdot
.77835 .05195 Mdot
.7784 .05208 Mdot
.77845 .05221 Mdot
.7785 .05233 Mdot
.77854 .05246 Mdot
.77859 .05259 Mdot
.77864 .05273 Mdot
.77869 .05286 Mdot
.77873 .053 Mdot
.77878 .05313 Mdot
.77883 .05327 Mdot
.77888 .0534 Mdot
.77892 .05353 Mdot
.77897 .05367 Mdot
.77902 .05381 Mdot
.77907 .05395 Mdot
.77911 .05408 Mdot
.77916 .05422 Mdot
.77921 .05435 Mdot
.77926 .05449 Mdot
.77931 .05463 Mdot
.77935 .05476 Mdot
.7794 .0549 Mdot
.77945 .05504 Mdot
.7795 .05517 Mdot
.77954 .05531 Mdot
.77959 .05545 Mdot
.77964 .05559 Mdot
.77969 .05572 Mdot
.77973 .05586 Mdot
.77978 .056 Mdot
.77983 .05615 Mdot
.77988 .05629 Mdot
.77992 .05643 Mdot
.77997 .05658 Mdot
.78002 .05672 Mdot
.78007 .05686 Mdot
.78011 .05701 Mdot
.78016 .05715 Mdot
.78021 .05729 Mdot
.78026 .05744 Mdot
.78031 .05758 Mdot
.78035 .05772 Mdot
.7804 .05787 Mdot
.78045 .05802 Mdot
.7805 .05818 Mdot
.78054 .05833 Mdot
.78059 .05848 Mdot
.78064 .05863 Mdot
.78069 .05879 Mdot
.78073 .05894 Mdot
.78078 .0591 Mdot
.78083 .05925 Mdot
.78088 .05941 Mdot
.78092 .05956 Mdot
.78097 .05971 Mdot
.78102 .05986 Mdot
.78107 .06002 Mdot
.78111 .06017 Mdot
.78116 .06033 Mdot
.78121 .06049 Mdot
.78126 .06065 Mdot
.78131 .0608 Mdot
.78135 .06096 Mdot
.7814 .06112 Mdot
.78145 .06128 Mdot
.7815 .06143 Mdot
.78154 .06159 Mdot
.78159 .06175 Mdot
.78164 .0619 Mdot
.78169 .06206 Mdot
.78173 .06221 Mdot
.78178 .06236 Mdot
.78183 .06251 Mdot
.78188 .06266 Mdot
.78192 .06281 Mdot
.78197 .06296 Mdot
.78202 .0631 Mdot
.78207 .06326 Mdot
.78211 .06341 Mdot
.78216 .06356 Mdot
.78221 .06372 Mdot
.78226 .06387 Mdot
.78231 .06403 Mdot
.78235 .06419 Mdot
.7824 .06434 Mdot
.78245 .0645 Mdot
.7825 .06465 Mdot
.78254 .06481 Mdot
.78259 .06496 Mdot
.78264 .06511 Mdot
.78269 .06527 Mdot
.78273 .06543 Mdot
.78278 .06559 Mdot
.78283 .06575 Mdot
.78288 .06591 Mdot
.78292 .06608 Mdot
.78297 .06624 Mdot
.78302 .06641 Mdot
.78307 .06657 Mdot
.78311 .06674 Mdot
.78316 .06691 Mdot
.78321 .06708 Mdot
.78326 .06724 Mdot
.78331 .06741 Mdot
.78335 .06758 Mdot
.7834 .06775 Mdot
.78345 .06792 Mdot
.7835 .06809 Mdot
.78354 .06825 Mdot
.78359 .06842 Mdot
.78364 .06858 Mdot
.78369 .06875 Mdot
.78373 .06892 Mdot
.78378 .06909 Mdot
.78383 .06925 Mdot
.78388 .06941 Mdot
.78392 .06958 Mdot
.78397 .06975 Mdot
.78402 .06991 Mdot
.78407 .07008 Mdot
.78411 .07025 Mdot
.78416 .07041 Mdot
.78421 .07058 Mdot
.78426 .07074 Mdot
.7843 .07091 Mdot
.78435 .07107 Mdot
.7844 .07123 Mdot
.78445 .0714 Mdot
.7845 .07156 Mdot
.78454 .07172 Mdot
.78459 .07189 Mdot
.78464 .07205 Mdot
.78469 .07222 Mdot
.78473 .07238 Mdot
.78478 .07255 Mdot
.78483 .07272 Mdot
.78488 .07288 Mdot
.78492 .07305 Mdot
.78497 .07321 Mdot
.78502 .07338 Mdot
.78507 .07354 Mdot
.78511 .0737 Mdot
.78516 .07387 Mdot
.78521 .07403 Mdot
.78526 .0742 Mdot
.7853 .07437 Mdot
.78535 .07454 Mdot
.7854 .0747 Mdot
.78545 .07488 Mdot
.7855 .07504 Mdot
.78554 .07522 Mdot
.78559 .07539 Mdot
.78564 .07556 Mdot
.78569 .07573 Mdot
.78573 .0759 Mdot
.78578 .07607 Mdot
.78583 .07624 Mdot
.78588 .07641 Mdot
.78592 .07658 Mdot
.78597 .07675 Mdot
.78602 .07692 Mdot
.78607 .0771 Mdot
.78611 .07727 Mdot
.78616 .07744 Mdot
.78621 .07761 Mdot
.78626 .07778 Mdot
.7863 .07795 Mdot
.78635 .07812 Mdot
.7864 .07829 Mdot
.78645 .07845 Mdot
.7865 .07862 Mdot
.78654 .07879 Mdot
.78659 .07896 Mdot
.78664 .07913 Mdot
.78669 .0793 Mdot
.78673 .07948 Mdot
.78678 .07965 Mdot
.78683 .07982 Mdot
.78688 .07999 Mdot
.78692 .08016 Mdot
.78697 .08033 Mdot
.78702 .0805 Mdot
.78707 .08068 Mdot
.78711 .08085 Mdot
.78716 .08103 Mdot
.78721 .08121 Mdot
.78726 .08139 Mdot
.7873 .08156 Mdot
.78735 .08174 Mdot
.7874 .08191 Mdot
.78745 .08209 Mdot
.7875 .08227 Mdot
.78754 .08245 Mdot
.78759 .08263 Mdot
.78764 .08281 Mdot
.78769 .083 Mdot
.78773 .08318 Mdot
.78778 .08336 Mdot
.78783 .08355 Mdot
.78788 .08373 Mdot
.78792 .08392 Mdot
.78797 .08411 Mdot
.78802 .0843 Mdot
.78807 .08449 Mdot
.78811 .08468 Mdot
.78816 .08486 Mdot
.78821 .08505 Mdot
.78826 .08524 Mdot
.7883 .08544 Mdot
.78835 .08563 Mdot
.7884 .08582 Mdot
.78845 .08601 Mdot
.78849 .0862 Mdot
.78854 .08639 Mdot
.78859 .08658 Mdot
.78864 .08677 Mdot
.78869 .08697 Mdot
.78873 .08716 Mdot
.78878 .08736 Mdot
.78883 .08756 Mdot
.78888 .08775 Mdot
.78892 .08795 Mdot
.78897 .08814 Mdot
.78902 .08834 Mdot
.78907 .08853 Mdot
.78911 .08873 Mdot
.78916 .08892 Mdot
.78921 .08911 Mdot
.78926 .0893 Mdot
.7893 .08949 Mdot
.78935 .08969 Mdot
.7894 .08988 Mdot
.78945 .09008 Mdot
.78949 .09027 Mdot
.78954 .09046 Mdot
.78959 .09066 Mdot
.78964 .09085 Mdot
.78969 .09104 Mdot
.78973 .09124 Mdot
.78978 .09144 Mdot
.78983 .09164 Mdot
.78988 .09184 Mdot
.78992 .09204 Mdot
.78997 .09224 Mdot
.79002 .09245 Mdot
.79007 .09265 Mdot
.79011 .09286 Mdot
.79016 .09306 Mdot
.79021 .09327 Mdot
.79026 .09347 Mdot
.7903 .09367 Mdot
.79035 .09387 Mdot
.7904 .09407 Mdot
.79045 .09427 Mdot
.79049 .09448 Mdot
.79054 .09468 Mdot
.79059 .09488 Mdot
.79064 .09508 Mdot
.79069 .09528 Mdot
.79073 .09549 Mdot
.79078 .09569 Mdot
.79083 .0959 Mdot
.79088 .09611 Mdot
.79092 .09632 Mdot
.79097 .09652 Mdot
.79102 .09673 Mdot
.79107 .09694 Mdot
.79111 .09715 Mdot
.79116 .09735 Mdot
.79121 .09756 Mdot
.79126 .09777 Mdot
.7913 .09797 Mdot
.79135 .09818 Mdot
.7914 .09838 Mdot
.79145 .09858 Mdot
.79149 .09877 Mdot
.79154 .09897 Mdot
.79159 .09918 Mdot
.79164 .09938 Mdot
.79169 .09958 Mdot
.79173 .09978 Mdot
.79178 .09998 Mdot
.79183 .10019 Mdot
.79188 .1004 Mdot
.79192 .10061 Mdot
.79197 .10083 Mdot
.79202 .10104 Mdot
.79207 .10126 Mdot
.79211 .10147 Mdot
.79216 .10169 Mdot
.79221 .1019 Mdot
.79226 .10212 Mdot
.7923 .10233 Mdot
.79235 .10255 Mdot
.7924 .10277 Mdot
.79245 .10299 Mdot
.79249 .10321 Mdot
.79254 .10343 Mdot
.79259 .10365 Mdot
.79264 .10387 Mdot
.79269 .1041 Mdot
.79273 .10432 Mdot
.79278 .10455 Mdot
.79283 .10478 Mdot
.79288 .105 Mdot
.79292 .10523 Mdot
.79297 .10546 Mdot
.79302 .1057 Mdot
.79307 .10593 Mdot
.79311 .10617 Mdot
.79316 .1064 Mdot
.79321 .10664 Mdot
.79326 .10688 Mdot
.7933 .10712 Mdot
.79335 .10736 Mdot
.7934 .10761 Mdot
.79345 .10785 Mdot
.79349 .1081 Mdot
.79354 .10835 Mdot
.79359 .10859 Mdot
.79364 .10884 Mdot
.79368 .10908 Mdot
.79373 .10932 Mdot
.79378 .10956 Mdot
.79383 .1098 Mdot
.79388 .11004 Mdot
.79392 .11028 Mdot
.79397 .11052 Mdot
.79402 .11076 Mdot
.79407 .111 Mdot
.79411 .11124 Mdot
.79416 .11148 Mdot
.79421 .11172 Mdot
.79426 .11196 Mdot
.7943 .1122 Mdot
.79435 .11245 Mdot
.7944 .11269 Mdot
.79445 .11294 Mdot
.79449 .11318 Mdot
.79454 .11343 Mdot
.79459 .11367 Mdot
.79464 .11392 Mdot
.79468 .11418 Mdot
.79473 .11443 Mdot
.79478 .11468 Mdot
.79483 .11494 Mdot
.79488 .1152 Mdot
.79492 .11545 Mdot
.79497 .11571 Mdot
.79502 .11596 Mdot
.79507 .11622 Mdot
.79511 .11647 Mdot
.79516 .11673 Mdot
.79521 .11699 Mdot
.79526 .11725 Mdot
.7953 .11751 Mdot
.79535 .11777 Mdot
.7954 .11803 Mdot
.79545 .11829 Mdot
.79549 .11855 Mdot
.79554 .11881 Mdot
.79559 .11908 Mdot
.79564 .11934 Mdot
.79568 .1196 Mdot
.79573 .11987 Mdot
.79578 .12014 Mdot
.79583 .12041 Mdot
.79588 .12068 Mdot
.79592 .12094 Mdot
.79597 .12121 Mdot
.79602 .12148 Mdot
.79607 .12175 Mdot
.79611 .12202 Mdot
.79616 .12229 Mdot
.79621 .12255 Mdot
.79626 .12282 Mdot
.7963 .12309 Mdot
.79635 .12336 Mdot
.7964 .12363 Mdot
.79645 .1239 Mdot
.79649 .12417 Mdot
.79654 .12444 Mdot
.79659 .12472 Mdot
.79664 .12499 Mdot
.79668 .12526 Mdot
.79673 .12553 Mdot
.79678 .1258 Mdot
.79683 .12607 Mdot
.79688 .12634 Mdot
.79692 .12661 Mdot
.79697 .12688 Mdot
.79702 .12716 Mdot
.79707 .12743 Mdot
.79711 .1277 Mdot
.79716 .12797 Mdot
.79721 .12824 Mdot
.79726 .12852 Mdot
.7973 .12879 Mdot
.79735 .12907 Mdot
.7974 .12935 Mdot
.79745 .12963 Mdot
.79749 .12991 Mdot
.79754 .13018 Mdot
.79759 .13046 Mdot
.79764 .13074 Mdot
.79768 .13102 Mdot
.79773 .13131 Mdot
.79778 .13159 Mdot
.79783 .13187 Mdot
.79787 .13216 Mdot
.79792 .13244 Mdot
.79797 .13272 Mdot
.79802 .133 Mdot
.79807 .13328 Mdot
.79811 .13355 Mdot
.79816 .13383 Mdot
.79821 .13412 Mdot
.79826 .1344 Mdot
.7983 .13469 Mdot
.79835 .13497 Mdot
.7984 .13525 Mdot
.79845 .13553 Mdot
.79849 .13582 Mdot
.79854 .1361 Mdot
.79859 .13638 Mdot
.79864 .13667 Mdot
.79868 .13695 Mdot
.79873 .13723 Mdot
.79878 .13752 Mdot
.79883 .13781 Mdot
.79887 .13809 Mdot
.79892 .13838 Mdot
.79897 .13867 Mdot
.79902 .13896 Mdot
.79907 .13926 Mdot
.79911 .13955 Mdot
.79916 .13984 Mdot
.79921 .14012 Mdot
.79926 .14041 Mdot
.7993 .1407 Mdot
.79935 .14098 Mdot
.7994 .14127 Mdot
.79945 .14155 Mdot
.79949 .14183 Mdot
.79954 .1421 Mdot
.79959 .14238 Mdot
.79964 .14266 Mdot
.79968 .14294 Mdot
.79973 .14322 Mdot
.79978 .14349 Mdot
.79983 .14377 Mdot
.79987 .14405 Mdot
.79992 .14433 Mdot
.79997 .14461 Mdot
.80002 .14489 Mdot
.80007 .14518 Mdot
.80011 .14546 Mdot
.80016 .14574 Mdot
.80021 .14602 Mdot
.80026 .1463 Mdot
.8003 .14658 Mdot
.80035 .14686 Mdot
.8004 .14714 Mdot
.80045 .14743 Mdot
.80049 .14771 Mdot
.80054 .14799 Mdot
.80059 .14828 Mdot
.80064 .14856 Mdot
.80068 .14884 Mdot
.80073 .14912 Mdot
.80078 .14939 Mdot
.80083 .14967 Mdot
.80087 .14994 Mdot
.80092 .15022 Mdot
.80097 .1505 Mdot
.80102 .15078 Mdot
.80107 .15106 Mdot
.80111 .15133 Mdot
.80116 .15161 Mdot
.80121 .15188 Mdot
.80126 .15216 Mdot
.8013 .15243 Mdot
.80135 .15271 Mdot
.8014 .15299 Mdot
.80145 .15327 Mdot
.80149 .15355 Mdot
.80154 .15382 Mdot
.80159 .1541 Mdot
.80164 .15437 Mdot
.80168 .15465 Mdot
.80173 .15492 Mdot
.80178 .15519 Mdot
.80183 .15546 Mdot
.80187 .15573 Mdot
.80192 .156 Mdot
.80197 .15627 Mdot
.80202 .15654 Mdot
.80207 .15681 Mdot
.80211 .15708 Mdot
.80216 .15736 Mdot
.80221 .15763 Mdot
.80226 .1579 Mdot
.8023 .15817 Mdot
.80235 .15844 Mdot
.8024 .15871 Mdot
.80245 .15898 Mdot
.80249 .15926 Mdot
.80254 .15953 Mdot
.80259 .1598 Mdot
.80264 .16008 Mdot
.80268 .16035 Mdot
.80273 .16062 Mdot
.80278 .16089 Mdot
.80283 .16117 Mdot
.80287 .16144 Mdot
.80292 .16172 Mdot
.80297 .16199 Mdot
.80302 .16226 Mdot
.80306 .16254 Mdot
.80311 .16281 Mdot
.80316 .16308 Mdot
.80321 .16335 Mdot
.80326 .16362 Mdot
.8033 .1639 Mdot
.80335 .16417 Mdot
.8034 .16445 Mdot
.80345 .16472 Mdot
.80349 .165 Mdot
.80354 .16527 Mdot
.80359 .16555 Mdot
.80364 .16582 Mdot
.80368 .16609 Mdot
.80373 .16637 Mdot
.80378 .16664 Mdot
.80383 .16692 Mdot
.80387 .1672 Mdot
.80392 .16747 Mdot
.80397 .16775 Mdot
.80402 .16803 Mdot
.80406 .16831 Mdot
.80411 .16859 Mdot
.80416 .16886 Mdot
.80421 .16914 Mdot
.80426 .16942 Mdot
.8043 .1697 Mdot
.80435 .16998 Mdot
.8044 .17026 Mdot
.80445 .17055 Mdot
.80449 .17083 Mdot
.80454 .17112 Mdot
.80459 .17141 Mdot
.80464 .1717 Mdot
.80468 .17199 Mdot
.80473 .17228 Mdot
.80478 .17257 Mdot
.80483 .17286 Mdot
.80487 .17315 Mdot
.80492 .17343 Mdot
.80497 .17372 Mdot
.80502 .17402 Mdot
.80506 .17431 Mdot
.80511 .1746 Mdot
.80516 .1749 Mdot
.80521 .17519 Mdot
.80526 .17548 Mdot
.8053 .17577 Mdot
.80535 .17606 Mdot
.8054 .17635 Mdot
.80545 .17664 Mdot
.80549 .17693 Mdot
.80554 .17722 Mdot
.80559 .17752 Mdot
.80564 .17781 Mdot
.80568 .1781 Mdot
.80573 .17839 Mdot
.80578 .17868 Mdot
.80583 .17897 Mdot
.80587 .17926 Mdot
.80592 .17955 Mdot
.80597 .17984 Mdot
.80602 .18013 Mdot
.80606 .18043 Mdot
.80611 .18072 Mdot
.80616 .18102 Mdot
.80621 .18131 Mdot
.80626 .18161 Mdot
.8063 .18191 Mdot
.80635 .1822 Mdot
.8064 .1825 Mdot
.80645 .18281 Mdot
.80649 .18311 Mdot
.80654 .18341 Mdot
.80659 .18371 Mdot
.80664 .18402 Mdot
.80668 .18432 Mdot
.80673 .18462 Mdot
.80678 .18492 Mdot
.80683 .18523 Mdot
.80687 .18553 Mdot
.80692 .18584 Mdot
.80697 .18614 Mdot
.80702 .18645 Mdot
.80706 .18676 Mdot
.80711 .18707 Mdot
.80716 .18737 Mdot
.80721 .18768 Mdot
.80725 .18799 Mdot
.8073 .1883 Mdot
.80735 .1886 Mdot
.8074 .18891 Mdot
.80745 .18922 Mdot
.80749 .18952 Mdot
.80754 .18983 Mdot
.80759 .19014 Mdot
.80764 .19044 Mdot
.80768 .19075 Mdot
.80773 .19105 Mdot
.80778 .19136 Mdot
.80783 .19167 Mdot
.80787 .19198 Mdot
.80792 .19228 Mdot
.80797 .19259 Mdot
.80802 .1929 Mdot
.80806 .1932 Mdot
.80811 .19351 Mdot
.80816 .19381 Mdot
.80821 .19412 Mdot
.80825 .19442 Mdot
.8083 .19472 Mdot
.80835 .19503 Mdot
.8084 .19533 Mdot
.80845 .19563 Mdot
.80849 .19594 Mdot
.80854 .19624 Mdot
.80859 .19655 Mdot
.80864 .19686 Mdot
.80868 .19717 Mdot
.80873 .19749 Mdot
.80878 .1978 Mdot
.80883 .19811 Mdot
.80887 .19843 Mdot
.80892 .19874 Mdot
.80897 .19906 Mdot
.80902 .19937 Mdot
.80906 .19969 Mdot
.80911 .20001 Mdot
.80916 .20033 Mdot
.80921 .20065 Mdot
.80925 .20097 Mdot
.8093 .20129 Mdot
.80935 .20161 Mdot
.8094 .20194 Mdot
.80945 .20226 Mdot
.80949 .20259 Mdot
.80954 .20291 Mdot
.80959 .20324 Mdot
.80964 .20357 Mdot
.80968 .2039 Mdot
.80973 .20423 Mdot
.80978 .20456 Mdot
.80983 .2049 Mdot
.80987 .20524 Mdot
.80992 .20557 Mdot
.80997 .20591 Mdot
.81002 .20624 Mdot
.81006 .20657 Mdot
.81011 .20691 Mdot
.81016 .20725 Mdot
.81021 .20759 Mdot
.81025 .20792 Mdot
.8103 .20826 Mdot
.81035 .20859 Mdot
.8104 .20892 Mdot
.81045 .20926 Mdot
.81049 .2096 Mdot
.81054 .20993 Mdot
.81059 .21027 Mdot
.81064 .2106 Mdot
.81068 .21094 Mdot
.81073 .21128 Mdot
.81078 .21161 Mdot
.81083 .21195 Mdot
.81087 .21228 Mdot
.81092 .21262 Mdot
.81097 .21295 Mdot
.81102 .21329 Mdot
.81106 .21362 Mdot
.81111 .21396 Mdot
.81116 .21429 Mdot
.81121 .21463 Mdot
.81125 .21496 Mdot
.8113 .2153 Mdot
.81135 .21564 Mdot
.8114 .21598 Mdot
.81145 .21631 Mdot
.81149 .21665 Mdot
.81154 .21699 Mdot
.81159 .21733 Mdot
.81164 .21766 Mdot
.81168 .218 Mdot
.81173 .21834 Mdot
.81178 .21868 Mdot
.81183 .21902 Mdot
.81187 .21936 Mdot
.81192 .2197 Mdot
.81197 .22004 Mdot
.81202 .22038 Mdot
.81206 .22072 Mdot
.81211 .22106 Mdot
.81216 .2214 Mdot
.81221 .22174 Mdot
.81225 .22208 Mdot
.8123 .22242 Mdot
.81235 .22275 Mdot
.8124 .22309 Mdot
.81244 .22343 Mdot
.81249 .22376 Mdot
.81254 .2241 Mdot
.81259 .22445 Mdot
.81264 .2248 Mdot
.81268 .22514 Mdot
.81273 .22549 Mdot
.81278 .22583 Mdot
.81283 .22618 Mdot
.81287 .22653 Mdot
.81292 .22688 Mdot
.81297 .22722 Mdot
.81302 .22757 Mdot
.81306 .22792 Mdot
.81311 .22826 Mdot
.81316 .22861 Mdot
.81321 .22895 Mdot
.81325 .2293 Mdot
.8133 .22965 Mdot
.81335 .23 Mdot
.8134 .23035 Mdot
.81344 .23069 Mdot
.81349 .23104 Mdot
.81354 .23139 Mdot
.81359 .23174 Mdot
.81364 .23209 Mdot
.81368 .23244 Mdot
.81373 .23279 Mdot
.81378 .23315 Mdot
.81383 .2335 Mdot
.81387 .23385 Mdot
.81392 .23421 Mdot
.81397 .23456 Mdot
.81402 .23492 Mdot
.81406 .23528 Mdot
.81411 .23564 Mdot
.81416 .23599 Mdot
.81421 .23634 Mdot
.81425 .2367 Mdot
.8143 .23705 Mdot
.81435 .2374 Mdot
.8144 .23775 Mdot
.81444 .2381 Mdot
.81449 .23845 Mdot
.81454 .2388 Mdot
.81459 .23915 Mdot
.81464 .23949 Mdot
.81468 .23984 Mdot
.81473 .24019 Mdot
.81478 .24053 Mdot
.81483 .24088 Mdot
.81487 .24122 Mdot
.81492 .24157 Mdot
.81497 .24192 Mdot
.81502 .24227 Mdot
.81506 .24262 Mdot
.81511 .24297 Mdot
.81516 .24331 Mdot
.81521 .24366 Mdot
.81525 .244 Mdot
.8153 .24434 Mdot
.81535 .24469 Mdot
.8154 .24504 Mdot
.81544 .24539 Mdot
.81549 .24573 Mdot
.81554 .24607 Mdot
.81559 .24642 Mdot
.81564 .24676 Mdot
.81568 .2471 Mdot
.81573 .24744 Mdot
.81578 .24779 Mdot
.81583 .24813 Mdot
.81587 .24848 Mdot
.81592 .24882 Mdot
.81597 .24917 Mdot
.81602 .24951 Mdot
.81606 .24986 Mdot
.81611 .2502 Mdot
.81616 .25055 Mdot
.81621 .2509 Mdot
.81625 .25125 Mdot
.8163 .2516 Mdot
.81635 .25195 Mdot
.8164 .25231 Mdot
.81644 .25266 Mdot
.81649 .25301 Mdot
.81654 .25336 Mdot
.81659 .25372 Mdot
.81664 .25408 Mdot
.81668 .25443 Mdot
.81673 .25478 Mdot
.81678 .25514 Mdot
.81683 .25549 Mdot
.81687 .25584 Mdot
.81692 .25619 Mdot
.81697 .25654 Mdot
.81702 .2569 Mdot
.81706 .25725 Mdot
.81711 .25761 Mdot
.81716 .25797 Mdot
.81721 .25833 Mdot
.81725 .25869 Mdot
.8173 .25904 Mdot
.81735 .2594 Mdot
.8174 .25975 Mdot
.81744 .26011 Mdot
.81749 .26046 Mdot
.81754 .26081 Mdot
.81759 .26116 Mdot
.81763 .26151 Mdot
.81768 .26187 Mdot
.81773 .26222 Mdot
.81778 .26258 Mdot
.81783 .26294 Mdot
.81787 .2633 Mdot
.81792 .26366 Mdot
.81797 .26401 Mdot
.81802 .26437 Mdot
.81806 .26473 Mdot
.81811 .26509 Mdot
.81816 .26545 Mdot
.81821 .26581 Mdot
.81825 .26617 Mdot
.8183 .26653 Mdot
.81835 .26688 Mdot
.8184 .26724 Mdot
.81844 .26759 Mdot
.81849 .26795 Mdot
.81854 .2683 Mdot
.81859 .26866 Mdot
.81863 .26901 Mdot
.81868 .26937 Mdot
.81873 .26972 Mdot
.81878 .27008 Mdot
.81883 .27044 Mdot
.81887 .27079 Mdot
.81892 .27115 Mdot
.81897 .27151 Mdot
.81902 .27186 Mdot
.81906 .27222 Mdot
.81911 .27258 Mdot
.81916 .27293 Mdot
.81921 .27329 Mdot
.81925 .27365 Mdot
.8193 .274 Mdot
.81935 .27436 Mdot
.8194 .27472 Mdot
.81944 .27508 Mdot
.81949 .27544 Mdot
.81954 .2758 Mdot
.81959 .27615 Mdot
.81963 .27651 Mdot
.81968 .27687 Mdot
.81973 .27723 Mdot
.81978 .27759 Mdot
.81983 .27794 Mdot
.81987 .2783 Mdot
.81992 .27866 Mdot
.81997 .27902 Mdot
.82002 .27937 Mdot
.82006 .27973 Mdot
.82011 .28009 Mdot
.82016 .28046 Mdot
.82021 .28082 Mdot
.82025 .28117 Mdot
.8203 .28153 Mdot
.82035 .28189 Mdot
.8204 .28225 Mdot
.82044 .28261 Mdot
.82049 .28297 Mdot
.82054 .28333 Mdot
.82059 .2837 Mdot
.82063 .28406 Mdot
.82068 .28443 Mdot
.82073 .28479 Mdot
.82078 .28516 Mdot
.82083 .28552 Mdot
.82087 .28588 Mdot
.82092 .28624 Mdot
.82097 .28661 Mdot
.82102 .28697 Mdot
.82106 .28733 Mdot
.82111 .2877 Mdot
.82116 .28806 Mdot
.82121 .28843 Mdot
.82125 .28879 Mdot
.8213 .28915 Mdot
.82135 .28952 Mdot
.8214 .28988 Mdot
.82144 .29024 Mdot
.82149 .2906 Mdot
.82154 .29096 Mdot
.82159 .29132 Mdot
.82163 .29168 Mdot
.82168 .29205 Mdot
.82173 .29241 Mdot
.82178 .29277 Mdot
.82182 .29313 Mdot
.82187 .29349 Mdot
.82192 .29385 Mdot
.82197 .29421 Mdot
.82202 .29456 Mdot
.82206 .29492 Mdot
.82211 .29528 Mdot
.82216 .29564 Mdot
.82221 .29599 Mdot
.82225 .29635 Mdot
.8223 .29671 Mdot
.82235 .29707 Mdot
.8224 .29743 Mdot
.82244 .29779 Mdot
.82249 .29815 Mdot
.82254 .29851 Mdot
.82259 .29888 Mdot
.82263 .29924 Mdot
.82268 .29961 Mdot
.82273 .29997 Mdot
.82278 .30033 Mdot
.82282 .30069 Mdot
.82287 .30106 Mdot
.82292 .30142 Mdot
.82297 .30178 Mdot
.82302 .30214 Mdot
.82306 .3025 Mdot
.82311 .30287 Mdot
.82316 .30323 Mdot
.82321 .3036 Mdot
.82325 .30396 Mdot
.8233 .30432 Mdot
.82335 .30469 Mdot
.8234 .30505 Mdot
.82344 .30542 Mdot
.82349 .30578 Mdot
.82354 .30615 Mdot
.82359 .30651 Mdot
.82363 .30688 Mdot
.82368 .30724 Mdot
.82373 .30761 Mdot
.82378 .30798 Mdot
.82382 .30834 Mdot
.82387 .30871 Mdot
.82392 .30907 Mdot
.82397 .30944 Mdot
.82402 .3098 Mdot
.82406 .31016 Mdot
.82411 .31053 Mdot
.82416 .31089 Mdot
.82421 .31125 Mdot
.82425 .31161 Mdot
.8243 .31198 Mdot
.82435 .31234 Mdot
.8244 .31271 Mdot
.82444 .31308 Mdot
.82449 .31345 Mdot
.82454 .31382 Mdot
.82459 .31419 Mdot
.82463 .31456 Mdot
.82468 .31493 Mdot
.82473 .3153 Mdot
.82478 .31568 Mdot
.82482 .31605 Mdot
.82487 .31643 Mdot
.82492 .3168 Mdot
.82497 .31717 Mdot
.82502 .31755 Mdot
.82506 .31792 Mdot
.82511 .31829 Mdot
.82516 .31866 Mdot
.82521 .31903 Mdot
.82525 .3194 Mdot
.8253 .31977 Mdot
.82535 .32014 Mdot
.8254 .32051 Mdot
.82544 .32088 Mdot
.82549 .32125 Mdot
.82554 .32162 Mdot
.82559 .32199 Mdot
.82563 .32236 Mdot
.82568 .32273 Mdot
.82573 .3231 Mdot
.82578 .32347 Mdot
.82582 .32385 Mdot
.82587 .32422 Mdot
.82592 .32459 Mdot
.82597 .32496 Mdot
.82602 .32533 Mdot
.82606 .32571 Mdot
.82611 .32608 Mdot
.82616 .32645 Mdot
.82621 .32682 Mdot
.82625 .32719 Mdot
.8263 .32755 Mdot
.82635 .32792 Mdot
.8264 .32829 Mdot
.82644 .32865 Mdot
.82649 .32902 Mdot
.82654 .32938 Mdot
.82659 .32974 Mdot
.82663 .3301 Mdot
.82668 .33046 Mdot
.82673 .33082 Mdot
.82678 .33118 Mdot
.82682 .33155 Mdot
.82687 .33191 Mdot
.82692 .33227 Mdot
.82697 .33263 Mdot
.82701 .33299 Mdot
.82706 .33336 Mdot
.82711 .33372 Mdot
.82716 .33408 Mdot
.82721 .33445 Mdot
.82725 .33481 Mdot
.8273 .33518 Mdot
.82735 .33554 Mdot
.8274 .3359 Mdot
.82744 .33626 Mdot
.82749 .33662 Mdot
.82754 .33698 Mdot
.82759 .33734 Mdot
.82763 .3377 Mdot
.82768 .33805 Mdot
.82773 .33841 Mdot
.82778 .33877 Mdot
.82782 .33912 Mdot
.82787 .33948 Mdot
.82792 .33984 Mdot
.82797 .3402 Mdot
.82801 .34056 Mdot
.82806 .34092 Mdot
.82811 .34127 Mdot
.82816 .34163 Mdot
.82821 .34198 Mdot
.82825 .34234 Mdot
.8283 .34269 Mdot
.82835 .34305 Mdot
.8284 .3434 Mdot
.82844 .34376 Mdot
.82849 .34411 Mdot
.82854 .34447 Mdot
.82859 .34482 Mdot
.82863 .34518 Mdot
.82868 .34554 Mdot
.82873 .34589 Mdot
.82878 .34625 Mdot
.82882 .34661 Mdot
.82887 .34697 Mdot
.82892 .34733 Mdot
.82897 .34769 Mdot
.82901 .34805 Mdot
.82906 .34841 Mdot
.82911 .34877 Mdot
.82916 .34913 Mdot
.82921 .34948 Mdot
.82925 .34984 Mdot
.8293 .3502 Mdot
.82935 .35056 Mdot
.8294 .35091 Mdot
.82944 .35126 Mdot
.82949 .35162 Mdot
.82954 .35197 Mdot
.82959 .35232 Mdot
.82963 .35266 Mdot
.82968 .35301 Mdot
.82973 .35335 Mdot
.82978 .3537 Mdot
.82982 .35404 Mdot
.82987 .35439 Mdot
.82992 .35474 Mdot
.82997 .35509 Mdot
.83001 .35544 Mdot
.83006 .35578 Mdot
.83011 .35613 Mdot
.83016 .35648 Mdot
.83021 .35682 Mdot
.83025 .35717 Mdot
.8303 .35751 Mdot
.83035 .35786 Mdot
.8304 .3582 Mdot
.83044 .35855 Mdot
.83049 .35889 Mdot
.83054 .35923 Mdot
.83059 .35957 Mdot
.83063 .35991 Mdot
.83068 .36025 Mdot
.83073 .36059 Mdot
.83078 .36093 Mdot
.83082 .36127 Mdot
.83087 .36161 Mdot
.83092 .36194 Mdot
.83097 .36228 Mdot
.83101 .36261 Mdot
.83106 .36295 Mdot
.83111 .36328 Mdot
.83116 .36361 Mdot
.8312 .36395 Mdot
.83125 .36429 Mdot
.8313 .36462 Mdot
.83135 .36496 Mdot
.8314 .36529 Mdot
.83144 .36562 Mdot
.83149 .36595 Mdot
.83154 .36629 Mdot
.83159 .36662 Mdot
.83163 .36696 Mdot
.83168 .3673 Mdot
.83173 .36763 Mdot
.83178 .36797 Mdot
.83182 .3683 Mdot
.83187 .36863 Mdot
.83192 .36896 Mdot
.83197 .3693 Mdot
.83201 .36963 Mdot
.83206 .36996 Mdot
.83211 .3703 Mdot
.83216 .37063 Mdot
.8322 .37097 Mdot
.83225 .3713 Mdot
.8323 .37163 Mdot
.83235 .37196 Mdot
.8324 .37229 Mdot
.83244 .37262 Mdot
.83249 .37295 Mdot
.83254 .37327 Mdot
.83259 .3736 Mdot
.83263 .37392 Mdot
.83268 .37425 Mdot
.83273 .37457 Mdot
.83278 .3749 Mdot
.83282 .37522 Mdot
.83287 .37554 Mdot
.83292 .37587 Mdot
.83297 .3762 Mdot
.83301 .37652 Mdot
.83306 .37685 Mdot
.83311 .37718 Mdot
.83316 .37751 Mdot
.8332 .37784 Mdot
.83325 .37818 Mdot
.8333 .37851 Mdot
.83335 .37885 Mdot
.8334 .37918 Mdot
.83344 .37952 Mdot
.83349 .37985 Mdot
.83354 .38019 Mdot
.83359 .38053 Mdot
.83363 .38086 Mdot
.83368 .3812 Mdot
.83373 .38154 Mdot
.83378 .38187 Mdot
.83382 .3822 Mdot
.83387 .38253 Mdot
.83392 .38287 Mdot
.83397 .3832 Mdot
.83401 .38353 Mdot
.83406 .38387 Mdot
.83411 .3842 Mdot
.83416 .38453 Mdot
.8342 .38487 Mdot
.83425 .3852 Mdot
.8343 .38553 Mdot
.83435 .38586 Mdot
.8344 .38619 Mdot
.83444 .38652 Mdot
.83449 .38685 Mdot
.83454 .38718 Mdot
.83459 .38751 Mdot
.83463 .38784 Mdot
.83468 .38817 Mdot
.83473 .3885 Mdot
.83478 .38883 Mdot
.83482 .38916 Mdot
.83487 .38949 Mdot
.83492 .38982 Mdot
.83497 .39015 Mdot
.83501 .39047 Mdot
.83506 .3908 Mdot
.83511 .39112 Mdot
.83516 .39144 Mdot
.8352 .39176 Mdot
.83525 .39209 Mdot
.8353 .3924 Mdot
.83535 .39272 Mdot
.8354 .39303 Mdot
.83544 .39335 Mdot
.83549 .39367 Mdot
.83554 .39399 Mdot
.83559 .39431 Mdot
.83563 .39462 Mdot
.83568 .39494 Mdot
.83573 .39526 Mdot
.83578 .39558 Mdot
.83582 .3959 Mdot
.83587 .39622 Mdot
.83592 .39654 Mdot
.83597 .39686 Mdot
.83601 .39718 Mdot
.83606 .3975 Mdot
.83611 .39781 Mdot
.83616 .39813 Mdot
.8362 .39844 Mdot
.83625 .39876 Mdot
.8363 .39907 Mdot
.83635 .39939 Mdot
.83639 .3997 Mdot
.83644 .40001 Mdot
.83649 .40032 Mdot
.83654 .40062 Mdot
.83659 .40093 Mdot
.83663 .40124 Mdot
.83668 .40154 Mdot
.83673 .40185 Mdot
.83678 .40215 Mdot
.83682 .40246 Mdot
.83687 .40276 Mdot
.83692 .40307 Mdot
.83697 .40337 Mdot
.83701 .40368 Mdot
.83706 .40398 Mdot
.83711 .40428 Mdot
.83716 .40459 Mdot
.8372 .40489 Mdot
.83725 .4052 Mdot
.8373 .40551 Mdot
.83735 .40581 Mdot
.83739 .40612 Mdot
.83744 .40642 Mdot
.83749 .40672 Mdot
.83754 .40702 Mdot
.83759 .40732 Mdot
.83763 .40762 Mdot
.83768 .40792 Mdot
.83773 .40822 Mdot
.83778 .40851 Mdot
.83782 .4088 Mdot
.83787 .40909 Mdot
.83792 .40938 Mdot
.83797 .40967 Mdot
.83801 .40996 Mdot
.83806 .41025 Mdot
.83811 .41054 Mdot
.83816 .41083 Mdot
.8382 .41112 Mdot
.83825 .41141 Mdot
.8383 .4117 Mdot
.83835 .41199 Mdot
.83839 .41228 Mdot
.83844 .41257 Mdot
.83849 .41287 Mdot
.83854 .41316 Mdot
.83859 .41345 Mdot
.83863 .41375 Mdot
.83868 .41404 Mdot
.83873 .41433 Mdot
.83878 .41462 Mdot
.83882 .41491 Mdot
.83887 .4152 Mdot
.83892 .41548 Mdot
.83897 .41577 Mdot
.83901 .41605 Mdot
.83906 .41634 Mdot
.83911 .41662 Mdot
.83916 .41691 Mdot
.8392 .41719 Mdot
.83925 .41748 Mdot
.8393 .41776 Mdot
.83935 .41804 Mdot
.83939 .41832 Mdot
.83944 .4186 Mdot
.83949 .41888 Mdot
.83954 .41915 Mdot
.83959 .41943 Mdot
.83963 .41971 Mdot
.83968 .41999 Mdot
.83973 .42027 Mdot
.83978 .42055 Mdot
.83982 .42082 Mdot
.83987 .4211 Mdot
.83992 .42138 Mdot
.83997 .42167 Mdot
.84001 .42195 Mdot
.84006 .42223 Mdot
.84011 .42251 Mdot
.84016 .42278 Mdot
.8402 .42306 Mdot
.84025 .42334 Mdot
.8403 .42362 Mdot
.84035 .42389 Mdot
.84039 .42417 Mdot
.84044 .42444 Mdot
.84049 .42472 Mdot
.84054 .42499 Mdot
.84058 .42525 Mdot
.84063 .42552 Mdot
.84068 .42578 Mdot
.84073 .42605 Mdot
.84078 .42631 Mdot
.84082 .42657 Mdot
.84087 .42684 Mdot
.84092 .4271 Mdot
.84097 .42736 Mdot
.84101 .42763 Mdot
.84106 .4279 Mdot
.84111 .42817 Mdot
.84116 .42844 Mdot
.8412 .4287 Mdot
.84125 .42897 Mdot
.8413 .42924 Mdot
.84135 .42951 Mdot
.84139 .42977 Mdot
.84144 .43004 Mdot
.84149 .43031 Mdot
.84154 .43058 Mdot
.84158 .43085 Mdot
.84163 .43111 Mdot
.84168 .43138 Mdot
.84173 .43164 Mdot
.84178 .43191 Mdot
.84182 .43218 Mdot
.84187 .43244 Mdot
.84192 .43271 Mdot
.84197 .43297 Mdot
.84201 .43323 Mdot
.84206 .4335 Mdot
.84211 .43376 Mdot
.84216 .43403 Mdot
.8422 .4343 Mdot
.84225 .43457 Mdot
.8423 .43483 Mdot
.84235 .4351 Mdot
.84239 .43537 Mdot
.84244 .43563 Mdot
.84249 .43589 Mdot
.84254 .43616 Mdot
.84258 .43642 Mdot
.84263 .43668 Mdot
.84268 .43694 Mdot
.84273 .4372 Mdot
.84278 .43746 Mdot
.84282 .43772 Mdot
.84287 .43798 Mdot
.84292 .43823 Mdot
.84297 .43849 Mdot
.84301 .43875 Mdot
.84306 .43901 Mdot
.84311 .43926 Mdot
.84316 .43951 Mdot
.8432 .43976 Mdot
.84325 .44001 Mdot
.8433 .44026 Mdot
.84335 .4405 Mdot
.84339 .44075 Mdot
.84344 .44099 Mdot
.84349 .44124 Mdot
.84354 .44148 Mdot
.84358 .44171 Mdot
.84363 .44195 Mdot
.84368 .44219 Mdot
.84373 .44244 Mdot
.84378 .44268 Mdot
.84382 .44292 Mdot
.84387 .44316 Mdot
.84392 .4434 Mdot
.84397 .44364 Mdot
.84401 .44388 Mdot
.84406 .44413 Mdot
.84411 .44437 Mdot
.84416 .44461 Mdot
.8442 .44485 Mdot
.84425 .44509 Mdot
.8443 .44533 Mdot
.84435 .44557 Mdot
.84439 .44581 Mdot
.84444 .44605 Mdot
.84449 .44629 Mdot
.84454 .44652 Mdot
.84458 .44675 Mdot
.84463 .44699 Mdot
.84468 .44723 Mdot
.84473 .44746 Mdot
.84478 .44769 Mdot
.84482 .44793 Mdot
.84487 .44817 Mdot
.84492 .4484 Mdot
.84497 .44864 Mdot
.84501 .44887 Mdot
.84506 .4491 Mdot
.84511 .44933 Mdot
.84516 .44956 Mdot
.8452 .44979 Mdot
.84525 .45002 Mdot
.8453 .45026 Mdot
.84535 .45049 Mdot
.84539 .45073 Mdot
.84544 .45097 Mdot
.84549 .45121 Mdot
.84554 .45145 Mdot
.84558 .45169 Mdot
.84563 .45193 Mdot
.84568 .45218 Mdot
.84573 .45242 Mdot
.84577 .45266 Mdot
.84582 .4529 Mdot
.84587 .45314 Mdot
.84592 .45338 Mdot
.84597 .45362 Mdot
.84601 .45386 Mdot
.84606 .4541 Mdot
.84611 .45434 Mdot
.84616 .45458 Mdot
.8462 .45482 Mdot
.84625 .45505 Mdot
.8463 .45529 Mdot
.84635 .45552 Mdot
.84639 .45576 Mdot
.84644 .45599 Mdot
.84649 .45623 Mdot
.84654 .45646 Mdot
.84658 .4567 Mdot
.84663 .45693 Mdot
.84668 .45717 Mdot
.84673 .4574 Mdot
.84677 .45764 Mdot
.84682 .45787 Mdot
.84687 .4581 Mdot
.84692 .45833 Mdot
.84697 .45856 Mdot
.84701 .45879 Mdot
.84706 .45901 Mdot
.84711 .45924 Mdot
.84716 .45946 Mdot
.8472 .45969 Mdot
.84725 .45992 Mdot
.8473 .46014 Mdot
.84735 .46037 Mdot
.84739 .4606 Mdot
.84744 .46083 Mdot
.84749 .46106 Mdot
.84754 .46129 Mdot
.84758 .46152 Mdot
.84763 .46175 Mdot
.84768 .46198 Mdot
.84773 .46221 Mdot
.84777 .46244 Mdot
.84782 .46268 Mdot
.84787 .46291 Mdot
.84792 .46315 Mdot
.84797 .46338 Mdot
.84801 .46361 Mdot
.84806 .46384 Mdot
.84811 .46408 Mdot
.84816 .46431 Mdot
.8482 .46454 Mdot
.84825 .46477 Mdot
.8483 .46501 Mdot
.84835 .46524 Mdot
.84839 .46548 Mdot
.84844 .46571 Mdot
.84849 .46594 Mdot
.84854 .46618 Mdot
.84858 .46641 Mdot
.84863 .46665 Mdot
.84868 .46688 Mdot
.84873 .46711 Mdot
.84877 .46734 Mdot
.84882 .46757 Mdot
.84887 .4678 Mdot
.84892 .46802 Mdot
.84897 .46825 Mdot
.84901 .46848 Mdot
.84906 .46871 Mdot
.84911 .46894 Mdot
.84916 .46917 Mdot
.8492 .4694 Mdot
.84925 .46963 Mdot
.8493 .46987 Mdot
.84935 .4701 Mdot
.84939 .47033 Mdot
.84944 .47057 Mdot
.84949 .4708 Mdot
.84954 .47103 Mdot
.84958 .47127 Mdot
.84963 .4715 Mdot
.84968 .47173 Mdot
.84973 .47197 Mdot
.84977 .47221 Mdot
.84982 .47244 Mdot
.84987 .47267 Mdot
.84992 .4729 Mdot
.84997 .47314 Mdot
.85001 .47337 Mdot
.85006 .4736 Mdot
.85011 .47383 Mdot
.85016 .47407 Mdot
.8502 .4743 Mdot
.85025 .47454 Mdot
.8503 .47478 Mdot
.85035 .47502 Mdot
.85039 .47526 Mdot
.85044 .4755 Mdot
.85049 .47574 Mdot
.85054 .47598 Mdot
.85058 .47622 Mdot
.85063 .47646 Mdot
.85068 .4767 Mdot
.85073 .47694 Mdot
.85077 .47719 Mdot
.85082 .47743 Mdot
.85087 .47767 Mdot
.85092 .47791 Mdot
.85096 .47816 Mdot
.85101 .47839 Mdot
.85106 .47863 Mdot
.85111 .47888 Mdot
.85116 .47912 Mdot
.8512 .47935 Mdot
.85125 .47959 Mdot
.8513 .47983 Mdot
.85135 .48008 Mdot
.85139 .48032 Mdot
.85144 .48056 Mdot
.85149 .4808 Mdot
.85154 .48104 Mdot
.85158 .48128 Mdot
.85163 .48151 Mdot
.85168 .48175 Mdot
.85173 .48198 Mdot
.85177 .48222 Mdot
.85182 .48245 Mdot
.85187 .48269 Mdot
.85192 .48293 Mdot
.85196 .48316 Mdot
.85201 .4834 Mdot
.85206 .48363 Mdot
.85211 .48387 Mdot
.85216 .4841 Mdot
.8522 .48434 Mdot
.85225 .48457 Mdot
.8523 .48481 Mdot
.85235 .48504 Mdot
.85239 .48528 Mdot
.85244 .48551 Mdot
.85249 .48574 Mdot
.85254 .48598 Mdot
.85258 .48622 Mdot
.85263 .48645 Mdot
.85268 .48668 Mdot
.85273 .48691 Mdot
.85277 .48714 Mdot
.85282 .48737 Mdot
.85287 .48761 Mdot
.85292 .48784 Mdot
.85296 .48807 Mdot
.85301 .4883 Mdot
.85306 .48853 Mdot
.85311 .48877 Mdot
.85316 .489 Mdot
.8532 .48923 Mdot
.85325 .48947 Mdot
.8533 .4897 Mdot
.85335 .48993 Mdot
.85339 .49016 Mdot
.85344 .49039 Mdot
.85349 .49062 Mdot
.85354 .49084 Mdot
.85358 .49107 Mdot
.85363 .4913 Mdot
.85368 .49153 Mdot
.85373 .49176 Mdot
.85377 .49199 Mdot
.85382 .49222 Mdot
.85387 .49245 Mdot
.85392 .49268 Mdot
.85396 .4929 Mdot
.85401 .49313 Mdot
.85406 .49335 Mdot
.85411 .49358 Mdot
.85416 .4938 Mdot
.8542 .49402 Mdot
.85425 .49425 Mdot
.8543 .49447 Mdot
.85435 .49469 Mdot
.85439 .49492 Mdot
.85444 .49514 Mdot
.85449 .49536 Mdot
.85454 .49559 Mdot
.85458 .49581 Mdot
.85463 .49604 Mdot
.85468 .49626 Mdot
.85473 .49648 Mdot
.85477 .49671 Mdot
.85482 .49693 Mdot
.85487 .49716 Mdot
.85492 .49738 Mdot
.85496 .4976 Mdot
.85501 .49781 Mdot
.85506 .49803 Mdot
.85511 .49824 Mdot
.85515 .49846 Mdot
.8552 .49868 Mdot
.85525 .4989 Mdot
.8553 .49911 Mdot
.85535 .49933 Mdot
.85539 .49954 Mdot
.85544 .49975 Mdot
.85549 .49997 Mdot
.85554 .50018 Mdot
.85558 .5004 Mdot
.85563 .50061 Mdot
.85568 .50081 Mdot
.85573 .50102 Mdot
.85577 .50123 Mdot
.85582 .50144 Mdot
.85587 .50164 Mdot
.85592 .50185 Mdot
.85596 .50205 Mdot
.85601 .50225 Mdot
.85606 .50246 Mdot
.85611 .50267 Mdot
.85615 .50288 Mdot
.8562 .50309 Mdot
.85625 .50329 Mdot
.8563 .50351 Mdot
.85635 .50372 Mdot
.85639 .50393 Mdot
.85644 .50415 Mdot
.85649 .50436 Mdot
.85654 .50458 Mdot
.85658 .50479 Mdot
.85663 .50501 Mdot
.85668 .50523 Mdot
.85673 .50544 Mdot
.85677 .50566 Mdot
.85682 .50588 Mdot
.85687 .50609 Mdot
.85692 .5063 Mdot
.85696 .50651 Mdot
.85701 .50673 Mdot
.85706 .50694 Mdot
.85711 .50714 Mdot
.85715 .50735 Mdot
.8572 .50756 Mdot
.85725 .50777 Mdot
.8573 .50797 Mdot
.85735 .50818 Mdot
.85739 .50838 Mdot
.85744 .50859 Mdot
.85749 .5088 Mdot
.85754 .509 Mdot
.85758 .50921 Mdot
.85763 .50941 Mdot
.85768 .50962 Mdot
.85773 .50983 Mdot
.85777 .51003 Mdot
.85782 .51024 Mdot
.85787 .51045 Mdot
.85792 .51066 Mdot
.85796 .51087 Mdot
.85801 .51107 Mdot
.85806 .51127 Mdot
.85811 .51147 Mdot
.85815 .51168 Mdot
.8582 .51188 Mdot
.85825 .51208 Mdot
.8583 .51228 Mdot
.85835 .51248 Mdot
.85839 .51268 Mdot
.85844 .51288 Mdot
.85849 .51308 Mdot
.85854 .51328 Mdot
.85858 .51347 Mdot
.85863 .51367 Mdot
.85868 .51386 Mdot
.85873 .51405 Mdot
.85877 .51425 Mdot
.85882 .51444 Mdot
.85887 .51463 Mdot
.85892 .51482 Mdot
.85896 .51501 Mdot
.85901 .5152 Mdot
.85906 .51539 Mdot
.85911 .51559 Mdot
.85915 .51578 Mdot
.8592 .51596 Mdot
.85925 .51615 Mdot
.8593 .51634 Mdot
.85935 .51652 Mdot
.85939 .51671 Mdot
.85944 .5169 Mdot
.85949 .51708 Mdot
.85954 .51726 Mdot
.85958 .51745 Mdot
.85963 .51763 Mdot
.85968 .51781 Mdot
.85973 .518 Mdot
.85977 .51818 Mdot
.85982 .51837 Mdot
.85987 .51855 Mdot
.85992 .51873 Mdot
.85996 .51891 Mdot
.86001 .5191 Mdot
.86006 .51928 Mdot
.86011 .51946 Mdot
.86015 .51964 Mdot
.8602 .51982 Mdot
.86025 .52001 Mdot
.8603 .52019 Mdot
.86034 .52037 Mdot
.86039 .52056 Mdot
.86044 .52074 Mdot
.86049 .52093 Mdot
.86054 .52111 Mdot
.86058 .52129 Mdot
.86063 .52147 Mdot
.86068 .52165 Mdot
.86073 .52184 Mdot
.86077 .52202 Mdot
.86082 .52221 Mdot
.86087 .52239 Mdot
.86092 .52257 Mdot
.86096 .52275 Mdot
.86101 .52293 Mdot
.86106 .5231 Mdot
.86111 .52328 Mdot
.86115 .52345 Mdot
.8612 .52363 Mdot
.86125 .5238 Mdot
.8613 .52398 Mdot
.86134 .52415 Mdot
.86139 .52432 Mdot
.86144 .5245 Mdot
.86149 .52468 Mdot
.86154 .52485 Mdot
.86158 .52503 Mdot
.86163 .5252 Mdot
.86168 .52537 Mdot
.86173 .52554 Mdot
.86177 .52572 Mdot
.86182 .52589 Mdot
.86187 .52606 Mdot
.86192 .52623 Mdot
.86196 .5264 Mdot
.86201 .52657 Mdot
.86206 .52674 Mdot
.86211 .52691 Mdot
.86215 .52708 Mdot
.8622 .52724 Mdot
.86225 .52741 Mdot
.8623 .52757 Mdot
.86234 .52774 Mdot
.86239 .5279 Mdot
.86244 .52806 Mdot
.86249 .52822 Mdot
.86254 .52839 Mdot
.86258 .52855 Mdot
.86263 .52871 Mdot
.86268 .52887 Mdot
.86273 .52903 Mdot
.86277 .52919 Mdot
.86282 .52935 Mdot
.86287 .52951 Mdot
.86292 .52967 Mdot
.86296 .52983 Mdot
.86301 .52999 Mdot
.86306 .53015 Mdot
.86311 .5303 Mdot
.86315 .53046 Mdot
.8632 .53061 Mdot
.86325 .53077 Mdot
.8633 .53092 Mdot
.86334 .53107 Mdot
.86339 .53122 Mdot
.86344 .53137 Mdot
.86349 .53152 Mdot
.86354 .53167 Mdot
.86358 .53182 Mdot
.86363 .53197 Mdot
.86368 .53212 Mdot
.86373 .53226 Mdot
.86377 .53241 Mdot
.86382 .53255 Mdot
.86387 .53269 Mdot
.86392 .53283 Mdot
.86396 .53296 Mdot
.86401 .5331 Mdot
.86406 .53323 Mdot
.86411 .53337 Mdot
.86415 .5335 Mdot
.8642 .53363 Mdot
.86425 .53376 Mdot
.8643 .5339 Mdot
.86434 .53403 Mdot
.86439 .53416 Mdot
.86444 .53429 Mdot
.86449 .53442 Mdot
.86453 .53455 Mdot
.86458 .53467 Mdot
.86463 .5348 Mdot
.86468 .53493 Mdot
.86473 .53505 Mdot
.86477 .53518 Mdot
.86482 .53531 Mdot
.86487 .53543 Mdot
.86492 .53556 Mdot
.86496 .53569 Mdot
.86501 .53582 Mdot
.86506 .53594 Mdot
.86511 .53607 Mdot
.86515 .5362 Mdot
.8652 .53633 Mdot
.86525 .53645 Mdot
.8653 .53658 Mdot
.86534 .53671 Mdot
.86539 .53683 Mdot
.86544 .53696 Mdot
.86549 .53708 Mdot
.86553 .5372 Mdot
.86558 .53733 Mdot
.86563 .53746 Mdot
.86568 .53758 Mdot
.86573 .53771 Mdot
.86577 .53784 Mdot
.86582 .53797 Mdot
.86587 .53809 Mdot
.86592 .53821 Mdot
.86596 .53833 Mdot
.86601 .53845 Mdot
.86606 .53857 Mdot
.86611 .53869 Mdot
.86615 .53881 Mdot
.8662 .53892 Mdot
.86625 .53904 Mdot
.8663 .53916 Mdot
.86634 .53927 Mdot
.86639 .53938 Mdot
.86644 .53949 Mdot
.86649 .5396 Mdot
.86653 .53971 Mdot
.86658 .53982 Mdot
.86663 .53992 Mdot
.86668 .54002 Mdot
.86673 .54012 Mdot
.86677 .54023 Mdot
.86682 .54033 Mdot
.86687 .54043 Mdot
.86692 .54054 Mdot
.86696 .54064 Mdot
.86701 .54075 Mdot
.86706 .54085 Mdot
.86711 .54095 Mdot
.86715 .54105 Mdot
.8672 .54114 Mdot
.86725 .54124 Mdot
.8673 .54134 Mdot
.86734 .54144 Mdot
.86739 .54153 Mdot
.86744 .54162 Mdot
.86749 .54172 Mdot
.86753 .54181 Mdot
.86758 .54189 Mdot
.86763 .54198 Mdot
.86768 .54207 Mdot
.86773 .54216 Mdot
.86777 .54225 Mdot
.86782 .54233 Mdot
.86787 .54242 Mdot
.86792 .5425 Mdot
.86796 .54259 Mdot
.86801 .54266 Mdot
.86806 .54274 Mdot
.86811 .54281 Mdot
.86815 .54289 Mdot
.8682 .54296 Mdot
.86825 .54303 Mdot
.8683 .5431 Mdot
.86834 .54317 Mdot
.86839 .54324 Mdot
.86844 .54331 Mdot
.86849 .54338 Mdot
.86853 .54344 Mdot
.86858 .54351 Mdot
.86863 .54357 Mdot
.86868 .54364 Mdot
.86873 .54371 Mdot
.86877 .54377 Mdot
.86882 .54384 Mdot
.86887 .5439 Mdot
.86892 .54397 Mdot
.86896 .54404 Mdot
.86901 .54411 Mdot
.86906 .54418 Mdot
.86911 .54424 Mdot
.86915 .54431 Mdot
.8692 .54437 Mdot
.86925 .54444 Mdot
.8693 .54451 Mdot
.86934 .54457 Mdot
.86939 .54464 Mdot
.86944 .54471 Mdot
.86949 .54477 Mdot
.86953 .54484 Mdot
.86958 .5449 Mdot
.86963 .54496 Mdot
.86968 .54502 Mdot
.86972 .54507 Mdot
.86977 .54513 Mdot
.86982 .54519 Mdot
.86987 .54524 Mdot
.86992 .5453 Mdot
.86996 .54536 Mdot
.87001 .54542 Mdot
.87006 .54549 Mdot
.87011 .54555 Mdot
.87015 .54561 Mdot
.8702 .54567 Mdot
.87025 .54573 Mdot
.8703 .54579 Mdot
.87034 .54584 Mdot
.87039 .5459 Mdot
.87044 .54596 Mdot
.87049 .54602 Mdot
.87053 .54608 Mdot
.87058 .54613 Mdot
.87063 .54619 Mdot
.87068 .54624 Mdot
.87072 .5463 Mdot
.87077 .54635 Mdot
.87082 .54641 Mdot
.87087 .54646 Mdot
.87092 .54651 Mdot
.87096 .54657 Mdot
.87101 .54663 Mdot
.87106 .54668 Mdot
.87111 .54674 Mdot
.87115 .5468 Mdot
.8712 .54686 Mdot
.87125 .54692 Mdot
.8713 .54699 Mdot
.87134 .54704 Mdot
.87139 .5471 Mdot
.87144 .54717 Mdot
.87149 .54723 Mdot
.87153 .54729 Mdot
.87158 .54734 Mdot
.87163 .5474 Mdot
.87168 .54746 Mdot
.87172 .54751 Mdot
.87177 .54756 Mdot
.87182 .54761 Mdot
.87187 .54767 Mdot
.87192 .54772 Mdot
.87196 .54777 Mdot
.87201 .54782 Mdot
.87206 .54787 Mdot
.87211 .54793 Mdot
.87215 .54798 Mdot
.8722 .54804 Mdot
.87225 .5481 Mdot
.8723 .54816 Mdot
.87234 .54822 Mdot
.87239 .54827 Mdot
.87244 .54833 Mdot
.87249 .54838 Mdot
.87253 .54844 Mdot
.87258 .54849 Mdot
.87263 .54854 Mdot
.87268 .54859 Mdot
.87272 .54863 Mdot
.87277 .54867 Mdot
.87282 .54872 Mdot
.87287 .54876 Mdot
.87292 .5488 Mdot
.87296 .54885 Mdot
.87301 .54889 Mdot
.87306 .54893 Mdot
.87311 .54897 Mdot
.87315 .549 Mdot
.8732 .54904 Mdot
.87325 .54908 Mdot
.8733 .54912 Mdot
.87334 .54915 Mdot
.87339 .54919 Mdot
.87344 .54923 Mdot
.87349 .54928 Mdot
.87353 .54932 Mdot
.87358 .54936 Mdot
.87363 .5494 Mdot
.87368 .54944 Mdot
.87372 .54948 Mdot
.87377 .54952 Mdot
.87382 .54956 Mdot
.87387 .5496 Mdot
.87391 .54964 Mdot
.87396 .54968 Mdot
.87401 .54972 Mdot
.87406 .54976 Mdot
.87411 .5498 Mdot
.87415 .54984 Mdot
.8742 .54988 Mdot
.87425 .54992 Mdot
.8743 .54997 Mdot
.87434 .55001 Mdot
.87439 .55005 Mdot
.87444 .55008 Mdot
.87449 .55012 Mdot
.87453 .55016 Mdot
.87458 .5502 Mdot
.87463 .55023 Mdot
.87468 .55027 Mdot
.87472 .5503 Mdot
.87477 .55034 Mdot
.87482 .55037 Mdot
.87487 .55041 Mdot
.87491 .55044 Mdot
.87496 .55048 Mdot
.87501 .55051 Mdot
.87506 .55054 Mdot
.87511 .55057 Mdot
.87515 .5506 Mdot
.8752 .55063 Mdot
.87525 .55066 Mdot
.8753 .55068 Mdot
.87534 .55071 Mdot
.87539 .55074 Mdot
.87544 .55077 Mdot
.87549 .5508 Mdot
.87553 .55082 Mdot
.87558 .55084 Mdot
.87563 .55086 Mdot
.87568 .55088 Mdot
.87572 .5509 Mdot
.87577 .55091 Mdot
.87582 .55093 Mdot
.87587 .55095 Mdot
.87591 .55096 Mdot
.87596 .55098 Mdot
.87601 .55099 Mdot
.87606 .55101 Mdot
.87611 .55103 Mdot
.87615 .55105 Mdot
.8762 .55107 Mdot
.87625 .55109 Mdot
.8763 .5511 Mdot
.87634 .55112 Mdot
.87639 .55113 Mdot
.87644 .55114 Mdot
.87649 .55115 Mdot
.87653 .55116 Mdot
.87658 .55117 Mdot
.87663 .55118 Mdot
.87668 .55118 Mdot
.87672 .55118 Mdot
.87677 .55118 Mdot
.87682 .55118 Mdot
.87687 .55119 Mdot
.87691 .55119 Mdot
.87696 .55119 Mdot
.87701 .55119 Mdot
.87706 .55119 Mdot
.87711 .55119 Mdot
.87715 .55119 Mdot
.8772 .55119 Mdot
.87725 .55118 Mdot
.8773 .55118 Mdot
.87734 .55117 Mdot
.87739 .55117 Mdot
.87744 .55116 Mdot
.87749 .55115 Mdot
.87753 .55114 Mdot
.87758 .55114 Mdot
.87763 .55113 Mdot
.87768 .55112 Mdot
.87772 .55111 Mdot
.87777 .55109 Mdot
.87782 .55108 Mdot
.87787 .55107 Mdot
.87791 .55106 Mdot
.87796 .55105 Mdot
.87801 .55104 Mdot
.87806 .55103 Mdot
.87811 .55101 Mdot
.87815 .551 Mdot
.8782 .55099 Mdot
.87825 .55097 Mdot
.8783 .55095 Mdot
.87834 .55093 Mdot
.87839 .55092 Mdot
.87844 .5509 Mdot
.87849 .55088 Mdot
.87853 .55085 Mdot
.87858 .55083 Mdot
.87863 .55081 Mdot
.87868 .55079 Mdot
.87872 .55076 Mdot
.87877 .55074 Mdot
.87882 .55071 Mdot
.87887 .55069 Mdot
.87891 .55067 Mdot
.87896 .55065 Mdot
.87901 .55062 Mdot
.87906 .5506 Mdot
.8791 .55057 Mdot
.87915 .55054 Mdot
.8792 .55051 Mdot
.87925 .55048 Mdot
.8793 .55045 Mdot
.87934 .55042 Mdot
.87939 .55039 Mdot
.87944 .55036 Mdot
.87949 .55034 Mdot
.87953 .55031 Mdot
.87958 .55028 Mdot
.87963 .55026 Mdot
.87968 .55023 Mdot
.87972 .5502 Mdot
.87977 .55016 Mdot
.87982 .55013 Mdot
.87987 .55009 Mdot
.87991 .55006 Mdot
.87996 .55002 Mdot
.88001 .54999 Mdot
.88006 .54995 Mdot
.8801 .54991 Mdot
.88015 .54987 Mdot
.8802 .54983 Mdot
.88025 .54978 Mdot
.8803 .54974 Mdot
.88034 .54969 Mdot
.88039 .54964 Mdot
.88044 .54959 Mdot
.88049 .54955 Mdot
.88053 .54949 Mdot
.88058 .54944 Mdot
.88063 .54939 Mdot
.88068 .54934 Mdot
.88072 .54928 Mdot
.88077 .54923 Mdot
.88082 .54917 Mdot
.88087 .54912 Mdot
.88091 .54906 Mdot
.88096 .549 Mdot
.88101 .54894 Mdot
.88106 .54888 Mdot
.8811 .54881 Mdot
.88115 .54875 Mdot
.8812 .54868 Mdot
.88125 .54861 Mdot
.8813 .54855 Mdot
.88134 .54848 Mdot
.88139 .54841 Mdot
.88144 .54834 Mdot
.88149 .54827 Mdot
.88153 .5482 Mdot
.88158 .54813 Mdot
.88163 .54805 Mdot
.88168 .54797 Mdot
.88172 .5479 Mdot
.88177 .54782 Mdot
.88182 .54774 Mdot
.88187 .54767 Mdot
.88191 .54759 Mdot
.88196 .54751 Mdot
.88201 .54743 Mdot
.88206 .54736 Mdot
.8821 .54727 Mdot
.88215 .54719 Mdot
.8822 .54711 Mdot
.88225 .54703 Mdot
.8823 .54695 Mdot
.88234 .54687 Mdot
.88239 .54678 Mdot
.88244 .5467 Mdot
.88249 .54662 Mdot
.88253 .54654 Mdot
.88258 .54645 Mdot
.88263 .54637 Mdot
.88268 .54628 Mdot
.88272 .5462 Mdot
.88277 .54611 Mdot
.88282 .54602 Mdot
.88287 .54594 Mdot
.88291 .54585 Mdot
.88296 .54576 Mdot
.88301 .54567 Mdot
.88306 .54558 Mdot
.8831 .54549 Mdot
.88315 .5454 Mdot
.8832 .54531 Mdot
.88325 .54521 Mdot
.8833 .54511 Mdot
.88334 .54501 Mdot
.88339 .54491 Mdot
.88344 .54481 Mdot
.88349 .54472 Mdot
.88353 .54462 Mdot
.88358 .54452 Mdot
.88363 .54442 Mdot
.88368 .54433 Mdot
.88372 .54423 Mdot
.88377 .54413 Mdot
.88382 .54403 Mdot
.88387 .54393 Mdot
.88391 .54383 Mdot
.88396 .54373 Mdot
.88401 .54362 Mdot
.88406 .54351 Mdot
.8841 .5434 Mdot
.88415 .54329 Mdot
.8842 .54318 Mdot
.88425 .54307 Mdot
.88429 .54296 Mdot
.88434 .54285 Mdot
.88439 .54274 Mdot
.88444 .54263 Mdot
.88449 .54252 Mdot
.88453 .54241 Mdot
.88458 .5423 Mdot
.88463 .54219 Mdot
.88468 .54208 Mdot
.88472 .54196 Mdot
.88477 .54184 Mdot
.88482 .54172 Mdot
.88487 .54161 Mdot
.88491 .54149 Mdot
.88496 .54137 Mdot
.88501 .54125 Mdot
.88506 .54114 Mdot
.8851 .54102 Mdot
.88515 .5409 Mdot
.8852 .54079 Mdot
.88525 .54067 Mdot
.88529 .54055 Mdot
.88534 .54043 Mdot
.88539 .54032 Mdot
.88544 .5402 Mdot
.88549 .54008 Mdot
.88553 .53997 Mdot
.88558 .53986 Mdot
.88563 .53975 Mdot
.88568 .53964 Mdot
.88572 .53952 Mdot
.88577 .5394 Mdot
.88582 .53928 Mdot
.88587 .53917 Mdot
.88591 .53905 Mdot
.88596 .53894 Mdot
.88601 .53882 Mdot
.88606 .5387 Mdot
.8861 .53858 Mdot
.88615 .53846 Mdot
.8862 .53834 Mdot
.88625 .53821 Mdot
.88629 .53809 Mdot
.88634 .53796 Mdot
.88639 .53784 Mdot
.88644 .53771 Mdot
.88649 .53758 Mdot
.88653 .53745 Mdot
.88658 .53732 Mdot
.88663 .53719 Mdot
.88668 .53705 Mdot
.88672 .53692 Mdot
.88677 .53678 Mdot
.88682 .53664 Mdot
.88687 .5365 Mdot
.88691 .53635 Mdot
.88696 .53621 Mdot
.88701 .53606 Mdot
.88706 .53591 Mdot
.8871 .53576 Mdot
.88715 .53562 Mdot
.8872 .53546 Mdot
.88725 .53531 Mdot
.88729 .53516 Mdot
.88734 .53501 Mdot
.88739 .53486 Mdot
.88744 .53471 Mdot
.88749 .53456 Mdot
.88753 .53441 Mdot
.88758 .53426 Mdot
.88763 .53411 Mdot
.88768 .53395 Mdot
.88772 .53379 Mdot
.88777 .53363 Mdot
.88782 .53347 Mdot
.88787 .53331 Mdot
.88791 .53316 Mdot
.88796 .53301 Mdot
.88801 .53285 Mdot
.88806 .5327 Mdot
.8881 .53255 Mdot
.88815 .53239 Mdot
.8882 .53224 Mdot
.88825 .53209 Mdot
.88829 .53193 Mdot
.88834 .53178 Mdot
.88839 .53162 Mdot
.88844 .53147 Mdot
.88848 .53131 Mdot
.88853 .53115 Mdot
.88858 .53099 Mdot
.88863 .53082 Mdot
.88868 .53066 Mdot
.88872 .5305 Mdot
.88877 .53034 Mdot
.88882 .53018 Mdot
.88887 .53002 Mdot
.88891 .52986 Mdot
.88896 .5297 Mdot
.88901 .52953 Mdot
.88906 .52937 Mdot
.8891 .52921 Mdot
.88915 .52905 Mdot
.8892 .52888 Mdot
.88925 .52872 Mdot
.88929 .52856 Mdot
.88934 .52839 Mdot
.88939 .52822 Mdot
.88944 .52805 Mdot
.88948 .52788 Mdot
.88953 .52771 Mdot
.88958 .52754 Mdot
.88963 .52737 Mdot
.88968 .52719 Mdot
.88972 .52702 Mdot
.88977 .52685 Mdot
.88982 .52668 Mdot
.88987 .52652 Mdot
.88991 .52635 Mdot
.88996 .52618 Mdot
.89001 .52601 Mdot
.89006 .52585 Mdot
.8901 .52568 Mdot
.89015 .52551 Mdot
.8902 .52534 Mdot
.89025 .52517 Mdot
.89029 .525 Mdot
.89034 .52483 Mdot
.89039 .52466 Mdot
.89044 .52449 Mdot
.89048 .52431 Mdot
.89053 .52414 Mdot
.89058 .52397 Mdot
.89063 .52379 Mdot
.89068 .52362 Mdot
.89072 .52344 Mdot
.89077 .52326 Mdot
.89082 .52308 Mdot
.89087 .5229 Mdot
.89091 .52272 Mdot
.89096 .52254 Mdot
.89101 .52236 Mdot
.89106 .52219 Mdot
.8911 .52201 Mdot
.89115 .52183 Mdot
.8912 .52165 Mdot
.89125 .52147 Mdot
.89129 .52128 Mdot
.89134 .52109 Mdot
.89139 .5209 Mdot
.89144 .52071 Mdot
.89148 .52051 Mdot
.89153 .52032 Mdot
.89158 .52013 Mdot
.89163 .51994 Mdot
.89168 .51974 Mdot
.89172 .51955 Mdot
.89177 .51935 Mdot
.89182 .51915 Mdot
.89187 .51895 Mdot
.89191 .51875 Mdot
.89196 .51855 Mdot
.89201 .51836 Mdot
.89206 .51816 Mdot
.8921 .51797 Mdot
.89215 .51777 Mdot
.8922 .51757 Mdot
.89225 .51738 Mdot
.89229 .51718 Mdot
.89234 .51698 Mdot
.89239 .51679 Mdot
.89244 .5166 Mdot
.89248 .51641 Mdot
.89253 .51622 Mdot
.89258 .51603 Mdot
.89263 .51583 Mdot
.89268 .51564 Mdot
.89272 .51544 Mdot
.89277 .51525 Mdot
.89282 .51506 Mdot
.89287 .51487 Mdot
.89291 .51467 Mdot
.89296 .51448 Mdot
.89301 .51429 Mdot
.89306 .5141 Mdot
.8931 .51391 Mdot
.89315 .51372 Mdot
.8932 .51353 Mdot
.89325 .51334 Mdot
.89329 .51316 Mdot
.89334 .51297 Mdot
.89339 .51278 Mdot
.89344 .51259 Mdot
.89348 .51239 Mdot
.89353 .5122 Mdot
.89358 .512 Mdot
.89363 .51181 Mdot
.89367 .51161 Mdot
.89372 .51141 Mdot
.89377 .51121 Mdot
.89382 .51101 Mdot
.89387 .51081 Mdot
.89391 .5106 Mdot
.89396 .5104 Mdot
.89401 .5102 Mdot
.89406 .50999 Mdot
.8941 .50979 Mdot
.89415 .50959 Mdot
.8942 .50939 Mdot
.89425 .50918 Mdot
.89429 .50898 Mdot
.89434 .50878 Mdot
.89439 .50857 Mdot
.89444 .50836 Mdot
.89448 .50816 Mdot
.89453 .50795 Mdot
.89458 .50774 Mdot
.89463 .50753 Mdot
.89467 .50732 Mdot
.89472 .50711 Mdot
.89477 .5069 Mdot
.89482 .50669 Mdot
.89487 .50649 Mdot
.89491 .50628 Mdot
.89496 .50607 Mdot
.89501 .50587 Mdot
.89506 .50566 Mdot
.8951 .50545 Mdot
.89515 .50525 Mdot
.8952 .50504 Mdot
.89525 .50483 Mdot
.89529 .50462 Mdot
.89534 .50442 Mdot
.89539 .50422 Mdot
.89544 .50402 Mdot
.89548 .50381 Mdot
.89553 .50361 Mdot
.89558 .50341 Mdot
.89563 .5032 Mdot
.89567 .503 Mdot
.89572 .5028 Mdot
.89577 .50259 Mdot
.89582 .50239 Mdot
.89587 .50219 Mdot
.89591 .50199 Mdot
.89596 .5018 Mdot
.89601 .5016 Mdot
.89606 .5014 Mdot
.8961 .50119 Mdot
.89615 .50099 Mdot
.8962 .50079 Mdot
.89625 .50059 Mdot
.89629 .50038 Mdot
.89634 .50018 Mdot
.89639 .49997 Mdot
.89644 .49977 Mdot
.89648 .49956 Mdot
.89653 .49935 Mdot
.89658 .49914 Mdot
.89663 .49894 Mdot
.89667 .49873 Mdot
.89672 .49852 Mdot
.89677 .49831 Mdot
.89682 .4981 Mdot
.89687 .49789 Mdot
.89691 .49768 Mdot
.89696 .49747 Mdot
.89701 .49727 Mdot
.89706 .49705 Mdot
.8971 .49685 Mdot
.89715 .49664 Mdot
.8972 .49642 Mdot
.89725 .49621 Mdot
.89729 .496 Mdot
.89734 .49579 Mdot
.89739 .49558 Mdot
.89744 .49537 Mdot
.89748 .49516 Mdot
.89753 .49494 Mdot
.89758 .49473 Mdot
.89763 .49451 Mdot
.89767 .49429 Mdot
.89772 .49407 Mdot
.89777 .49385 Mdot
.89782 .49363 Mdot
.89786 .49341 Mdot
.89791 .4932 Mdot
.89796 .49298 Mdot
.89801 .49276 Mdot
.89806 .49254 Mdot
.8981 .49232 Mdot
.89815 .4921 Mdot
.8982 .49187 Mdot
.89825 .49165 Mdot
.89829 .49143 Mdot
.89834 .4912 Mdot
.89839 .49098 Mdot
.89844 .49075 Mdot
.89848 .49053 Mdot
.89853 .4903 Mdot
.89858 .49008 Mdot
.89863 .48985 Mdot
.89867 .48962 Mdot
.89872 .48939 Mdot
.89877 .48916 Mdot
.89882 .48893 Mdot
.89886 .48869 Mdot
.89891 .48845 Mdot
.89896 .48821 Mdot
.89901 .48798 Mdot
.89906 .48774 Mdot
.8991 .4875 Mdot
.89915 .48726 Mdot
.8992 .48701 Mdot
.89925 .48677 Mdot
.89929 .48652 Mdot
.89934 .48628 Mdot
.89939 .48603 Mdot
.89944 .48579 Mdot
.89948 .48554 Mdot
.89953 .4853 Mdot
.89958 .48505 Mdot
.89963 .4848 Mdot
.89967 .48455 Mdot
.89972 .4843 Mdot
.89977 .48405 Mdot
.89982 .4838 Mdot
.89986 .48356 Mdot
.89991 .48331 Mdot
.89996 .48307 Mdot
.90001 .48282 Mdot
.90006 .48257 Mdot
.9001 .48232 Mdot
.90015 .48207 Mdot
.9002 .48182 Mdot
.90025 .48156 Mdot
.90029 .48131 Mdot
.90034 .48105 Mdot
.90039 .4808 Mdot
.90044 .48055 Mdot
.90048 .4803 Mdot
.90053 .48005 Mdot
.90058 .4798 Mdot
.90063 .47955 Mdot
.90067 .4793 Mdot
.90072 .47905 Mdot
.90077 .4788 Mdot
.90082 .47855 Mdot
.90086 .47831 Mdot
.90091 .47806 Mdot
.90096 .47782 Mdot
.90101 .47758 Mdot
.90106 .47733 Mdot
.9011 .47709 Mdot
.90115 .47684 Mdot
.9012 .47659 Mdot
.90125 .47634 Mdot
.90129 .47609 Mdot
.90134 .47583 Mdot
.90139 .47558 Mdot
.90144 .47532 Mdot
.90148 .47507 Mdot
.90153 .47481 Mdot
.90158 .47455 Mdot
.90163 .47429 Mdot
.90167 .47403 Mdot
.90172 .47377 Mdot
.90177 .47351 Mdot
.90182 .47325 Mdot
.90186 .47298 Mdot
.90191 .47271 Mdot
.90196 .47245 Mdot
.90201 .47218 Mdot
.90206 .47191 Mdot
.9021 .47164 Mdot
.90215 .47137 Mdot
.9022 .4711 Mdot
.90225 .47084 Mdot
.90229 .47057 Mdot
.90234 .4703 Mdot
.90239 .47004 Mdot
.90244 .46977 Mdot
.90248 .46951 Mdot
.90253 .46924 Mdot
.90258 .46898 Mdot
.90263 .46871 Mdot
.90267 .46844 Mdot
.90272 .46817 Mdot
.90277 .4679 Mdot
.90282 .46763 Mdot
.90286 .46735 Mdot
.90291 .46708 Mdot
.90296 .4668 Mdot
.90301 .46653 Mdot
.90305 .46625 Mdot
.9031 .46597 Mdot
.90315 .4657 Mdot
.9032 .46542 Mdot
.90325 .46514 Mdot
.90329 .46486 Mdot
.90334 .46458 Mdot
.90339 .46429 Mdot
.90344 .464 Mdot
.90348 .46372 Mdot
.90353 .46343 Mdot
.90358 .46315 Mdot
.90363 .46286 Mdot
.90367 .46258 Mdot
.90372 .4623 Mdot
.90377 .46202 Mdot
.90382 .46174 Mdot
.90386 .46146 Mdot
.90391 .46118 Mdot
.90396 .4609 Mdot
.90401 .46062 Mdot
.90405 .46034 Mdot
.9041 .46006 Mdot
.90415 .45977 Mdot
.9042 .45949 Mdot
.90425 .4592 Mdot
.90429 .45891 Mdot
.90434 .45863 Mdot
.90439 .45835 Mdot
.90444 .45806 Mdot
.90448 .45778 Mdot
.90453 .4575 Mdot
.90458 .45721 Mdot
.90463 .45693 Mdot
.90467 .45664 Mdot
.90472 .45635 Mdot
.90477 .45606 Mdot
.90482 .45577 Mdot
.90486 .45548 Mdot
.90491 .45518 Mdot
.90496 .45489 Mdot
.90501 .4546 Mdot
.90505 .45431 Mdot
.9051 .45402 Mdot
.90515 .45373 Mdot
.9052 .45344 Mdot
.90525 .45315 Mdot
.90529 .45287 Mdot
.90534 .45258 Mdot
.90539 .45229 Mdot
.90544 .45201 Mdot
.90548 .45172 Mdot
.90553 .45143 Mdot
.90558 .45115 Mdot
.90563 .45087 Mdot
.90567 .45058 Mdot
.90572 .4503 Mdot
.90577 .45002 Mdot
.90582 .44973 Mdot
.90586 .44945 Mdot
.90591 .44918 Mdot
.90596 .4489 Mdot
.90601 .44862 Mdot
.90605 .44835 Mdot
.9061 .44807 Mdot
.90615 .4478 Mdot
.9062 .44753 Mdot
.90625 .44726 Mdot
.90629 .44699 Mdot
.90634 .44672 Mdot
.90639 .44645 Mdot
.90644 .44618 Mdot
.90648 .44591 Mdot
.90653 .44564 Mdot
.90658 .44536 Mdot
.90663 .44509 Mdot
.90667 .44482 Mdot
.90672 .44454 Mdot
.90677 .44426 Mdot
.90682 .44399 Mdot
.90686 .44371 Mdot
.90691 .44344 Mdot
.90696 .44316 Mdot
.90701 .44289 Mdot
.90705 .44262 Mdot
.9071 .44235 Mdot
.90715 .44208 Mdot
.9072 .44181 Mdot
.90724 .44154 Mdot
.90729 .44128 Mdot
.90734 .44101 Mdot
.90739 .44074 Mdot
.90744 .44047 Mdot
.90748 .4402 Mdot
.90753 .43993 Mdot
.90758 .43966 Mdot
.90763 .43939 Mdot
.90767 .43911 Mdot
.90772 .43884 Mdot
.90777 .43857 Mdot
.90782 .43829 Mdot
.90786 .43801 Mdot
.90791 .43774 Mdot
.90796 .43746 Mdot
.90801 .43719 Mdot
.90805 .43692 Mdot
.9081 .43664 Mdot
.90815 .43636 Mdot
.9082 .43609 Mdot
.90824 .43581 Mdot
.90829 .43554 Mdot
.90834 .43526 Mdot
.90839 .43498 Mdot
.90844 .43471 Mdot
.90848 .43443 Mdot
.90853 .43416 Mdot
.90858 .43388 Mdot
.90863 .4336 Mdot
.90867 .43333 Mdot
.90872 .43305 Mdot
.90877 .43277 Mdot
.90882 .43249 Mdot
.90886 .4322 Mdot
.90891 .43192 Mdot
.90896 .43163 Mdot
.90901 .43135 Mdot
.90905 .43106 Mdot
.9091 .43077 Mdot
.90915 .43049 Mdot
.9092 .4302 Mdot
.90924 .42992 Mdot
.90929 .42963 Mdot
.90934 .42935 Mdot
.90939 .42906 Mdot
.90944 .42878 Mdot
.90948 .4285 Mdot
.90953 .42821 Mdot
.90958 .42793 Mdot
.90963 .42764 Mdot
.90967 .42736 Mdot
.90972 .42708 Mdot
.90977 .42679 Mdot
.90982 .4265 Mdot
.90986 .42622 Mdot
.90991 .42593 Mdot
.90996 .42565 Mdot
.91001 .42536 Mdot
.91005 .42507 Mdot
.9101 .42479 Mdot
.91015 .4245 Mdot
.9102 .42421 Mdot
.91024 .42392 Mdot
.91029 .42363 Mdot
.91034 .42335 Mdot
.91039 .42306 Mdot
.91044 .42278 Mdot
.91048 .42249 Mdot
.91053 .4222 Mdot
.91058 .42191 Mdot
.91063 .42162 Mdot
.91067 .42133 Mdot
.91072 .42105 Mdot
.91077 .42076 Mdot
.91082 .42048 Mdot
.91086 .42019 Mdot
.91091 .41991 Mdot
.91096 .41962 Mdot
.91101 .41933 Mdot
.91105 .41904 Mdot
.9111 .41875 Mdot
.91115 .41846 Mdot
.9112 .41817 Mdot
.91124 .41788 Mdot
.91129 .41758 Mdot
.91134 .41729 Mdot
.91139 .41699 Mdot
.91144 .4167 Mdot
.91148 .41641 Mdot
.91153 .41612 Mdot
.91158 .41583 Mdot
.91163 .41554 Mdot
.91167 .41524 Mdot
.91172 .41496 Mdot
.91177 .41467 Mdot
.91182 .41438 Mdot
.91186 .41409 Mdot
.91191 .41379 Mdot
.91196 .4135 Mdot
.91201 .41321 Mdot
.91205 .41292 Mdot
.9121 .41262 Mdot
.91215 .41233 Mdot
.9122 .41204 Mdot
.91224 .41174 Mdot
.91229 .41144 Mdot
.91234 .41114 Mdot
.91239 .41085 Mdot
.91243 .41055 Mdot
.91248 .41025 Mdot
.91253 .40995 Mdot
.91258 .40965 Mdot
.91263 .40935 Mdot
.91267 .40906 Mdot
.91272 .40876 Mdot
.91277 .40846 Mdot
.91282 .40816 Mdot
.91286 .40786 Mdot
.91291 .40756 Mdot
.91296 .40725 Mdot
.91301 .40695 Mdot
.91305 .40664 Mdot
.9131 .40634 Mdot
.91315 .40603 Mdot
.9132 .40573 Mdot
.91324 .40542 Mdot
.91329 .40511 Mdot
.91334 .4048 Mdot
.91339 .40448 Mdot
.91343 .40417 Mdot
.91348 .40385 Mdot
.91353 .40353 Mdot
.91358 .4032 Mdot
.91363 .40289 Mdot
.91367 .40256 Mdot
.91372 .40224 Mdot
.91377 .40193 Mdot
.91382 .40161 Mdot
.91386 .40128 Mdot
.91391 .40096 Mdot
.91396 .40063 Mdot
.91401 .40031 Mdot
.91405 .39999 Mdot
.9141 .39966 Mdot
.91415 .39934 Mdot
.9142 .39902 Mdot
.91424 .39869 Mdot
.91429 .39838 Mdot
.91434 .39806 Mdot
.91439 .39774 Mdot
.91443 .39741 Mdot
.91448 .3971 Mdot
.91453 .39677 Mdot
.91458 .39645 Mdot
.91463 .39613 Mdot
.91467 .39581 Mdot
.91472 .39548 Mdot
.91477 .39516 Mdot
.91482 .39484 Mdot
.91486 .39452 Mdot
.91491 .39419 Mdot
.91496 .39387 Mdot
.91501 .39356 Mdot
.91505 .39324 Mdot
.9151 .39292 Mdot
.91515 .3926 Mdot
.9152 .39228 Mdot
.91524 .39196 Mdot
.91529 .39165 Mdot
.91534 .39133 Mdot
.91539 .39101 Mdot
.91543 .39069 Mdot
.91548 .39037 Mdot
.91553 .39006 Mdot
.91558 .38974 Mdot
.91563 .38942 Mdot
.91567 .3891 Mdot
.91572 .38878 Mdot
.91577 .38846 Mdot
.91582 .38814 Mdot
.91586 .38783 Mdot
.91591 .38751 Mdot
.91596 .38719 Mdot
.91601 .38687 Mdot
.91605 .38655 Mdot
.9161 .38623 Mdot
.91615 .38591 Mdot
.9162 .38559 Mdot
.91624 .38527 Mdot
.91629 .38495 Mdot
.91634 .38464 Mdot
.91639 .38431 Mdot
.91643 .38399 Mdot
.91648 .38367 Mdot
.91653 .38335 Mdot
.91658 .38302 Mdot
.91663 .3827 Mdot
.91667 .38237 Mdot
.91672 .38205 Mdot
.91677 .38172 Mdot
.91682 .3814 Mdot
.91686 .38107 Mdot
.91691 .38075 Mdot
.91696 .38043 Mdot
.91701 .38011 Mdot
.91705 .37978 Mdot
.9171 .37946 Mdot
.91715 .37913 Mdot
.9172 .37881 Mdot
.91724 .37848 Mdot
.91729 .37815 Mdot
.91734 .37782 Mdot
.91739 .3775 Mdot
.91743 .37717 Mdot
.91748 .37684 Mdot
.91753 .37652 Mdot
.91758 .37619 Mdot
.91762 .37586 Mdot
.91767 .37553 Mdot
.91772 .3752 Mdot
.91777 .37487 Mdot
.91782 .37454 Mdot
.91786 .37421 Mdot
.91791 .37388 Mdot
.91796 .37355 Mdot
.91801 .37322 Mdot
.91805 .37289 Mdot
.9181 .37256 Mdot
.91815 .37223 Mdot
.9182 .3719 Mdot
.91824 .37158 Mdot
.91829 .37125 Mdot
.91834 .37093 Mdot
.91839 .3706 Mdot
.91843 .37028 Mdot
.91848 .36995 Mdot
.91853 .36963 Mdot
.91858 .3693 Mdot
.91862 .36898 Mdot
.91867 .36865 Mdot
.91872 .36832 Mdot
.91877 .36799 Mdot
.91882 .36766 Mdot
.91886 .36734 Mdot
.91891 .36701 Mdot
.91896 .36669 Mdot
.91901 .36636 Mdot
.91905 .36603 Mdot
.9191 .36571 Mdot
.91915 .36539 Mdot
.9192 .36506 Mdot
.91924 .36474 Mdot
.91929 .36442 Mdot
.91934 .36409 Mdot
.91939 .36377 Mdot
.91943 .36345 Mdot
.91948 .36312 Mdot
.91953 .3628 Mdot
.91958 .36247 Mdot
.91962 .36215 Mdot
.91967 .36182 Mdot
.91972 .3615 Mdot
.91977 .36117 Mdot
.91982 .36085 Mdot
.91986 .36053 Mdot
.91991 .36021 Mdot
.91996 .35988 Mdot
.92001 .35956 Mdot
.92005 .35923 Mdot
.9201 .3589 Mdot
.92015 .35858 Mdot
.9202 .35825 Mdot
.92024 .35792 Mdot
.92029 .3576 Mdot
.92034 .35728 Mdot
.92039 .35696 Mdot
.92043 .35664 Mdot
.92048 .35632 Mdot
.92053 .356 Mdot
.92058 .35568 Mdot
.92062 .35536 Mdot
.92067 .35504 Mdot
.92072 .35471 Mdot
.92077 .35439 Mdot
.92082 .35406 Mdot
.92086 .35374 Mdot
.92091 .35341 Mdot
.92096 .35309 Mdot
.92101 .35277 Mdot
.92105 .35244 Mdot
.9211 .35212 Mdot
.92115 .35179 Mdot
.9212 .35146 Mdot
.92124 .35114 Mdot
.92129 .35081 Mdot
.92134 .35048 Mdot
.92139 .35016 Mdot
.92143 .34983 Mdot
.92148 .3495 Mdot
.92153 .34918 Mdot
.92158 .34885 Mdot
.92162 .34852 Mdot
.92167 .3482 Mdot
.92172 .34787 Mdot
.92177 .34754 Mdot
.92181 .34721 Mdot
.92186 .34688 Mdot
.92191 .34655 Mdot
.92196 .34622 Mdot
.92201 .34589 Mdot
.92205 .34556 Mdot
.9221 .34523 Mdot
.92215 .3449 Mdot
.9222 .34457 Mdot
.92224 .34425 Mdot
.92229 .34392 Mdot
.92234 .34359 Mdot
.92239 .34326 Mdot
.92243 .34293 Mdot
.92248 .3426 Mdot
.92253 .34227 Mdot
.92258 .34194 Mdot
.92262 .34161 Mdot
.92267 .34128 Mdot
.92272 .34095 Mdot
.92277 .34062 Mdot
.92281 .34028 Mdot
.92286 .33995 Mdot
.92291 .33962 Mdot
.92296 .33928 Mdot
.92301 .33895 Mdot
.92305 .33861 Mdot
.9231 .33827 Mdot
.92315 .33793 Mdot
.9232 .33759 Mdot
.92324 .33726 Mdot
.92329 .33692 Mdot
.92334 .33659 Mdot
.92339 .33625 Mdot
.92343 .33591 Mdot
.92348 .33558 Mdot
.92353 .33524 Mdot
.92358 .3349 Mdot
.92362 .33456 Mdot
.92367 .33422 Mdot
.92372 .33389 Mdot
.92377 .33355 Mdot
.92381 .33321 Mdot
.92386 .33287 Mdot
.92391 .33253 Mdot
.92396 .33219 Mdot
.92401 .33186 Mdot
.92405 .33152 Mdot
.9241 .33118 Mdot
.92415 .33085 Mdot
.9242 .33051 Mdot
.92424 .33017 Mdot
.92429 .32984 Mdot
.92434 .32951 Mdot
.92439 .32918 Mdot
.92443 .32885 Mdot
.92448 .32851 Mdot
.92453 .32818 Mdot
.92458 .32785 Mdot
.92462 .32752 Mdot
.92467 .32719 Mdot
.92472 .32685 Mdot
.92477 .32653 Mdot
.92481 .3262 Mdot
.92486 .32587 Mdot
.92491 .32554 Mdot
.92496 .32521 Mdot
.92501 .32488 Mdot
.92505 .32456 Mdot
.9251 .32423 Mdot
.92515 .3239 Mdot
.9252 .32358 Mdot
.92524 .32325 Mdot
.92529 .32293 Mdot
.92534 .3226 Mdot
.92539 .32228 Mdot
.92543 .32195 Mdot
.92548 .32163 Mdot
.92553 .3213 Mdot
.92558 .32098 Mdot
.92562 .32065 Mdot
.92567 .32033 Mdot
.92572 .32001 Mdot
.92577 .31969 Mdot
.92581 .31936 Mdot
.92586 .31904 Mdot
.92591 .31872 Mdot
.92596 .31839 Mdot
.92601 .31807 Mdot
.92605 .31775 Mdot
.9261 .31742 Mdot
.92615 .3171 Mdot
.9262 .31677 Mdot
.92624 .31645 Mdot
.92629 .31612 Mdot
.92634 .3158 Mdot
.92639 .31548 Mdot
.92643 .31515 Mdot
.92648 .31483 Mdot
.92653 .31451 Mdot
.92658 .31419 Mdot
.92662 .31386 Mdot
.92667 .31354 Mdot
.92672 .31322 Mdot
.92677 .3129 Mdot
.92681 .31258 Mdot
.92686 .31226 Mdot
.92691 .31195 Mdot
.92696 .31163 Mdot
.927 .31132 Mdot
.92705 .311 Mdot
.9271 .31069 Mdot
.92715 .31037 Mdot
.9272 .31005 Mdot
.92724 .30974 Mdot
.92729 .30942 Mdot
.92734 .3091 Mdot
.92739 .30878 Mdot
.92743 .30846 Mdot
.92748 .30813 Mdot
.92753 .30781 Mdot
.92758 .30749 Mdot
.92762 .30717 Mdot
.92767 .30684 Mdot
.92772 .30651 Mdot
.92777 .30619 Mdot
.92781 .30586 Mdot
.92786 .30553 Mdot
.92791 .3052 Mdot
.92796 .30487 Mdot
.928 .30454 Mdot
.92805 .30421 Mdot
.9281 .30389 Mdot
.92815 .30356 Mdot
.9282 .30324 Mdot
.92824 .30291 Mdot
.92829 .30259 Mdot
.92834 .30226 Mdot
.92839 .30194 Mdot
.92843 .30161 Mdot
.92848 .30128 Mdot
.92853 .30096 Mdot
.92858 .30063 Mdot
.92862 .3003 Mdot
.92867 .29997 Mdot
.92872 .29965 Mdot
.92877 .29933 Mdot
.92881 .29901 Mdot
.92886 .2987 Mdot
.92891 .29838 Mdot
.92896 .29806 Mdot
.929 .29774 Mdot
.92905 .29743 Mdot
.9291 .29711 Mdot
.92915 .29679 Mdot
.9292 .29647 Mdot
.92924 .29615 Mdot
.92929 .29583 Mdot
.92934 .29551 Mdot
.92939 .29519 Mdot
.92943 .29486 Mdot
.92948 .29454 Mdot
.92953 .29422 Mdot
.92958 .2939 Mdot
.92962 .29358 Mdot
.92967 .29326 Mdot
.92972 .29294 Mdot
.92977 .29263 Mdot
.92981 .29232 Mdot
.92986 .292 Mdot
.92991 .29169 Mdot
.92996 .29138 Mdot
.93 .29107 Mdot
.93005 .29076 Mdot
.9301 .29045 Mdot
.93015 .29014 Mdot
.9302 .28983 Mdot
.93024 .28953 Mdot
.93029 .28922 Mdot
.93034 .28891 Mdot
.93039 .2886 Mdot
.93043 .28829 Mdot
.93048 .28797 Mdot
.93053 .28766 Mdot
.93058 .28735 Mdot
.93062 .28704 Mdot
.93067 .28673 Mdot
.93072 .28642 Mdot
.93077 .2861 Mdot
.93081 .28579 Mdot
.93086 .28548 Mdot
.93091 .28516 Mdot
.93096 .28485 Mdot
.931 .28453 Mdot
.93105 .28422 Mdot
.9311 .28391 Mdot
.93115 .2836 Mdot
.93119 .28329 Mdot
.93124 .28298 Mdot
.93129 .28267 Mdot
.93134 .28236 Mdot
.93139 .28205 Mdot
.93143 .28175 Mdot
.93148 .28144 Mdot
.93153 .28113 Mdot
.93158 .28082 Mdot
.93162 .28051 Mdot
.93167 .2802 Mdot
.93172 .27989 Mdot
.93177 .27958 Mdot
.93181 .27927 Mdot
.93186 .27896 Mdot
.93191 .27865 Mdot
.93196 .27833 Mdot
.932 .27802 Mdot
.93205 .27771 Mdot
.9321 .2774 Mdot
.93215 .27708 Mdot
.93219 .27677 Mdot
.93224 .27645 Mdot
.93229 .27614 Mdot
.93234 .27582 Mdot
.93239 .2755 Mdot
.93243 .27519 Mdot
.93248 .27488 Mdot
.93253 .27456 Mdot
.93258 .27425 Mdot
.93262 .27394 Mdot
.93267 .27363 Mdot
.93272 .27332 Mdot
.93277 .27302 Mdot
.93281 .27271 Mdot
.93286 .2724 Mdot
.93291 .27209 Mdot
.93296 .27178 Mdot
.933 .27147 Mdot
.93305 .27116 Mdot
.9331 .27085 Mdot
.93315 .27054 Mdot
.93319 .27024 Mdot
.93324 .26993 Mdot
.93329 .26963 Mdot
.93334 .26932 Mdot
.93339 .26901 Mdot
.93343 .26871 Mdot
.93348 .2684 Mdot
.93353 .26809 Mdot
.93358 .26779 Mdot
.93362 .26748 Mdot
.93367 .26718 Mdot
.93372 .26687 Mdot
.93377 .26656 Mdot
.93381 .26625 Mdot
.93386 .26594 Mdot
.93391 .26563 Mdot
.93396 .26533 Mdot
.934 .26502 Mdot
.93405 .26471 Mdot
.9341 .2644 Mdot
.93415 .2641 Mdot
.93419 .26379 Mdot
.93424 .26348 Mdot
.93429 .26317 Mdot
.93434 .26286 Mdot
.93439 .26256 Mdot
.93443 .26225 Mdot
.93448 .26195 Mdot
.93453 .26164 Mdot
.93458 .26134 Mdot
.93462 .26103 Mdot
.93467 .26073 Mdot
.93472 .26043 Mdot
.93477 .26013 Mdot
.93481 .25983 Mdot
.93486 .25954 Mdot
.93491 .25924 Mdot
.93496 .25894 Mdot
.935 .25865 Mdot
.93505 .25835 Mdot
.9351 .25805 Mdot
.93515 .25774 Mdot
.93519 .25744 Mdot
.93524 .25714 Mdot
.93529 .25684 Mdot
.93534 .25654 Mdot
.93539 .25625 Mdot
.93543 .25595 Mdot
.93548 .25566 Mdot
.93553 .25537 Mdot
.93558 .25508 Mdot
.93562 .25478 Mdot
.93567 .25449 Mdot
.93572 .2542 Mdot
.93577 .25391 Mdot
.93581 .25362 Mdot
.93586 .25333 Mdot
.93591 .25304 Mdot
.93596 .25275 Mdot
.936 .25246 Mdot
.93605 .25217 Mdot
.9361 .25187 Mdot
.93615 .25158 Mdot
.93619 .25129 Mdot
.93624 .251 Mdot
.93629 .2507 Mdot
.93634 .25041 Mdot
.93638 .25012 Mdot
.93643 .24983 Mdot
.93648 .24954 Mdot
.93653 .24925 Mdot
.93658 .24896 Mdot
.93662 .24868 Mdot
.93667 .2484 Mdot
.93672 .24813 Mdot
.93677 .24785 Mdot
.93681 .24757 Mdot
.93686 .2473 Mdot
.93691 .24702 Mdot
.93696 .24675 Mdot
.937 .24648 Mdot
.93705 .2462 Mdot
.9371 .24593 Mdot
.93715 .24565 Mdot
.93719 .24538 Mdot
.93724 .2451 Mdot
.93729 .24483 Mdot
.93734 .24456 Mdot
.93738 .24429 Mdot
.93743 .24402 Mdot
.93748 .24374 Mdot
.93753 .24347 Mdot
.93758 .2432 Mdot
.93762 .24293 Mdot
.93767 .24266 Mdot
.93772 .24239 Mdot
.93777 .24212 Mdot
.93781 .24185 Mdot
.93786 .24158 Mdot
.93791 .24131 Mdot
.93796 .24104 Mdot
.938 .24077 Mdot
.93805 .2405 Mdot
.9381 .24023 Mdot
.93815 .23996 Mdot
.93819 .23969 Mdot
.93824 .23942 Mdot
.93829 .23915 Mdot
.93834 .23888 Mdot
.93838 .23861 Mdot
.93843 .23834 Mdot
.93848 .23807 Mdot
.93853 .2378 Mdot
.93858 .23753 Mdot
.93862 .23726 Mdot
.93867 .23698 Mdot
.93872 .23671 Mdot
.93877 .23643 Mdot
.93881 .23616 Mdot
.93886 .23588 Mdot
.93891 .2356 Mdot
.93896 .23532 Mdot
.939 .23504 Mdot
.93905 .23476 Mdot
.9391 .23448 Mdot
.93915 .2342 Mdot
.93919 .23392 Mdot
.93924 .23363 Mdot
.93929 .23335 Mdot
.93934 .23306 Mdot
.93938 .23277 Mdot
.93943 .23249 Mdot
.93948 .2322 Mdot
.93953 .23191 Mdot
.93958 .23163 Mdot
.93962 .23134 Mdot
.93967 .23106 Mdot
.93972 .23078 Mdot
.93977 .2305 Mdot
.93981 .23022 Mdot
.93986 .22994 Mdot
.93991 .22966 Mdot
.93996 .22938 Mdot
.94 .2291 Mdot
.94005 .22883 Mdot
.9401 .22856 Mdot
.94015 .22828 Mdot
.94019 .22801 Mdot
.94024 .22773 Mdot
.94029 .22746 Mdot
.94034 .22719 Mdot
.94038 .22691 Mdot
.94043 .22664 Mdot
.94048 .22636 Mdot
.94053 .22609 Mdot
.94057 .22581 Mdot
.94062 .22554 Mdot
.94067 .22526 Mdot
.94072 .22499 Mdot
.94077 .22473 Mdot
.94081 .22446 Mdot
.94086 .22419 Mdot
.94091 .22392 Mdot
.94096 .22365 Mdot
.941 .22338 Mdot
.94105 .22311 Mdot
.9411 .22284 Mdot
.94115 .22257 Mdot
.94119 .2223 Mdot
.94124 .22203 Mdot
.94129 .22177 Mdot
.94134 .2215 Mdot
.94138 .22124 Mdot
.94143 .22097 Mdot
.94148 .22071 Mdot
.94153 .22044 Mdot
.94157 .22017 Mdot
.94162 .21991 Mdot
.94167 .21964 Mdot
.94172 .21938 Mdot
.94177 .21911 Mdot
.94181 .21884 Mdot
.94186 .21858 Mdot
.94191 .21831 Mdot
.94196 .21804 Mdot
.942 .21776 Mdot
.94205 .21749 Mdot
.9421 .21721 Mdot
.94215 .21693 Mdot
.94219 .21665 Mdot
.94224 .21637 Mdot
.94229 .21609 Mdot
.94234 .21581 Mdot
.94238 .21553 Mdot
.94243 .21525 Mdot
.94248 .21497 Mdot
.94253 .21469 Mdot
.94257 .21442 Mdot
.94262 .21414 Mdot
.94267 .21386 Mdot
.94272 .21358 Mdot
.94277 .2133 Mdot
.94281 .21302 Mdot
.94286 .21274 Mdot
.94291 .21246 Mdot
.94296 .21218 Mdot
.943 .2119 Mdot
.94305 .21162 Mdot
.9431 .21134 Mdot
.94315 .21105 Mdot
.94319 .21077 Mdot
.94324 .21048 Mdot
.94329 .21019 Mdot
.94334 .20991 Mdot
.94338 .20963 Mdot
.94343 .20934 Mdot
.94348 .20906 Mdot
.94353 .20878 Mdot
.94357 .20849 Mdot
.94362 .20822 Mdot
.94367 .20794 Mdot
.94372 .20766 Mdot
.94377 .20738 Mdot
.94381 .2071 Mdot
.94386 .20681 Mdot
.94391 .20653 Mdot
.94396 .20625 Mdot
.944 .20596 Mdot
.94405 .20568 Mdot
.9441 .2054 Mdot
.94415 .20511 Mdot
.94419 .20483 Mdot
.94424 .20455 Mdot
.94429 .20427 Mdot
.94434 .20398 Mdot
.94438 .2037 Mdot
.94443 .20342 Mdot
.94448 .20313 Mdot
.94453 .20285 Mdot
.94457 .20257 Mdot
.94462 .20229 Mdot
.94467 .20201 Mdot
.94472 .20172 Mdot
.94477 .20144 Mdot
.94481 .20116 Mdot
.94486 .20088 Mdot
.94491 .2006 Mdot
.94496 .20032 Mdot
.945 .20003 Mdot
.94505 .19975 Mdot
.9451 .19947 Mdot
.94515 .19919 Mdot
.94519 .19891 Mdot
.94524 .19862 Mdot
.94529 .19834 Mdot
.94534 .19806 Mdot
.94538 .19778 Mdot
.94543 .19749 Mdot
.94548 .19721 Mdot
.94553 .19693 Mdot
.94557 .19664 Mdot
.94562 .19636 Mdot
.94567 .19607 Mdot
.94572 .19579 Mdot
.94576 .1955 Mdot
.94581 .19521 Mdot
.94586 .19493 Mdot
.94591 .19464 Mdot
.94596 .19436 Mdot
.946 .19407 Mdot
.94605 .19379 Mdot
.9461 .1935 Mdot
.94615 .19322 Mdot
.94619 .19294 Mdot
.94624 .19266 Mdot
.94629 .19238 Mdot
.94634 .19209 Mdot
.94638 .19181 Mdot
.94643 .19153 Mdot
.94648 .19124 Mdot
.94653 .19096 Mdot
.94657 .19067 Mdot
.94662 .19039 Mdot
.94667 .1901 Mdot
.94672 .18982 Mdot
.94676 .18954 Mdot
.94681 .18926 Mdot
.94686 .18898 Mdot
.94691 .18871 Mdot
.94696 .18844 Mdot
.947 .18816 Mdot
.94705 .18789 Mdot
.9471 .18762 Mdot
.94715 .18735 Mdot
.94719 .18708 Mdot
.94724 .1868 Mdot
.94729 .18653 Mdot
.94734 .18626 Mdot
.94738 .18599 Mdot
.94743 .18572 Mdot
.94748 .18545 Mdot
.94753 .18518 Mdot
.94757 .18491 Mdot
.94762 .18464 Mdot
.94767 .18437 Mdot
.94772 .1841 Mdot
.94776 .18383 Mdot
.94781 .18356 Mdot
.94786 .18328 Mdot
.94791 .18301 Mdot
.94796 .18275 Mdot
.948 .18247 Mdot
.94805 .1822 Mdot
.9481 .18193 Mdot
.94815 .18166 Mdot
.94819 .18139 Mdot
.94824 .18112 Mdot
.94829 .18085 Mdot
.94834 .18057 Mdot
.94838 .1803 Mdot
.94843 .18002 Mdot
.94848 .17975 Mdot
.94853 .17947 Mdot
.94857 .1792 Mdot
.94862 .17893 Mdot
.94867 .17866 Mdot
.94872 .1784 Mdot
.94876 .17813 Mdot
.94881 .17787 Mdot
.94886 .1776 Mdot
.94891 .17733 Mdot
.94896 .17706 Mdot
.949 .1768 Mdot
.94905 .17653 Mdot
.9491 .17627 Mdot
.94915 .176 Mdot
.94919 .17574 Mdot
.94924 .17548 Mdot
.94929 .17522 Mdot
.94934 .17496 Mdot
.94938 .17469 Mdot
.94943 .17443 Mdot
.94948 .17417 Mdot
.94953 .17391 Mdot
.94957 .17365 Mdot
.94962 .17339 Mdot
.94967 .17314 Mdot
.94972 .17288 Mdot
.94976 .17262 Mdot
.94981 .17236 Mdot
.94986 .1721 Mdot
.94991 .17184 Mdot
.94996 .17157 Mdot
.95 .17131 Mdot
.95005 .17105 Mdot
.9501 .17078 Mdot
.95015 .17052 Mdot
.95019 .17026 Mdot
.95024 .17 Mdot
.95029 .16974 Mdot
.95034 .16947 Mdot
.95038 .16921 Mdot
.95043 .16895 Mdot
.95048 .16869 Mdot
.95053 .16843 Mdot
.95057 .16816 Mdot
.95062 .16789 Mdot
.95067 .16762 Mdot
.95072 .16735 Mdot
.95076 .16708 Mdot
.95081 .1668 Mdot
.95086 .16653 Mdot
.95091 .16626 Mdot
.95095 .16599 Mdot
.951 .16572 Mdot
.95105 .16545 Mdot
.9511 .16517 Mdot
.95115 .1649 Mdot
.95119 .16462 Mdot
.95124 .16434 Mdot
.95129 .16406 Mdot
.95134 .16378 Mdot
.95138 .16351 Mdot
.95143 .16323 Mdot
.95148 .16295 Mdot
.95153 .16267 Mdot
.95157 .1624 Mdot
.95162 .16212 Mdot
.95167 .16185 Mdot
.95172 .16157 Mdot
.95176 .1613 Mdot
.95181 .16103 Mdot
.95186 .16076 Mdot
.95191 .16049 Mdot
.95195 .16022 Mdot
.952 .15994 Mdot
.95205 .15967 Mdot
.9521 .1594 Mdot
.95215 .15913 Mdot
.95219 .15886 Mdot
.95224 .1586 Mdot
.95229 .15833 Mdot
.95234 .15806 Mdot
.95238 .15778 Mdot
.95243 .15751 Mdot
.95248 .15724 Mdot
.95253 .15697 Mdot
.95257 .15669 Mdot
.95262 .15642 Mdot
.95267 .15615 Mdot
.95272 .15588 Mdot
.95276 .1556 Mdot
.95281 .15533 Mdot
.95286 .15505 Mdot
.95291 .15477 Mdot
.95295 .15449 Mdot
.953 .15421 Mdot
.95305 .15393 Mdot
.9531 .15366 Mdot
.95315 .15338 Mdot
.95319 .15311 Mdot
.95324 .15283 Mdot
.95329 .15256 Mdot
.95334 .15228 Mdot
.95338 .15201 Mdot
.95343 .15173 Mdot
.95348 .15146 Mdot
.95353 .15118 Mdot
.95357 .1509 Mdot
.95362 .15062 Mdot
.95367 .15034 Mdot
.95372 .15007 Mdot
.95376 .14979 Mdot
.95381 .14951 Mdot
.95386 .14924 Mdot
.95391 .14897 Mdot
.95395 .14869 Mdot
.954 .14842 Mdot
.95405 .14814 Mdot
.9541 .14787 Mdot
.95415 .14759 Mdot
.95419 .14732 Mdot
.95424 .14705 Mdot
.95429 .14678 Mdot
.95434 .14651 Mdot
.95438 .14624 Mdot
.95443 .14597 Mdot
.95448 .1457 Mdot
.95453 .14543 Mdot
.95457 .14517 Mdot
.95462 .1449 Mdot
.95467 .14463 Mdot
.95472 .14437 Mdot
.95476 .14411 Mdot
.95481 .14384 Mdot
.95486 .14358 Mdot
.95491 .14331 Mdot
.95495 .14305 Mdot
.955 .14279 Mdot
.95505 .14252 Mdot
.9551 .14226 Mdot
.95514 .142 Mdot
.95519 .14174 Mdot
.95524 .14148 Mdot
.95529 .14123 Mdot
.95534 .14097 Mdot
.95538 .14072 Mdot
.95543 .14047 Mdot
.95548 .14022 Mdot
.95553 .13997 Mdot
.95557 .13971 Mdot
.95562 .13946 Mdot
.95567 .1392 Mdot
.95572 .13895 Mdot
.95576 .13869 Mdot
.95581 .13844 Mdot
.95586 .13819 Mdot
.95591 .13793 Mdot
.95595 .13768 Mdot
.956 .13742 Mdot
.95605 .13717 Mdot
.9561 .13692 Mdot
.95614 .13667 Mdot
.95619 .13642 Mdot
.95624 .13617 Mdot
.95629 .13592 Mdot
.95634 .13567 Mdot
.95638 .13543 Mdot
.95643 .13518 Mdot
.95648 .13494 Mdot
.95653 .1347 Mdot
.95657 .13446 Mdot
.95662 .13422 Mdot
.95667 .13397 Mdot
.95672 .13373 Mdot
.95676 .13348 Mdot
.95681 .13324 Mdot
.95686 .13299 Mdot
.95691 .13274 Mdot
.95695 .1325 Mdot
.957 .13225 Mdot
.95705 .13201 Mdot
.9571 .13177 Mdot
.95714 .13152 Mdot
.95719 .13129 Mdot
.95724 .13104 Mdot
.95729 .13081 Mdot
.95734 .13057 Mdot
.95738 .13032 Mdot
.95743 .13008 Mdot
.95748 .12984 Mdot
.95753 .1296 Mdot
.95757 .12936 Mdot
.95762 .12912 Mdot
.95767 .12887 Mdot
.95772 .12863 Mdot
.95776 .12839 Mdot
.95781 .12815 Mdot
.95786 .12791 Mdot
.95791 .12767 Mdot
.95795 .12743 Mdot
.958 .12719 Mdot
.95805 .12695 Mdot
.9581 .12671 Mdot
.95814 .12647 Mdot
.95819 .12623 Mdot
.95824 .12599 Mdot
.95829 .12575 Mdot
.95834 .12551 Mdot
.95838 .12527 Mdot
.95843 .12503 Mdot
.95848 .12479 Mdot
.95853 .12455 Mdot
.95857 .12431 Mdot
.95862 .12407 Mdot
.95867 .12382 Mdot
.95872 .12358 Mdot
.95876 .12333 Mdot
.95881 .12309 Mdot
.95886 .12285 Mdot
.95891 .12261 Mdot
.95895 .12236 Mdot
.959 .12212 Mdot
.95905 .12187 Mdot
.9591 .12163 Mdot
.95914 .12138 Mdot
.95919 .12114 Mdot
.95924 .12089 Mdot
.95929 .12065 Mdot
.95934 .1204 Mdot
.95938 .12016 Mdot
.95943 .11991 Mdot
.95948 .11967 Mdot
.95953 .11942 Mdot
.95957 .11917 Mdot
.95962 .11892 Mdot
.95967 .11867 Mdot
.95972 .11843 Mdot
.95976 .11818 Mdot
.95981 .11794 Mdot
.95986 .11769 Mdot
.95991 .11745 Mdot
.95995 .1172 Mdot
.96 .11696 Mdot
.96005 .11671 Mdot
.9601 .11646 Mdot
.96014 .11622 Mdot
.96019 .11597 Mdot
.96024 .11573 Mdot
.96029 .11548 Mdot
.96033 .11523 Mdot
.96038 .11498 Mdot
.96043 .11473 Mdot
.96048 .11449 Mdot
.96053 .11424 Mdot
.96057 .114 Mdot
.96062 .11376 Mdot
.96067 .11352 Mdot
.96072 .11328 Mdot
.96076 .11304 Mdot
.96081 .1128 Mdot
.96086 .11256 Mdot
.96091 .11232 Mdot
.96095 .11208 Mdot
.961 .11185 Mdot
.96105 .11161 Mdot
.9611 .11138 Mdot
.96114 .11114 Mdot
.96119 .11091 Mdot
.96124 .11067 Mdot
.96129 .11044 Mdot
.96133 .11021 Mdot
.96138 .10998 Mdot
.96143 .10975 Mdot
.96148 .10953 Mdot
.96153 .1093 Mdot
.96157 .10908 Mdot
.96162 .10885 Mdot
.96167 .10863 Mdot
.96172 .10841 Mdot
.96176 .10819 Mdot
.96181 .10797 Mdot
.96186 .10775 Mdot
.96191 .10753 Mdot
.96195 .1073 Mdot
.962 .10708 Mdot
.96205 .10687 Mdot
.9621 .10665 Mdot
.96214 .10643 Mdot
.96219 .10621 Mdot
.96224 .10599 Mdot
.96229 .10577 Mdot
.96233 .10555 Mdot
.96238 .10533 Mdot
.96243 .10512 Mdot
.96248 .1049 Mdot
.96253 .10469 Mdot
.96257 .10447 Mdot
.96262 .10426 Mdot
.96267 .10404 Mdot
.96272 .10383 Mdot
.96276 .10362 Mdot
.96281 .10341 Mdot
.96286 .1032 Mdot
.96291 .10299 Mdot
.96295 .10278 Mdot
.963 .10257 Mdot
.96305 .10236 Mdot
.9631 .10216 Mdot
.96314 .10195 Mdot
.96319 .10175 Mdot
.96324 .10154 Mdot
.96329 .10134 Mdot
.96333 .10113 Mdot
.96338 .10093 Mdot
.96343 .10072 Mdot
.96348 .10052 Mdot
.96353 .10031 Mdot
.96357 .1001 Mdot
.96362 .0999 Mdot
.96367 .09969 Mdot
.96372 .09948 Mdot
.96376 .09927 Mdot
.96381 .09907 Mdot
.96386 .09886 Mdot
.96391 .09865 Mdot
.96395 .09844 Mdot
.964 .09823 Mdot
.96405 .09803 Mdot
.9641 .09782 Mdot
.96414 .09762 Mdot
.96419 .09741 Mdot
.96424 .0972 Mdot
.96429 .097 Mdot
.96433 .09679 Mdot
.96438 .09658 Mdot
.96443 .09638 Mdot
.96448 .09618 Mdot
.96452 .09597 Mdot
.96457 .09577 Mdot
.96462 .09557 Mdot
.96467 .09537 Mdot
.96472 .09516 Mdot
.96476 .09496 Mdot
.96481 .09476 Mdot
.96486 .09455 Mdot
.96491 .09435 Mdot
.96495 .09414 Mdot
.965 .09394 Mdot
.96505 .09373 Mdot
.9651 .09353 Mdot
.96514 .09333 Mdot
.96519 .09312 Mdot
.96524 .09292 Mdot
.96529 .09272 Mdot
.96533 .09252 Mdot
.96538 .09233 Mdot
.96543 .09213 Mdot
.96548 .09193 Mdot
.96552 .09173 Mdot
.96557 .09153 Mdot
.96562 .09132 Mdot
.96567 .09112 Mdot
.96572 .09093 Mdot
.96576 .09073 Mdot
.96581 .09053 Mdot
.96586 .09033 Mdot
.96591 .09013 Mdot
.96595 .08992 Mdot
.966 .08972 Mdot
.96605 .08952 Mdot
.9661 .08932 Mdot
.96614 .08913 Mdot
.96619 .08893 Mdot
.96624 .08873 Mdot
.96629 .08854 Mdot
.96633 .08835 Mdot
.96638 .08816 Mdot
.96643 .08797 Mdot
.96648 .08778 Mdot
.96652 .0876 Mdot
.96657 .08741 Mdot
.96662 .08723 Mdot
.96667 .08704 Mdot
.96672 .08686 Mdot
.96676 .08667 Mdot
.96681 .08649 Mdot
.96686 .0863 Mdot
.96691 .08612 Mdot
.96695 .08594 Mdot
.967 .08576 Mdot
.96705 .08558 Mdot
.9671 .0854 Mdot
.96714 .08522 Mdot
.96719 .08504 Mdot
.96724 .08487 Mdot
.96729 .08469 Mdot
.96733 .08451 Mdot
.96738 .08433 Mdot
.96743 .08414 Mdot
.96748 .08396 Mdot
.96752 .08378 Mdot
.96757 .0836 Mdot
.96762 .08342 Mdot
.96767 .08324 Mdot
.96772 .08306 Mdot
.96776 .08289 Mdot
.96781 .08271 Mdot
.96786 .08254 Mdot
.96791 .08237 Mdot
.96795 .0822 Mdot
.968 .08202 Mdot
.96805 .08185 Mdot
.9681 .08168 Mdot
.96814 .08151 Mdot
.96819 .08133 Mdot
.96824 .08116 Mdot
.96829 .08099 Mdot
.96833 .08081 Mdot
.96838 .08064 Mdot
.96843 .08046 Mdot
.96848 .08029 Mdot
.96852 .08012 Mdot
.96857 .07995 Mdot
.96862 .07977 Mdot
.96867 .0796 Mdot
.96872 .07944 Mdot
.96876 .07927 Mdot
.96881 .07911 Mdot
.96886 .07894 Mdot
.96891 .07878 Mdot
.96895 .07862 Mdot
.969 .07846 Mdot
.96905 .0783 Mdot
.9691 .07814 Mdot
.96914 .07798 Mdot
.96919 .07783 Mdot
.96924 .07767 Mdot
.96929 .07751 Mdot
.96933 .07735 Mdot
.96938 .07719 Mdot
.96943 .07703 Mdot
.96948 .07688 Mdot
.96952 .07672 Mdot
.96957 .07656 Mdot
.96962 .0764 Mdot
.96967 .07624 Mdot
.96971 .07608 Mdot
.96976 .07592 Mdot
.96981 .07576 Mdot
.96986 .0756 Mdot
.96991 .07545 Mdot
.96995 .07529 Mdot
.97 .07513 Mdot
.97005 .07498 Mdot
.9701 .07482 Mdot
.97014 .07466 Mdot
.97019 .07451 Mdot
.97024 .07436 Mdot
.97029 .07421 Mdot
.97033 .07405 Mdot
.97038 .0739 Mdot
.97043 .07375 Mdot
.97048 .0736 Mdot
.97052 .07345 Mdot
.97057 .07331 Mdot
.97062 .07316 Mdot
.97067 .07302 Mdot
.97071 .07288 Mdot
.97076 .07273 Mdot
.97081 .07259 Mdot
.97086 .07245 Mdot
.97091 .07231 Mdot
.97095 .07217 Mdot
.971 .07204 Mdot
.97105 .0719 Mdot
.9711 .07175 Mdot
.97114 .07161 Mdot
.97119 .07147 Mdot
.97124 .07133 Mdot
.97129 .07119 Mdot
.97133 .07106 Mdot
.97138 .07092 Mdot
.97143 .07079 Mdot
.97148 .07066 Mdot
.97152 .07053 Mdot
.97157 .0704 Mdot
.97162 .07027 Mdot
.97167 .07015 Mdot
.97171 .07002 Mdot
.97176 .06989 Mdot
.97181 .06977 Mdot
.97186 .06964 Mdot
.97191 .06951 Mdot
.97195 .06938 Mdot
.972 .06926 Mdot
.97205 .06914 Mdot
.9721 .06901 Mdot
.97214 .06889 Mdot
.97219 .06877 Mdot
.97224 .06866 Mdot
.97229 .06854 Mdot
.97233 .06843 Mdot
.97238 .06831 Mdot
.97243 .0682 Mdot
.97248 .06808 Mdot
.97252 .06797 Mdot
.97257 .06785 Mdot
.97262 .06774 Mdot
.97267 .06763 Mdot
.97271 .06753 Mdot
.97276 .06742 Mdot
.97281 .06731 Mdot
.97286 .0672 Mdot
.97291 .06709 Mdot
.97295 .06699 Mdot
.973 .06688 Mdot
.97305 .06677 Mdot
.9731 .06667 Mdot
.97314 .06656 Mdot
.97319 .06646 Mdot
.97324 .06636 Mdot
.97329 .06625 Mdot
.97333 .06615 Mdot
.97338 .06604 Mdot
.97343 .06594 Mdot
.97348 .06583 Mdot
.97352 .06573 Mdot
.97357 .06563 Mdot
.97362 .06552 Mdot
.97367 .06542 Mdot
.97371 .06532 Mdot
.97376 .06522 Mdot
.97381 .06512 Mdot
.97386 .06502 Mdot
.9739 .06493 Mdot
.97395 .06483 Mdot
.974 .06474 Mdot
.97405 .06465 Mdot
.9741 .06456 Mdot
.97414 .06446 Mdot
.97419 .06437 Mdot
.97424 .06428 Mdot
.97429 .06418 Mdot
.97433 .06409 Mdot
.97438 .064 Mdot
.97443 .06391 Mdot
.97448 .06381 Mdot
.97452 .06372 Mdot
.97457 .06363 Mdot
.97462 .06354 Mdot
.97467 .06345 Mdot
.97471 .06336 Mdot
.97476 .06327 Mdot
.97481 .06318 Mdot
.97486 .06309 Mdot
.9749 .06301 Mdot
.97495 .06292 Mdot
.975 .06283 Mdot
.97505 .06274 Mdot
.9751 .06265 Mdot
.97514 .06256 Mdot
.97519 .06248 Mdot
.97524 .06239 Mdot
.97529 .06231 Mdot
.97533 .06223 Mdot
.97538 .06215 Mdot
.97543 .06208 Mdot
.97548 .062 Mdot
.97552 .06193 Mdot
.97557 .06185 Mdot
.97562 .06178 Mdot
.97567 .0617 Mdot
.97571 .06163 Mdot
.97576 .06155 Mdot
.97581 .06148 Mdot
.97586 .06141 Mdot
.9759 .06134 Mdot
.97595 .06127 Mdot
.976 .0612 Mdot
.97605 .06113 Mdot
.9761 .06107 Mdot
.97614 .06101 Mdot
.97619 .06094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP008_oonfX3o`00Oooooo]ZoooonfXMoookJP008_oonfX3o`00O`Wooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002;ooo]Z0ol007l9oookJPGo0000oooonf[ooookJPoooo]Z000BoookJP[o001o
1_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX001;ooo]Z2_l007l6oookJP?o001o2Ooo
nfX6o`000?oooo]ZoooonfX>oookJP008_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02;ooo]Z0ol007l9oookJPGo0000oooonf[ooookJPoooo]Z000RoookJP?o001o2OoonfX5o`000?oo
oo]ZoooonfX?oookJP008_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX001oooo]Z1_l0
07l9oookJPGo0000oooonfXAoookJP?o0000n_oonfX001oooo]Z1_l007l9oookJPGo0000oooonfX?
oookJPOo0000n?oonfX0027ooo]Z1?l007l9oookJPGo0000oooonfX>oookJPWo0000mooonfX002;o
oo]Z0ol007l9oookJPGo0000oooonfX>oookJP[o0000m_oonfX002kooo]Z1Ol0003ooookJPgooo]Z
3?l0003eoookJP00;_oonfX5o`000?oooo]Z3?oonfX6o`0000;ooo]Z1Ol0003eoookJP00;_oonfX5
o`00033ooo]Z1Ol0003FoookJPGo00001?oonfX5o`000?Cooo]Z000^oookJPGo0000;ooonfX7o`00
0=Cooo]Z1Ol00005oookJPGo0000I_oonfX4o`0008[ooo]Z000^oookJPGo0000;_oonfX9o`000=?o
oo]Z1Ol00006oookJPCo0000IOoonfX7o`0008Sooo]Z000^oookJPGo0000;_oonfX:o`000=7ooo]Z
1Ol00007oookJPGo0000HooonfX9o`0008Oooo]Z000^oookJPGo0000;OoonfX5o`000003oookJ_l0
003o000000?o0000dOoonfX5o`0000Oooo]Z1Ol0001RoookJP_o0000Q_oonfX002kooo]Z1Ol0000]
oookJPGo00000_oonfX5o`000=3ooo]Z1?l00009oookJPCo0000HOoonfX<o`0008Kooo]Z000^oook
JPGo0000;?oonfX5o`0000?ooo]Z1Ol0001ToookJPCo0000IooonfX5o`0000Wooo]Z1Ol0001Poook
JPGo00000ooonfX5o`0008Gooo]Z000^oookJPGo0000;?oonfX5o`0000Cooo]Z1Ol0001QoookJPOo
0000I_oonfX5o`0000Wooo]Z1Ol0001OoookJPGo00001?oonfX5o`0008Gooo]Z000^oookJPGo0000
:ooonfX5o`0000Gooo]Z1Ol0001PoookJPWo0000IOoonfX4o`0000_ooo]Z1?l0001OoookJPGo0000
1OoonfX5o`0008Cooo]Z000^oookJPGo0000:ooonfX5o`0000Kooo]Z1?l0001OoookJP_o0000Hooo
nfX5o`0000_ooo]Z1?l0001NoookJPGo00001_oonfX5o`0008Cooo]Z000^oookJPGo0000:ooonfX4
o`0000Oooo]Z1Ol0001NoookJPco0000H_oonfX5o`0000_ooo]Z1Ol0001MoookJPGo00001ooonfX5
o`0008?ooo]Z000^oookJPGo0000:_oonfX5o`0000Oooo]Z1Ol0001MoookJPGo00000ooonfX5o`00
06;ooo]Z1?l0000<oookJPGo0000GOoonfX4o`0000Sooo]Z1Ol00023oookJP00;_oonfX5o`0002[o
oo]Z1Ol00008oookJPCo0000GOoonfX5o`0000Cooo]Z1Ol0001PoookJPGo00003OoonfX4o`0005co
oo]Z1Ol00009oookJPCo0000PooonfX002kooo]Z1Ol0000ZoookJPCo00002OoonfX5o`0005_ooo]Z
1Ol00005oookJPGo0000H?oonfX5o`0000gooo]Z1Ol0001KoookJPGo00002OoonfX5o`0008;ooo]Z
000^oookJPGo0000:_oonfX4o`0000Wooo]Z1Ol0001KoookJPGo00001_oonfX5o`0005oooo]Z1?l0
000>oookJPGo0000F_oonfX5o`0000[ooo]Z1Ol00022oookJP00;_oonfX5o`0002Wooo]Z1Ol0000:
oookJPCo0000F_oonfX5o`0000Oooo]Z1Ol0001OoookJPCo00003ooonfX4o`0005[ooo]Z1Ol0000;
oookJPCo0000P_oonfX002kooo]Z1Ol0000YoookJPGo00002_oonfX4o`0005[ooo]Z1Ol00008oook
JPGo0000GOoonfX5o`0000oooo]Z1?l0001JoookJPCo00003?oonfX5o`00087ooo]Z000^oookJPGo
0000:OoonfX4o`0000_ooo]Z1Ol0001HoookJPGo00002OoonfX5o`0005gooo]Z1?l0000@oookJPCo
0000FOoonfX5o`0000cooo]Z1Ol00021oookJP00;_oonfX5o`0002Wooo]Z1?l0000;oookJPGo0000
F?oonfX5o`0000[ooo]Z1Ol0001LoookJPCo00004?oonfX5o`0005Sooo]Z1Ol0000=oookJPCo0000
POoonfX002kooo]Z1Ol0000XoookJPGo00003?oonfX4o`0005Sooo]Z1?l0000;oookJPGo0000G?oo
nfX4o`00013ooo]Z1Ol0001HoookJPCo00003_oonfX5o`0006;ooo]Z0ol0000KoookJP00;_oonfX5
o`0002Sooo]Z1?l0000=oookJPCo0000EooonfX5o`0000cooo]Z1Ol0001JoookJPGo00004OoonfX4
o`0005Oooo]Z1Ol0000>oookJPGo0000HOoonfX5o`0001[ooo]Z000^oookJPGo0000:?oonfX4o`00
00gooo]Z1Ol0001FoookJPGo00003?oonfX5o`0005[ooo]Z1Ol0000AoookJPCo0000EooonfX5o`00
00oooo]Z1?l0001QoookJPGo00006_oonfX002kooo]Z1Ol0000XoookJPCo00003OoonfX5o`0005Ko
oo]Z1?l0000>oookJPCo0000F_oonfX4o`0001;ooo]Z1?l0001GoookJPCo00004?oonfX5o`0005oo
oo]Z1Ol0000KoookJP00;_oonfX5o`0002Oooo]Z1Ol0000>oookJPCo0000E_oonfX4o`0000kooo]Z
1Ol0001IoookJPCo00004_oonfX5o`0005Kooo]Z1?l0000@oookJPGo0000GooonfX5o`0001_ooo]Z
000^oookJPGo00009ooonfX5o`0000kooo]Z1?l0001EoookJPGo00003_oonfX5o`0005Wooo]Z1?l0
000BoookJPGo0000EOoonfX5o`00017ooo]Z1?l0001OoookJPCo00007?oonfX002kooo]Z1Ol0000W
oookJPCo00003ooonfX4o`0005Gooo]Z1Ol0000?oookJPCo0000F?oonfX5o`0001?ooo]Z1?l0001E
oookJPGo00004OoonfX4o`0005kooo]Z1Ol0000LoookJP00;_oonfX5o`0002Oooo]Z1?l0000?oook
JPGo0000E?oonfX4o`00013ooo]Z1?l0001HoookJPGo00004ooonfX4o`0005Gooo]Z1?l0000Boook
JPGo0000GOoonfX5o`0001cooo]Z000^oookJPGo00009_oonfX5o`0000oooo]Z1Ol0001DoookJPCo
00004?oonfX5o`0005Oooo]Z1?l0000DoookJPCo0000EOoonfX4o`0001?ooo]Z1?l0001MoookJPCo
00007OoonfX002kooo]Z1Ol0000VoookJPGo00004?oonfX4o`0005Cooo]Z1?l0000@oookJPGo0000
EooonfX4o`0001Cooo]Z1Ol0001CoookJPGo00004ooonfX4o`0005cooo]Z1Ol0000MoookJP00;_oo
nfX5o`0002Kooo]Z1?l0000AoookJPCo0000DooonfX5o`00017ooo]Z1?l0001GoookJPCo00005?oo
nfX5o`0005?ooo]Z1Ol0000CoookJPGo0000FooonfX5o`0001gooo]Z000^oookJPGo00009_oonfX4
o`00017ooo]Z1?l0001CoookJPCo00004_oonfX5o`0005Gooo]Z1Ol0000EoookJPCo0000DooonfX4
o`0001Cooo]Z1Ol0001KoookJPCo00007_oonfX002kooo]Z1Ol0000VoookJPCo00004OoonfX4o`00
05?ooo]Z1?l0000BoookJPGo0000EOoonfX5o`0001Gooo]Z1?l0001CoookJPCo00005OoonfX4o`00
05[ooo]Z1Ol0000NoookJP00;_oonfX5o`0002Kooo]Z1?l0000AoookJPGo0000D_oonfX4o`0001?o
oo]Z1?l0001EoookJPCo00005_oonfX4o`0005?ooo]Z1?l0000EoookJPCo0000F_oonfX5o`0001ko
oo]Z000^oookJPGo00009OoonfX5o`00017ooo]Z1Ol0001AoookJPGo00004ooonfX4o`0005Gooo]Z
1?l0000FoookJPGo0000DOoonfX5o`0001Gooo]Z1Ol0001IoookJPCo00007ooonfX002kooo]Z1Ol0
000UoookJPCo00004ooonfX4o`00057ooo]Z1Ol0000CoookJPCo0000EOoonfX4o`0001Kooo]Z1Ol0
001AoookJPGo00005OoonfX5o`0005Wooo]Z1?l0000OoookJP00;_oonfX5o`0002Gooo]Z1?l0000C
oookJPCo0000DOoonfX4o`0001Cooo]Z1Ol0001DoookJPCo00005ooonfX4o`00057ooo]Z1?l0000G
oookJPCo0000F?oonfX5o`0001oooo]Z000^oookJPGo00009OoonfX4o`0001?ooo]Z1?l0001Aoook
JPCo00005OoonfX4o`0005?ooo]Z1Ol0000GoookJPCo0000DOoonfX4o`0001Oooo]Z1?l0001Hoook
JPGo00007ooonfX002kooo]Z1Ol0000UoookJPCo00004ooonfX5o`00053ooo]Z1?l0000EoookJPCo
0000DooonfX5o`0001Oooo]Z1?l0001AoookJPCo00005ooonfX5o`0005Oooo]Z1?l0000PoookJP00
;_oonfX5o`0002Cooo]Z1Ol0000CoookJPGo0000CooonfX5o`0001Gooo]Z1?l0001CoookJPCo0000
6?oonfX4o`00053ooo]Z1Ol0000GoookJPGo0000EooonfX4o`00023ooo]Z000^oookJPGo00009?oo
nfX5o`0001Cooo]Z1?l0001?oookJPGo00005OoonfX5o`0005;ooo]Z1?l0000HoookJPGo0000Cooo
nfX5o`0001Sooo]Z1?l0001GoookJPCo00008?oonfX002kooo]Z1Ol0000ToookJPCo00005OoonfX4
o`0004oooo]Z1?l0000FoookJPGo0000D_oonfX4o`0001Sooo]Z1Ol0001?oookJPCo00006OoonfX4
o`0005Kooo]Z1Ol0000PoookJP00;_oonfX5o`0002Cooo]Z1?l0000EoookJPCo0000CooonfX4o`00
01Oooo]Z1?l0001BoookJPCo00006OoonfX4o`0004oooo]Z1?l0000IoookJPGo0000EOoonfX5o`00
023ooo]Z000^oookJPGo00009?oonfX4o`0001Gooo]Z1?l0001?oookJPCo00005ooonfX4o`00057o
oo]Z1Ol0000IoookJPCo0000CooonfX4o`0001Wooo]Z1Ol0001EoookJPCo00008OoonfX002kooo]Z
1Ol0000ToookJPCo00005OoonfX5o`0004gooo]Z1Ol0000GoookJPGo0000D?oonfX5o`0001Wooo]Z
1?l0001?oookJPCo00006_oonfX4o`0005Gooo]Z1?l0000QoookJP00;_oonfX5o`0002Cooo]Z1?l0
000EoookJPGo0000COoonfX5o`0001Oooo]Z1Ol0001@oookJPCo00006_oonfX4o`0004kooo]Z1Ol0
000JoookJPCo0000E?oonfX5o`00027ooo]Z000^oookJPGo00008ooonfX5o`0001Kooo]Z1?l0001=
oookJPCo00006OoonfX4o`00053ooo]Z1?l0000JoookJPGo0000COoonfX5o`0001[ooo]Z1?l0001D
oookJPGo00008OoonfX002kooo]Z1Ol0000SoookJPGo00005_oonfX4o`0004gooo]Z1?l0000Ioook
JPCo0000D?oonfX4o`0001[ooo]Z1Ol0001=oookJPCo00006ooonfX5o`0005?ooo]Z1?l0000Roook
JP00;_oonfX5o`0002?ooo]Z1?l0000GoookJPCo0000COoonfX4o`0001Wooo]Z1?l0001@oookJPCo
00006ooonfX4o`0004gooo]Z1?l0000KoookJPGo0000DooonfX4o`0002;ooo]Z000^oookJPGo0000
8ooonfX4o`0001Oooo]Z1?l0001<oookJPGo00006OoonfX5o`0004oooo]Z1?l0000KoookJPCo0000
COoonfX4o`0001cooo]Z1?l0001CoookJPCo00008_oonfX002kooo]Z1Ol0000SoookJPCo00005ooo
nfX5o`0004_ooo]Z1Ol0000IoookJPGo0000C_oonfX5o`0001_ooo]Z1?l0001=oookJPCo00007?oo
nfX4o`0005;ooo]Z1Ol0000RoookJP00;_oonfX5o`0002?ooo]Z1?l0000GoookJPGo0000BooonfX4
o`0001_ooo]Z1?l0001>oookJPGo00006ooonfX4o`0004cooo]Z1Ol0000LoookJPCo0000D_oonfX5
o`0002;ooo]Z000^oookJPGo00008ooonfX4o`0001Sooo]Z1?l0001;oookJPCo00006ooonfX4o`00
04kooo]Z1?l0000LoookJPCo0000C?oonfX5o`0001cooo]Z1?l0001BoookJPCo00008ooonfX002ko
oo]Z1Ol0000RoookJPGo00006?oonfX4o`0004_ooo]Z1?l0000KoookJPCo0000C_oonfX4o`0001co
oo]Z1Ol0001;oookJPCo00007OoonfX5o`00057ooo]Z1?l0000SoookJP00;_oonfX5o`0002;ooo]Z
1?l0000IoookJPCo0000BooonfX4o`0001_ooo]Z1Ol0001=oookJPCo00007OoonfX4o`0004_ooo]Z
1?l0000NoookJPCo0000DOoonfX4o`0002?ooo]Z000^oookJPGo00008_oonfX4o`0001Wooo]Z1?l0
001:oookJPGo00006ooonfX5o`0004gooo]Z1?l0000MoookJPCo0000BooonfX4o`0001kooo]Z1?l0
001@oookJPGo00008ooonfX002kooo]Z1Ol0000RoookJPCo00006OoonfX5o`0004Wooo]Z1Ol0000L
oookJPCo0000C?oonfX5o`0001gooo]Z1?l0001;oookJPCo00007_oonfX4o`00053ooo]Z1Ol0000S
oookJP00;_oonfX5o`0002;ooo]Z1?l0000IoookJPGo0000BOoonfX4o`0001gooo]Z1?l0001<oook
JPGo00007OoonfX4o`0004[ooo]Z1Ol0000NoookJPCo0000D?oonfX4o`0002Cooo]Z000^oookJPGo
00008_oonfX4o`0001[ooo]Z1?l00019oookJPCo00007OoonfX4o`0004cooo]Z1?l0000NoookJPCo
0000B_oonfX5o`0001kooo]Z1Ol0001?oookJPCo00009?oonfX002kooo]Z1Ol0000RoookJPCo0000
6_oonfX4o`0004Wooo]Z1?l0000MoookJPCo0000C?oonfX4o`0001kooo]Z1Ol00019oookJPCo0000
7ooonfX5o`0004oooo]Z1?l0000ToookJP00;_oonfX5o`00027ooo]Z1Ol0000JoookJPCo0000BOoo
nfX4o`0001gooo]Z1Ol0001;oookJPCo00007_oonfX5o`0004Wooo]Z1?l0000PoookJPCo0000C_oo
nfX5o`0002Cooo]Z000^oookJPGo00008OoonfX5o`0001[ooo]Z1?l00018oookJPGo00007OoonfX5
o`0004_ooo]Z1?l0000OoookJPCo0000BOoonfX4o`00023ooo]Z1?l0001>oookJPGo00009?oonfX0
02kooo]Z1Ol0000QoookJPCo00006ooonfX4o`0004Sooo]Z1Ol0000NoookJPCo0000BooonfX4o`00
01oooo]Z1?l00019oookJPCo00008?oonfX4o`0004kooo]Z1?l0000UoookJP00;_oonfX5o`00027o
oo]Z1?l0000KoookJPGo0000AooonfX4o`0001oooo]Z1?l0001;oookJPCo00007ooonfX4o`0004So
oo]Z1Ol0000PoookJPCo0000C_oonfX4o`0002Gooo]Z000^oookJPGo00008OoonfX4o`0001_ooo]Z
1Ol00017oookJPCo00007ooonfX4o`0004[ooo]Z1Ol0000OoookJPCo0000B?oonfX5o`00023ooo]Z
1Ol0001=oookJPCo00009OoonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0
000QoookJPCo00007?oonfX4o`0004Oooo]Z1?l0000OoookJPCo0000B_oonfX5o`0001oooo]Z1?l0
0018oookJPCo00008OoonfX5o`0004gooo]Z1?l0000UoookJP004?oonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001o2?oonfX5o`00027ooo]Z1?l0000LoookJPCo0000AooonfX4o`0001oooo]Z1Ol00019
oookJPCo00008?oonfX5o`0004Oooo]Z1?l0000RoookJPCo0000C?oonfX5o`0002Gooo]Z000@oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2?oonfX5o`00023ooo]Z1Ol0000LoookJPCo0000A_oonfX5o`0001oooo]Z1Ol0
0019oookJPCo00008?oonfX5o`0004Oooo]Z1?l0000RoookJPCo0000C?oonfX5o`0002Gooo]Z0003
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000P
oookJPGo00007?oonfX4o`0004Kooo]Z1Ol0000PoookJPCo0000BOoonfX4o`00027ooo]Z1?l00017
oookJPCo00008_oonfX4o`0004cooo]Z1?l0000VoookJP000ooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1_l0000OoookJPCo00007OoonfX4o`0004Kooo]Z1?l0000Qoook
JPCo0000BOoonfX4o`00027ooo]Z1?l00017oookJPCo00008_oonfX4o`0004cooo]Z1?l0000Voook
JP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`00023ooo]Z1?l0000MoookJPGo
0000AOoonfX4o`00027ooo]Z1?l00019oookJPCo00008OoonfX4o`0004Kooo]Z1Ol0000RoookJPGo
0000BooonfX4o`0002Kooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
1ooonfX5o`00023ooo]Z1?l0000MoookJPGo0000AOoonfX4o`00027ooo]Z1?l00018oookJPGo0000
8OoonfX4o`0004Kooo]Z1?l0000SoookJPGo0000B_oonfX5o`0002Kooo]Z000?oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l8oookJPGo00008?oonfX4o`0001kooo]Z1?l00015oookJPCo00008Ooo
nfX5o`0004Oooo]Z1Ol0000QoookJPCo0000A_oonfX4o`0002Cooo]Z1?l0001:oookJPGo00009_oo
nfX000oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Wooo]Z1Ol0000PoookJPCo00007_oonfX4
o`0004Gooo]Z1?l0000QoookJPGo0000AooonfX4o`0002;ooo]Z1?l00016oookJPCo00009?oonfX4
o`0004[ooo]Z1?l0000WoookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`00
023ooo]Z1?l0000NoookJPCo0000A?oonfX5o`0002;ooo]Z1?l00017oookJPCo00008_oonfX5o`00
04Gooo]Z1?l0000ToookJPCo0000B_oonfX4o`0002Oooo]Z000@oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX2o`00O`gooo]Z1Ol0000OoookJPGo00007_oonfX4o`0004Cooo]Z1Ol0000Roook
JPCo0000AooonfX4o`0002;ooo]Z1Ol00015oookJPCo00009?oonfX4o`0004[ooo]Z1?l0000Woook
JP004?oonfX7o`00O`Wooo]Z1ol007l7oookJPGo00007ooonfX4o`0001oooo]Z1?l00014oookJPCo
00008ooonfX4o`0004Oooo]Z1?l0000SoookJPCo0000AOoonfX4o`0002Cooo]Z1Ol00019oookJPCo
00009ooonfX0017ooo]Z1Ol007l:oookJPOo001o1ooonfX5o`0001oooo]Z1?l0000OoookJPCo0000
A?oonfX4o`0002?ooo]Z1?l00017oookJPCo00008ooonfX4o`0004Cooo]Z1Ol0000ToookJPGo0000
B?oonfX5o`0002Oooo]Z000^oookJPGo00007ooonfX4o`0001oooo]Z1Ol00013oookJPCo00008ooo
nfX4o`0004Oooo]Z1?l0000SoookJPCo0000A?oonfX4o`0002Kooo]Z1?l00018oookJPGo00009ooo
nfX002kooo]Z1Ol0000OoookJPCo00008?oonfX4o`0004?ooo]Z1?l0000SoookJPGo0000AOoonfX5
o`0002?ooo]Z1?l00014oookJPCo00009_oonfX4o`0004Sooo]Z1?l0000XoookJP00;_oonfX5o`00
01oooo]Z1?l0000PoookJPCo0000@ooonfX4o`0002Cooo]Z1?l00015oookJPGo00008ooonfX4o`00
04Cooo]Z1?l0000VoookJPCo0000B?oonfX4o`0002Sooo]Z000^oookJPGo00007ooonfX4o`00023o
oo]Z1?l00012oookJPGo00009?oonfX4o`0004Gooo]Z1?l0000ToookJPCo0000A?oonfX4o`0002Ko
oo]Z1?l00018oookJPCo0000:?oonfX002kooo]Z1Ol0000NoookJPGo00008?oonfX4o`0004;ooo]Z
1Ol0000ToookJPCo0000AOoonfX4o`0002Cooo]Z1Ol00013oookJPCo00009_oonfX5o`0004Oooo]Z
1?l0000XoookJP00;_oonfX5o`0001kooo]Z1Ol0000PoookJPCo0000@_oonfX4o`0002Gooo]Z1?l0
0015oookJPCo00009?oonfX5o`0004?ooo]Z1?l0000VoookJPGo0000A_oonfX5o`0002Sooo]Z000^
oookJPGo00007_oonfX4o`00027ooo]Z1?l00012oookJPCo00009OoonfX4o`0004Gooo]Z1?l0000U
oookJPCo0000@_oonfX5o`0002Oooo]Z1?l00016oookJPGo0000:?oonfX002kooo]Z1Ol0000Noook
JPCo00008OoonfX5o`00047ooo]Z1?l0000UoookJPCo0000AOoonfX4o`0002Gooo]Z1?l00012oook
JPGo00009ooonfX4o`0004Kooo]Z1?l0000YoookJP00;_oonfX5o`0001kooo]Z1?l0000QoookJPGo
0000@OoonfX4o`0002Gooo]Z1Ol00014oookJPCo00009OoonfX4o`0004;ooo]Z1?l0000XoookJPCo
0000A_oonfX4o`0002Wooo]Z000^oookJPGo00007_oonfX4o`0002;ooo]Z1?l00011oookJPCo0000
9_oonfX4o`0004?ooo]Z1Ol0000UoookJPCo0000@_oonfX4o`0002Sooo]Z1?l00016oookJPCo0000
:OoonfX002kooo]Z1Ol0000NoookJPCo00008_oonfX4o`00043ooo]Z1Ol0000VoookJPCo0000@ooo
nfX5o`0002Gooo]Z1?l00012oookJPCo0000:?oonfX5o`0004Gooo]Z1?l0000YoookJP00;_oonfX5
o`0001kooo]Z1?l0000RoookJPCo0000@?oonfX5o`0002Kooo]Z1?l00013oookJPCo00009_oonfX4
o`0004;ooo]Z1?l0000XoookJPGo0000A?oonfX5o`0002Wooo]Z000^oookJPGo00007_oonfX4o`00
02;ooo]Z1?l00010oookJPCo00009ooonfX4o`0004?ooo]Z1?l0000VoookJPCo0000@_oonfX4o`00
02Wooo]Z1?l00014oookJPCo0000:_oonfX002kooo]Z1Ol0000MoookJPGo00008_oonfX4o`00043o
oo]Z1?l0000WoookJPCo0000@ooonfX4o`0002Kooo]Z1Ol00011oookJPCo0000:OoonfX4o`0004Co
oo]Z1?l0000ZoookJP00;_oonfX5o`0001gooo]Z1?l0000SoookJPCo0000@?oonfX4o`0002Oooo]Z
1?l00013oookJPCo00009_oonfX5o`00043ooo]Z1Ol0000YoookJPCo0000A?oonfX4o`0002[ooo]Z
000^oookJPGo00007OoonfX4o`0002?ooo]Z1Ol0000ooookJPCo00009ooonfX5o`0004;ooo]Z1?l0
000WoookJPCo0000@?oonfX5o`0002Wooo]Z1?l00014oookJPCo0000:_oonfX002kooo]Z1Ol0000M
oookJPCo00008ooonfX5o`0003oooo]Z1?l0000WoookJPGo0000@_oonfX4o`0002Oooo]Z1?l00010
oookJPCo0000:_oonfX4o`0004Cooo]Z1?l0000ZoookJP00;_oonfX5o`0001gooo]Z1?l0000Toook
JPCo0000?_oonfX5o`0002Sooo]Z1?l00011oookJPGo00009ooonfX4o`00043ooo]Z1?l0000Zoook
JPGo0000@_oonfX5o`0002[ooo]Z000^oookJPGo00007OoonfX4o`0002Cooo]Z1?l0000noookJPGo
0000:?oonfX4o`00047ooo]Z1Ol0000WoookJPCo0000@?oonfX4o`0002[ooo]Z1Ol00012oookJPCo
0000:ooonfX002kooo]Z1Ol0000MoookJPCo00009?oonfX4o`0003kooo]Z1?l0000YoookJPCo0000
@OoonfX4o`0002Sooo]Z1?l00010oookJPCo0000:ooonfX4o`0004;ooo]Z1?l0000[oookJP00;_oo
nfX5o`0001gooo]Z1?l0000ToookJPCo0000?_oonfX4o`0002Wooo]Z1?l00011oookJPCo0000:?oo
nfX4o`00043ooo]Z1?l0000[oookJPCo0000@_oonfX4o`0002_ooo]Z000^oookJPGo00007?oonfX5
o`0002Cooo]Z1?l0000noookJPCo0000:OoonfX4o`00047ooo]Z1?l0000XoookJPGo0000?_oonfX5
o`0002_ooo]Z1?l00012oookJPCo0000:ooonfX002kooo]Z1Ol0000LoookJPGo00009?oonfX4o`00
03kooo]Z1?l0000YoookJPGo0000@?oonfX4o`0002Sooo]Z1Ol0000noookJPGo0000:ooonfX4o`00
047ooo]Z1Ol0000[oookJP00;_oonfX5o`0001cooo]Z1?l0000UoookJPGo0000?OoonfX4o`0002Wo
oo]Z1Ol00010oookJPCo0000:OoonfX4o`0003kooo]Z1?l0000/oookJPCo0000@OoonfX5o`0002_o
oo]Z000^oookJPGo00007?oonfX4o`0002Gooo]Z1Ol0000moookJPCo0000:_oonfX4o`00043ooo]Z
1?l0000YoookJPCo0000?_oonfX4o`0002cooo]Z1Ol00010oookJPCo0000;?oonfX002kooo]Z1Ol0
000LoookJPCo00009_oonfX4o`0003cooo]Z1Ol0000ZoookJPCo0000?ooonfX5o`0002Wooo]Z1?l0
000noookJPCo0000;?oonfX5o`00043ooo]Z1?l0000/oookJP00;_oonfX5o`0001cooo]Z1?l0000V
oookJPCo0000??oonfX5o`0002[ooo]Z1?l0000ooookJPGo0000:OoonfX4o`0003kooo]Z1?l0000]
oookJPCo0000@?oonfX4o`0002cooo]Z000^oookJPGo00007?oonfX4o`0002Kooo]Z1?l0000loook
JPCo0000:ooonfX4o`0003oooo]Z1?l0000ZoookJPCo0000?_oonfX4o`0002gooo]Z1?l00010oook
JPCo0000;?oonfX002kooo]Z1Ol0000LoookJPCo00009_oonfX4o`0003cooo]Z1?l0000[oookJPCo
0000?ooonfX4o`0002[ooo]Z1?l0000noookJPCo0000;OoonfX4o`0003oooo]Z1Ol0000/oookJP00
;_oonfX5o`0001cooo]Z1?l0000VoookJPCo0000??oonfX4o`0002_ooo]Z1Ol0000noookJPCo0000
:_oonfX4o`0003gooo]Z1Ol0000]oookJPCo0000?ooonfX5o`0002cooo]Z000^oookJPGo00006ooo
nfX5o`0002Kooo]Z1?l0000loookJPCo0000:ooonfX5o`0003kooo]Z1?l0000ZoookJPGo0000??oo
nfX5o`0002gooo]Z1?l0000ooookJPCo0000;OoonfX002kooo]Z1Ol0000KoookJPGo00009_oonfX5
o`0003_ooo]Z1?l0000/oookJPCo0000?_oonfX4o`0002[ooo]Z1Ol0000loookJPCo0000;_oonfX5
o`0003kooo]Z1?l0000]oookJP00;_oonfX5o`0001_ooo]Z1?l0000WoookJPGo0000>ooonfX4o`00
02cooo]Z1?l0000noookJPCo0000:ooonfX4o`0003cooo]Z1?l0000^oookJPGo0000?_oonfX4o`00
02gooo]Z000^oookJPGo00006ooonfX4o`0002Sooo]Z1?l0000joookJPGo0000;?oonfX4o`0003go
oo]Z1Ol0000[oookJPCo0000??oonfX4o`0002oooo]Z1?l0000noookJPCo0000;OoonfX002kooo]Z
1Ol0000KoookJPCo0000:?oonfX4o`0003[ooo]Z1Ol0000/oookJPCo0000?OoonfX5o`0002_ooo]Z
1?l0000loookJPCo0000;ooonfX4o`0003gooo]Z1Ol0000]oookJP00;_oonfX5o`0001_ooo]Z1?l0
000XoookJPCo0000>_oonfX4o`0002gooo]Z1?l0000moookJPCo0000;?oonfX4o`0003cooo]Z1?l0
000_oookJPCo0000?OoonfX5o`0002gooo]Z000^oookJPGo00006ooonfX4o`0002Sooo]Z1?l0000j
oookJPCo0000;OoonfX5o`0003cooo]Z1?l0000/oookJPCo0000??oonfX4o`0002oooo]Z1?l0000m
oookJPCo0000;_oonfX002kooo]Z1Ol0000KoookJPCo0000:?oonfX4o`0003[ooo]Z1?l0000]oook
JPGo0000??oonfX4o`0002cooo]Z1?l0000koookJPGo0000;ooonfX4o`0003gooo]Z1?l0000^oook
JP00;_oonfX5o`0001_ooo]Z1?l0000XoookJPCo0000>_oonfX4o`0002kooo]Z1?l0000loookJPCo
0000;?oonfX4o`0003_ooo]Z1?l0000`oookJPGo0000??oonfX4o`0002kooo]Z000^oookJPGo0000
6_oonfX5o`0002Sooo]Z1Ol0000ioookJPCo0000;_oonfX4o`0003cooo]Z1?l0000/oookJPCo0000
>ooonfX4o`00033ooo]Z1Ol0000loookJPCo0000;_oonfX002kooo]Z1Ol0000JoookJPCo0000:Ooo
nfX5o`0003Wooo]Z1?l0000^oookJPCo0000??oonfX4o`0002cooo]Z1Ol0000joookJPCo0000<Ooo
nfX4o`0003_ooo]Z1Ol0000^oookJP00;_oonfX5o`0001[ooo]Z1?l0000ZoookJPCo0000>OoonfX4
o`0002kooo]Z1?l0000loookJPCo0000;?oonfX5o`0003[ooo]Z1?l0000aoookJPCo0000>ooonfX5
o`0002kooo]Z000^oookJPGo00006_oonfX4o`0002[ooo]Z1?l0000hoookJPGo0000;_oonfX4o`00
03_ooo]Z1Ol0000]oookJPCo0000>_oonfX4o`00037ooo]Z1?l0000koookJPCo0000;ooonfX002ko
oo]Z1Ol0000JoookJPCo0000:_oonfX4o`0003Sooo]Z1?l0000_oookJPCo0000>ooonfX5o`0002go
oo]Z1?l0000joookJPCo0000<OoonfX4o`0003_ooo]Z1?l0000_oookJP00;_oonfX5o`0001[ooo]Z
1?l0000ZoookJPCo0000>?oonfX4o`0002oooo]Z1Ol0000joookJPCo0000;_oonfX4o`0003Wooo]Z
1Ol0000aoookJPCo0000>ooonfX4o`0002oooo]Z000^oookJPGo00006_oonfX4o`0002[ooo]Z1?l0
000hoookJPCo0000;ooonfX5o`0003[ooo]Z1?l0000^oookJPCo0000>OoonfX5o`00037ooo]Z1?l0
000koookJPCo0000;ooonfX002kooo]Z1Ol0000JoookJPCo0000:_oonfX4o`0003Sooo]Z1?l0000`
oookJPCo0000>_oonfX4o`0002kooo]Z1?l0000ioookJPCo0000<_oonfX5o`0003Wooo]Z1Ol0000_
oookJP00;_oonfX5o`0001[ooo]Z1?l0000ZoookJPCo0000>?oonfX4o`00033ooo]Z1?l0000joook
JPCo0000;_oonfX4o`0003Wooo]Z1?l0000coookJPCo0000>OoonfX5o`0002oooo]Z000^oookJPGo
00006OoonfX5o`0002[ooo]Z1Ol0000goookJPCo0000<?oonfX4o`0003[ooo]Z1?l0000^oookJPCo
0000>OoonfX4o`0003?ooo]Z1?l0000ioookJPCo0000<?oonfX002kooo]Z1Ol0000IoookJPCo0000
;?oonfX4o`0001_ooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`?ooo]Z1?l00003o`00Obgooo]Z
1?l0000VoookJP?o001o1OoonfX5o`00O`Gooo]Z0_l007l4o`0000Cooo]Z1Ol007l5oookJPGo001o
6ooonfX5o`0003;ooo]Z0ol007l3oookJPCo00000ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z
1Ol007lBoookJPCo0000=ooonfX2o`00O`Co00000ol007l3oookJPGo001o1OoonfX5o`00O`Gooo]Z
1Ol007l5oookJPGo001o1ooonfX002kooo]Z1Ol0000IoookJPCo0000;?oonfX4o`0001[ooo]Z1ol0
07l3oookJPOo001o0ooonfX7o`00O`03oookJ_l0003o000000?o00001?l007l/oookJPCo00009_oo
nfX3o`00O`Cooo]Z1ol007l3oookJP?o001o1?l00003oookJPOo001o0ooonfX7o`00Oa[ooo]Z1Ol0
000boookJP?o001o0ooonfX4o`0000Co001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o4Ooo
nfX4o`0003Oooo]Z0_l007l4o`0000?o001o0_oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooo
nfX7o`00O`Kooo]Z000^oookJPGo00006OoonfX4o`0002cooo]Z1?l0000IoookJPCo001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01Ooonf[o001o
o`00Ool007oooo]Z00Go000000Cooo]Zo`00Ool007oo001o;?oonfX5o`0002Gooo]Z0ol007l4oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`Go00000ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJPCo0000<_oonfX3o`00O`?ooo]Z
1?l000001?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lAoookJPCo0000=ooo
nfX2o`00O`Co00001OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Kooo]Z000^oookJPGo00006OoonfX4o`0002cooo]Z1?l0000IoookJP?o001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1?l0
0003oookJP?o001o:ooonfX5o`0002Gooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Co00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00Oa[ooo]Z1?l0000boookJP?o001o0ooonfX4o`0000;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l@oookJPCo0000>?oonfX5o`0000Cooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0000IoookJPCo0000;?oonfX4o`00
01oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Co00000ooonfX3o`00Obcooo]Z1?l0000UoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l4o`0000;o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007lJoookJPCo0000<_oonfX3o`00O`;ooo]Z1Ol00002oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o4?oonfX5o`0003Oooo]Z1Ol000001?l007oooo]Z
oookJ_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5
o`0001Wooo]Z1?l0000/oookJPCo00007ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1?l00003oookJP?o001o;?oonfX4o`0002Gooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Co00000_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oa[ooo]Z1?l0000b
oookJP?o001o0_oonfX4o`0000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l@oookJPGo
0000=ooonfX4o`0000?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP00;_oonfX5o`0001Wooo]Z1?l0000/oookJPCo00006_oonfX2o`00O`;ooo]Z1?l007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Co0000
0ooonfX3o`00Obcooo]Z1?l0000UoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l4o`0000;o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007lJoookJPCo0000<_oonfX3o`00O`;ooo]Z1?l00002oookJPCo001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o4OoonfX4o`0003Oooo]Z1?l00003o`00O`;ooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0000IoookJPCo0000;?oonfX5
o`0001Wooo]Z1ol007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l4o`0000?ooo]Z0ol007l/oookJPCo00009OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o1?l00002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o6_oonfX4o`0003;ooo]Z0ol007l2oookJPCo00001Ol007l2oook
JP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o4OoonfX4o`0003Oooo]Z1?l000001Ooonf[o001oo`00Ool007oooo]Z00?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo00006?oonfX5o`00
02cooo]Z1Ol0000IoookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1?l00003oookJP?o001o;?oonfX4o`0002Gooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Co00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oa[ooo]Z1?l0000boookJP?o001o0_oonfX4o`0000Co
001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00Oa7ooo]Z1?l0000foookJP03o`00Ool0003o000000;o000000Gooo]Z
o`00Ool007oo001ooookJP03o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oook
JP00;_oonfX5o`0001Sooo]Z1Ol0000]oookJPCo00006OoonfX2o`00O`Oooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Co00000ooonfX3o`00Obcooo]Z1?l0000Roook
JPKo001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4o`0000;o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lJoookJPCo0000
;ooonfX6o`00O`;ooo]Z1?l00007oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o4OoonfX4o`0003Kooo]Z00?o001oo`00
0?l000000_l000001Ooonf[o001oo`00Ool007oooo]Z00?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z000^oookJPGo00006?oonfX4o`0002kooo]Z1?l0000IoookJP;o001o
2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l5o`00
0003o`00Oooonf[o001o00;o001o;OoonfX5o`00027ooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX2o`00O`Co000000Co001ooookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o6ooonfX5o`0002kooo]Z1_l007l2oookJPCo
00002?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o4_oonfX4o`0003Kooo]Z1Ol000001?oonf[o001oo`00
Ool007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oo
nfX002kooo]Z1Ol0000HoookJPCo0000;_oonfX4o`0001[ooo]Z1ol007l2oookJPOo001o0ooonfX7
o`00O`Co00001_l007l]oookJPGo00008ooonfX4o`00O`Cooo]Z1ol007l3oookJP03o`00Ool0003o
000000?o000000Co001ooookJ_oonf[ooo]Z1ol007l3oookJPOo001o6ooonfX5o`00033ooo]Z1?l0
07l2oookJPCo00001_l007l2oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007lBoookJPCo0000=_oo
nfX4o`0000Co001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`Kooo]Z000^
oookJPGo00006?oonfX4o`0002kooo]Z1?l0000JoookJPOo001o0ooonfX5o`00O`Gooo]Z1Ol007l0
0ooonf[o0000o`000002o`0000Go001o;ooonfX4o`0002Cooo]Z0ol007l5oookJPGo001o1OoonfX4
o`000003o`00Oooonf[ooo]Z00?ooo]Z1Ol007l5oookJPGo001o7OoonfX4o`00037ooo]Z0ol007l0
0ooonf[o0000o`000003o`0000Ko001o0ooonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o4ooonfX5
o`0003Gooo]Z1?l00003o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l7
oookJP00;_oonfX5o`0001Sooo]Z1?l0000^oookJPCo0000=?oonfX4o`0003Cooo]Z1?l0000foook
JPCo0000<_oonfX4o`0003Gooo]Z1Ol0000foookJPCo0000=OoonfX4o`0003;ooo]Z000^oookJPGo
00006?oonfX4o`0002kooo]Z1?l0000doookJPCo0000=?oonfX4o`0003Kooo]Z1?l0000boookJPCo
0000=OoonfX4o`0003Oooo]Z1?l0000eoookJPCo0000<_oonfX002kooo]Z1Ol0000HoookJPCo0000
;_oonfX4o`0003Cooo]Z1?l0000doookJPCo0000=_oonfX4o`0003;ooo]Z1?l0000eoookJPCo0000
=ooonfX4o`0003Gooo]Z1?l0000boookJP00;_oonfX5o`0001Sooo]Z1?l0000^oookJPGo0000<ooo
nfX4o`0003Cooo]Z1?l0000foookJPCo0000<_oonfX4o`0003Gooo]Z1?l0000goookJPCo0000=?oo
nfX5o`0003;ooo]Z000^oookJPGo00005ooonfX5o`0002oooo]Z1?l0000coookJPCo0000=?oonfX4
o`0003Kooo]Z1?l0000boookJPCo0000=OoonfX4o`0003Oooo]Z1?l0000doookJPGo0000<_oonfX0
02kooo]Z1Ol0000GoookJPGo0000;ooonfX4o`0003;ooo]Z1Ol0000doookJPGo0000=OoonfX4o`00
03;ooo]Z1?l0000eoookJPCo0000=ooonfX4o`0003Cooo]Z1?l0000coookJP008_oonf[oo`000?oo
00004ol0000=oookJP008_oonf[oo`000?oo00004ol0000=oookJP008_oonf[oo`000?oo00004ol0
000=oookJP008_oonf[oo`000?oo00004ol0000=oookJP008_oonf[oo`000?oo00004ol0000=oook
JP00;_oonfX5o`0001Oooo]Z1?l0000`oookJPCo0000:ooonfX00ol0003ooo]ZoookJP04oookJPCo
0000=_oonfX4o`0003Cooo]Z1Ol0000coookJPCo0000<ooonfX4o`0000kooo]Z00?o0000oookJ_oo
nfX0:?oonfX4o`0003;ooo]Z1Ol0000FoookJP03o`000?oonf[ooo]Z01[ooo]Z000^oookJPGo0000
5ooonfX4o`00033ooo]Z1Ol0000aoookJPCo0000=_oonfX4o`0003Cooo]Z1?l0000doookJPCo0000
<ooonfX4o`0003Wooo]Z1?l0000boookJPCo0000=?oonfX002kooo]Z1Ol0000GoookJPCo0000<?oo
nfX5o`00037ooo]Z1?l0000foookJPGo0000<ooonfX4o`0003Cooo]Z1?l0000coookJPCo0000>Ooo
nfX4o`0003;ooo]Z1?l0000doookJP00;_oonfX5o`0001Kooo]Z1Ol0000aoookJPCo0000<?oonfX5
o`0003Kooo]Z1Ol0000coookJPCo0000=?oonfX4o`0003?ooo]Z1?l0000ioookJPGo0000<OoonfX4
o`0003Cooo]Z000^oookJPGo00005_oonfX4o`0003;ooo]Z1?l0000`oookJPGo0000=ooonfX4o`00
03;ooo]Z1Ol0000doookJPCo0000<ooonfX4o`0003Wooo]Z1Ol0000aoookJPCo0000=?oonfX002ko
oo]Z1Ol0000FoookJPCo0000<_oonfX4o`00033ooo]Z1?l0000hoookJPCo0000<_oonfX5o`0003Co
oo]Z1Ol0000aoookJPGo0000>_oonfX4o`00037ooo]Z1?l0000doookJP00;_oonfX5o`0001Kooo]Z
1?l0000boookJPCo0000<?oonfX4o`0003Sooo]Z1?l0000boookJPCo0000=OoonfX5o`00037ooo]Z
1Ol0000joookJPCo0000<?oonfX5o`0003Cooo]Z000^oookJPGo00005_oonfX4o`0003;ooo]Z1?l0
000`oookJPCo0000>?oonfX4o`0003;ooo]Z1?l0000foookJPCo0000<OoonfX4o`0003_ooo]Z1?l0
000`oookJPGo0000=?oonfX002kooo]Z1Ol0000FoookJPCo0000<_oonfX4o`00033ooo]Z1?l0000h
oookJPCo0000<_oonfX4o`0003Kooo]Z1?l0000aoookJPCo0000>ooonfX4o`00033ooo]Z1?l0000e
oookJP00;_oonfX5o`0001Kooo]Z1?l0000boookJPCo0000<?oonfX4o`0003Sooo]Z1?l0000boook
JPCo0000=_oonfX4o`00037ooo]Z1?l0000koookJPCo0000<?oonfX4o`0003Gooo]Z000^oookJPGo
00005_oonfX4o`0003;ooo]Z1Ol0000_oookJPCo0000>?oonfX5o`00037ooo]Z1?l0000foookJPCo
0000<OoonfX4o`0003_ooo]Z1?l0000`oookJPCo0000=OoonfX002kooo]Z1Ol0000FoookJPCo0000
<_oonfX5o`0002oooo]Z1?l0000hoookJPGo0000<OoonfX4o`0003Kooo]Z1?l0000aoookJPCo0000
>ooonfX5o`0002oooo]Z1?l0000eoookJP00;_oonfX5o`0001Gooo]Z1Ol0000coookJPCo0000;_oo
nfX5o`0003Wooo]Z1?l0000aoookJPCo0000=_oonfX4o`00037ooo]Z1?l0000loookJPCo0000;ooo
nfX4o`0003Gooo]Z000^oookJPGo00005OoonfX4o`0003Cooo]Z1?l0000^oookJPGo0000>OoonfX4
o`00033ooo]Z1Ol0000foookJPCo0000<OoonfX4o`0003cooo]Z1?l0000^oookJPGo0000=OoonfX0
02kooo]Z1Ol0000EoookJPCo0000=?oonfX4o`0002kooo]Z1?l0000joookJPCo0000<?oonfX5o`00
03Kooo]Z1Ol0000_oookJPGo0000??oonfX4o`0002kooo]Z1?l0000foookJP00;_oonfX5o`0001Go
oo]Z1?l0000doookJPCo0000;_oonfX4o`0003[ooo]Z1?l0000`oookJPCo0000=ooonfX5o`0002oo
oo]Z1?l0000moookJPCo0000;_oonfX4o`0003Kooo]Z000^oookJPGo00005OoonfX4o`0003Cooo]Z
1?l0000^oookJPCo0000>_oonfX4o`00033ooo]Z1?l0000hoookJPCo0000;ooonfX4o`0003gooo]Z
1?l0000^oookJPCo0000=_oonfX002kooo]Z1Ol0000EoookJPCo0000=?oonfX4o`0002kooo]Z1?l0
000joookJPCo0000<?oonfX4o`0003Sooo]Z1?l0000_oookJPCo0000?OoonfX4o`0002kooo]Z1?l0
000foookJP00;_oonfX5o`0001Gooo]Z1?l0000doookJPCo0000;_oonfX4o`0003[ooo]Z1Ol0000_
oookJPCo0000>?oonfX4o`0002oooo]Z1?l0000moookJPGo0000;OoonfX4o`0003Kooo]Z000^oook
JPGo00005OoonfX4o`0003Cooo]Z1Ol0000]oookJPCo0000>ooonfX4o`0002oooo]Z1?l0000hoook
JPCo0000;ooonfX4o`0003gooo]Z1Ol0000]oookJPCo0000=_oonfX002kooo]Z1Ol0000EoookJPCo
0000=?oonfX5o`0002cooo]Z1Ol0000koookJPCo0000;ooonfX4o`0003Sooo]Z1?l0000_oookJPCo
0000?_oonfX4o`0002cooo]Z1Ol0000foookJP00;_oonfX5o`0001Cooo]Z1Ol0000eoookJPCo0000
;?oonfX5o`0003_ooo]Z1?l0000_oookJPCo0000>?oonfX4o`0002oooo]Z1?l0000noookJPCo0000
;?oonfX4o`0003Oooo]Z000^oookJPGo00005?oonfX4o`0003Kooo]Z1?l0000/oookJPCo0000??oo
nfX4o`0002kooo]Z1Ol0000hoookJPCo0000;_oonfX5o`0003kooo]Z1?l0000/oookJPCo0000=ooo
nfX002kooo]Z1Ol0000DoookJPCo0000=_oonfX4o`0002cooo]Z1?l0000loookJPCo0000;_oonfX5
o`0003Sooo]Z1Ol0000]oookJPGo0000?_oonfX4o`0002cooo]Z1?l0000goookJP00;_oonfX5o`00
01Cooo]Z1?l0000foookJPCo0000;?oonfX4o`0003cooo]Z1?l0000^oookJPCo0000>OoonfX5o`00
02gooo]Z1?l0000ooookJPCo0000;?oonfX4o`0003Oooo]Z000^oookJPGo00005?oonfX4o`0003Ko
oo]Z1?l0000/oookJPCo0000??oonfX5o`0002gooo]Z1?l0000joookJPCo0000;OoonfX4o`0003oo
oo]Z1?l0000/oookJPCo0000=ooonfX002kooo]Z1Ol0000DoookJPCo0000=_oonfX4o`0002cooo]Z
1?l0000loookJPGo0000;OoonfX4o`0003[ooo]Z1?l0000]oookJPCo0000?ooonfX5o`0002[ooo]Z
1Ol0000goookJP00;_oonfX5o`0001Cooo]Z1?l0000foookJPCo0000;?oonfX4o`0003gooo]Z1?l0
000]oookJPCo0000>_oonfX4o`0002gooo]Z1?l00010oookJPCo0000:_oonfX5o`0003Oooo]Z000^
oookJPGo00005?oonfX4o`0003Kooo]Z1Ol0000[oookJPCo0000?OoonfX4o`0002gooo]Z1?l0000j
oookJPCo0000;OoonfX4o`00043ooo]Z1?l0000ZoookJPCo0000>?oonfX002kooo]Z1Ol0000Coook
JPGo0000=_oonfX5o`0002[ooo]Z1Ol0000moookJPCo0000;OoonfX4o`0003[ooo]Z1?l0000]oook
JPCo0000@?oonfX4o`0002[ooo]Z1?l0000hoookJP00;_oonfX5o`0001?ooo]Z1Ol0000goookJPCo
0000:_oonfX5o`0003gooo]Z1?l0000/oookJPGo0000>_oonfX4o`0002cooo]Z1Ol00010oookJPCo
0000:_oonfX4o`0003Sooo]Z000^oookJPGo00004ooonfX4o`0003Sooo]Z1?l0000ZoookJPCo0000
?_oonfX4o`0002cooo]Z1Ol0000joookJPCo0000;?oonfX5o`00043ooo]Z1?l0000ZoookJPCo0000
>?oonfX002kooo]Z1Ol0000CoookJPCo0000>?oonfX4o`0002[ooo]Z1?l0000noookJPCo0000;?oo
nfX4o`0003_ooo]Z1?l0000/oookJPCo0000@OoonfX4o`0002[ooo]Z1?l0000hoookJP00;_oonfX5
o`0001?ooo]Z1?l0000hoookJPCo0000:_oonfX4o`0003kooo]Z1Ol0000[oookJPCo0000>ooonfX5
o`0002_ooo]Z1?l00011oookJPGo0000:?oonfX5o`0003Sooo]Z000^oookJPGo00004ooonfX4o`00
03Sooo]Z1?l0000ZoookJPCo0000?_oonfX5o`0002_ooo]Z1?l0000koookJPGo0000:ooonfX4o`00
04;ooo]Z1?l0000XoookJPGo0000>?oonfX002kooo]Z1Ol0000CoookJPCo0000>?oonfX4o`0002[o
oo]Z1?l0000ooookJPCo0000:ooonfX4o`0003cooo]Z1?l0000[oookJPCo0000@_oonfX4o`0002So
oo]Z1?l0000ioookJP00;_oonfX5o`0001?ooo]Z1?l0000hoookJPCo0000:_oonfX4o`0003oooo]Z
1?l0000[oookJPCo0000??oonfX4o`0002_ooo]Z1?l00012oookJPCo0000:?oonfX4o`0003Wooo]Z
000^oookJPGo00004ooonfX4o`0003Sooo]Z1Ol0000YoookJPCo0000?ooonfX4o`0002_ooo]Z1?l0
000loookJPCo0000:ooonfX4o`0004;ooo]Z1?l0000XoookJPCo0000>OoonfX002kooo]Z1Ol0000B
oookJPGo0000>?oonfX5o`0002Sooo]Z1Ol0000ooookJPCo0000:_oonfX5o`0003cooo]Z1?l0000Z
oookJPGo0000@_oonfX4o`0002Sooo]Z1?l0000ioookJP00;_oonfX5o`0001;ooo]Z1Ol0000ioook
JPCo0000:?oonfX5o`0003oooo]Z1?l0000ZoookJPGo0000??oonfX4o`0002[ooo]Z1Ol00012oook
JPCo0000:?oonfX4o`0003Wooo]Z000^oookJPGo00004_oonfX4o`0003[ooo]Z1?l0000XoookJPCo
0000@?oonfX4o`0002[ooo]Z1?l0000moookJPCo0000:_oonfX4o`0004?ooo]Z1Ol0000VoookJPGo
0000>OoonfX002kooo]Z1Ol0000BoookJPCo0000>_oonfX4o`0002Sooo]Z1?l00010oookJPGo0000
:OoonfX4o`0003gooo]Z1Ol0000YoookJPCo0000A?oonfX4o`0002Kooo]Z1Ol0000ioookJP00;_oo
nfX5o`0001;ooo]Z1?l0000joookJPCo0000:?oonfX4o`00047ooo]Z1?l0000YoookJPCo0000?Ooo
nfX5o`0002Wooo]Z1?l00014oookJPCo00009_oonfX4o`0003[ooo]Z000^oookJPGo00004_oonfX4
o`0003[ooo]Z1?l0000XoookJPCo0000@OoonfX4o`0002Wooo]Z1?l0000noookJPCo0000:OoonfX4
o`0004Cooo]Z1?l0000VoookJPCo0000>_oonfX002kooo]Z1Ol0000BoookJPCo0000>_oonfX4o`00
02Sooo]Z1?l00011oookJPCo0000:OoonfX4o`0003kooo]Z1?l0000YoookJPCo0000A?oonfX4o`00
02Kooo]Z1?l0000joookJP00;_oonfX5o`0001;ooo]Z1?l0000joookJPCo0000:?oonfX4o`00047o
oo]Z1?l0000YoookJPCo0000?_oonfX4o`0002Wooo]Z1?l00014oookJPCo00009_oonfX4o`0003[o
oo]Z000^oookJPGo00004_oonfX4o`0003[ooo]Z1Ol0000WoookJPCo0000@OoonfX4o`0002Sooo]Z
1Ol0000noookJPCo0000:?oonfX5o`0004Cooo]Z1Ol0000UoookJPCo0000>_oonfX002kooo]Z1Ol0
000AoookJPGo0000>_oonfX5o`0002Kooo]Z1Ol00011oookJPCo0000:?oonfX5o`0003kooo]Z1?l0
000XoookJPGo0000A?oonfX5o`0002Cooo]Z1Ol0000joookJP00;_oonfX5o`00017ooo]Z1Ol0000k
oookJPCo00009_oonfX5o`00047ooo]Z1Ol0000WoookJPCo0000?ooonfX4o`0002Sooo]Z1?l00016
oookJPCo00009?oonfX5o`0003[ooo]Z000^oookJPGo00004OoonfX4o`0003cooo]Z1?l0000Voook
JPCo0000@_oonfX5o`0002Oooo]Z1?l0000ooookJPCo0000:?oonfX4o`0004Kooo]Z1?l0000Toook
JPCo0000>ooonfX002kooo]Z1Ol0000AoookJPCo0000??oonfX4o`0002Kooo]Z1?l00013oookJPCo
00009ooonfX4o`0003oooo]Z1Ol0000WoookJPCo0000A_oonfX4o`0002Cooo]Z1?l0000koookJP00
;_oonfX5o`00017ooo]Z1?l0000loookJPCo00009_oonfX4o`0004?ooo]Z1?l0000WoookJPCo0000
?ooonfX5o`0002Oooo]Z1?l00016oookJPCo00009?oonfX4o`0003_ooo]Z000^oookJPGo00004Ooo
nfX4o`0003cooo]Z1?l0000VoookJPCo0000@ooonfX4o`0002Oooo]Z1?l00010oookJPCo00009ooo
nfX4o`0004Kooo]Z1?l0000ToookJPCo0000>ooonfX002kooo]Z1Ol0000AoookJPCo0000??oonfX4
o`0002Kooo]Z1?l00013oookJPCo00009ooonfX4o`00043ooo]Z1?l0000WoookJPCo0000A_oonfX5
o`0002;ooo]Z1Ol0000koookJP00;_oonfX5o`00017ooo]Z1?l0000loookJPGo00009OoonfX4o`00
04?ooo]Z1?l0000VoookJPGo0000@?oonfX4o`0002Kooo]Z1Ol00016oookJPGo00008_oonfX5o`00
03_ooo]Z000^oookJPGo00004OoonfX4o`0003cooo]Z1Ol0000UoookJPCo0000@ooonfX5o`0002Go
oo]Z1?l00011oookJPCo00009_oonfX5o`0004Oooo]Z1?l0000RoookJPCo0000??oonfX002kooo]Z
1Ol0000@oookJPGo0000?OoonfX4o`0002Cooo]Z1Ol00013oookJPGo00009OoonfX4o`00047ooo]Z
1?l0000VoookJPCo0000B?oonfX4o`0002;ooo]Z1?l0000loookJP00;_oonfX5o`00013ooo]Z1?l0
000noookJPCo00009?oonfX5o`0004Cooo]Z1?l0000UoookJPCo0000@OoonfX4o`0002Kooo]Z1?l0
0018oookJPCo00008_oonfX4o`0003cooo]Z000^oookJPGo00004?oonfX4o`0003kooo]Z1?l0000T
oookJPCo0000AOoonfX4o`0002Gooo]Z1?l00011oookJPGo00009OoonfX4o`0004Sooo]Z1?l0000R
oookJPCo0000??oonfX002kooo]Z1Ol0000@oookJPCo0000?_oonfX4o`0002Cooo]Z1?l00015oook
JPCo00009OoonfX4o`00047ooo]Z1Ol0000UoookJPCo0000B?oonfX5o`00023ooo]Z1Ol0000loook
JP00;_oonfX5o`00013ooo]Z1?l0000noookJPCo00009?oonfX4o`0004Gooo]Z1?l0000UoookJPCo
0000@_oonfX4o`0002Gooo]Z1?l00018oookJPGo00008?oonfX5o`0003cooo]Z000^oookJPGo0000
4?oonfX4o`0003kooo]Z1?l0000ToookJPCo0000AOoonfX4o`0002Cooo]Z1Ol00012oookJPCo0000
9OoonfX4o`0004Wooo]Z1?l0000PoookJPCo0000?OoonfX002kooo]Z1Ol0000@oookJPCo0000?_oo
nfX4o`0002Cooo]Z1?l00015oookJPGo00008ooonfX5o`0004;ooo]Z1?l0000ToookJPGo0000BOoo
nfX4o`00023ooo]Z1?l0000moookJP00;_oonfX5o`00013ooo]Z1?l0000noookJPGo00008ooonfX4
o`0004Gooo]Z1Ol0000SoookJPCo0000@ooonfX4o`0002Cooo]Z1Ol00019oookJPCo00008?oonfX4
o`0003gooo]Z000^oookJPGo00003ooonfX5o`0003kooo]Z1Ol0000RoookJPGo0000A_oonfX4o`00
02?ooo]Z1?l00013oookJPCo00009?oonfX4o`0004[ooo]Z1Ol0000OoookJPCo0000?OoonfX002ko
oo]Z1Ol0000?oookJPGo0000?ooonfX4o`0002;ooo]Z1Ol00016oookJPCo00008ooonfX4o`0004?o
oo]Z1?l0000ToookJPCo0000B_oonfX5o`0001kooo]Z1Ol0000moookJP00;_oonfX5o`0000oooo]Z
1?l00010oookJPCo00008_oonfX4o`0004Oooo]Z1?l0000SoookJPCo0000@ooonfX5o`0002?ooo]Z
1?l0001;oookJPCo00007_oonfX5o`0003gooo]Z000^oookJPGo00003ooonfX4o`00043ooo]Z1?l0
000RoookJPCo0000AooonfX4o`0002;ooo]Z1Ol00013oookJPGo00008ooonfX4o`0004_ooo]Z1?l0
000NoookJPCo0000?_oonfX002kooo]Z1Ol0000?oookJPCo0000@?oonfX4o`0002;ooo]Z1?l00017
oookJPCo00008_oonfX5o`0004Cooo]Z1?l0000SoookJPCo0000BooonfX4o`0001kooo]Z1?l0000n
oookJP00;_oonfX5o`0000oooo]Z1?l00010oookJPCo00008_oonfX4o`0004Oooo]Z1Ol0000Qoook
JPCo0000AOoonfX4o`0002?ooo]Z1?l0001;oookJPCo00007_oonfX4o`0003kooo]Z000^oookJPGo
00003ooonfX4o`00043ooo]Z1Ol0000QoookJPCo0000AooonfX5o`00027ooo]Z1?l00015oookJPCo
00008_oonfX5o`0004_ooo]Z1Ol0000MoookJPCo0000?_oonfX002kooo]Z1Ol0000?oookJPCo0000
@?oonfX5o`00027ooo]Z1?l00018oookJPCo00008OoonfX4o`0004Gooo]Z1?l0000RoookJPGo0000
BooonfX5o`0001cooo]Z1Ol0000noookJP004OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2Ooo
nfX5o`0000kooo]Z1Ol00011oookJPCo00008?oonfX5o`0004Sooo]Z1?l0000QoookJPCo0000AOoo
nfX4o`0002;ooo]Z1?l0001=oookJPCo00007?oonfX5o`0003kooo]Z000@oookJPOo001o0ooonfX3
o`00O`;ooo]Z1ol007l8oookJPGo00003_oonfX4o`0004;ooo]Z1?l0000PoookJPGo0000B?oonfX4
o`00027ooo]Z1?l00015oookJPCo00008_oonfX4o`0004gooo]Z1?l0000LoookJPCo0000?ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l8oookJPGo00003_oonfX4o`0004;ooo]Z1?l0000PoookJPCo0000BOoo
nfX4o`00023ooo]Z1Ol00015oookJPGo00008OoonfX4o`0004gooo]Z1?l0000LoookJPCo0000?ooo
nfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00003_oonfX4
o`0004;ooo]Z1?l0000PoookJPCo0000BOoonfX4o`00023ooo]Z1Ol00015oookJPGo00008OoonfX4
o`0004gooo]Z1Ol0000KoookJPCo0000?ooonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1_l0000=oookJPCo0000@_oonfX4o`00023ooo]Z1?l00019oookJPGo00007ooonfX4o`00
04Oooo]Z1?l0000QoookJPCo0000COoonfX5o`0001_ooo]Z1?l0000ooookJP003ooonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX5o`0000kooo]Z1?l00012oookJPGo00007ooonfX4o`0004Wo
oo]Z1Ol0000OoookJPCo0000AooonfX4o`00027ooo]Z1?l0001>oookJPCo00006_oonfX5o`0003oo
oo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX5o`0000kooo]Z
1?l00012oookJPGo00007ooonfX4o`0004[ooo]Z1?l0000OoookJPCo0000AooonfX4o`00023ooo]Z
1Ol0001>oookJPCo00006_oonfX5o`0003oooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l8oookJPGo00003OoonfX5o`0004?ooo]Z1?l0000OoookJPCo0000B_oonfX4o`0001kooo]Z1Ol0
0017oookJPCo00008?oonfX5o`0004kooo]Z1?l0000JoookJPCo0000@?oonfX000oooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Wooo]Z1Ol0000=oookJPGo0000@ooonfX4o`0001kooo]Z1Ol0001:
oookJPCo00007_oonfX5o`0004Oooo]Z1?l0000PoookJPCo0000CooonfX5o`0001Wooo]Z1?l00010
oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`0000gooo]Z1?l00014oook
JPCo00007_oonfX5o`0004[ooo]Z1?l0000NoookJPCo0000B?oonfX4o`00023ooo]Z1?l0001?oook
JPGo00006OoonfX4o`00043ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
O`gooo]Z1Ol0000=oookJPCo0000A?oonfX4o`0001kooo]Z1?l0001;oookJPCo00007_oonfX4o`00
04Sooo]Z1Ol0000OoookJPCo0000D?oonfX4o`0001Wooo]Z1?l00010oookJP004?oonfX7o`00O`Wo
oo]Z1ol007l7oookJPGo00003OoonfX4o`0004Cooo]Z1?l0000NoookJPCo0000BooonfX5o`0001go
oo]Z1?l00018oookJPGo00007ooonfX4o`00053ooo]Z1?l0000HoookJPGo0000@?oonfX0017ooo]Z
1Ol007l:oookJPOo001o1ooonfX5o`0000gooo]Z1?l00014oookJPGo00007OoonfX4o`0004_ooo]Z
1Ol0000MoookJPCo0000BOoonfX4o`0001oooo]Z1?l0001@oookJPCo00006?oonfX5o`00043ooo]Z
000^oookJPGo00003OoonfX4o`0004Cooo]Z1Ol0000MoookJPCo0000C?oonfX4o`0001cooo]Z1Ol0
0019oookJPCo00007_oonfX5o`00053ooo]Z1Ol0000GoookJPCo0000@OoonfX002kooo]Z1Ol0000=
oookJPCo0000AOoonfX4o`0001gooo]Z1?l0001<oookJPCo00007?oonfX5o`0004Wooo]Z1?l0000N
oookJPGo0000DOoonfX4o`0001Oooo]Z1?l00011oookJP00;_oonfX5o`0000cooo]Z1Ol00015oook
JPCo00007?oonfX5o`0004cooo]Z1?l0000LoookJPCo0000B_oonfX4o`0001kooo]Z1?l0001Boook
JPCo00005ooonfX4o`00047ooo]Z000^oookJPGo00003?oonfX5o`0004Gooo]Z1?l0000LoookJPGo
0000C?oonfX4o`0001cooo]Z1?l0001:oookJPCo00007_oonfX4o`0005;ooo]Z1?l0000FoookJPGo
0000@OoonfX002kooo]Z1Ol0000<oookJPCo0000A_oonfX4o`0001cooo]Z1?l0001=oookJPCo0000
7?oonfX4o`0004[ooo]Z1Ol0000MoookJPCo0000D_oonfX4o`0001Kooo]Z1Ol00011oookJP00;_oo
nfX5o`0000cooo]Z1?l00016oookJPGo00006ooonfX4o`0004gooo]Z1Ol0000KoookJPCo0000B_oo
nfX5o`0001gooo]Z1?l0001BoookJPGo00005OoonfX4o`0004;ooo]Z000^oookJPGo00003?oonfX4
o`0004Kooo]Z1Ol0000KoookJPCo0000COoonfX5o`0001[ooo]Z1Ol0001;oookJPCo00007OoonfX4
o`0005?ooo]Z1?l0000EoookJPCo0000@_oonfX002kooo]Z1Ol0000<oookJPCo0000AooonfX4o`00
01_ooo]Z1?l0001>oookJPCo00006_oonfX5o`0004_ooo]Z1?l0000LoookJPGo0000DooonfX4o`00
01Gooo]Z1?l00012oookJP00;_oonfX5o`0000cooo]Z1?l00017oookJPCo00006ooonfX4o`0004ko
oo]Z1?l0000JoookJPCo0000C?oonfX4o`0001cooo]Z1?l0001DoookJPCo00005OoonfX4o`0004;o
oo]Z000^oookJPGo00002ooonfX5o`0004Oooo]Z1?l0000JoookJPGo0000C_oonfX4o`0001[ooo]Z
1?l0001<oookJPCo00007?oonfX4o`0005Cooo]Z1?l0000DoookJPGo0000@_oonfX002kooo]Z1Ol0
000;oookJPGo0000AooonfX4o`0001[ooo]Z1Ol0001>oookJPCo00006_oonfX4o`0004cooo]Z1?l0
000LoookJPCo0000E?oonfX5o`0001?ooo]Z1Ol00012oookJP00;_oonfX5o`0000_ooo]Z1?l00018
oookJPCo00006_oonfX4o`0004oooo]Z1Ol0000HoookJPGo0000C?oonfX5o`0001_ooo]Z1?l0001E
oookJPCo00004ooonfX4o`0004?ooo]Z000^oookJPGo00002ooonfX4o`0004Sooo]Z1Ol0000Ioook
JPCo0000CooonfX5o`0001Sooo]Z1Ol0001<oookJPGo00006ooonfX4o`0005Gooo]Z1?l0000Coook
JPCo0000@ooonfX002kooo]Z1Ol0000;oookJPCo0000BOoonfX4o`0001Wooo]Z1?l0001@oookJPCo
00006?oonfX4o`0004kooo]Z1?l0000JoookJPGo0000EOoonfX4o`0001;ooo]Z1Ol00013oookJP00
;_oonfX5o`0000_ooo]Z1?l00019oookJPCo00006OoonfX4o`00053ooo]Z1?l0000HoookJPCo0000
C_oonfX4o`0001[ooo]Z1Ol0001EoookJPGo00004OoonfX5o`0004?ooo]Z000^oookJPGo00002ooo
nfX4o`0004Wooo]Z1?l0000IoookJPCo0000D?oonfX4o`0001Oooo]Z1Ol0001>oookJPCo00006_oo
nfX4o`0005Kooo]Z1Ol0000AoookJPCo0000A?oonfX002kooo]Z1Ol0000:oookJPGo0000BOoonfX4
o`0001Sooo]Z1Ol0001@oookJPCo00005ooonfX5o`0004kooo]Z1?l0000JoookJPCo0000EooonfX4
o`00017ooo]Z1?l00014oookJP00;_oonfX5o`0000[ooo]Z1Ol00019oookJPCo00006?oonfX5o`00
053ooo]Z1?l0000GoookJPCo0000CooonfX4o`0001[ooo]Z1?l0001GoookJPCo00004OoonfX4o`00
04Cooo]Z000^oookJPGo00002_oonfX4o`0004[ooo]Z1Ol0000GoookJPCo0000DOoonfX5o`0001Ko
oo]Z1?l0001?oookJPGo00006OoonfX4o`0005Oooo]Z1?l0000@oookJPGo0000A?oonfX002kooo]Z
1Ol0000:oookJPCo0000BooonfX4o`0001Oooo]Z1?l0001BoookJPCo00005_oonfX4o`00053ooo]Z
1?l0000HoookJPGo0000EooonfX5o`0000oooo]Z1Ol00014oookJP00;_oonfX5o`0000[ooo]Z1?l0
001;oookJPCo00005ooonfX4o`0005;ooo]Z1?l0000EoookJPGo0000D?oonfX4o`0001Sooo]Z1Ol0
001GoookJPGo00003ooonfX4o`0004Gooo]Z000^oookJPGo00002_oonfX4o`0004_ooo]Z1?l0000G
oookJPCo0000D_oonfX4o`0001Gooo]Z1Ol0001@oookJPCo00006?oonfX4o`0005Wooo]Z1?l0000?
oookJPCo0000AOoonfX002kooo]Z1Ol0000:oookJPCo0000BooonfX4o`0001Kooo]Z1Ol0001Boook
JPCo00005OoonfX4o`00057ooo]Z1?l0000HoookJPCo0000FOoonfX4o`0000kooo]Z1Ol00015oook
JP00;_oonfX5o`0000Wooo]Z1Ol0001;oookJPGo00005OoonfX5o`0005;ooo]Z1?l0000EoookJPCo
0000DOoonfX4o`0001Sooo]Z1?l0001IoookJPGo00003OoonfX5o`0004Gooo]Z000^oookJPGo0000
2OoonfX5o`0004_ooo]Z1Ol0000EoookJPCo0000DooonfX5o`0001?ooo]Z1Ol0001AoookJPGo0000
5ooonfX4o`0005Wooo]Z1Ol0000=oookJPCo0000A_oonfX002kooo]Z1Ol00009oookJPCo0000COoo
nfX4o`0001Gooo]Z1?l0001CoookJPGo00004ooonfX5o`00057ooo]Z1Ol0000FoookJPGo0000F_oo
nfX4o`0000gooo]Z1?l00016oookJP00;_oonfX5o`0000Wooo]Z1?l0001=oookJPCo00005OoonfX4
o`0005Cooo]Z1?l0000CoookJPCo0000DooonfX4o`0001Kooo]Z1Ol0001JoookJPCo00003?oonfX5
o`0004Kooo]Z000^oookJPGo00002OoonfX4o`0004gooo]Z1?l0000EoookJPCo0000E?oonfX4o`00
01?ooo]Z1?l0001CoookJPCo00005_oonfX4o`0005_ooo]Z1Ol0000;oookJPGo0000A_oonfX002ko
oo]Z1Ol00009oookJPCo0000COoonfX4o`0001Cooo]Z1Ol0001DoookJPCo00004_oonfX5o`0005?o
oo]Z1?l0000FoookJPCo0000FooonfX5o`0000_ooo]Z1?l00017oookJP00;_oonfX5o`0000Sooo]Z
1Ol0001=oookJPGo00004ooonfX5o`0005Cooo]Z1Ol0000AoookJPGo0000DooonfX5o`0001Gooo]Z
1?l0001LoookJPCo00002ooonfX4o`0004Oooo]Z000^oookJPGo00002?oonfX5o`0004kooo]Z1?l0
000CoookJPCo0000EOoonfX5o`00017ooo]Z1?l0001DoookJPGo00005?oonfX5o`0005cooo]Z1Ol0
0009oookJPGo0000AooonfX002kooo]Z1Ol00008oookJPCo0000CooonfX4o`0001?ooo]Z1?l0001F
oookJPCo00004OoonfX4o`0005Gooo]Z1?l0000DoookJPGo0000G?oonfX5o`0000Wooo]Z1Ol00017
oookJP00;_oonfX5o`0000Sooo]Z1?l0001?oookJPCo00004ooonfX4o`0005Kooo]Z1?l0000@oook
JPGo0000EOoonfX4o`0001Cooo]Z1?l0001NoookJPCo00002OoonfX4o`0004Sooo]Z000^oookJPGo
00002?oonfX4o`0004oooo]Z1Ol0000AoookJPGo0000E_oonfX4o`00013ooo]Z1Ol0001EoookJPCo
00005?oonfX4o`0005kooo]Z1Ol00007oookJPGo0000B?oonfX002kooo]Z1Ol00008oookJPCo0000
CooonfX5o`00017ooo]Z1Ol0001FoookJPGo00003ooonfX4o`0005Kooo]Z1?l0000DoookJPCo0000
G_oonfX5o`0000Oooo]Z1Ol00018oookJP00;_oonfX5o`0000Oooo]Z1Ol0001@oookJPCo00004Ooo
nfX4o`0005Oooo]Z1Ol0000?oookJPCo0000E_oonfX5o`0001;ooo]Z1Ol0001OoookJPCo00001ooo
nfX4o`0004Wooo]Z000^oookJPGo00001ooonfX4o`00057ooo]Z1?l0000AoookJPCo0000F?oonfX4
o`0000kooo]Z1Ol0001FoookJPGo00004_oonfX5o`0005oooo]Z1Ol00005oookJPGo0000BOoonfX0
02kooo]Z1Ol00007oookJPCo0000DOoonfX4o`00017ooo]Z1?l0001HoookJPCo00003_oonfX5o`00
05Oooo]Z1?l0000BoookJPCo0000H?oonfX5o`0000Gooo]Z1Ol00019oookJP00;_oonfX5o`0000Oo
oo]Z1?l0001AoookJPGo00003ooonfX5o`0005Sooo]Z1?l0000>oookJPCo0000F?oonfX4o`0001;o
oo]Z1?l0001QoookJPGo00000ooonfX5o`0004[ooo]Z000^oookJPGo00001_oonfX5o`00057ooo]Z
1Ol0000?oookJPGo0000F?oonfX5o`0000cooo]Z1Ol0001HoookJPCo00004OoonfX5o`00067ooo]Z
1_l00002oookJPGo0000B_oonfX002kooo]Z1Ol00006oookJPGo0000D_oonfX4o`0000oooo]Z1?l0
001IoookJPGo00003?oonfX5o`0005Sooo]Z1Ol0000@oookJPGo0000H_oonfX;o`0004_ooo]Z000^
oookJPGo00001_oonfX4o`0005?ooo]Z1?l0000?oookJPCo0000F_oonfX4o`0000cooo]Z1?l0001I
oookJPGo00004?oonfX4o`0006Cooo]Z2_l0001;oookJP00;_oonfX5o`0000Kooo]Z1?l0001Coook
JPGo00003_oonfX4o`0005[ooo]Z1?l0000;oookJPGo0000F_oonfX4o`00013ooo]Z1?l0001Uoook
JPSo0000C?oonfX002kooo]Z1Ol00006oookJPCo0000DooonfX5o`0000gooo]Z1Ol0001JoookJPCo
00002ooonfX5o`0005[ooo]Z1?l0000@oookJPCo0000I_oonfX6o`0004gooo]Z000^oookJPGo0000
1OoonfX5o`0005Cooo]Z1?l0000=oookJPGo0000F_oonfX5o`0000[ooo]Z1?l0001KoookJPCo0000
3ooonfX5o`0006Oooo]Z1?l0001>oookJP00;_oonfX5o`0000Gooo]Z1Ol0001DoookJPCo00003Ooo
nfX4o`0005_ooo]Z1Ol00009oookJPGo0000FooonfX5o`0000kooo]Z1Ol0002ioookJP00;_oonfX5
o`0000Gooo]Z1?l0001EoookJPGo00003?oonfX4o`0005cooo]Z1?l00009oookJPGo0000FooonfX5
o`0000kooo]Z1?l0002joookJP00;_oonfX5o`0000Gooo]Z1?l0001FoookJPCo00002ooonfX5o`00
05cooo]Z1Ol00007oookJPGo0000GOoonfX4o`0000gooo]Z1Ol0002joookJP00;_oonfX5o`0000Go
oo]Z1?l0001FoookJPCo00002ooonfX5o`0005cooo]Z1Ol00007oookJPGo0000GOoonfX4o`0000go
oo]Z1Ol0002joookJP00;_oonfX5o`0000Cooo]Z1Ol0001FoookJPGo00002_oonfX4o`0005kooo]Z
1?l00006oookJPGo0000G_oonfX5o`0000cooo]Z1?l0002koookJP00;_oonfX5o`0000Cooo]Z1Ol0
001FoookJPGo00002OoonfX5o`0005kooo]Z1Ol00005oookJPGo0000G_oonfX5o`0000_ooo]Z1Ol0
002koookJP00;_oonfX5o`0000Cooo]Z1?l0001HoookJPCo00002OoonfX5o`0005kooo]Z1Ol00004
oookJPGo0000H?oonfX4o`0000_ooo]Z1Ol0002koookJP00;_oonfX5o`0000Cooo]Z1?l0001Hoook
JPGo00002?oonfX4o`00063ooo]Z1Ol00002oookJPKo0000H?oonfX5o`0000[ooo]Z1?l0002loook
JP00;_oonfX5o`0000?ooo]Z1Ol0001HoookJPGo00001ooonfX5o`00063ooo]Z3?l0001QoookJPGo
00002OoonfX5o`000;cooo]Z000^oookJPGo00000ooonfX5o`0005Wooo]Z1Ol00006oookJPGo0000
HOoonfX:o`0006?ooo]Z1?l00009oookJPGo0000_?oonfX002kooo]Z1Ol00003oookJPCo0000F_oo
nfX5o`0000Kooo]Z1?l0001RoookJPWo0000I?oonfX5o`0000Sooo]Z1?l0002moookJP00;_oonfX5
o`0000?ooo]Z1?l0001KoookJPGo00001?oonfX5o`0006?ooo]Z1ol0001UoookJPGo00001ooonfX5
o`000;gooo]Z000^oookJPGo00000_oonfX5o`0005_ooo]Z1_l00003oookJPGo0000I?oonfX4o`00
06Sooo]Z1?l00007oookJPGo0000_OoonfX002kooo]Z1Ol00002oookJPGo0000G?oonfX<o`000=7o
oo]Z1Ol00005oookJPGo0000__oonfX002kooo]Z1Ol00002oookJPCo0000G_oonfX;o`000=7ooo]Z
1Ol00005oookJPGo0000__oonfX002kooo]Z1Ol00002oookJPCo0000GooonfX9o`000=?ooo]Z1Ol0
0003oookJPGo0000_ooonfX002kooo]Z1Ol000000ooonf[o0000o`000003o`00063ooo]Z1ol0003D
oookJPGo00000_oonfX6o`000;oooo]Z000^oookJPGo000000?ooo]Zo`000?l000000ol0001Qoook
JPCo0000eooonfX;o`000<3ooo]Z000^oookJPGo000000?ooo]Zo`000?l000000_l0003ooookJSko
oo]Z2_l00031oookJP00;_oonfX:o`000?oooo]Z?ooonfX8o`000<;ooo]Z000^oookJP[o0000oooo
nfY0oookJPKo0000`ooonfX002;ooo]Z0ol007l9oookJPWo0000oooonfY2oookJPCo0000a?oonfX0
02;ooo]Z0ol007l9oookJPWo0000oooonf[ooookJP_ooo]Z000RoookJP?o001o2OoonfX8o`000?oo
oo]ZoooonfX<oookJP008_oonfX3o`00O`Wooo]Z2?l0003ooookJ_oooo]Z3?oonfX002;ooo]Z0ol0
07l9oookJPOo0000oooonf[ooookJPgooo]Z000RoookJP?o001o2OoonfX6o`000?oooo]ZoooonfX>
oookJP008_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002;ooo]Z0ol007l9oookJPGo
0000oooonf[ooookJPoooo]Z000RoookJP?o001o2OoonfX5o`000?oooo]ZoooonfX?oookJP007ooo
nfX6o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX001oooo]Z1_l007l9oookJPGo0000oooonf[o
oookJPoooo]Z000QoookJPCo001o2OoonfX5o`000?oooo]ZoooonfX?oookJP008_oonfX3o`00O`Wo
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1941.8, -1.12394, 40.0401, \
0.00633927}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[TheData[\([2]\)]]\)], "Input",
  CellTags->"mmtag:23:noise__random"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.309017 29430.8 [
[.26188 .29652 -22 -20 ]
[.26188 .29652 22 0 ]
[.49995 .29652 -27 -20 ]
[.49995 .29652 27 0 ]
[.73802 .29652 -27 -20 ]
[.73802 .29652 27 0 ]
[.9761 .29652 -27 -20 ]
[.9761 .29652 27 0 ]
[.01131 .01471 -81.9375 -10 ]
[.01131 .01471 0 10 ]
[.01131 .16186 -80.4375 -11.9688 ]
[.01131 .16186 0 11.9688 ]
[.01131 .45617 -67.5 -11.9688 ]
[.01131 .45617 0 11.9688 ]
[.01131 .60333 -69 -10 ]
[.01131 .60333 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .30902 m
.26188 .31527 L
s
gsave
.26188 .29652 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .30902 m
.49995 .31527 L
s
gsave
.49995 .29652 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .30902 m
.73802 .31527 L
s
gsave
.73802 .29652 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .30902 m
.9761 .31527 L
s
gsave
.9761 .29652 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .30902 m
.07142 .31277 L
s
.11904 .30902 m
.11904 .31277 L
s
.16665 .30902 m
.16665 .31277 L
s
.21427 .30902 m
.21427 .31277 L
s
.3095 .30902 m
.3095 .31277 L
s
.35711 .30902 m
.35711 .31277 L
s
.40472 .30902 m
.40472 .31277 L
s
.45234 .30902 m
.45234 .31277 L
s
.54757 .30902 m
.54757 .31277 L
s
.59518 .30902 m
.59518 .31277 L
s
.6428 .30902 m
.6428 .31277 L
s
.69041 .30902 m
.69041 .31277 L
s
.78564 .30902 m
.78564 .31277 L
s
.83325 .30902 m
.83325 .31277 L
s
.88087 .30902 m
.88087 .31277 L
s
.92848 .30902 m
.92848 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.02381 .01471 m
.03006 .01471 L
s
gsave
.01131 .01471 -142.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.00001) show
1.000 setlinewidth
grestore
.02381 .16186 m
.03006 .16186 L
s
gsave
.01131 .16186 -141.438 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 22.938 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
88.438 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
102.438 22.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
122.438 14.312 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
131.188 14.312 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -128.5 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.938 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
75.500 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
89.500 22.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
109.500 14.312 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
118.250 14.312 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.02381 .60333 m
.03006 .60333 L
s
gsave
.01131 .60333 -130 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.00001) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .30902 Mdot
.0239 .30902 Mdot
.02395 .18496 Mdot
.024 .10012 Mdot
.02405 .33792 Mdot
.0241 .25607 Mdot
.02414 .46073 Mdot
.02419 .56512 Mdot
.02424 .48003 Mdot
.02429 .30155 Mdot
.02433 .52129 Mdot
.02438 .34186 Mdot
.02443 .56932 Mdot
.02448 .57685 Mdot
.02452 .42207 Mdot
.02457 .52727 Mdot
.02462 .4689 Mdot
.02467 .17972 Mdot
.02471 .30294 Mdot
.02476 .51004 Mdot
.02481 .11834 Mdot
.02486 .46436 Mdot
.0249 .04387 Mdot
.02495 .29667 Mdot
.025 .4275 Mdot
.02505 .44564 Mdot
.0251 .46224 Mdot
.02514 .21125 Mdot
.02519 .10429 Mdot
.02524 .20427 Mdot
.02529 .01621 Mdot
.02533 .24946 Mdot
.02538 .22758 Mdot
.02543 .50605 Mdot
.02548 .09824 Mdot
.02552 .51093 Mdot
.02557 .26159 Mdot
.02562 .53252 Mdot
.02567 .2795 Mdot
.02571 .58698 Mdot
.02576 .39601 Mdot
.02581 .36751 Mdot
.02586 .57988 Mdot
.0259 .09165 Mdot
.02595 .29238 Mdot
.026 .50647 Mdot
.02605 .55072 Mdot
.0261 .39831 Mdot
.02614 .4682 Mdot
.02619 .07554 Mdot
.02624 .10319 Mdot
.02629 .20177 Mdot
.02633 .37862 Mdot
.02638 .47459 Mdot
.02643 .10169 Mdot
.02648 .55564 Mdot
.02652 .16575 Mdot
.02657 .57187 Mdot
.02662 .01816 Mdot
.02667 .05942 Mdot
.02671 .50749 Mdot
.02676 .05406 Mdot
.02681 .34198 Mdot
.02686 .07576 Mdot
.0269 .12619 Mdot
.02695 .28987 Mdot
.027 .36543 Mdot
.02705 .58744 Mdot
.02709 .43714 Mdot
.02714 .38673 Mdot
.02719 .41803 Mdot
.02724 .20384 Mdot
.02729 .57226 Mdot
.02733 .3259 Mdot
.02738 .32954 Mdot
.02743 .01678 Mdot
.02748 .20835 Mdot
.02752 .45463 Mdot
.02757 .24256 Mdot
.02762 .06447 Mdot
.02767 .05731 Mdot
.02771 .48608 Mdot
.02776 .23911 Mdot
.02781 .01976 Mdot
.02786 .15315 Mdot
.0279 .44673 Mdot
.02795 .50045 Mdot
.028 .54732 Mdot
.02805 .04168 Mdot
.02809 .17157 Mdot
.02814 .14974 Mdot
.02819 .5632 Mdot
.02824 .20787 Mdot
.02829 .38816 Mdot
.02833 .33503 Mdot
.02838 .37408 Mdot
.02843 .23893 Mdot
.02848 .07698 Mdot
.02852 .02019 Mdot
.02857 .37201 Mdot
.02862 .04528 Mdot
.02867 .22567 Mdot
.02871 .38096 Mdot
.02876 .32225 Mdot
.02881 .5913 Mdot
.02886 .34292 Mdot
.0289 .15656 Mdot
.02895 .31721 Mdot
.029 .45285 Mdot
.02905 .49951 Mdot
.02909 .25943 Mdot
.02914 .37322 Mdot
.02919 .42588 Mdot
.02924 .34265 Mdot
.02929 .1244 Mdot
.02933 .41334 Mdot
.02938 .23273 Mdot
.02943 .55781 Mdot
.02948 .3927 Mdot
.02952 .05397 Mdot
.02957 .59713 Mdot
.02962 .49554 Mdot
.02967 .38721 Mdot
.02971 .28528 Mdot
.02976 .56655 Mdot
.02981 .28458 Mdot
.02986 .02096 Mdot
.0299 .56635 Mdot
.02995 .57858 Mdot
.03 .54499 Mdot
.03005 .46773 Mdot
.03009 .26385 Mdot
.03014 .14044 Mdot
.03019 .06019 Mdot
.03024 .22301 Mdot
.03029 .49396 Mdot
.03033 .31788 Mdot
.03038 .32086 Mdot
.03043 .11332 Mdot
.03048 .09533 Mdot
.03052 .09986 Mdot
.03057 .36637 Mdot
.03062 .32395 Mdot
.03067 .05608 Mdot
.03071 .10606 Mdot
.03076 .47415 Mdot
.03081 .54006 Mdot
.03086 .37412 Mdot
.0309 .14283 Mdot
.03095 .20428 Mdot
.031 .53381 Mdot
.03105 .4111 Mdot
.03109 .16758 Mdot
.03114 .26262 Mdot
.03119 .08079 Mdot
.03124 .16195 Mdot
.03128 .04185 Mdot
.03133 .21714 Mdot
.03138 .4611 Mdot
.03143 .27132 Mdot
.03148 .3273 Mdot
.03152 .49961 Mdot
.03157 .36249 Mdot
.03162 .19069 Mdot
.03167 .24215 Mdot
.03171 .14795 Mdot
.03176 .05325 Mdot
.03181 .14932 Mdot
.03186 .1508 Mdot
.0319 .27712 Mdot
.03195 .11652 Mdot
.032 .37853 Mdot
.03205 .02267 Mdot
.03209 .08755 Mdot
.03214 .18604 Mdot
.03219 .57076 Mdot
.03224 .45842 Mdot
.03228 .42825 Mdot
.03233 .11996 Mdot
.03238 .42351 Mdot
.03243 .43128 Mdot
.03248 .22581 Mdot
.03252 .26218 Mdot
.03257 .1669 Mdot
.03262 .11869 Mdot
.03267 .32953 Mdot
.03271 .50302 Mdot
.03276 .57954 Mdot
.03281 .47987 Mdot
.03286 .19629 Mdot
.0329 .46447 Mdot
.03295 .44492 Mdot
.033 .34378 Mdot
.03305 .52249 Mdot
.03309 .36266 Mdot
.03314 .0811 Mdot
.03319 .33582 Mdot
.03324 .44965 Mdot
.03328 .19133 Mdot
.03333 .11367 Mdot
.03338 .48072 Mdot
.03343 .03611 Mdot
.03348 .08608 Mdot
.03352 .29349 Mdot
.03357 .06415 Mdot
.03362 .41362 Mdot
.03367 .42722 Mdot
.03371 .14129 Mdot
.03376 .54878 Mdot
.03381 .0988 Mdot
.03386 .52753 Mdot
.0339 .16508 Mdot
.03395 .08362 Mdot
.034 .50584 Mdot
.03405 .07777 Mdot
.03409 .32349 Mdot
.03414 .34316 Mdot
.03419 .58667 Mdot
.03424 .31844 Mdot
.03428 .25709 Mdot
.03433 .02205 Mdot
.03438 .15172 Mdot
.03443 .14182 Mdot
.03448 .15813 Mdot
.03452 .14465 Mdot
.03457 .13032 Mdot
.03462 .07045 Mdot
.03467 .46796 Mdot
.03471 .09521 Mdot
.03476 .32002 Mdot
.03481 .24655 Mdot
.03486 .34138 Mdot
.0349 .14975 Mdot
.03495 .23593 Mdot
.035 .32234 Mdot
.03505 .191 Mdot
.03509 .08084 Mdot
.03514 .33342 Mdot
.03519 .25928 Mdot
.03524 .47084 Mdot
.03528 .34101 Mdot
.03533 .35007 Mdot
.03538 .54416 Mdot
.03543 .22846 Mdot
.03548 .33367 Mdot
.03552 .21306 Mdot
.03557 .41705 Mdot
.03562 .08504 Mdot
.03567 .20373 Mdot
.03571 .09744 Mdot
.03576 .36131 Mdot
.03581 .2204 Mdot
.03586 .12324 Mdot
.0359 .38075 Mdot
.03595 .12947 Mdot
.036 .48235 Mdot
.03605 .57681 Mdot
.03609 .15952 Mdot
.03614 .41046 Mdot
.03619 .30605 Mdot
.03624 .51068 Mdot
.03628 .42943 Mdot
.03633 .16589 Mdot
.03638 .43854 Mdot
.03643 .18437 Mdot
.03647 .09407 Mdot
.03652 .22506 Mdot
.03657 .22479 Mdot
.03662 .45403 Mdot
.03667 .48434 Mdot
.03671 .41133 Mdot
.03676 .15446 Mdot
.03681 .265 Mdot
.03686 .4016 Mdot
.0369 .06472 Mdot
.03695 .53738 Mdot
.037 .15647 Mdot
.03705 .03556 Mdot
.03709 .53857 Mdot
.03714 .06974 Mdot
.03719 .18299 Mdot
.03724 .47937 Mdot
.03728 .14282 Mdot
.03733 .36701 Mdot
.03738 .27564 Mdot
.03743 .06464 Mdot
.03747 .58026 Mdot
.03752 .5318 Mdot
.03757 .10597 Mdot
.03762 .5739 Mdot
.03767 .36991 Mdot
.03771 .32172 Mdot
.03776 .25527 Mdot
.03781 .10427 Mdot
.03786 .5619 Mdot
.0379 .18197 Mdot
.03795 .5936 Mdot
.038 .30599 Mdot
.03805 .51189 Mdot
.03809 .24792 Mdot
.03814 .45183 Mdot
.03819 .28513 Mdot
.03824 .57664 Mdot
.03828 .19288 Mdot
.03833 .28355 Mdot
.03838 .4091 Mdot
.03843 .44853 Mdot
.03847 .4292 Mdot
.03852 .02262 Mdot
.03857 .35916 Mdot
.03862 .4716 Mdot
.03867 .50072 Mdot
.03871 .51997 Mdot
.03876 .38859 Mdot
.03881 .1164 Mdot
.03886 .19371 Mdot
.0389 .27941 Mdot
.03895 .29903 Mdot
.039 .15782 Mdot
.03905 .02645 Mdot
.03909 .28913 Mdot
.03914 .59637 Mdot
.03919 .24926 Mdot
.03924 .38186 Mdot
.03928 .44063 Mdot
.03933 .32594 Mdot
.03938 .27594 Mdot
.03943 .20368 Mdot
.03947 .17178 Mdot
.03952 .52017 Mdot
.03957 .43074 Mdot
.03962 .37781 Mdot
.03967 .16387 Mdot
.03971 .17572 Mdot
.03976 .56247 Mdot
.03981 .48041 Mdot
.03986 .24723 Mdot
.0399 .39045 Mdot
.03995 .46078 Mdot
.04 .30141 Mdot
.04005 .57115 Mdot
.04009 .10613 Mdot
.04014 .31767 Mdot
.04019 .28967 Mdot
.04024 .29672 Mdot
.04028 .11308 Mdot
.04033 .08313 Mdot
.04038 .51114 Mdot
.04043 .45942 Mdot
.04047 .39047 Mdot
.04052 .41051 Mdot
.04057 .32217 Mdot
.04062 .30235 Mdot
.04066 .47362 Mdot
.04071 .58309 Mdot
.04076 .54768 Mdot
.04081 .15318 Mdot
.04086 .31261 Mdot
.0409 .03533 Mdot
.04095 .08198 Mdot
.041 .50928 Mdot
.04105 .52549 Mdot
.04109 .17788 Mdot
.04114 .38389 Mdot
.04119 .54146 Mdot
.04124 .43407 Mdot
.04128 .46353 Mdot
.04133 .10893 Mdot
.04138 .25945 Mdot
.04143 .3357 Mdot
.04147 .39511 Mdot
.04152 .20111 Mdot
.04157 .40335 Mdot
.04162 .54855 Mdot
.04166 .58793 Mdot
.04171 .48227 Mdot
.04176 .11571 Mdot
.04181 .08964 Mdot
.04186 .01954 Mdot
.0419 .53791 Mdot
.04195 .56585 Mdot
.042 .38035 Mdot
.04205 .58754 Mdot
.04209 .47064 Mdot
.04214 .07128 Mdot
.04219 .45819 Mdot
.04224 .42437 Mdot
.04228 .10145 Mdot
.04233 .13314 Mdot
.04238 .03882 Mdot
.04243 .56416 Mdot
.04247 .59585 Mdot
.04252 .47702 Mdot
.04257 .30645 Mdot
.04262 .18376 Mdot
.04266 .40944 Mdot
.04271 .08838 Mdot
.04276 .36122 Mdot
.04281 .19916 Mdot
.04286 .5305 Mdot
.0429 .576 Mdot
.04295 .28629 Mdot
.043 .19432 Mdot
.04305 .59592 Mdot
.04309 .02485 Mdot
.04314 .50927 Mdot
.04319 .21011 Mdot
.04324 .13999 Mdot
.04328 .5569 Mdot
.04333 .06579 Mdot
.04338 .38907 Mdot
.04343 .05324 Mdot
.04347 .43846 Mdot
.04352 .04167 Mdot
.04357 .42823 Mdot
.04362 .06072 Mdot
.04366 .56477 Mdot
.04371 .33855 Mdot
.04376 .25918 Mdot
.04381 .2546 Mdot
.04386 .49109 Mdot
.0439 .58065 Mdot
.04395 .07473 Mdot
.044 .32743 Mdot
.04405 .51842 Mdot
.04409 .30907 Mdot
.04414 .48373 Mdot
.04419 .33484 Mdot
.04424 .50828 Mdot
.04428 .40313 Mdot
.04433 .28833 Mdot
.04438 .20956 Mdot
.04443 .55471 Mdot
.04447 .35205 Mdot
.04452 .50259 Mdot
.04457 .17103 Mdot
.04462 .13095 Mdot
.04466 .32508 Mdot
.04471 .08906 Mdot
.04476 .12502 Mdot
.04481 .16951 Mdot
.04486 .58986 Mdot
.0449 .43321 Mdot
.04495 .47374 Mdot
.045 .28174 Mdot
.04505 .02392 Mdot
.04509 .37318 Mdot
.04514 .16102 Mdot
.04519 .36664 Mdot
.04524 .31818 Mdot
.04528 .49278 Mdot
.04533 .4295 Mdot
.04538 .46169 Mdot
.04543 .51838 Mdot
.04547 .21915 Mdot
.04552 .23465 Mdot
.04557 .5103 Mdot
.04562 .18104 Mdot
.04566 .31989 Mdot
.04571 .07833 Mdot
.04576 .39406 Mdot
.04581 .45928 Mdot
.04585 .24554 Mdot
.0459 .55664 Mdot
.04595 .23925 Mdot
.046 .47275 Mdot
.04605 .41566 Mdot
.04609 .09761 Mdot
.04614 .56083 Mdot
.04619 .46354 Mdot
.04624 .05718 Mdot
.04628 .53992 Mdot
.04633 .2089 Mdot
.04638 .16007 Mdot
.04643 .16773 Mdot
.04647 .12512 Mdot
.04652 .35054 Mdot
.04657 .24501 Mdot
.04662 .5519 Mdot
.04666 .4938 Mdot
.04671 .44356 Mdot
.04676 .07868 Mdot
.04681 .24672 Mdot
.04685 .43018 Mdot
.0469 .06421 Mdot
.04695 .22273 Mdot
.047 .01589 Mdot
.04705 .47687 Mdot
.04709 .42828 Mdot
.04714 .3533 Mdot
.04719 .20356 Mdot
.04724 .39397 Mdot
.04728 .47078 Mdot
.04733 .49309 Mdot
.04738 .16109 Mdot
.04743 .45738 Mdot
.04747 .27659 Mdot
.04752 .34773 Mdot
.04757 .59668 Mdot
.04762 .34696 Mdot
.04766 .52937 Mdot
.04771 .11743 Mdot
.04776 .05949 Mdot
.04781 .45649 Mdot
.04785 .10052 Mdot
.0479 .05345 Mdot
.04795 .4161 Mdot
.048 .04101 Mdot
.04805 .05102 Mdot
.04809 .43405 Mdot
.04814 .41492 Mdot
.04819 .16747 Mdot
.04824 .22606 Mdot
.04828 .09546 Mdot
.04833 .22607 Mdot
.04838 .37683 Mdot
.04843 .35861 Mdot
.04847 .20569 Mdot
.04852 .07969 Mdot
.04857 .52278 Mdot
.04862 .09673 Mdot
.04866 .46128 Mdot
.04871 .08633 Mdot
.04876 .19053 Mdot
.04881 .17069 Mdot
.04885 .35857 Mdot
.0489 .04155 Mdot
.04895 .33737 Mdot
.049 .08487 Mdot
.04905 .31982 Mdot
.04909 .22878 Mdot
.04914 .31106 Mdot
.04919 .04856 Mdot
.04924 .4891 Mdot
.04928 .41718 Mdot
.04933 .1583 Mdot
.04938 .42582 Mdot
.04943 .40835 Mdot
.04947 .20582 Mdot
.04952 .38479 Mdot
.04957 .08192 Mdot
.04962 .21736 Mdot
.04966 .14084 Mdot
.04971 .46534 Mdot
.04976 .58851 Mdot
.04981 .3594 Mdot
.04985 .06922 Mdot
.0499 .28952 Mdot
.04995 .43253 Mdot
.05 .01555 Mdot
.05004 .04238 Mdot
.05009 .55548 Mdot
.05014 .36237 Mdot
.05019 .29905 Mdot
.05024 .41693 Mdot
.05028 .25913 Mdot
.05033 .32852 Mdot
.05038 .41328 Mdot
.05043 .60307 Mdot
.05047 .11554 Mdot
.05052 .50602 Mdot
.05057 .01964 Mdot
.05062 .41196 Mdot
.05066 .33407 Mdot
.05071 .43881 Mdot
.05076 .4056 Mdot
.05081 .28583 Mdot
.05085 .47205 Mdot
.0509 .45362 Mdot
.05095 .06091 Mdot
.051 .23131 Mdot
.05104 .19724 Mdot
.05109 .0358 Mdot
.05114 .06007 Mdot
.05119 .20364 Mdot
.05124 .24508 Mdot
.05128 .27675 Mdot
.05133 .36434 Mdot
.05138 .39004 Mdot
.05143 .58928 Mdot
.05147 .55156 Mdot
.05152 .55439 Mdot
.05157 .39029 Mdot
.05162 .48846 Mdot
.05166 .06025 Mdot
.05171 .54946 Mdot
.05176 .58166 Mdot
.05181 .1691 Mdot
.05185 .22477 Mdot
.0519 .15857 Mdot
.05195 .31054 Mdot
.052 .30037 Mdot
.05204 .37447 Mdot
.05209 .11237 Mdot
.05214 .09394 Mdot
.05219 .11784 Mdot
.05224 .35338 Mdot
.05228 .06701 Mdot
.05233 .49362 Mdot
.05238 .47608 Mdot
.05243 .09134 Mdot
.05247 .30599 Mdot
.05252 .11829 Mdot
.05257 .49012 Mdot
.05262 .14311 Mdot
.05266 .35493 Mdot
.05271 .33132 Mdot
.05276 .01638 Mdot
.05281 .09757 Mdot
.05285 .40879 Mdot
.0529 .35299 Mdot
.05295 .4506 Mdot
.053 .47613 Mdot
.05304 .26494 Mdot
.05309 .05715 Mdot
.05314 .16494 Mdot
.05319 .11637 Mdot
.05324 .16728 Mdot
.05328 .56654 Mdot
.05333 .0618 Mdot
.05338 .36631 Mdot
.05343 .11498 Mdot
.05347 .08763 Mdot
.05352 .18905 Mdot
.05357 .28967 Mdot
.05362 .41231 Mdot
.05366 .57267 Mdot
.05371 .30225 Mdot
.05376 .16127 Mdot
.05381 .07209 Mdot
.05385 .25606 Mdot
.0539 .30058 Mdot
.05395 .07841 Mdot
.054 .26663 Mdot
.05404 .5064 Mdot
.05409 .4533 Mdot
.05414 .2056 Mdot
.05419 .0164 Mdot
.05424 .46396 Mdot
.05428 .30307 Mdot
.05433 .10394 Mdot
.05438 .45245 Mdot
.05443 .50074 Mdot
.05447 .25598 Mdot
.05452 .34096 Mdot
.05457 .35218 Mdot
.05462 .42781 Mdot
.05466 .08164 Mdot
.05471 .066 Mdot
.05476 .54319 Mdot
.05481 .45847 Mdot
.05485 .38272 Mdot
.0549 .50805 Mdot
.05495 .48581 Mdot
.055 .21712 Mdot
.05504 .09685 Mdot
.05509 .44435 Mdot
.05514 .23389 Mdot
.05519 .31404 Mdot
.05523 .24687 Mdot
.05528 .25345 Mdot
.05533 .2322 Mdot
.05538 .45341 Mdot
.05543 .54712 Mdot
.05547 .16422 Mdot
.05552 .38308 Mdot
.05557 .55599 Mdot
.05562 .30585 Mdot
.05566 .42658 Mdot
.05571 .04561 Mdot
.05576 .14289 Mdot
.05581 .23891 Mdot
.05585 .37529 Mdot
.0559 .10574 Mdot
.05595 .28775 Mdot
.056 .45952 Mdot
.05604 .47057 Mdot
.05609 .22326 Mdot
.05614 .08534 Mdot
.05619 .37738 Mdot
.05623 .04093 Mdot
.05628 .59269 Mdot
.05633 .37462 Mdot
.05638 .14523 Mdot
.05643 .3908 Mdot
.05647 .3752 Mdot
.05652 .52454 Mdot
.05657 .20144 Mdot
.05662 .24129 Mdot
.05666 .59544 Mdot
.05671 .57187 Mdot
.05676 .49892 Mdot
.05681 .41804 Mdot
.05685 .56454 Mdot
.0569 .44369 Mdot
.05695 .27471 Mdot
.057 .05745 Mdot
.05704 .4735 Mdot
.05709 .17065 Mdot
.05714 .41851 Mdot
.05719 .19021 Mdot
.05723 .26495 Mdot
.05728 .10002 Mdot
.05733 .05584 Mdot
.05738 .16398 Mdot
.05743 .27558 Mdot
.05747 .32873 Mdot
.05752 .51394 Mdot
.05757 .37651 Mdot
.05762 .50371 Mdot
.05766 .40751 Mdot
.05771 .32721 Mdot
.05776 .14992 Mdot
.05781 .51159 Mdot
.05785 .43896 Mdot
.0579 .43162 Mdot
.05795 .33521 Mdot
.058 .55038 Mdot
.05804 .5986 Mdot
.05809 .17162 Mdot
.05814 .29247 Mdot
.05819 .09159 Mdot
.05823 .44265 Mdot
.05828 .35643 Mdot
.05833 .11697 Mdot
.05838 .42997 Mdot
.05843 .35734 Mdot
.05847 .3153 Mdot
.05852 .55631 Mdot
.05857 .16909 Mdot
.05862 .04332 Mdot
.05866 .40469 Mdot
.05871 .19451 Mdot
.05876 .26871 Mdot
.05881 .23914 Mdot
.05885 .09219 Mdot
.0589 .0593 Mdot
.05895 .36044 Mdot
.059 .4035 Mdot
.05904 .26389 Mdot
.05909 .32741 Mdot
.05914 .41338 Mdot
.05919 .40822 Mdot
.05923 .10698 Mdot
.05928 .04965 Mdot
.05933 .3365 Mdot
.05938 .5689 Mdot
.05943 .35388 Mdot
.05947 .53601 Mdot
.05952 .50986 Mdot
.05957 .22627 Mdot
.05962 .05329 Mdot
.05966 .58302 Mdot
.05971 .35548 Mdot
.05976 .19766 Mdot
.05981 .25193 Mdot
.05985 .40322 Mdot
.0599 .10148 Mdot
.05995 .56185 Mdot
.06 .17445 Mdot
.06004 .35862 Mdot
.06009 .34436 Mdot
.06014 .17306 Mdot
.06019 .51389 Mdot
.06023 .04592 Mdot
.06028 .53431 Mdot
.06033 .36816 Mdot
.06038 .42161 Mdot
.06042 .59959 Mdot
.06047 .21251 Mdot
.06052 .40259 Mdot
.06057 .08244 Mdot
.06062 .07829 Mdot
.06066 .30598 Mdot
.06071 .19103 Mdot
.06076 .04386 Mdot
.06081 .09859 Mdot
.06085 .55382 Mdot
.0609 .59669 Mdot
.06095 .39525 Mdot
.061 .2987 Mdot
.06104 .46705 Mdot
.06109 .04956 Mdot
.06114 .23551 Mdot
.06119 .5434 Mdot
.06123 .1374 Mdot
.06128 .47982 Mdot
.06133 .32495 Mdot
.06138 .51219 Mdot
.06142 .20642 Mdot
.06147 .12637 Mdot
.06152 .50666 Mdot
.06157 .51593 Mdot
.06162 .59723 Mdot
.06166 .32711 Mdot
.06171 .43893 Mdot
.06176 .45235 Mdot
.06181 .30596 Mdot
.06185 .15079 Mdot
.0619 .40978 Mdot
.06195 .36847 Mdot
.062 .35546 Mdot
.06204 .15742 Mdot
.06209 .02923 Mdot
.06214 .08447 Mdot
.06219 .49173 Mdot
.06223 .12257 Mdot
.06228 .39705 Mdot
.06233 .14439 Mdot
.06238 .36904 Mdot
.06242 .24608 Mdot
.06247 .08681 Mdot
.06252 .23552 Mdot
.06257 .17733 Mdot
.06262 .13442 Mdot
.06266 .18347 Mdot
.06271 .32292 Mdot
.06276 .18343 Mdot
.06281 .41063 Mdot
.06285 .34787 Mdot
.0629 .47389 Mdot
.06295 .4808 Mdot
.063 .27455 Mdot
.06304 .54142 Mdot
.06309 .12013 Mdot
.06314 .14005 Mdot
.06319 .13184 Mdot
.06323 .52689 Mdot
.06328 .05037 Mdot
.06333 .25164 Mdot
.06338 .02398 Mdot
.06342 .14455 Mdot
.06347 .5093 Mdot
.06352 .48593 Mdot
.06357 .38123 Mdot
.06362 .07245 Mdot
.06366 .28849 Mdot
.06371 .3233 Mdot
.06376 .26152 Mdot
.06381 .49231 Mdot
.06385 .5689 Mdot
.0639 .15458 Mdot
.06395 .45421 Mdot
.064 .15915 Mdot
.06404 .10971 Mdot
.06409 .27711 Mdot
.06414 .19437 Mdot
.06419 .22106 Mdot
.06423 .5929 Mdot
.06428 .15177 Mdot
.06433 .07723 Mdot
.06438 .29749 Mdot
.06442 .55724 Mdot
.06447 .50345 Mdot
.06452 .06796 Mdot
.06457 .16765 Mdot
.06461 .06265 Mdot
.06466 .03223 Mdot
.06471 .29006 Mdot
.06476 .1099 Mdot
.06481 .37748 Mdot
.06485 .31225 Mdot
.0649 .04325 Mdot
.06495 .22092 Mdot
.065 .41191 Mdot
.06504 .17238 Mdot
.06509 .19236 Mdot
.06514 .07648 Mdot
.06519 .31691 Mdot
.06523 .49859 Mdot
.06528 .60132 Mdot
.06533 .45875 Mdot
.06538 .32733 Mdot
.06542 .36154 Mdot
.06547 .5388 Mdot
.06552 .17597 Mdot
.06557 .37342 Mdot
.06561 .46142 Mdot
.06566 .48554 Mdot
.06571 .02303 Mdot
.06576 .32548 Mdot
.06581 .4439 Mdot
.06585 .21019 Mdot
.0659 .51645 Mdot
.06595 .55132 Mdot
.066 .14636 Mdot
.06604 .18165 Mdot
.06609 .31024 Mdot
.06614 .15412 Mdot
.06619 .57731 Mdot
.06623 .59261 Mdot
.06628 .24847 Mdot
.06633 .44054 Mdot
.06638 .09342 Mdot
.06642 .59461 Mdot
.06647 .39304 Mdot
.06652 .12791 Mdot
.06657 .33521 Mdot
.06661 .07052 Mdot
.06666 .23178 Mdot
.06671 .35782 Mdot
.06676 .47712 Mdot
.06681 .18831 Mdot
.06685 .22346 Mdot
.0669 .04704 Mdot
.06695 .04793 Mdot
.067 .58145 Mdot
.06704 .31033 Mdot
.06709 .09904 Mdot
.06714 .5049 Mdot
.06719 .41451 Mdot
.06723 .0148 Mdot
.06728 .54825 Mdot
.06733 .53091 Mdot
.06738 .42523 Mdot
.06742 .36965 Mdot
.06747 .12242 Mdot
.06752 .4522 Mdot
.06757 .43394 Mdot
.06761 .57994 Mdot
.06766 .59784 Mdot
.06771 .1317 Mdot
.06776 .37812 Mdot
.06781 .36286 Mdot
.06785 .25473 Mdot
.0679 .25791 Mdot
.06795 .20453 Mdot
.068 .15411 Mdot
.06804 .22239 Mdot
.06809 .22469 Mdot
.06814 .22641 Mdot
.06819 .4471 Mdot
.06823 .13806 Mdot
.06828 .32312 Mdot
.06833 .41522 Mdot
.06838 .44701 Mdot
.06842 .19313 Mdot
.06847 .39553 Mdot
.06852 .59332 Mdot
.06857 .09207 Mdot
.06861 .08542 Mdot
.06866 .54665 Mdot
.06871 .17409 Mdot
.06876 .11546 Mdot
.06881 .09091 Mdot
.06885 .42966 Mdot
.0689 .39929 Mdot
.06895 .35592 Mdot
.069 .4395 Mdot
.06904 .18646 Mdot
.06909 .20948 Mdot
.06914 .21652 Mdot
.06919 .23182 Mdot
.06923 .5651 Mdot
.06928 .58639 Mdot
.06933 .37275 Mdot
.06938 .10847 Mdot
.06942 .25669 Mdot
.06947 .18588 Mdot
.06952 .52906 Mdot
.06957 .51866 Mdot
.06961 .46449 Mdot
.06966 .19588 Mdot
.06971 .4517 Mdot
.06976 .44795 Mdot
.0698 .52117 Mdot
.06985 .0365 Mdot
.0699 .35095 Mdot
.06995 .37175 Mdot
.07 .10622 Mdot
.07004 .24053 Mdot
.07009 .59836 Mdot
.07014 .53557 Mdot
.07019 .52309 Mdot
.07023 .04576 Mdot
.07028 .39654 Mdot
.07033 .31846 Mdot
.07038 .56131 Mdot
.07042 .06269 Mdot
.07047 .0385 Mdot
.07052 .2247 Mdot
.07057 .31933 Mdot
.07061 .48014 Mdot
.07066 .11277 Mdot
.07071 .30936 Mdot
.07076 .45817 Mdot
.0708 .29897 Mdot
.07085 .26439 Mdot
.0709 .46473 Mdot
.07095 .54033 Mdot
.071 .27718 Mdot
.07104 .51676 Mdot
.07109 .10769 Mdot
.07114 .44882 Mdot
.07119 .05136 Mdot
.07123 .52173 Mdot
.07128 .17544 Mdot
.07133 .52906 Mdot
.07138 .0203 Mdot
.07142 .1399 Mdot
.07147 .4603 Mdot
.07152 .57107 Mdot
.07157 .56094 Mdot
.07161 .1161 Mdot
.07166 .25031 Mdot
.07171 .26645 Mdot
.07176 .0955 Mdot
.0718 .01804 Mdot
.07185 .54427 Mdot
.0719 .4116 Mdot
.07195 .39986 Mdot
.072 .35698 Mdot
.07204 .09425 Mdot
.07209 .4746 Mdot
.07214 .13739 Mdot
.07219 .44354 Mdot
.07223 .58989 Mdot
.07228 .04049 Mdot
.07233 .10074 Mdot
.07238 .52513 Mdot
.07242 .42916 Mdot
.07247 .11475 Mdot
.07252 .09514 Mdot
.07257 .39994 Mdot
.07261 .57218 Mdot
.07266 .147 Mdot
.07271 .13753 Mdot
.07276 .29854 Mdot
.0728 .33658 Mdot
.07285 .48388 Mdot
.0729 .05674 Mdot
.07295 .29521 Mdot
.073 .39564 Mdot
.07304 .08699 Mdot
.07309 .2602 Mdot
.07314 .54155 Mdot
.07319 .3161 Mdot
.07323 .21572 Mdot
.07328 .13752 Mdot
.07333 .11272 Mdot
.07338 .32953 Mdot
.07342 .18994 Mdot
.07347 .05149 Mdot
.07352 .19092 Mdot
.07357 .5037 Mdot
.07361 .0899 Mdot
.07366 .55967 Mdot
.07371 .39431 Mdot
.07376 .53484 Mdot
.0738 .54622 Mdot
.07385 .43685 Mdot
.0739 .11047 Mdot
.07395 .21296 Mdot
.07399 .07705 Mdot
.07404 .39482 Mdot
.07409 .41859 Mdot
.07414 .42065 Mdot
.07419 .59338 Mdot
.07423 .14933 Mdot
.07428 .48036 Mdot
.07433 .11926 Mdot
.07438 .39237 Mdot
.07442 .02652 Mdot
.07447 .38235 Mdot
.07452 .39306 Mdot
.07457 .21714 Mdot
.07461 .57835 Mdot
.07466 .20614 Mdot
.07471 .49268 Mdot
.07476 .14195 Mdot
.0748 .03339 Mdot
.07485 .41515 Mdot
.0749 .56117 Mdot
.07495 .19905 Mdot
.07499 .19987 Mdot
.07504 .31939 Mdot
.07509 .36291 Mdot
.07514 .13671 Mdot
.07519 .40837 Mdot
.07523 .50412 Mdot
.07528 .54559 Mdot
.07533 .14666 Mdot
.07538 .27375 Mdot
.07542 .03846 Mdot
.07547 .44103 Mdot
.07552 .35761 Mdot
.07557 .26194 Mdot
.07561 .25944 Mdot
.07566 .06268 Mdot
.07571 .15518 Mdot
.07576 .28691 Mdot
.0758 .06801 Mdot
.07585 .17333 Mdot
.0759 .02794 Mdot
.07595 .26823 Mdot
.07599 .25619 Mdot
.07604 .21548 Mdot
.07609 .43221 Mdot
.07614 .08307 Mdot
.07619 .54012 Mdot
.07623 .45589 Mdot
.07628 .31021 Mdot
.07633 .27802 Mdot
.07638 .05071 Mdot
.07642 .51363 Mdot
.07647 .17826 Mdot
.07652 .01898 Mdot
.07657 .02696 Mdot
.07661 .08731 Mdot
.07666 .42397 Mdot
.07671 .36037 Mdot
.07676 .37084 Mdot
.0768 .03934 Mdot
.07685 .2835 Mdot
.0769 .08817 Mdot
.07695 .31753 Mdot
.07699 .46934 Mdot
.07704 .27027 Mdot
.07709 .42327 Mdot
.07714 .07606 Mdot
.07719 .26856 Mdot
.07723 .44138 Mdot
.07728 .35491 Mdot
.07733 .13926 Mdot
.07738 .41599 Mdot
.07742 .14588 Mdot
.07747 .0916 Mdot
.07752 .10326 Mdot
.07757 .50569 Mdot
.07761 .57095 Mdot
.07766 .08732 Mdot
.07771 .09101 Mdot
.07776 .43309 Mdot
.0778 .16169 Mdot
.07785 .33028 Mdot
.0779 .3235 Mdot
.07795 .40846 Mdot
.07799 .48151 Mdot
.07804 .25681 Mdot
.07809 .02067 Mdot
.07814 .54245 Mdot
.07819 .22595 Mdot
.07823 .43687 Mdot
.07828 .54794 Mdot
.07833 .28859 Mdot
.07838 .38789 Mdot
.07842 .09666 Mdot
.07847 .42339 Mdot
.07852 .47593 Mdot
.07857 .25672 Mdot
.07861 .01977 Mdot
.07866 .33484 Mdot
.07871 .57356 Mdot
.07876 .2891 Mdot
.0788 .53578 Mdot
.07885 .25854 Mdot
.0789 .15519 Mdot
.07895 .14212 Mdot
.07899 .22021 Mdot
.07904 .53837 Mdot
.07909 .35005 Mdot
.07914 .26394 Mdot
.07918 .56672 Mdot
.07923 .53241 Mdot
.07928 .41093 Mdot
.07933 .0527 Mdot
.07938 .14457 Mdot
.07942 .5878 Mdot
.07947 .13704 Mdot
.07952 .26813 Mdot
.07957 .06261 Mdot
.07961 .17912 Mdot
.07966 .26444 Mdot
.07971 .02612 Mdot
.07976 .05755 Mdot
.0798 .4476 Mdot
.07985 .29421 Mdot
.0799 .34034 Mdot
.07995 .12509 Mdot
.07999 .20377 Mdot
.08004 .15373 Mdot
.08009 .21293 Mdot
.08014 .50821 Mdot
.08018 .26872 Mdot
.08023 .407 Mdot
.08028 .55232 Mdot
.08033 .54481 Mdot
.08038 .33964 Mdot
.08042 .5994 Mdot
.08047 .51433 Mdot
.08052 .41495 Mdot
.08057 .35517 Mdot
.08061 .47706 Mdot
.08066 .26092 Mdot
.08071 .36704 Mdot
.08076 .19076 Mdot
.0808 .22733 Mdot
.08085 .24951 Mdot
.0809 .32421 Mdot
.08095 .34649 Mdot
.08099 .53644 Mdot
.08104 .51249 Mdot
.08109 .21382 Mdot
.08114 .15742 Mdot
.08118 .39742 Mdot
.08123 .31427 Mdot
.08128 .30894 Mdot
.08133 .49203 Mdot
.08138 .59375 Mdot
.08142 .36527 Mdot
.08147 .36746 Mdot
.08152 .16709 Mdot
.08157 .59767 Mdot
.08161 .45426 Mdot
.08166 .55584 Mdot
.08171 .41525 Mdot
.08176 .13532 Mdot
.0818 .20805 Mdot
.08185 .2035 Mdot
.0819 .2392 Mdot
.08195 .51132 Mdot
.08199 .56187 Mdot
.08204 .48262 Mdot
.08209 .49604 Mdot
.08214 .5782 Mdot
.08218 .06409 Mdot
.08223 .2835 Mdot
.08228 .35332 Mdot
.08233 .19549 Mdot
.08238 .35314 Mdot
.08242 .57789 Mdot
.08247 .46462 Mdot
.08252 .20507 Mdot
.08257 .5912 Mdot
.08261 .22514 Mdot
.08266 .31223 Mdot
.08271 .21072 Mdot
.08276 .15165 Mdot
.0828 .27262 Mdot
.08285 .50031 Mdot
.0829 .0901 Mdot
.08295 .54692 Mdot
.08299 .08383 Mdot
.08304 .27582 Mdot
.08309 .18211 Mdot
.08314 .58837 Mdot
.08318 .20454 Mdot
.08323 .38311 Mdot
.08328 .20723 Mdot
.08333 .539 Mdot
.08337 .52436 Mdot
.08342 .0445 Mdot
.08347 .02645 Mdot
.08352 .20056 Mdot
.08357 .5498 Mdot
.08361 .1832 Mdot
.08366 .42471 Mdot
.08371 .21269 Mdot
.08376 .33937 Mdot
.0838 .4743 Mdot
.08385 .2287 Mdot
.0839 .07575 Mdot
.08395 .08146 Mdot
.08399 .57731 Mdot
.08404 .1533 Mdot
.08409 .13216 Mdot
.08414 .60095 Mdot
.08418 .3162 Mdot
.08423 .57452 Mdot
.08428 .14711 Mdot
.08433 .41112 Mdot
.08437 .53642 Mdot
.08442 .382 Mdot
.08447 .21144 Mdot
.08452 .49008 Mdot
.08457 .50663 Mdot
.08461 .37025 Mdot
.08466 .02559 Mdot
.08471 .54361 Mdot
.08476 .33813 Mdot
.0848 .54887 Mdot
.08485 .41623 Mdot
.0849 .21894 Mdot
.08495 .46716 Mdot
.08499 .33488 Mdot
.08504 .35519 Mdot
.08509 .1522 Mdot
.08514 .49318 Mdot
.08518 .19628 Mdot
.08523 .23774 Mdot
.08528 .15457 Mdot
.08533 .19169 Mdot
.08537 .22509 Mdot
.08542 .10534 Mdot
.08547 .34678 Mdot
.08552 .25859 Mdot
.08557 .44642 Mdot
.08561 .49722 Mdot
.08566 .46002 Mdot
.08571 .35529 Mdot
.08576 .09087 Mdot
.0858 .48634 Mdot
.08585 .51974 Mdot
.0859 .03187 Mdot
.08595 .14532 Mdot
.08599 .08482 Mdot
.08604 .31551 Mdot
.08609 .16803 Mdot
.08614 .41377 Mdot
.08618 .33295 Mdot
.08623 .17802 Mdot
.08628 .27818 Mdot
.08633 .2322 Mdot
.08637 .10993 Mdot
.08642 .03816 Mdot
.08647 .1012 Mdot
.08652 .02182 Mdot
.08657 .0193 Mdot
.08661 .2947 Mdot
.08666 .44593 Mdot
.08671 .17872 Mdot
.08676 .1254 Mdot
.0868 .43801 Mdot
.08685 .10535 Mdot
.0869 .10256 Mdot
.08695 .24239 Mdot
.08699 .52159 Mdot
.08704 .08819 Mdot
.08709 .56056 Mdot
.08714 .17228 Mdot
.08718 .22079 Mdot
.08723 .52349 Mdot
.08728 .1615 Mdot
.08733 .44265 Mdot
.08737 .05748 Mdot
.08742 .26002 Mdot
.08747 .53263 Mdot
.08752 .34744 Mdot
.08757 .03403 Mdot
.08761 .17352 Mdot
.08766 .52552 Mdot
.08771 .34285 Mdot
.08776 .34265 Mdot
.0878 .33091 Mdot
.08785 .36151 Mdot
.0879 .23215 Mdot
.08795 .50797 Mdot
.08799 .24027 Mdot
.08804 .27365 Mdot
.08809 .59309 Mdot
.08814 .5897 Mdot
.08818 .16679 Mdot
.08823 .31642 Mdot
.08828 .43551 Mdot
.08833 .38362 Mdot
.08837 .24663 Mdot
.08842 .16963 Mdot
.08847 .59618 Mdot
.08852 .34085 Mdot
.08856 .58994 Mdot
.08861 .24032 Mdot
.08866 .26345 Mdot
.08871 .32154 Mdot
.08876 .43112 Mdot
.0888 .31812 Mdot
.08885 .52393 Mdot
.0889 .58221 Mdot
.08895 .11492 Mdot
.08899 .55994 Mdot
.08904 .30649 Mdot
.08909 .08895 Mdot
.08914 .47797 Mdot
.08918 .30099 Mdot
.08923 .31673 Mdot
.08928 .10257 Mdot
.08933 .32589 Mdot
.08937 .5879 Mdot
.08942 .48454 Mdot
.08947 .32228 Mdot
.08952 .09397 Mdot
.08956 .43298 Mdot
.08961 .49169 Mdot
.08966 .58475 Mdot
.08971 .10736 Mdot
.08976 .20737 Mdot
.0898 .24294 Mdot
.08985 .27792 Mdot
.0899 .27956 Mdot
.08995 .49257 Mdot
.08999 .32234 Mdot
.09004 .29903 Mdot
.09009 .17935 Mdot
.09014 .53596 Mdot
.09018 .03056 Mdot
.09023 .22479 Mdot
.09028 .3047 Mdot
.09033 .24967 Mdot
.09037 .31715 Mdot
.09042 .13692 Mdot
.09047 .58214 Mdot
.09052 .26509 Mdot
.09056 .43594 Mdot
.09061 .41797 Mdot
.09066 .50288 Mdot
.09071 .43543 Mdot
.09076 .54758 Mdot
.0908 .43655 Mdot
.09085 .41023 Mdot
.0909 .24277 Mdot
.09095 .31934 Mdot
.09099 .17334 Mdot
.09104 .14538 Mdot
.09109 .35352 Mdot
.09114 .60033 Mdot
.09118 .47763 Mdot
.09123 .56936 Mdot
.09128 .42089 Mdot
.09133 .58448 Mdot
.09137 .26755 Mdot
.09142 .27936 Mdot
.09147 .18593 Mdot
.09152 .28203 Mdot
.09156 .14534 Mdot
.09161 .30055 Mdot
.09166 .52416 Mdot
.09171 .44942 Mdot
.09176 .3307 Mdot
.0918 .40099 Mdot
.09185 .10343 Mdot
.0919 .50517 Mdot
.09195 .49748 Mdot
.09199 .59408 Mdot
.09204 .46399 Mdot
.09209 .20054 Mdot
.09214 .33885 Mdot
.09218 .46341 Mdot
.09223 .12517 Mdot
.09228 .20354 Mdot
.09233 .46455 Mdot
.09237 .49738 Mdot
.09242 .30761 Mdot
.09247 .22238 Mdot
.09252 .2117 Mdot
.09256 .23272 Mdot
.09261 .13639 Mdot
.09266 .54367 Mdot
.09271 .08107 Mdot
.09276 .5355 Mdot
.0928 .21555 Mdot
.09285 .10896 Mdot
.0929 .3537 Mdot
.09295 .14922 Mdot
.09299 .12682 Mdot
.09304 .20711 Mdot
.09309 .45955 Mdot
.09314 .15846 Mdot
.09318 .26616 Mdot
.09323 .02128 Mdot
.09328 .13541 Mdot
.09333 .29838 Mdot
.09337 .1557 Mdot
.09342 .42106 Mdot
.09347 .27419 Mdot
.09352 .40433 Mdot
.09356 .45142 Mdot
.09361 .21339 Mdot
.09366 .07719 Mdot
.09371 .18631 Mdot
.09375 .32974 Mdot
.0938 .27304 Mdot
.09385 .59944 Mdot
.0939 .25413 Mdot
.09395 .1289 Mdot
.09399 .1788 Mdot
.09404 .26045 Mdot
.09409 .11962 Mdot
.09414 .01678 Mdot
.09418 .57501 Mdot
.09423 .40423 Mdot
.09428 .56448 Mdot
.09433 .35395 Mdot
.09437 .56844 Mdot
.09442 .28353 Mdot
.09447 .28081 Mdot
.09452 .21296 Mdot
.09456 .16209 Mdot
.09461 .02405 Mdot
.09466 .47981 Mdot
.09471 .36487 Mdot
.09475 .55202 Mdot
.0948 .55019 Mdot
.09485 .30821 Mdot
.0949 .04983 Mdot
.09495 .29369 Mdot
.09499 .55407 Mdot
.09504 .06879 Mdot
.09509 .52426 Mdot
.09514 .1296 Mdot
.09518 .30833 Mdot
.09523 .5525 Mdot
.09528 .52218 Mdot
.09533 .15791 Mdot
.09537 .50743 Mdot
.09542 .59134 Mdot
.09547 .18294 Mdot
.09552 .19279 Mdot
.09556 .2386 Mdot
.09561 .32524 Mdot
.09566 .57331 Mdot
.09571 .04541 Mdot
.09575 .22926 Mdot
.0958 .44876 Mdot
.09585 .22315 Mdot
.0959 .09672 Mdot
.09595 .2824 Mdot
.09599 .15526 Mdot
.09604 .18803 Mdot
.09609 .40636 Mdot
.09614 .33165 Mdot
.09618 .10118 Mdot
.09623 .2671 Mdot
.09628 .29147 Mdot
.09633 .03803 Mdot
.09637 .15201 Mdot
.09642 .34824 Mdot
.09647 .14827 Mdot
.09652 .13393 Mdot
.09656 .16399 Mdot
.09661 .18 Mdot
.09666 .5588 Mdot
.09671 .49865 Mdot
.09675 .44208 Mdot
.0968 .21002 Mdot
.09685 .52809 Mdot
.0969 .2841 Mdot
.09695 .59665 Mdot
.09699 .59019 Mdot
.09704 .44608 Mdot
.09709 .01641 Mdot
.09714 .4561 Mdot
.09718 .41687 Mdot
.09723 .05443 Mdot
.09728 .28809 Mdot
.09733 .36963 Mdot
.09737 .16448 Mdot
.09742 .36629 Mdot
.09747 .26477 Mdot
.09752 .23233 Mdot
.09756 .41956 Mdot
.09761 .23273 Mdot
.09766 .14555 Mdot
.09771 .08305 Mdot
.09775 .25427 Mdot
.0978 .27726 Mdot
.09785 .25022 Mdot
.0979 .2443 Mdot
.09794 .05896 Mdot
.09799 .35249 Mdot
.09804 .56945 Mdot
.09809 .25098 Mdot
.09814 .0721 Mdot
.09818 .50973 Mdot
.09823 .56775 Mdot
.09828 .3982 Mdot
.09833 .25856 Mdot
.09837 .47001 Mdot
.09842 .29437 Mdot
.09847 .04328 Mdot
.09852 .10879 Mdot
.09856 .11843 Mdot
.09861 .04431 Mdot
.09866 .41428 Mdot
.09871 .29255 Mdot
.09875 .48903 Mdot
.0988 .50209 Mdot
.09885 .34594 Mdot
.0989 .05299 Mdot
.09894 .22648 Mdot
.09899 .26658 Mdot
.09904 .11635 Mdot
.09909 .59735 Mdot
.09914 .47731 Mdot
.09918 .30045 Mdot
.09923 .4687 Mdot
.09928 .53996 Mdot
.09933 .5709 Mdot
.09937 .33603 Mdot
.09942 .08521 Mdot
.09947 .29611 Mdot
.09952 .1156 Mdot
.09956 .05636 Mdot
.09961 .05664 Mdot
.09966 .20203 Mdot
.09971 .60049 Mdot
.09975 .02676 Mdot
.0998 .24568 Mdot
.09985 .5128 Mdot
.0999 .12617 Mdot
.09994 .12799 Mdot
.09999 .50307 Mdot
.10004 .47452 Mdot
.10009 .50302 Mdot
.10014 .46474 Mdot
.10018 .40142 Mdot
.10023 .48049 Mdot
.10028 .04042 Mdot
.10033 .17899 Mdot
.10037 .53604 Mdot
.10042 .54386 Mdot
.10047 .07285 Mdot
.10052 .44629 Mdot
.10056 .46554 Mdot
.10061 .26246 Mdot
.10066 .56057 Mdot
.10071 .40464 Mdot
.10075 .42361 Mdot
.1008 .07514 Mdot
.10085 .56341 Mdot
.1009 .39259 Mdot
.10094 .19264 Mdot
.10099 .16566 Mdot
.10104 .45194 Mdot
.10109 .27931 Mdot
.10114 .2929 Mdot
.10118 .29447 Mdot
.10123 .55225 Mdot
.10128 .4179 Mdot
.10133 .4948 Mdot
.10137 .4173 Mdot
.10142 .52653 Mdot
.10147 .25362 Mdot
.10152 .56209 Mdot
.10156 .47677 Mdot
.10161 .46839 Mdot
.10166 .41065 Mdot
.10171 .11126 Mdot
.10175 .22902 Mdot
.1018 .51115 Mdot
.10185 .02072 Mdot
.1019 .29097 Mdot
.10194 .16859 Mdot
.10199 .55106 Mdot
.10204 .23145 Mdot
.10209 .11304 Mdot
.10214 .01763 Mdot
.10218 .11383 Mdot
.10223 .55546 Mdot
.10228 .42347 Mdot
.10233 .32649 Mdot
.10237 .16491 Mdot
.10242 .15227 Mdot
.10247 .532 Mdot
.10252 .51251 Mdot
.10256 .2417 Mdot
.10261 .50197 Mdot
.10266 .57323 Mdot
.10271 .05046 Mdot
.10275 .37663 Mdot
.1028 .10603 Mdot
.10285 .47668 Mdot
.1029 .42476 Mdot
.10294 .46881 Mdot
.10299 .10002 Mdot
.10304 .20042 Mdot
.10309 .27089 Mdot
.10313 .52107 Mdot
.10318 .4719 Mdot
.10323 .10208 Mdot
.10328 .26796 Mdot
.10333 .42195 Mdot
.10337 .51976 Mdot
.10342 .28193 Mdot
.10347 .5448 Mdot
.10352 .27176 Mdot
.10356 .3822 Mdot
.10361 .35326 Mdot
.10366 .047 Mdot
.10371 .04476 Mdot
.10375 .48355 Mdot
.1038 .38336 Mdot
.10385 .59987 Mdot
.1039 .27146 Mdot
.10394 .39223 Mdot
.10399 .51 Mdot
.10404 .18981 Mdot
.10409 .40597 Mdot
.10413 .30692 Mdot
.10418 .32429 Mdot
.10423 .52225 Mdot
.10428 .48823 Mdot
.10433 .43834 Mdot
.10437 .23692 Mdot
.10442 .26899 Mdot
.10447 .08098 Mdot
.10452 .52191 Mdot
.10456 .55831 Mdot
.10461 .32752 Mdot
.10466 .41255 Mdot
.10471 .15442 Mdot
.10475 .21975 Mdot
.1048 .29523 Mdot
.10485 .38249 Mdot
.1049 .27419 Mdot
.10494 .43972 Mdot
.10499 .29869 Mdot
.10504 .12574 Mdot
.10509 .48528 Mdot
.10513 .53305 Mdot
.10518 .12358 Mdot
.10523 .3231 Mdot
.10528 .19307 Mdot
.10533 .22347 Mdot
.10537 .20466 Mdot
.10542 .43819 Mdot
.10547 .35805 Mdot
.10552 .58987 Mdot
.10556 .53899 Mdot
.10561 .37192 Mdot
.10566 .43947 Mdot
.10571 .04627 Mdot
.10575 .22618 Mdot
.1058 .5627 Mdot
.10585 .29976 Mdot
.1059 .42985 Mdot
.10594 .53427 Mdot
.10599 .19491 Mdot
.10604 .04028 Mdot
.10609 .59345 Mdot
.10613 .2503 Mdot
.10618 .08387 Mdot
.10623 .15833 Mdot
.10628 .07511 Mdot
.10633 .14143 Mdot
.10637 .3641 Mdot
.10642 .56858 Mdot
.10647 .45497 Mdot
.10652 .5401 Mdot
.10656 .52924 Mdot
.10661 .22523 Mdot
.10666 .46843 Mdot
.10671 .01582 Mdot
.10675 .17202 Mdot
.1068 .38909 Mdot
.10685 .43686 Mdot
.1069 .39297 Mdot
.10694 .21265 Mdot
.10699 .10404 Mdot
.10704 .02172 Mdot
.10709 .46202 Mdot
.10713 .03245 Mdot
.10718 .07846 Mdot
.10723 .03159 Mdot
.10728 .22643 Mdot
.10732 .5519 Mdot
.10737 .52346 Mdot
.10742 .5598 Mdot
.10747 .09971 Mdot
.10752 .20251 Mdot
.10756 .5582 Mdot
.10761 .11954 Mdot
.10766 .16294 Mdot
.10771 .2766 Mdot
.10775 .34767 Mdot
.1078 .25444 Mdot
.10785 .16183 Mdot
.1079 .11928 Mdot
.10794 .56191 Mdot
.10799 .4209 Mdot
.10804 .37219 Mdot
.10809 .50996 Mdot
.10813 .47258 Mdot
.10818 .41389 Mdot
.10823 .5135 Mdot
.10828 .49221 Mdot
.10832 .40883 Mdot
.10837 .39701 Mdot
.10842 .30178 Mdot
.10847 .54364 Mdot
.10852 .4887 Mdot
.10856 .44053 Mdot
.10861 .21677 Mdot
.10866 .35584 Mdot
.10871 .53382 Mdot
.10875 .3357 Mdot
.1088 .06854 Mdot
.10885 .09395 Mdot
.1089 .20086 Mdot
.10894 .09597 Mdot
.10899 .51003 Mdot
.10904 .57799 Mdot
.10909 .24227 Mdot
.10913 .27839 Mdot
.10918 .15255 Mdot
.10923 .08274 Mdot
.10928 .37302 Mdot
.10932 .46783 Mdot
.10937 .24237 Mdot
.10942 .19385 Mdot
.10947 .56751 Mdot
.10952 .08553 Mdot
.10956 .54392 Mdot
.10961 .25354 Mdot
.10966 .09352 Mdot
.10971 .24833 Mdot
.10975 .34186 Mdot
.1098 .50103 Mdot
.10985 .16302 Mdot
.1099 .51596 Mdot
.10994 .28802 Mdot
.10999 .42179 Mdot
.11004 .56549 Mdot
.11009 .4347 Mdot
.11013 .38132 Mdot
.11018 .44713 Mdot
.11023 .33792 Mdot
.11028 .17101 Mdot
.11032 .24348 Mdot
.11037 .3791 Mdot
.11042 .56823 Mdot
.11047 .30651 Mdot
.11052 .01581 Mdot
.11056 .19995 Mdot
.11061 .01543 Mdot
.11066 .23569 Mdot
.11071 .07521 Mdot
.11075 .54973 Mdot
.1108 .52523 Mdot
.11085 .59069 Mdot
.1109 .33668 Mdot
.11094 .06341 Mdot
.11099 .37692 Mdot
.11104 .08944 Mdot
.11109 .06337 Mdot
.11113 .24494 Mdot
.11118 .41476 Mdot
.11123 .25807 Mdot
.11128 .28538 Mdot
.11132 .40114 Mdot
.11137 .09155 Mdot
.11142 .10177 Mdot
.11147 .05661 Mdot
.11152 .03675 Mdot
.11156 .12665 Mdot
.11161 .39858 Mdot
.11166 .0555 Mdot
.11171 .44012 Mdot
.11175 .12593 Mdot
.1118 .1776 Mdot
.11185 .58361 Mdot
.1119 .49371 Mdot
.11194 .20402 Mdot
.11199 .19024 Mdot
.11204 .26164 Mdot
.11209 .44501 Mdot
.11213 .43043 Mdot
.11218 .1155 Mdot
.11223 .21298 Mdot
.11228 .21478 Mdot
.11232 .03037 Mdot
.11237 .46076 Mdot
.11242 .53093 Mdot
.11247 .41697 Mdot
.11251 .54215 Mdot
.11256 .3737 Mdot
.11261 .48903 Mdot
.11266 .39493 Mdot
.11271 .43021 Mdot
.11275 .57845 Mdot
.1128 .44824 Mdot
.11285 .55813 Mdot
.1129 .31898 Mdot
.11294 .41556 Mdot
.11299 .46795 Mdot
.11304 .07913 Mdot
.11309 .12967 Mdot
.11313 .24003 Mdot
.11318 .22102 Mdot
.11323 .23744 Mdot
.11328 .30257 Mdot
.11332 .13924 Mdot
.11337 .02275 Mdot
.11342 .03737 Mdot
.11347 .2869 Mdot
.11351 .2818 Mdot
.11356 .09514 Mdot
.11361 .22373 Mdot
.11366 .34808 Mdot
.11371 .51143 Mdot
.11375 .20944 Mdot
.1138 .43213 Mdot
.11385 .5212 Mdot
.1139 .5363 Mdot
.11394 .36453 Mdot
.11399 .47733 Mdot
.11404 .21693 Mdot
.11409 .13545 Mdot
.11413 .4999 Mdot
.11418 .41291 Mdot
.11423 .10197 Mdot
.11428 .49874 Mdot
.11432 .29359 Mdot
.11437 .19017 Mdot
.11442 .40273 Mdot
.11447 .37422 Mdot
.11451 .28555 Mdot
.11456 .16751 Mdot
.11461 .13054 Mdot
.11466 .10712 Mdot
.11471 .20512 Mdot
.11475 .5471 Mdot
.1148 .38578 Mdot
.11485 .19902 Mdot
.1149 .59901 Mdot
.11494 .12967 Mdot
.11499 .4679 Mdot
.11504 .26604 Mdot
.11509 .24919 Mdot
.11513 .25567 Mdot
.11518 .26568 Mdot
.11523 .1453 Mdot
.11528 .35261 Mdot
.11532 .44609 Mdot
.11537 .17842 Mdot
.11542 .24988 Mdot
.11547 .07373 Mdot
.11551 .27063 Mdot
.11556 .37901 Mdot
.11561 .47899 Mdot
.11566 .3915 Mdot
.11571 .11783 Mdot
.11575 .26319 Mdot
.1158 .38658 Mdot
.11585 .20109 Mdot
.1159 .17406 Mdot
.11594 .48073 Mdot
.11599 .20227 Mdot
.11604 .2054 Mdot
.11609 .05909 Mdot
.11613 .02754 Mdot
.11618 .53955 Mdot
.11623 .55954 Mdot
.11628 .40675 Mdot
.11632 .36519 Mdot
.11637 .40896 Mdot
.11642 .22164 Mdot
.11647 .56398 Mdot
.11651 .20148 Mdot
.11656 .17378 Mdot
.11661 .16262 Mdot
.11666 .30807 Mdot
.1167 .42579 Mdot
.11675 .29812 Mdot
.1168 .37444 Mdot
.11685 .20494 Mdot
.1169 .17731 Mdot
.11694 .51486 Mdot
.11699 .18807 Mdot
.11704 .04559 Mdot
.11709 .2999 Mdot
.11713 .3273 Mdot
.11718 .58599 Mdot
.11723 .58982 Mdot
.11728 .28707 Mdot
.11732 .39108 Mdot
.11737 .04116 Mdot
.11742 .19778 Mdot
.11747 .52521 Mdot
.11751 .58545 Mdot
.11756 .42285 Mdot
.11761 .23712 Mdot
.11766 .33844 Mdot
.1177 .42638 Mdot
.11775 .27494 Mdot
.1178 .53238 Mdot
.11785 .51597 Mdot
.1179 .14297 Mdot
.11794 .50382 Mdot
.11799 .34215 Mdot
.11804 .35337 Mdot
.11809 .23144 Mdot
.11813 .33046 Mdot
.11818 .31127 Mdot
.11823 .06817 Mdot
.11828 .50746 Mdot
.11832 .3478 Mdot
.11837 .32477 Mdot
.11842 .38443 Mdot
.11847 .13108 Mdot
.11851 .32135 Mdot
.11856 .14169 Mdot
.11861 .46255 Mdot
.11866 .14896 Mdot
.1187 .50183 Mdot
.11875 .50789 Mdot
.1188 .13882 Mdot
.11885 .32591 Mdot
.1189 .2416 Mdot
.11894 .57883 Mdot
.11899 .22617 Mdot
.11904 .19764 Mdot
.11909 .3411 Mdot
.11913 .25139 Mdot
.11918 .47612 Mdot
.11923 .56953 Mdot
.11928 .02535 Mdot
.11932 .54345 Mdot
.11937 .42266 Mdot
.11942 .07678 Mdot
.11947 .28088 Mdot
.11951 .23339 Mdot
.11956 .05293 Mdot
.11961 .54902 Mdot
.11966 .56286 Mdot
.1197 .10641 Mdot
.11975 .19371 Mdot
.1198 .41477 Mdot
.11985 .07574 Mdot
.1199 .20184 Mdot
.11994 .06961 Mdot
.11999 .10358 Mdot
.12004 .43747 Mdot
.12009 .22633 Mdot
.12013 .44677 Mdot
.12018 .50926 Mdot
.12023 .11107 Mdot
.12028 .57826 Mdot
.12032 .57397 Mdot
.12037 .54305 Mdot
.12042 .10043 Mdot
.12047 .04952 Mdot
.12051 .16602 Mdot
.12056 .48098 Mdot
.12061 .42288 Mdot
.12066 .41945 Mdot
.1207 .1278 Mdot
.12075 .53528 Mdot
.1208 .46334 Mdot
.12085 .32775 Mdot
.1209 .53741 Mdot
.12094 .13522 Mdot
.12099 .40231 Mdot
.12104 .14062 Mdot
.12109 .48251 Mdot
.12113 .04635 Mdot
.12118 .56817 Mdot
.12123 .51761 Mdot
.12128 .05045 Mdot
.12132 .14042 Mdot
.12137 .47181 Mdot
.12142 .54268 Mdot
.12147 .07981 Mdot
.12151 .20069 Mdot
.12156 .38609 Mdot
.12161 .50787 Mdot
.12166 .51711 Mdot
.1217 .32303 Mdot
.12175 .56654 Mdot
.1218 .10313 Mdot
.12185 .40402 Mdot
.12189 .39108 Mdot
.12194 .1179 Mdot
.12199 .3787 Mdot
.12204 .46994 Mdot
.12209 .27056 Mdot
.12213 .31891 Mdot
.12218 .25279 Mdot
.12223 .59076 Mdot
.12228 .23892 Mdot
.12232 .35407 Mdot
.12237 .3385 Mdot
.12242 .55501 Mdot
.12247 .11321 Mdot
.12251 .48558 Mdot
.12256 .39915 Mdot
.12261 .48991 Mdot
.12266 .51585 Mdot
.1227 .1142 Mdot
.12275 .49461 Mdot
.1228 .57613 Mdot
.12285 .20752 Mdot
.12289 .15099 Mdot
.12294 .40619 Mdot
.12299 .18681 Mdot
.12304 .41977 Mdot
.12309 .04779 Mdot
.12313 .04219 Mdot
.12318 .3202 Mdot
.12323 .16392 Mdot
.12328 .3322 Mdot
.12332 .39273 Mdot
.12337 .33277 Mdot
.12342 .52832 Mdot
.12347 .58146 Mdot
.12351 .06893 Mdot
.12356 .38108 Mdot
.12361 .42982 Mdot
.12366 .11059 Mdot
.1237 .2731 Mdot
.12375 .49449 Mdot
.1238 .5173 Mdot
.12385 .59972 Mdot
.12389 .38182 Mdot
.12394 .52168 Mdot
.12399 .32448 Mdot
.12404 .46344 Mdot
.12409 .57895 Mdot
.12413 .34958 Mdot
.12418 .50803 Mdot
.12423 .43035 Mdot
.12428 .55147 Mdot
.12432 .04409 Mdot
.12437 .35882 Mdot
.12442 .11286 Mdot
.12447 .17345 Mdot
.12451 .31465 Mdot
.12456 .43383 Mdot
.12461 .13472 Mdot
.12466 .11923 Mdot
.1247 .53689 Mdot
.12475 .01872 Mdot
.1248 .03884 Mdot
.12485 .44945 Mdot
.12489 .05711 Mdot
.12494 .10475 Mdot
.12499 .04245 Mdot
.12504 .08234 Mdot
.12509 .13875 Mdot
.12513 .38359 Mdot
.12518 .18233 Mdot
.12523 .10671 Mdot
.12528 .3925 Mdot
.12532 .47889 Mdot
.12537 .3553 Mdot
.12542 .15857 Mdot
.12547 .36312 Mdot
.12551 .13477 Mdot
.12556 .25715 Mdot
.12561 .58844 Mdot
.12566 .06318 Mdot
.1257 .30427 Mdot
.12575 .13714 Mdot
.1258 .48392 Mdot
.12585 .12961 Mdot
.12589 .30026 Mdot
.12594 .11301 Mdot
.12599 .04918 Mdot
.12604 .08721 Mdot
.12609 .21022 Mdot
.12613 .08528 Mdot
.12618 .57016 Mdot
.12623 .55178 Mdot
.12628 .42995 Mdot
.12632 .50627 Mdot
.12637 .47815 Mdot
.12642 .17399 Mdot
.12647 .55439 Mdot
.12651 .16568 Mdot
.12656 .33429 Mdot
.12661 .4142 Mdot
.12666 .43433 Mdot
.1267 .51185 Mdot
.12675 .34918 Mdot
.1268 .36572 Mdot
.12685 .14477 Mdot
.12689 .38941 Mdot
.12694 .46858 Mdot
.12699 .25082 Mdot
.12704 .44784 Mdot
.12708 .29111 Mdot
.12713 .43411 Mdot
.12718 .17832 Mdot
.12723 .25233 Mdot
.12728 .22054 Mdot
.12732 .46728 Mdot
.12737 .22986 Mdot
.12742 .42571 Mdot
.12747 .31759 Mdot
.12751 .59245 Mdot
.12756 .07058 Mdot
.12761 .47465 Mdot
.12766 .16663 Mdot
.1277 .27286 Mdot
.12775 .25971 Mdot
.1278 .05503 Mdot
.12785 .2581 Mdot
.12789 .52701 Mdot
.12794 .49731 Mdot
.12799 .51358 Mdot
.12804 .47202 Mdot
.12808 .07314 Mdot
.12813 .2612 Mdot
.12818 .08045 Mdot
.12823 .19562 Mdot
.12828 .24235 Mdot
.12832 .09759 Mdot
.12837 .43145 Mdot
.12842 .5784 Mdot
.12847 .3784 Mdot
.12851 .47106 Mdot
.12856 .02045 Mdot
.12861 .27552 Mdot
.12866 .38927 Mdot
.1287 .41519 Mdot
.12875 .14913 Mdot
.1288 .1236 Mdot
.12885 .13112 Mdot
.12889 .1702 Mdot
.12894 .10881 Mdot
.12899 .46882 Mdot
.12904 .20743 Mdot
.12908 .27621 Mdot
.12913 .19855 Mdot
.12918 .60013 Mdot
.12923 .149 Mdot
.12928 .02972 Mdot
.12932 .13281 Mdot
.12937 .41922 Mdot
.12942 .50997 Mdot
.12947 .53545 Mdot
.12951 .30468 Mdot
.12956 .44415 Mdot
.12961 .14628 Mdot
.12966 .0791 Mdot
.1297 .29894 Mdot
.12975 .18334 Mdot
.1298 .36033 Mdot
.12985 .26723 Mdot
.12989 .16452 Mdot
.12994 .07445 Mdot
.12999 .24392 Mdot
.13004 .11174 Mdot
.13008 .07041 Mdot
.13013 .20895 Mdot
.13018 .0512 Mdot
.13023 .43886 Mdot
.13028 .47518 Mdot
.13032 .21214 Mdot
.13037 .50553 Mdot
.13042 .42384 Mdot
.13047 .35708 Mdot
.13051 .39625 Mdot
.13056 .59888 Mdot
.13061 .49172 Mdot
.13066 .06711 Mdot
.1307 .55542 Mdot
.13075 .46731 Mdot
.1308 .42733 Mdot
.13085 .37149 Mdot
.13089 .3868 Mdot
.13094 .12169 Mdot
.13099 .17481 Mdot
.13104 .22168 Mdot
.13108 .32706 Mdot
.13113 .4811 Mdot
.13118 .07777 Mdot
.13123 .16598 Mdot
.13127 .13282 Mdot
.13132 .4446 Mdot
.13137 .24224 Mdot
.13142 .29412 Mdot
.13147 .524 Mdot
.13151 .5424 Mdot
.13156 .42172 Mdot
.13161 .54036 Mdot
.13166 .14246 Mdot
.1317 .54685 Mdot
.13175 .53333 Mdot
.1318 .48796 Mdot
.13185 .19036 Mdot
.13189 .09424 Mdot
.13194 .12071 Mdot
.13199 .13118 Mdot
.13204 .40689 Mdot
.13208 .57588 Mdot
.13213 .54923 Mdot
.13218 .51282 Mdot
.13223 .09454 Mdot
.13227 .10949 Mdot
.13232 .48617 Mdot
.13237 .36155 Mdot
.13242 .56505 Mdot
.13247 .26821 Mdot
.13251 .25863 Mdot
.13256 .08213 Mdot
.13261 .05576 Mdot
.13266 .32913 Mdot
.1327 .44024 Mdot
.13275 .14509 Mdot
.1328 .51662 Mdot
.13285 .38561 Mdot
.13289 .51023 Mdot
.13294 .26046 Mdot
.13299 .34097 Mdot
.13304 .30608 Mdot
.13308 .40423 Mdot
.13313 .14399 Mdot
.13318 .5374 Mdot
.13323 .33352 Mdot
.13327 .45833 Mdot
.13332 .2345 Mdot
.13337 .45757 Mdot
.13342 .23874 Mdot
.13347 .57549 Mdot
.13351 .47628 Mdot
.13356 .49584 Mdot
.13361 .57385 Mdot
.13366 .33156 Mdot
.1337 .40885 Mdot
.13375 .45479 Mdot
.1338 .25943 Mdot
.13385 .49465 Mdot
.13389 .27847 Mdot
.13394 .5415 Mdot
.13399 .47714 Mdot
.13404 .58774 Mdot
.13408 .03272 Mdot
.13413 .21524 Mdot
.13418 .18577 Mdot
.13423 .19822 Mdot
.13427 .49205 Mdot
.13432 .28117 Mdot
.13437 .45557 Mdot
.13442 .34322 Mdot
.13447 .27227 Mdot
.13451 .42693 Mdot
.13456 .23154 Mdot
.13461 .37106 Mdot
.13466 .39932 Mdot
.1347 .53441 Mdot
.13475 .26101 Mdot
.1348 .0542 Mdot
.13485 .59379 Mdot
.13489 .09433 Mdot
.13494 .0163 Mdot
.13499 .16288 Mdot
.13504 .33003 Mdot
.13508 .15616 Mdot
.13513 .14248 Mdot
.13518 .17846 Mdot
.13523 .31202 Mdot
.13527 .54424 Mdot
.13532 .56004 Mdot
.13537 .58356 Mdot
.13542 .42329 Mdot
.13547 .27779 Mdot
.13551 .11918 Mdot
.13556 .25505 Mdot
.13561 .16574 Mdot
.13566 .45419 Mdot
.1357 .49096 Mdot
.13575 .48732 Mdot
.1358 .36974 Mdot
.13585 .5231 Mdot
.13589 .24466 Mdot
.13594 .44783 Mdot
.13599 .37928 Mdot
.13604 .44348 Mdot
.13608 .24307 Mdot
.13613 .29966 Mdot
.13618 .06396 Mdot
.13623 .30204 Mdot
.13627 .1153 Mdot
.13632 .13591 Mdot
.13637 .35526 Mdot
.13642 .36112 Mdot
.13646 .15858 Mdot
.13651 .15567 Mdot
.13656 .53529 Mdot
.13661 .09804 Mdot
.13666 .05411 Mdot
.1367 .50394 Mdot
.13675 .38426 Mdot
.1368 .24718 Mdot
.13685 .16648 Mdot
.13689 .03133 Mdot
.13694 .02923 Mdot
.13699 .32741 Mdot
.13704 .52514 Mdot
.13708 .18683 Mdot
.13713 .25327 Mdot
.13718 .48725 Mdot
.13723 .29677 Mdot
.13727 .49049 Mdot
.13732 .20402 Mdot
.13737 .19992 Mdot
.13742 .19618 Mdot
.13746 .36929 Mdot
.13751 .45209 Mdot
.13756 .44213 Mdot
.13761 .05231 Mdot
.13766 .22832 Mdot
.1377 .52012 Mdot
.13775 .35879 Mdot
.1378 .60152 Mdot
.13785 .3277 Mdot
.13789 .15057 Mdot
.13794 .12632 Mdot
.13799 .44975 Mdot
.13804 .31108 Mdot
.13808 .13605 Mdot
.13813 .40224 Mdot
.13818 .52794 Mdot
.13823 .13897 Mdot
.13827 .4861 Mdot
.13832 .51832 Mdot
.13837 .24587 Mdot
.13842 .2518 Mdot
.13846 .29678 Mdot
.13851 .33311 Mdot
.13856 .0644 Mdot
.13861 .48584 Mdot
.13866 .44802 Mdot
.1387 .49431 Mdot
.13875 .0268 Mdot
.1388 .27223 Mdot
.13885 .53122 Mdot
.13889 .15022 Mdot
.13894 .02861 Mdot
.13899 .54785 Mdot
.13904 .39537 Mdot
.13908 .03861 Mdot
.13913 .18218 Mdot
.13918 .25147 Mdot
.13923 .27403 Mdot
.13927 .23969 Mdot
.13932 .25757 Mdot
.13937 .12722 Mdot
.13942 .39126 Mdot
.13946 .3247 Mdot
.13951 .02641 Mdot
.13956 .47874 Mdot
.13961 .10918 Mdot
.13966 .59492 Mdot
.1397 .56533 Mdot
.13975 .59623 Mdot
.1398 .26448 Mdot
.13985 .11532 Mdot
.13989 .55324 Mdot
.13994 .33871 Mdot
.13999 .33659 Mdot
.14004 .56842 Mdot
.14008 .53935 Mdot
.14013 .39419 Mdot
.14018 .54454 Mdot
.14023 .54453 Mdot
.14027 .37188 Mdot
.14032 .15742 Mdot
.14037 .28522 Mdot
.14042 .31954 Mdot
.14046 .12902 Mdot
.14051 .04491 Mdot
.14056 .49729 Mdot
.14061 .59817 Mdot
.14065 .11732 Mdot
.1407 .16949 Mdot
.14075 .40282 Mdot
.1408 .01796 Mdot
.14085 .15531 Mdot
.14089 .17659 Mdot
.14094 .15304 Mdot
.14099 .50596 Mdot
.14104 .20539 Mdot
.14108 .44121 Mdot
.14113 .41979 Mdot
.14118 .54086 Mdot
.14123 .26937 Mdot
.14127 .06173 Mdot
.14132 .47857 Mdot
.14137 .59966 Mdot
.14142 .50082 Mdot
.14146 .50763 Mdot
.14151 .20805 Mdot
.14156 .29483 Mdot
.14161 .38651 Mdot
.14165 .47743 Mdot
.1417 .31409 Mdot
.14175 .29999 Mdot
.1418 .2839 Mdot
.14185 .32264 Mdot
.14189 .51459 Mdot
.14194 .29674 Mdot
.14199 .1433 Mdot
.14204 .16076 Mdot
.14208 .37625 Mdot
.14213 .3941 Mdot
.14218 .54123 Mdot
.14223 .32288 Mdot
.14227 .5598 Mdot
.14232 .45656 Mdot
.14237 .28657 Mdot
.14242 .27586 Mdot
.14246 .09594 Mdot
.14251 .46022 Mdot
.14256 .38908 Mdot
.14261 .37155 Mdot
.14265 .49121 Mdot
.1427 .1801 Mdot
.14275 .01728 Mdot
.1428 .49745 Mdot
.14285 .19183 Mdot
.14289 .48343 Mdot
.14294 .3367 Mdot
.14299 .18952 Mdot
.14304 .28056 Mdot
.14308 .2014 Mdot
.14313 .20811 Mdot
.14318 .04348 Mdot
.14323 .50764 Mdot
.14327 .41063 Mdot
.14332 .2702 Mdot
.14337 .32393 Mdot
.14342 .55117 Mdot
.14346 .55739 Mdot
.14351 .58695 Mdot
.14356 .06278 Mdot
.14361 .46994 Mdot
.14365 .11187 Mdot
.1437 .21258 Mdot
.14375 .29455 Mdot
.1438 .58205 Mdot
.14385 .5351 Mdot
.14389 .21001 Mdot
.14394 .40042 Mdot
.14399 .40493 Mdot
.14404 .06637 Mdot
.14408 .47663 Mdot
.14413 .2256 Mdot
.14418 .13908 Mdot
.14423 .4683 Mdot
.14427 .28323 Mdot
.14432 .19684 Mdot
.14437 .23477 Mdot
.14442 .07238 Mdot
.14446 .02774 Mdot
.14451 .47624 Mdot
.14456 .28693 Mdot
.14461 .11831 Mdot
.14465 .04411 Mdot
.1447 .42817 Mdot
.14475 .42031 Mdot
.1448 .02115 Mdot
.14485 .43485 Mdot
.14489 .14833 Mdot
.14494 .44158 Mdot
.14499 .08937 Mdot
.14504 .23955 Mdot
.14508 .35124 Mdot
.14513 .05136 Mdot
.14518 .03771 Mdot
.14523 .36625 Mdot
.14527 .14034 Mdot
.14532 .51561 Mdot
.14537 .17274 Mdot
.14542 .09773 Mdot
.14546 .54683 Mdot
.14551 .29555 Mdot
.14556 .11507 Mdot
.14561 .0847 Mdot
.14565 .08531 Mdot
.1457 .02334 Mdot
.14575 .60008 Mdot
.1458 .0553 Mdot
.14584 .26046 Mdot
.14589 .20635 Mdot
.14594 .59364 Mdot
.14599 .22377 Mdot
.14604 .12684 Mdot
.14608 .36809 Mdot
.14613 .51898 Mdot
.14618 .58754 Mdot
.14623 .37893 Mdot
.14627 .33144 Mdot
.14632 .49597 Mdot
.14637 .236 Mdot
.14642 .25329 Mdot
.14646 .41915 Mdot
.14651 .33794 Mdot
.14656 .15298 Mdot
.14661 .30978 Mdot
.14665 .13831 Mdot
.1467 .23758 Mdot
.14675 .08299 Mdot
.1468 .23918 Mdot
.14684 .12968 Mdot
.14689 .24082 Mdot
.14694 .04239 Mdot
.14699 .58204 Mdot
.14704 .52666 Mdot
.14708 .25051 Mdot
.14713 .42195 Mdot
.14718 .46991 Mdot
.14723 .17328 Mdot
.14727 .33486 Mdot
.14732 .43773 Mdot
.14737 .1057 Mdot
.14742 .44517 Mdot
.14746 .44221 Mdot
.14751 .21643 Mdot
.14756 .45573 Mdot
.14761 .04073 Mdot
.14765 .11897 Mdot
.1477 .07816 Mdot
.14775 .16066 Mdot
.1478 .50574 Mdot
.14784 .48472 Mdot
.14789 .5985 Mdot
.14794 .5248 Mdot
.14799 .39077 Mdot
.14804 .25861 Mdot
.14808 .57081 Mdot
.14813 .54608 Mdot
.14818 .46744 Mdot
.14823 .02281 Mdot
.14827 .16357 Mdot
.14832 .09088 Mdot
.14837 .30886 Mdot
.14842 .29128 Mdot
.14846 .32917 Mdot
.14851 .58851 Mdot
.14856 .46702 Mdot
.14861 .4524 Mdot
.14865 .12744 Mdot
.1487 .14749 Mdot
.14875 .441 Mdot
.1488 .34813 Mdot
.14884 .06399 Mdot
.14889 .59015 Mdot
.14894 .53859 Mdot
.14899 .46674 Mdot
.14904 .06882 Mdot
.14908 .08006 Mdot
.14913 .16252 Mdot
.14918 .22284 Mdot
.14923 .10134 Mdot
.14927 .1373 Mdot
.14932 .29841 Mdot
.14937 .21474 Mdot
.14942 .54109 Mdot
.14946 .06113 Mdot
.14951 .59287 Mdot
.14956 .52678 Mdot
.14961 .22663 Mdot
.14965 .07595 Mdot
.1497 .14056 Mdot
.14975 .08909 Mdot
.1498 .1139 Mdot
.14984 .53179 Mdot
.14989 .30288 Mdot
.14994 .34429 Mdot
.14999 .06461 Mdot
.15003 .54496 Mdot
.15008 .36762 Mdot
.15013 .48088 Mdot
.15018 .59912 Mdot
.15023 .47961 Mdot
.15027 .21981 Mdot
.15032 .27275 Mdot
.15037 .51249 Mdot
.15042 .35701 Mdot
.15046 .52472 Mdot
.15051 .07272 Mdot
.15056 .57473 Mdot
.15061 .31059 Mdot
.15065 .53517 Mdot
.1507 .14927 Mdot
.15075 .36281 Mdot
.1508 .24935 Mdot
.15084 .40932 Mdot
.15089 .07488 Mdot
.15094 .26362 Mdot
.15099 .32088 Mdot
.15103 .12114 Mdot
.15108 .33392 Mdot
.15113 .21371 Mdot
.15118 .37925 Mdot
.15123 .35684 Mdot
.15127 .45637 Mdot
.15132 .21792 Mdot
.15137 .50296 Mdot
.15142 .15175 Mdot
.15146 .19832 Mdot
.15151 .30875 Mdot
.15156 .16066 Mdot
.15161 .23035 Mdot
.15165 .14031 Mdot
.1517 .33735 Mdot
.15175 .45339 Mdot
.1518 .29851 Mdot
.15184 .59436 Mdot
.15189 .57786 Mdot
.15194 .21875 Mdot
.15199 .49252 Mdot
.15203 .53419 Mdot
.15208 .32895 Mdot
.15213 .5012 Mdot
.15218 .38609 Mdot
.15223 .21498 Mdot
.15227 .12995 Mdot
.15232 .13666 Mdot
.15237 .04395 Mdot
.15242 .36194 Mdot
.15246 .51535 Mdot
.15251 .23703 Mdot
.15256 .49553 Mdot
.15261 .17833 Mdot
.15265 .22131 Mdot
.1527 .09108 Mdot
.15275 .27989 Mdot
.1528 .05273 Mdot
.15284 .48729 Mdot
.15289 .24101 Mdot
.15294 .5847 Mdot
.15299 .06169 Mdot
.15303 .51275 Mdot
.15308 .03697 Mdot
.15313 .10689 Mdot
.15318 .13082 Mdot
.15323 .19851 Mdot
.15327 .13909 Mdot
.15332 .32413 Mdot
.15337 .51917 Mdot
.15342 .08327 Mdot
.15346 .01714 Mdot
.15351 .29489 Mdot
.15356 .17193 Mdot
.15361 .17124 Mdot
.15365 .38344 Mdot
.1537 .40268 Mdot
.15375 .59693 Mdot
.1538 .55326 Mdot
.15384 .30707 Mdot
.15389 .1375 Mdot
.15394 .55891 Mdot
.15399 .08067 Mdot
.15403 .08077 Mdot
.15408 .15612 Mdot
.15413 .51193 Mdot
.15418 .17125 Mdot
.15423 .05851 Mdot
.15427 .06394 Mdot
.15432 .39582 Mdot
.15437 .57606 Mdot
.15442 .52274 Mdot
.15446 .34313 Mdot
.15451 .47998 Mdot
.15456 .5075 Mdot
.15461 .52031 Mdot
.15465 .06296 Mdot
.1547 .32275 Mdot
.15475 .35097 Mdot
.1548 .15158 Mdot
.15484 .2636 Mdot
.15489 .32914 Mdot
.15494 .40104 Mdot
.15499 .44783 Mdot
.15503 .14081 Mdot
.15508 .37356 Mdot
.15513 .33507 Mdot
.15518 .38177 Mdot
.15522 .58802 Mdot
.15527 .46495 Mdot
.15532 .17853 Mdot
.15537 .33797 Mdot
.15542 .53879 Mdot
.15546 .08383 Mdot
.15551 .2058 Mdot
.15556 .41855 Mdot
.15561 .21036 Mdot
.15565 .20718 Mdot
.1557 .30162 Mdot
.15575 .50157 Mdot
.1558 .16212 Mdot
.15584 .48775 Mdot
.15589 .55398 Mdot
.15594 .3647 Mdot
.15599 .50184 Mdot
.15603 .17332 Mdot
.15608 .16766 Mdot
.15613 .52019 Mdot
.15618 .37573 Mdot
.15622 .40309 Mdot
.15627 .43591 Mdot
.15632 .15312 Mdot
.15637 .39104 Mdot
.15642 .54147 Mdot
.15646 .27208 Mdot
.15651 .41848 Mdot
.15656 .45557 Mdot
.15661 .47234 Mdot
.15665 .08099 Mdot
.1567 .60325 Mdot
.15675 .25992 Mdot
.1568 .27987 Mdot
.15684 .3827 Mdot
.15689 .11639 Mdot
.15694 .11251 Mdot
.15699 .39544 Mdot
.15703 .43204 Mdot
.15708 .35502 Mdot
.15713 .214 Mdot
.15718 .23684 Mdot
.15722 .27909 Mdot
.15727 .43816 Mdot
.15732 .44159 Mdot
.15737 .43707 Mdot
.15742 .4465 Mdot
.15746 .29975 Mdot
.15751 .06526 Mdot
.15756 .49893 Mdot
.15761 .18913 Mdot
.15765 .4846 Mdot
.1577 .21301 Mdot
.15775 .0413 Mdot
.1578 .12284 Mdot
.15784 .48467 Mdot
.15789 .55642 Mdot
.15794 .36476 Mdot
.15799 .34347 Mdot
.15803 .38299 Mdot
.15808 .45862 Mdot
.15813 .57264 Mdot
.15818 .51476 Mdot
.15822 .04268 Mdot
.15827 .25933 Mdot
.15832 .35051 Mdot
.15837 .25038 Mdot
.15842 .20784 Mdot
.15846 .42106 Mdot
.15851 .51676 Mdot
.15856 .4072 Mdot
.15861 .51142 Mdot
.15865 .37051 Mdot
.1587 .03254 Mdot
.15875 .23278 Mdot
.1588 .04153 Mdot
.15884 .1722 Mdot
.15889 .59456 Mdot
.15894 .12465 Mdot
.15899 .16019 Mdot
.15903 .21911 Mdot
.15908 .24451 Mdot
.15913 .3845 Mdot
.15918 .38052 Mdot
.15922 .36382 Mdot
.15927 .2752 Mdot
.15932 .47306 Mdot
.15937 .35255 Mdot
.15942 .1192 Mdot
.15946 .52801 Mdot
.15951 .23739 Mdot
.15956 .15942 Mdot
.15961 .30147 Mdot
.15965 .02596 Mdot
.1597 .43351 Mdot
.15975 .25132 Mdot
.1598 .53429 Mdot
.15984 .59675 Mdot
.15989 .21544 Mdot
.15994 .22449 Mdot
.15999 .37679 Mdot
.16003 .01689 Mdot
.16008 .1055 Mdot
.16013 .07902 Mdot
.16018 .17239 Mdot
.16022 .3757 Mdot
.16027 .32433 Mdot
.16032 .30182 Mdot
.16037 .4119 Mdot
.16041 .11521 Mdot
.16046 .45459 Mdot
.16051 .5526 Mdot
.16056 .30741 Mdot
.16061 .19053 Mdot
.16065 .23191 Mdot
.1607 .40789 Mdot
.16075 .02065 Mdot
.1608 .17928 Mdot
.16084 .40172 Mdot
.16089 .17127 Mdot
.16094 .08969 Mdot
.16099 .18586 Mdot
.16103 .20099 Mdot
.16108 .55011 Mdot
.16113 .31622 Mdot
.16118 .18367 Mdot
.16122 .1102 Mdot
.16127 .4858 Mdot
.16132 .15853 Mdot
.16137 .41129 Mdot
.16141 .3892 Mdot
.16146 .19868 Mdot
.16151 .34996 Mdot
.16156 .31079 Mdot
.16161 .53794 Mdot
.16165 .24941 Mdot
.1617 .05726 Mdot
.16175 .13497 Mdot
.1618 .32074 Mdot
.16184 .44485 Mdot
.16189 .05131 Mdot
.16194 .55902 Mdot
.16199 .52234 Mdot
.16203 .28829 Mdot
.16208 .56495 Mdot
.16213 .38787 Mdot
.16218 .33605 Mdot
.16222 .34151 Mdot
.16227 .26344 Mdot
.16232 .21891 Mdot
.16237 .24056 Mdot
.16241 .45904 Mdot
.16246 .11961 Mdot
.16251 .41094 Mdot
.16256 .45468 Mdot
.16261 .27506 Mdot
.16265 .37298 Mdot
.1627 .11486 Mdot
.16275 .52007 Mdot
.1628 .04035 Mdot
.16284 .33044 Mdot
.16289 .58321 Mdot
.16294 .21404 Mdot
.16299 .19883 Mdot
.16303 .29383 Mdot
.16308 .0389 Mdot
.16313 .29503 Mdot
.16318 .51386 Mdot
.16322 .33221 Mdot
.16327 .25435 Mdot
.16332 .5623 Mdot
.16337 .18707 Mdot
.16341 .08348 Mdot
.16346 .05015 Mdot
.16351 .33646 Mdot
.16356 .33136 Mdot
.16361 .56719 Mdot
.16365 .24253 Mdot
.1637 .4851 Mdot
.16375 .07101 Mdot
.1638 .20891 Mdot
.16384 .14238 Mdot
.16389 .56836 Mdot
.16394 .04536 Mdot
.16399 .4818 Mdot
.16403 .16249 Mdot
.16408 .36903 Mdot
.16413 .44986 Mdot
.16418 .20268 Mdot
.16422 .1383 Mdot
.16427 .0887 Mdot
.16432 .53932 Mdot
.16437 .4738 Mdot
.16441 .48728 Mdot
.16446 .12972 Mdot
.16451 .36696 Mdot
.16456 .40503 Mdot
.1646 .45184 Mdot
.16465 .39659 Mdot
.1647 .05031 Mdot
.16475 .44117 Mdot
.1648 .22401 Mdot
.16484 .51482 Mdot
.16489 .58263 Mdot
.16494 .24696 Mdot
.16499 .09634 Mdot
.16503 .54978 Mdot
.16508 .55198 Mdot
.16513 .36849 Mdot
.16518 .53717 Mdot
.16522 .19547 Mdot
.16527 .11683 Mdot
.16532 .18052 Mdot
.16537 .41357 Mdot
.16541 .12147 Mdot
.16546 .18083 Mdot
.16551 .31005 Mdot
.16556 .52962 Mdot
.1656 .59507 Mdot
.16565 .4172 Mdot
.1657 .50835 Mdot
.16575 .09249 Mdot
.1658 .21319 Mdot
.16584 .38159 Mdot
.16589 .08189 Mdot
.16594 .47181 Mdot
.16599 .3017 Mdot
.16603 .40228 Mdot
.16608 .43825 Mdot
.16613 .39018 Mdot
.16618 .35524 Mdot
.16622 .45363 Mdot
.16627 .08447 Mdot
.16632 .45634 Mdot
.16637 .17448 Mdot
.16641 .35151 Mdot
.16646 .50727 Mdot
.16651 .05748 Mdot
.16656 .06772 Mdot
.1666 .18538 Mdot
.16665 .21193 Mdot
.1667 .13118 Mdot
.16675 .07597 Mdot
.1668 .37151 Mdot
.16684 .30691 Mdot
.16689 .05339 Mdot
.16694 .46611 Mdot
.16699 .59325 Mdot
.16703 .23974 Mdot
.16708 .18491 Mdot
.16713 .17912 Mdot
.16718 .20567 Mdot
.16722 .40481 Mdot
.16727 .39805 Mdot
.16732 .42721 Mdot
.16737 .35537 Mdot
.16741 .33505 Mdot
.16746 .54504 Mdot
.16751 .26743 Mdot
.16756 .01857 Mdot
.1676 .43111 Mdot
.16765 .50227 Mdot
.1677 .21443 Mdot
.16775 .43651 Mdot
.1678 .23388 Mdot
.16784 .3858 Mdot
.16789 .15316 Mdot
.16794 .07971 Mdot
.16799 .5303 Mdot
.16803 .34711 Mdot
.16808 .29038 Mdot
.16813 .08979 Mdot
.16818 .30527 Mdot
.16822 .17691 Mdot
.16827 .12597 Mdot
.16832 .48744 Mdot
.16837 .50378 Mdot
.16841 .38219 Mdot
.16846 .30209 Mdot
.16851 .14678 Mdot
.16856 .18343 Mdot
.1686 .44048 Mdot
.16865 .04936 Mdot
.1687 .14292 Mdot
.16875 .35565 Mdot
.1688 .54153 Mdot
.16884 .43826 Mdot
.16889 .30973 Mdot
.16894 .13648 Mdot
.16899 .17045 Mdot
.16903 .29981 Mdot
.16908 .24473 Mdot
.16913 .20951 Mdot
.16918 .42666 Mdot
.16922 .02414 Mdot
.16927 .16966 Mdot
.16932 .50756 Mdot
.16937 .26445 Mdot
.16941 .50149 Mdot
.16946 .28554 Mdot
.16951 .01849 Mdot
.16956 .48559 Mdot
.1696 .21411 Mdot
.16965 .15347 Mdot
.1697 .43838 Mdot
.16975 .05982 Mdot
.16979 .17945 Mdot
.16984 .02526 Mdot
.16989 .09744 Mdot
.16994 .12161 Mdot
.16999 .34451 Mdot
.17003 .31886 Mdot
.17008 .56429 Mdot
.17013 .55449 Mdot
.17018 .05941 Mdot
.17022 .08883 Mdot
.17027 .36949 Mdot
.17032 .14254 Mdot
.17037 .04999 Mdot
.17041 .5225 Mdot
.17046 .46525 Mdot
.17051 .48141 Mdot
.17056 .15182 Mdot
.1706 .25167 Mdot
.17065 .46147 Mdot
.1707 .59915 Mdot
.17075 .54104 Mdot
.17079 .1129 Mdot
.17084 .03779 Mdot
.17089 .55404 Mdot
.17094 .3763 Mdot
.17099 .10235 Mdot
.17103 .54368 Mdot
.17108 .44714 Mdot
.17113 .04649 Mdot
.17118 .38682 Mdot
.17122 .58272 Mdot
.17127 .49597 Mdot
.17132 .5904 Mdot
.17137 .31269 Mdot
.17141 .22794 Mdot
.17146 .36814 Mdot
.17151 .55513 Mdot
.17156 .39351 Mdot
.1716 .36602 Mdot
.17165 .49005 Mdot
.1717 .41801 Mdot
.17175 .15655 Mdot
.17179 .50788 Mdot
.17184 .49422 Mdot
.17189 .4803 Mdot
.17194 .05836 Mdot
.17199 .48479 Mdot
.17203 .54351 Mdot
.17208 .11871 Mdot
.17213 .55934 Mdot
.17218 .54443 Mdot
.17222 .11108 Mdot
.17227 .08692 Mdot
.17232 .18723 Mdot
.17237 .56504 Mdot
.17241 .21844 Mdot
.17246 .09984 Mdot
.17251 .47786 Mdot
.17256 .35181 Mdot
.1726 .45363 Mdot
.17265 .14804 Mdot
.1727 .09906 Mdot
.17275 .58911 Mdot
.17279 .5669 Mdot
.17284 .33336 Mdot
.17289 .54583 Mdot
.17294 .09595 Mdot
.17299 .08738 Mdot
.17303 .45639 Mdot
.17308 .50218 Mdot
.17313 .21448 Mdot
.17318 .1472 Mdot
.17322 .35239 Mdot
.17327 .54617 Mdot
.17332 .27337 Mdot
.17337 .05082 Mdot
.17341 .28018 Mdot
.17346 .37365 Mdot
.17351 .31166 Mdot
.17356 .43571 Mdot
.1736 .19504 Mdot
.17365 .49911 Mdot
.1737 .56318 Mdot
.17375 .58541 Mdot
.17379 .06171 Mdot
.17384 .41477 Mdot
.17389 .57739 Mdot
.17394 .03322 Mdot
.17398 .33167 Mdot
.17403 .47226 Mdot
.17408 .49615 Mdot
.17413 .54916 Mdot
.17418 .47861 Mdot
.17422 .57341 Mdot
.17427 .29638 Mdot
.17432 .41667 Mdot
.17437 .14093 Mdot
.17441 .04195 Mdot
.17446 .03771 Mdot
.17451 .38055 Mdot
.17456 .46407 Mdot
.1746 .27162 Mdot
.17465 .32938 Mdot
.1747 .54817 Mdot
.17475 .28374 Mdot
.17479 .37583 Mdot
.17484 .36953 Mdot
.17489 .56608 Mdot
.17494 .23674 Mdot
.17498 .56439 Mdot
.17503 .39546 Mdot
.17508 .54758 Mdot
.17513 .5084 Mdot
.17518 .10684 Mdot
.17522 .50263 Mdot
.17527 .60174 Mdot
.17532 .0445 Mdot
.17537 .13676 Mdot
.17541 .22096 Mdot
.17546 .19978 Mdot
.17551 .5069 Mdot
.17556 .10952 Mdot
.1756 .19796 Mdot
.17565 .42256 Mdot
.1757 .05753 Mdot
.17575 .44122 Mdot
.17579 .4719 Mdot
.17584 .47771 Mdot
.17589 .37712 Mdot
.17594 .08009 Mdot
.17598 .11709 Mdot
.17603 .51495 Mdot
.17608 .15508 Mdot
.17613 .11903 Mdot
.17618 .32495 Mdot
.17622 .5707 Mdot
.17627 .25001 Mdot
.17632 .02689 Mdot
.17637 .42564 Mdot
.17641 .57229 Mdot
.17646 .22022 Mdot
.17651 .49346 Mdot
.17656 .21939 Mdot
.1766 .38721 Mdot
.17665 .31665 Mdot
.1767 .39865 Mdot
.17675 .03614 Mdot
.17679 .56798 Mdot
.17684 .27382 Mdot
.17689 .56075 Mdot
.17694 .16757 Mdot
.17698 .10497 Mdot
.17703 .50003 Mdot
.17708 .49537 Mdot
.17713 .06519 Mdot
.17718 .19335 Mdot
.17722 .35966 Mdot
.17727 .39105 Mdot
.17732 .34356 Mdot
.17737 .22597 Mdot
.17741 .12435 Mdot
.17746 .37887 Mdot
.17751 .52125 Mdot
.17756 .25701 Mdot
.1776 .50746 Mdot
.17765 .48873 Mdot
.1777 .31656 Mdot
.17775 .47312 Mdot
.17779 .20552 Mdot
.17784 .10479 Mdot
.17789 .29513 Mdot
.17794 .50847 Mdot
.17798 .53502 Mdot
.17803 .14736 Mdot
.17808 .14227 Mdot
.17813 .4182 Mdot
.17818 .0497 Mdot
.17822 .25532 Mdot
.17827 .09179 Mdot
.17832 .23957 Mdot
.17837 .29337 Mdot
.17841 .4676 Mdot
.17846 .35155 Mdot
.17851 .02831 Mdot
.17856 .18373 Mdot
.1786 .10344 Mdot
.17865 .43363 Mdot
.1787 .37463 Mdot
.17875 .27959 Mdot
.17879 .21803 Mdot
.17884 .13178 Mdot
.17889 .50483 Mdot
.17894 .08878 Mdot
.17898 .12795 Mdot
.17903 .43998 Mdot
.17908 .59968 Mdot
.17913 .15709 Mdot
.17917 .58391 Mdot
.17922 .31241 Mdot
.17927 .19619 Mdot
.17932 .12209 Mdot
.17937 .3433 Mdot
.17941 .23533 Mdot
.17946 .55995 Mdot
.17951 .43205 Mdot
.17956 .47903 Mdot
.1796 .4871 Mdot
.17965 .54635 Mdot
.1797 .26303 Mdot
.17975 .3903 Mdot
.17979 .06817 Mdot
.17984 .18643 Mdot
.17989 .58676 Mdot
.17994 .18697 Mdot
.17998 .53972 Mdot
.18003 .28493 Mdot
.18008 .51268 Mdot
.18013 .07373 Mdot
.18017 .11445 Mdot
.18022 .28857 Mdot
.18027 .3703 Mdot
.18032 .09315 Mdot
.18037 .40537 Mdot
.18041 .10709 Mdot
.18046 .26292 Mdot
.18051 .35317 Mdot
.18056 .18475 Mdot
.1806 .15047 Mdot
.18065 .4342 Mdot
.1807 .47747 Mdot
.18075 .30097 Mdot
.18079 .20744 Mdot
.18084 .18588 Mdot
.18089 .10188 Mdot
.18094 .24751 Mdot
.18098 .03572 Mdot
.18103 .20245 Mdot
.18108 .51823 Mdot
.18113 .31112 Mdot
.18117 .35411 Mdot
.18122 .29309 Mdot
.18127 .4592 Mdot
.18132 .21137 Mdot
.18137 .08025 Mdot
.18141 .52611 Mdot
.18146 .38077 Mdot
.18151 .40933 Mdot
.18156 .57648 Mdot
.1816 .2779 Mdot
.18165 .0423 Mdot
.1817 .23929 Mdot
.18175 .44072 Mdot
.18179 .44703 Mdot
.18184 .16816 Mdot
.18189 .54164 Mdot
.18194 .24799 Mdot
.18198 .27585 Mdot
.18203 .08099 Mdot
.18208 .30884 Mdot
.18213 .22698 Mdot
.18217 .08811 Mdot
.18222 .16608 Mdot
.18227 .60105 Mdot
.18232 .47619 Mdot
.18237 .39835 Mdot
.18241 .3102 Mdot
.18246 .40439 Mdot
.18251 .41066 Mdot
.18256 .47556 Mdot
.1826 .53276 Mdot
.18265 .59838 Mdot
.1827 .4375 Mdot
.18275 .21237 Mdot
.18279 .50517 Mdot
.18284 .3738 Mdot
.18289 .60011 Mdot
.18294 .36866 Mdot
.18298 .35172 Mdot
.18303 .43549 Mdot
.18308 .36683 Mdot
.18313 .10752 Mdot
.18317 .28544 Mdot
.18322 .14136 Mdot
.18327 .15456 Mdot
.18332 .03411 Mdot
.18336 .13407 Mdot
.18341 .14363 Mdot
.18346 .28169 Mdot
.18351 .23909 Mdot
.18356 .42719 Mdot
.1836 .34257 Mdot
.18365 .47436 Mdot
.1837 .36686 Mdot
.18375 .49776 Mdot
.18379 .34751 Mdot
.18384 .05157 Mdot
.18389 .1692 Mdot
.18394 .59592 Mdot
.18398 .57704 Mdot
.18403 .05479 Mdot
.18408 .40386 Mdot
.18413 .25891 Mdot
.18417 .15626 Mdot
.18422 .29128 Mdot
.18427 .31105 Mdot
.18432 .57679 Mdot
.18436 .02961 Mdot
.18441 .15143 Mdot
.18446 .29165 Mdot
.18451 .45743 Mdot
.18456 .48931 Mdot
.1846 .47306 Mdot
.18465 .06727 Mdot
.1847 .04495 Mdot
.18475 .16144 Mdot
.18479 .60202 Mdot
.18484 .30373 Mdot
.18489 .15051 Mdot
.18494 .41726 Mdot
.18498 .56516 Mdot
.18503 .14924 Mdot
.18508 .15792 Mdot
.18513 .44354 Mdot
.18517 .52508 Mdot
.18522 .34871 Mdot
.18527 .50234 Mdot
.18532 .30199 Mdot
.18536 .24851 Mdot
.18541 .05237 Mdot
.18546 .52887 Mdot
.18551 .28709 Mdot
.18556 .11179 Mdot
.1856 .36404 Mdot
.18565 .08615 Mdot
.1857 .40111 Mdot
.18575 .24205 Mdot
.18579 .31149 Mdot
.18584 .05591 Mdot
.18589 .25437 Mdot
.18594 .24336 Mdot
.18598 .02246 Mdot
.18603 .50873 Mdot
.18608 .44044 Mdot
.18613 .28152 Mdot
.18617 .47654 Mdot
.18622 .36551 Mdot
.18627 .60022 Mdot
.18632 .35977 Mdot
.18636 .14254 Mdot
.18641 .4665 Mdot
.18646 .31294 Mdot
.18651 .12597 Mdot
.18656 .10489 Mdot
.1866 .54095 Mdot
.18665 .04056 Mdot
.1867 .02889 Mdot
.18675 .34417 Mdot
.18679 .46951 Mdot
.18684 .24278 Mdot
.18689 .39016 Mdot
.18694 .04739 Mdot
.18698 .4283 Mdot
.18703 .59173 Mdot
.18708 .16151 Mdot
.18713 .03964 Mdot
.18717 .5229 Mdot
.18722 .166 Mdot
.18727 .48331 Mdot
.18732 .16642 Mdot
.18736 .1721 Mdot
.18741 .1691 Mdot
.18746 .13825 Mdot
.18751 .03859 Mdot
.18756 .30892 Mdot
.1876 .45949 Mdot
.18765 .02699 Mdot
.1877 .53702 Mdot
.18775 .3713 Mdot
.18779 .43363 Mdot
.18784 .60143 Mdot
.18789 .20756 Mdot
.18794 .50512 Mdot
.18798 .20556 Mdot
.18803 .22598 Mdot
.18808 .17488 Mdot
.18813 .09152 Mdot
.18817 .21716 Mdot
.18822 .07918 Mdot
.18827 .14995 Mdot
.18832 .17195 Mdot
.18836 .06587 Mdot
.18841 .19919 Mdot
.18846 .58686 Mdot
.18851 .60317 Mdot
.18855 .5001 Mdot
.1886 .07565 Mdot
.18865 .56298 Mdot
.1887 .30896 Mdot
.18875 .05532 Mdot
.18879 .06336 Mdot
.18884 .04067 Mdot
.18889 .54099 Mdot
.18894 .22501 Mdot
.18898 .06526 Mdot
.18903 .43643 Mdot
.18908 .05058 Mdot
.18913 .03416 Mdot
.18917 .4426 Mdot
.18922 .27625 Mdot
.18927 .56238 Mdot
.18932 .42032 Mdot
.18936 .37813 Mdot
.18941 .14101 Mdot
.18946 .40514 Mdot
.18951 .36916 Mdot
.18955 .19365 Mdot
.1896 .15748 Mdot
.18965 .40529 Mdot
.1897 .47239 Mdot
.18975 .13271 Mdot
.18979 .19783 Mdot
.18984 .11104 Mdot
.18989 .43178 Mdot
.18994 .08406 Mdot
.18998 .17187 Mdot
.19003 .17338 Mdot
.19008 .22147 Mdot
.19013 .03352 Mdot
.19017 .33877 Mdot
.19022 .13751 Mdot
.19027 .20203 Mdot
.19032 .19424 Mdot
.19036 .07722 Mdot
.19041 .17846 Mdot
.19046 .38503 Mdot
.19051 .41943 Mdot
.19055 .53954 Mdot
.1906 .37664 Mdot
.19065 .03058 Mdot
.1907 .24049 Mdot
.19075 .39676 Mdot
.19079 .57468 Mdot
.19084 .16152 Mdot
.19089 .12248 Mdot
.19094 .21365 Mdot
.19098 .47834 Mdot
.19103 .33307 Mdot
.19108 .05313 Mdot
.19113 .05649 Mdot
.19117 .31967 Mdot
.19122 .1263 Mdot
.19127 .03432 Mdot
.19132 .32104 Mdot
.19136 .19686 Mdot
.19141 .5276 Mdot
.19146 .44341 Mdot
.19151 .25853 Mdot
.19155 .03311 Mdot
.1916 .15727 Mdot
.19165 .03868 Mdot
.1917 .32232 Mdot
.19175 .2598 Mdot
.19179 .1414 Mdot
.19184 .40152 Mdot
.19189 .52888 Mdot
.19194 .28845 Mdot
.19198 .58321 Mdot
.19203 .29375 Mdot
.19208 .32994 Mdot
.19213 .41343 Mdot
.19217 .26485 Mdot
.19222 .25533 Mdot
.19227 .28817 Mdot
.19232 .10847 Mdot
.19236 .15326 Mdot
.19241 .23571 Mdot
.19246 .57045 Mdot
.19251 .51493 Mdot
.19255 .22899 Mdot
.1926 .39563 Mdot
.19265 .32663 Mdot
.1927 .49653 Mdot
.19275 .08643 Mdot
.19279 .37166 Mdot
.19284 .01902 Mdot
.19289 .25144 Mdot
.19294 .54835 Mdot
.19298 .57346 Mdot
.19303 .09346 Mdot
.19308 .56632 Mdot
.19313 .56846 Mdot
.19317 .29442 Mdot
.19322 .36684 Mdot
.19327 .16759 Mdot
.19332 .31832 Mdot
.19336 .0538 Mdot
.19341 .09338 Mdot
.19346 .07383 Mdot
.19351 .17976 Mdot
.19355 .42141 Mdot
.1936 .12626 Mdot
.19365 .16222 Mdot
.1937 .5541 Mdot
.19374 .04049 Mdot
.19379 .40295 Mdot
.19384 .26902 Mdot
.19389 .48238 Mdot
.19394 .27216 Mdot
.19398 .39865 Mdot
.19403 .03229 Mdot
.19408 .53736 Mdot
.19413 .30202 Mdot
.19417 .3199 Mdot
.19422 .0693 Mdot
.19427 .57222 Mdot
.19432 .02231 Mdot
.19436 .55638 Mdot
.19441 .50504 Mdot
.19446 .26861 Mdot
.19451 .57184 Mdot
.19455 .47771 Mdot
.1946 .44592 Mdot
.19465 .10356 Mdot
.1947 .16513 Mdot
.19474 .36616 Mdot
.19479 .2984 Mdot
.19484 .15279 Mdot
.19489 .13935 Mdot
.19494 .56653 Mdot
.19498 .04409 Mdot
.19503 .27374 Mdot
.19508 .47052 Mdot
.19513 .1826 Mdot
.19517 .0265 Mdot
.19522 .3397 Mdot
.19527 .18321 Mdot
.19532 .46603 Mdot
.19536 .56052 Mdot
.19541 .37081 Mdot
.19546 .1756 Mdot
.19551 .51297 Mdot
.19555 .0702 Mdot
.1956 .11691 Mdot
.19565 .20709 Mdot
.1957 .04997 Mdot
.19574 .22761 Mdot
.19579 .02806 Mdot
.19584 .05667 Mdot
.19589 .28713 Mdot
.19594 .53253 Mdot
.19598 .4786 Mdot
.19603 .52064 Mdot
.19608 .32392 Mdot
.19613 .50315 Mdot
.19617 .21957 Mdot
.19622 .06482 Mdot
.19627 .15603 Mdot
.19632 .49136 Mdot
.19636 .48319 Mdot
.19641 .48494 Mdot
.19646 .29333 Mdot
.19651 .53416 Mdot
.19655 .12709 Mdot
.1966 .32405 Mdot
.19665 .38369 Mdot
.1967 .47867 Mdot
.19674 .02489 Mdot
.19679 .13166 Mdot
.19684 .34843 Mdot
.19689 .26577 Mdot
.19694 .60015 Mdot
.19698 .0897 Mdot
.19703 .07601 Mdot
.19708 .33657 Mdot
.19713 .13626 Mdot
.19717 .17239 Mdot
.19722 .35541 Mdot
.19727 .43674 Mdot
.19732 .52002 Mdot
.19736 .12227 Mdot
.19741 .21409 Mdot
.19746 .54871 Mdot
.19751 .05153 Mdot
.19755 .24066 Mdot
.1976 .52408 Mdot
.19765 .02925 Mdot
.1977 .52777 Mdot
.19774 .51994 Mdot
.19779 .1551 Mdot
.19784 .15391 Mdot
.19789 .51759 Mdot
.19793 .40298 Mdot
.19798 .41 Mdot
.19803 .49146 Mdot
.19808 .52077 Mdot
.19813 .32799 Mdot
.19817 .3487 Mdot
.19822 .1696 Mdot
.19827 .39921 Mdot
.19832 .17031 Mdot
.19836 .59662 Mdot
.19841 .33619 Mdot
.19846 .48252 Mdot
.19851 .06274 Mdot
.19855 .39724 Mdot
.1986 .39081 Mdot
.19865 .44569 Mdot
.1987 .42541 Mdot
.19874 .47648 Mdot
.19879 .37626 Mdot
.19884 .52125 Mdot
.19889 .5088 Mdot
.19893 .33609 Mdot
.19898 .23706 Mdot
.19903 .01836 Mdot
.19908 .12052 Mdot
.19913 .52941 Mdot
.19917 .34893 Mdot
.19922 .10092 Mdot
.19927 .39586 Mdot
.19932 .19542 Mdot
.19936 .19404 Mdot
.19941 .30504 Mdot
.19946 .24026 Mdot
.19951 .20213 Mdot
.19955 .46117 Mdot
.1996 .42584 Mdot
.19965 .19222 Mdot
.1997 .40822 Mdot
.19974 .08507 Mdot
.19979 .58347 Mdot
.19984 .37014 Mdot
.19989 .53506 Mdot
.19993 .31213 Mdot
.19998 .07694 Mdot
.20003 .46466 Mdot
.20008 .21368 Mdot
.20013 .08978 Mdot
.20017 .07328 Mdot
.20022 .35885 Mdot
.20027 .28759 Mdot
.20032 .34418 Mdot
.20036 .57569 Mdot
.20041 .56632 Mdot
.20046 .10688 Mdot
.20051 .16485 Mdot
.20055 .28536 Mdot
.2006 .34077 Mdot
.20065 .50808 Mdot
.2007 .307 Mdot
.20074 .46284 Mdot
.20079 .16326 Mdot
.20084 .11457 Mdot
.20089 .23664 Mdot
.20093 .48269 Mdot
.20098 .39645 Mdot
.20103 .18283 Mdot
.20108 .52783 Mdot
.20113 .42047 Mdot
.20117 .53511 Mdot
.20122 .57248 Mdot
.20127 .45276 Mdot
.20132 .36189 Mdot
.20136 .19096 Mdot
.20141 .2996 Mdot
.20146 .12329 Mdot
.20151 .38953 Mdot
.20155 .22797 Mdot
.2016 .20743 Mdot
.20165 .56177 Mdot
.2017 .11888 Mdot
.20174 .49052 Mdot
.20179 .30268 Mdot
.20184 .26947 Mdot
.20189 .25937 Mdot
.20193 .34197 Mdot
.20198 .20282 Mdot
.20203 .04754 Mdot
.20208 .38 Mdot
.20213 .54885 Mdot
.20217 .0347 Mdot
.20222 .12304 Mdot
.20227 .56286 Mdot
.20232 .02845 Mdot
.20236 .06554 Mdot
.20241 .2736 Mdot
.20246 .21567 Mdot
.20251 .44081 Mdot
.20255 .36926 Mdot
.2026 .16502 Mdot
.20265 .42946 Mdot
.2027 .22755 Mdot
.20274 .17654 Mdot
.20279 .20658 Mdot
.20284 .32528 Mdot
.20289 .34036 Mdot
.20293 .47719 Mdot
.20298 .54043 Mdot
.20303 .08063 Mdot
.20308 .60171 Mdot
.20312 .28907 Mdot
.20317 .5076 Mdot
.20322 .30395 Mdot
.20327 .06757 Mdot
.20332 .26909 Mdot
.20336 .39927 Mdot
.20341 .34442 Mdot
.20346 .05382 Mdot
.20351 .21826 Mdot
.20355 .14038 Mdot
.2036 .14346 Mdot
.20365 .21633 Mdot
.2037 .45232 Mdot
.20374 .57868 Mdot
.20379 .31733 Mdot
.20384 .5921 Mdot
.20389 .29049 Mdot
.20393 .38681 Mdot
.20398 .59537 Mdot
.20403 .26646 Mdot
.20408 .41662 Mdot
.20412 .4497 Mdot
.20417 .52945 Mdot
.20422 .26807 Mdot
.20427 .14226 Mdot
.20432 .54543 Mdot
.20436 .2402 Mdot
.20441 .21521 Mdot
.20446 .47649 Mdot
.20451 .16086 Mdot
.20455 .49911 Mdot
.2046 .1761 Mdot
.20465 .27294 Mdot
.2047 .03519 Mdot
.20474 .37035 Mdot
.20479 .56309 Mdot
.20484 .42395 Mdot
.20489 .05983 Mdot
.20493 .06773 Mdot
.20498 .57431 Mdot
.20503 .14817 Mdot
.20508 .27635 Mdot
.20512 .07569 Mdot
.20517 .32257 Mdot
.20522 .33488 Mdot
.20527 .42997 Mdot
.20532 .14956 Mdot
.20536 .0692 Mdot
.20541 .20733 Mdot
.20546 .48787 Mdot
.20551 .51268 Mdot
.20555 .45731 Mdot
.2056 .33416 Mdot
.20565 .34171 Mdot
.2057 .02829 Mdot
.20574 .29592 Mdot
.20579 .07592 Mdot
.20584 .32123 Mdot
.20589 .26126 Mdot
.20593 .33616 Mdot
.20598 .2553 Mdot
.20603 .2761 Mdot
.20608 .20824 Mdot
.20612 .36517 Mdot
.20617 .12184 Mdot
.20622 .60308 Mdot
.20627 .14726 Mdot
.20632 .05731 Mdot
.20636 .39028 Mdot
.20641 .18782 Mdot
.20646 .60102 Mdot
.20651 .59143 Mdot
.20655 .19767 Mdot
.2066 .30328 Mdot
.20665 .10305 Mdot
.2067 .14883 Mdot
.20674 .46683 Mdot
.20679 .56489 Mdot
.20684 .08947 Mdot
.20689 .45623 Mdot
.20693 .40561 Mdot
.20698 .25838 Mdot
.20703 .43154 Mdot
.20708 .13478 Mdot
.20712 .16502 Mdot
.20717 .5856 Mdot
.20722 .23801 Mdot
.20727 .37294 Mdot
.20731 .0579 Mdot
.20736 .58584 Mdot
.20741 .10546 Mdot
.20746 .33034 Mdot
.20751 .27094 Mdot
.20755 .41273 Mdot
.2076 .10776 Mdot
.20765 .34223 Mdot
.2077 .08798 Mdot
.20774 .12416 Mdot
.20779 .01942 Mdot
.20784 .20811 Mdot
.20789 .22448 Mdot
.20793 .16259 Mdot
.20798 .53328 Mdot
.20803 .3552 Mdot
.20808 .42219 Mdot
.20812 .50754 Mdot
.20817 .11645 Mdot
.20822 .23513 Mdot
.20827 .27187 Mdot
.20831 .52527 Mdot
.20836 .48177 Mdot
.20841 .46551 Mdot
.20846 .22868 Mdot
.20851 .54275 Mdot
.20855 .39102 Mdot
.2086 .14988 Mdot
.20865 .56107 Mdot
.2087 .14472 Mdot
.20874 .29797 Mdot
.20879 .41098 Mdot
.20884 .4878 Mdot
.20889 .03527 Mdot
.20893 .29326 Mdot
.20898 .21758 Mdot
.20903 .27803 Mdot
.20908 .47601 Mdot
.20912 .36331 Mdot
.20917 .46571 Mdot
.20922 .45917 Mdot
.20927 .57179 Mdot
.20931 .26157 Mdot
.20936 .24529 Mdot
.20941 .20201 Mdot
.20946 .06123 Mdot
.20951 .38312 Mdot
.20955 .3831 Mdot
.2096 .57665 Mdot
.20965 .12181 Mdot
.2097 .59543 Mdot
.20974 .24793 Mdot
.20979 .03029 Mdot
.20984 .58041 Mdot
.20989 .31217 Mdot
.20993 .44027 Mdot
.20998 .14582 Mdot
.21003 .55985 Mdot
.21008 .03362 Mdot
.21012 .2374 Mdot
.21017 .47111 Mdot
.21022 .09855 Mdot
.21027 .27364 Mdot
.21031 .37501 Mdot
.21036 .02665 Mdot
.21041 .13008 Mdot
.21046 .02678 Mdot
.21051 .14443 Mdot
.21055 .42797 Mdot
.2106 .08356 Mdot
.21065 .24698 Mdot
.2107 .36466 Mdot
.21074 .45464 Mdot
.21079 .56508 Mdot
.21084 .25488 Mdot
.21089 .13144 Mdot
.21093 .43906 Mdot
.21098 .588 Mdot
.21103 .54604 Mdot
.21108 .2945 Mdot
.21112 .30795 Mdot
.21117 .04286 Mdot
.21122 .52713 Mdot
.21127 .07181 Mdot
.21131 .44016 Mdot
.21136 .54764 Mdot
.21141 .2682 Mdot
.21146 .30012 Mdot
.21151 .42822 Mdot
.21155 .43226 Mdot
.2116 .25613 Mdot
.21165 .1704 Mdot
.2117 .01497 Mdot
.21174 .36341 Mdot
.21179 .02386 Mdot
.21184 .40906 Mdot
.21189 .16365 Mdot
.21193 .40165 Mdot
.21198 .37231 Mdot
.21203 .29233 Mdot
.21208 .32792 Mdot
.21212 .41698 Mdot
.21217 .4296 Mdot
.21222 .60116 Mdot
.21227 .03468 Mdot
.21231 .38883 Mdot
.21236 .50579 Mdot
.21241 .54406 Mdot
.21246 .19784 Mdot
.2125 .44452 Mdot
.21255 .2523 Mdot
.2126 .25865 Mdot
.21265 .37294 Mdot
.2127 .02697 Mdot
.21274 .59949 Mdot
.21279 .10296 Mdot
.21284 .37268 Mdot
.21289 .26689 Mdot
.21293 .59034 Mdot
.21298 .29722 Mdot
.21303 .22374 Mdot
.21308 .46856 Mdot
.21312 .23274 Mdot
.21317 .0196 Mdot
.21322 .49914 Mdot
.21327 .06629 Mdot
.21331 .40647 Mdot
.21336 .02176 Mdot
.21341 .47917 Mdot
.21346 .28079 Mdot
.2135 .504 Mdot
.21355 .08103 Mdot
.2136 .29604 Mdot
.21365 .4396 Mdot
.2137 .26641 Mdot
.21374 .42571 Mdot
.21379 .52642 Mdot
.21384 .42734 Mdot
.21389 .27024 Mdot
.21393 .33746 Mdot
.21398 .16845 Mdot
.21403 .17516 Mdot
.21408 .28323 Mdot
.21412 .05495 Mdot
.21417 .54803 Mdot
.21422 .30992 Mdot
.21427 .0652 Mdot
.21431 .05006 Mdot
.21436 .0636 Mdot
.21441 .25833 Mdot
.21446 .26206 Mdot
.2145 .04301 Mdot
.21455 .18775 Mdot
.2146 .58087 Mdot
.21465 .36139 Mdot
.2147 .5653 Mdot
.21474 .49504 Mdot
.21479 .15598 Mdot
.21484 .10969 Mdot
.21489 .1543 Mdot
.21493 .57194 Mdot
.21498 .33197 Mdot
.21503 .44277 Mdot
.21508 .42016 Mdot
.21512 .4182 Mdot
.21517 .17152 Mdot
.21522 .17425 Mdot
.21527 .37992 Mdot
.21531 .47349 Mdot
.21536 .46493 Mdot
.21541 .12376 Mdot
.21546 .34457 Mdot
.2155 .4246 Mdot
.21555 .2213 Mdot
.2156 .46502 Mdot
.21565 .31627 Mdot
.2157 .25156 Mdot
.21574 .24376 Mdot
.21579 .11834 Mdot
.21584 .3543 Mdot
.21589 .35984 Mdot
.21593 .10248 Mdot
.21598 .02336 Mdot
.21603 .21471 Mdot
.21608 .39123 Mdot
.21612 .37384 Mdot
.21617 .18391 Mdot
.21622 .39787 Mdot
.21627 .57635 Mdot
.21631 .21702 Mdot
.21636 .02437 Mdot
.21641 .03266 Mdot
.21646 .11757 Mdot
.2165 .35542 Mdot
.21655 .50393 Mdot
.2166 .29141 Mdot
.21665 .2963 Mdot
.21669 .14882 Mdot
.21674 .05362 Mdot
.21679 .57846 Mdot
.21684 .05945 Mdot
.21689 .50839 Mdot
.21693 .5386 Mdot
.21698 .23887 Mdot
.21703 .30293 Mdot
.21708 .42062 Mdot
.21712 .52994 Mdot
.21717 .03887 Mdot
.21722 .51503 Mdot
.21727 .06149 Mdot
.21731 .36074 Mdot
.21736 .24432 Mdot
.21741 .542 Mdot
.21746 .44779 Mdot
.2175 .35108 Mdot
.21755 .22638 Mdot
.2176 .43914 Mdot
.21765 .10708 Mdot
.21769 .45047 Mdot
.21774 .53829 Mdot
.21779 .15755 Mdot
.21784 .56158 Mdot
.21789 .41156 Mdot
.21793 .56316 Mdot
.21798 .11281 Mdot
.21803 .0679 Mdot
.21808 .47629 Mdot
.21812 .339 Mdot
.21817 .4132 Mdot
.21822 .25061 Mdot
.21827 .54967 Mdot
.21831 .31484 Mdot
.21836 .5015 Mdot
.21841 .20383 Mdot
.21846 .20364 Mdot
.2185 .08522 Mdot
.21855 .56283 Mdot
.2186 .35937 Mdot
.21865 .45589 Mdot
.21869 .46217 Mdot
.21874 .1384 Mdot
.21879 .267 Mdot
.21884 .02013 Mdot
.21889 .5272 Mdot
.21893 .58417 Mdot
.21898 .30874 Mdot
.21903 .21189 Mdot
.21908 .56737 Mdot
.21912 .48607 Mdot
.21917 .25555 Mdot
.21922 .33893 Mdot
.21927 .24308 Mdot
.21931 .08757 Mdot
.21936 .01965 Mdot
.21941 .39258 Mdot
.21946 .53157 Mdot
.2195 .18939 Mdot
.21955 .41915 Mdot
.2196 .20365 Mdot
.21965 .46105 Mdot
.21969 .22989 Mdot
.21974 .07449 Mdot
.21979 .35109 Mdot
.21984 .60221 Mdot
.21989 .10621 Mdot
.21993 .41082 Mdot
.21998 .34567 Mdot
.22003 .08972 Mdot
.22008 .12536 Mdot
.22012 .11679 Mdot
.22017 .14849 Mdot
.22022 .12568 Mdot
.22027 .24262 Mdot
.22031 .46456 Mdot
.22036 .41289 Mdot
.22041 .48593 Mdot
.22046 .16976 Mdot
.2205 .45962 Mdot
.22055 .03502 Mdot
.2206 .55769 Mdot
.22065 .58369 Mdot
.22069 .05518 Mdot
.22074 .43469 Mdot
.22079 .11134 Mdot
.22084 .3685 Mdot
.22089 .58401 Mdot
.22093 .09832 Mdot
.22098 .11246 Mdot
.22103 .277 Mdot
.22108 .18789 Mdot
.22112 .35598 Mdot
.22117 .03745 Mdot
.22122 .16635 Mdot
.22127 .08581 Mdot
.22131 .2222 Mdot
.22136 .5151 Mdot
.22141 .52706 Mdot
.22146 .22457 Mdot
.2215 .41263 Mdot
.22155 .04388 Mdot
.2216 .37201 Mdot
.22165 .36828 Mdot
.22169 .39233 Mdot
.22174 .08952 Mdot
.22179 .39165 Mdot
.22184 .32781 Mdot
.22188 .56096 Mdot
.22193 .5815 Mdot
.22198 .03785 Mdot
.22203 .34713 Mdot
.22208 .47735 Mdot
.22212 .48375 Mdot
.22217 .36418 Mdot
.22222 .17395 Mdot
.22227 .13608 Mdot
.22231 .46102 Mdot
.22236 .21253 Mdot
.22241 .10284 Mdot
.22246 .51721 Mdot
.2225 .54925 Mdot
.22255 .2888 Mdot
.2226 .4816 Mdot
.22265 .11928 Mdot
.22269 .52008 Mdot
.22274 .52011 Mdot
.22279 .12803 Mdot
.22284 .33028 Mdot
.22288 .44527 Mdot
.22293 .14317 Mdot
.22298 .40354 Mdot
.22303 .37265 Mdot
.22308 .46709 Mdot
.22312 .12003 Mdot
.22317 .07112 Mdot
.22322 .49863 Mdot
.22327 .58666 Mdot
.22331 .35918 Mdot
.22336 .5005 Mdot
.22341 .37725 Mdot
.22346 .14036 Mdot
.2235 .16136 Mdot
.22355 .41236 Mdot
.2236 .46337 Mdot
.22365 .19444 Mdot
.22369 .47588 Mdot
.22374 .53409 Mdot
.22379 .3588 Mdot
.22384 .27769 Mdot
.22388 .55909 Mdot
.22393 .42077 Mdot
.22398 .04322 Mdot
.22403 .43574 Mdot
.22408 .43063 Mdot
.22412 .03194 Mdot
.22417 .2739 Mdot
.22422 .57198 Mdot
.22427 .32531 Mdot
.22431 .56415 Mdot
.22436 .3786 Mdot
.22441 .58864 Mdot
.22446 .56945 Mdot
.2245 .07836 Mdot
.22455 .01605 Mdot
.2246 .46299 Mdot
.22465 .42281 Mdot
.22469 .26932 Mdot
.22474 .15601 Mdot
.22479 .28327 Mdot
.22484 .55025 Mdot
.22488 .33856 Mdot
.22493 .40053 Mdot
.22498 .02029 Mdot
.22503 .59448 Mdot
.22508 .52111 Mdot
.22512 .37202 Mdot
.22517 .18787 Mdot
.22522 .17856 Mdot
.22527 .50388 Mdot
.22531 .11283 Mdot
.22536 .21922 Mdot
.22541 .45658 Mdot
.22546 .54305 Mdot
.2255 .33756 Mdot
.22555 .2339 Mdot
.2256 .49045 Mdot
.22565 .4794 Mdot
.22569 .33621 Mdot
.22574 .37423 Mdot
.22579 .08236 Mdot
.22584 .22478 Mdot
.22588 .19492 Mdot
.22593 .10568 Mdot
.22598 .13543 Mdot
.22603 .48955 Mdot
.22608 .39771 Mdot
.22612 .10009 Mdot
.22617 .14428 Mdot
.22622 .57176 Mdot
.22627 .0404 Mdot
.22631 .51555 Mdot
.22636 .56904 Mdot
.22641 .08259 Mdot
.22646 .53089 Mdot
.2265 .31104 Mdot
.22655 .12717 Mdot
.2266 .14287 Mdot
.22665 .20805 Mdot
.22669 .09184 Mdot
.22674 .24004 Mdot
.22679 .26679 Mdot
.22684 .47516 Mdot
.22688 .32094 Mdot
.22693 .17239 Mdot
.22698 .05671 Mdot
.22703 .29495 Mdot
.22707 .22997 Mdot
.22712 .05167 Mdot
.22717 .17049 Mdot
.22722 .50057 Mdot
.22727 .14458 Mdot
.22731 .51071 Mdot
.22736 .20205 Mdot
.22741 .47488 Mdot
.22746 .23236 Mdot
.2275 .545 Mdot
.22755 .13416 Mdot
.2276 .54731 Mdot
.22765 .52465 Mdot
.22769 .43253 Mdot
.22774 .59462 Mdot
.22779 .35397 Mdot
.22784 .44751 Mdot
.22788 .2072 Mdot
.22793 .34254 Mdot
.22798 .48214 Mdot
.22803 .14128 Mdot
.22807 .04951 Mdot
.22812 .30053 Mdot
.22817 .2019 Mdot
.22822 .51464 Mdot
.22827 .60117 Mdot
.22831 .14475 Mdot
.22836 .30466 Mdot
.22841 .38477 Mdot
.22846 .10517 Mdot
.2285 .54603 Mdot
.22855 .43311 Mdot
.2286 .16712 Mdot
.22865 .1635 Mdot
.22869 .42657 Mdot
.22874 .48912 Mdot
.22879 .2458 Mdot
.22884 .33429 Mdot
.22888 .43527 Mdot
.22893 .14986 Mdot
.22898 .40161 Mdot
.22903 .1418 Mdot
.22907 .10744 Mdot
.22912 .27105 Mdot
.22917 .27504 Mdot
.22922 .10699 Mdot
.22927 .41023 Mdot
.22931 .08386 Mdot
.22936 .36372 Mdot
.22941 .10914 Mdot
.22946 .28019 Mdot
.2295 .38253 Mdot
.22955 .58227 Mdot
.2296 .01869 Mdot
.22965 .33748 Mdot
.22969 .55275 Mdot
.22974 .42986 Mdot
.22979 .45852 Mdot
.22984 .51424 Mdot
.22988 .07833 Mdot
.22993 .19878 Mdot
.22998 .13894 Mdot
.23003 .09367 Mdot
.23007 .53179 Mdot
.23012 .40049 Mdot
.23017 .60047 Mdot
.23022 .58955 Mdot
.23027 .27545 Mdot
.23031 .14016 Mdot
.23036 .50818 Mdot
.23041 .19403 Mdot
.23046 .2063 Mdot
.2305 .37977 Mdot
.23055 .41375 Mdot
.2306 .51717 Mdot
.23065 .4271 Mdot
.23069 .40082 Mdot
.23074 .40977 Mdot
.23079 .1944 Mdot
.23084 .47768 Mdot
.23088 .57428 Mdot
.23093 .55458 Mdot
.23098 .28348 Mdot
.23103 .41406 Mdot
.23107 .39021 Mdot
.23112 .43035 Mdot
.23117 .20452 Mdot
.23122 .48559 Mdot
.23126 .59305 Mdot
.23131 .43321 Mdot
.23136 .21829 Mdot
.23141 .22485 Mdot
.23146 .46759 Mdot
.2315 .52835 Mdot
.23155 .03897 Mdot
.2316 .03326 Mdot
.23165 .10253 Mdot
.23169 .12932 Mdot
.23174 .12512 Mdot
.23179 .20949 Mdot
.23184 .30504 Mdot
.23188 .32287 Mdot
.23193 .53405 Mdot
.23198 .33514 Mdot
.23203 .33409 Mdot
.23207 .37162 Mdot
.23212 .26528 Mdot
.23217 .5244 Mdot
.23222 .5472 Mdot
.23226 .54459 Mdot
.23231 .07546 Mdot
.23236 .05352 Mdot
.23241 .55748 Mdot
.23246 .12609 Mdot
.2325 .4605 Mdot
.23255 .432 Mdot
.2326 .10459 Mdot
.23265 .20106 Mdot
.23269 .43624 Mdot
.23274 .41345 Mdot
.23279 .01676 Mdot
.23284 .08645 Mdot
.23288 .32582 Mdot
.23293 .21867 Mdot
.23298 .31505 Mdot
.23303 .3669 Mdot
.23307 .39509 Mdot
.23312 .48686 Mdot
.23317 .58429 Mdot
.23322 .59861 Mdot
.23326 .14452 Mdot
.23331 .56578 Mdot
.23336 .0518 Mdot
.23341 .06873 Mdot
.23346 .08377 Mdot
.2335 .52697 Mdot
.23355 .09765 Mdot
.2336 .54597 Mdot
.23365 .22659 Mdot
.23369 .10968 Mdot
.23374 .59638 Mdot
.23379 .35962 Mdot
.23384 .39368 Mdot
.23388 .29955 Mdot
.23393 .59433 Mdot
.23398 .28787 Mdot
.23403 .08257 Mdot
.23407 .09559 Mdot
.23412 .29399 Mdot
.23417 .5243 Mdot
.23422 .29081 Mdot
.23426 .21205 Mdot
.23431 .31303 Mdot
.23436 .52901 Mdot
.23441 .161 Mdot
.23446 .24959 Mdot
.2345 .27594 Mdot
.23455 .47499 Mdot
.2346 .09194 Mdot
.23465 .32595 Mdot
.23469 .193 Mdot
.23474 .53235 Mdot
.23479 .46867 Mdot
.23484 .23099 Mdot
.23488 .19995 Mdot
.23493 .18744 Mdot
.23498 .08969 Mdot
.23503 .53476 Mdot
.23507 .20894 Mdot
.23512 .50289 Mdot
.23517 .02183 Mdot
.23522 .45388 Mdot
.23526 .51828 Mdot
.23531 .58192 Mdot
.23536 .33435 Mdot
.23541 .25654 Mdot
.23546 .21997 Mdot
.2355 .06762 Mdot
.23555 .18806 Mdot
.2356 .02166 Mdot
.23565 .54735 Mdot
.23569 .19596 Mdot
.23574 .11083 Mdot
.23579 .29903 Mdot
.23584 .36906 Mdot
.23588 .26694 Mdot
.23593 .24548 Mdot
.23598 .08275 Mdot
.23603 .18382 Mdot
.23607 .09421 Mdot
.23612 .17049 Mdot
.23617 .15132 Mdot
.23622 .5782 Mdot
.23626 .19464 Mdot
.23631 .16337 Mdot
.23636 .30076 Mdot
.23641 .07463 Mdot
.23645 .21605 Mdot
.2365 .43235 Mdot
.23655 .05893 Mdot
.2366 .45799 Mdot
.23665 .16314 Mdot
.23669 .259 Mdot
.23674 .05198 Mdot
.23679 .51396 Mdot
.23684 .57051 Mdot
.23688 .16289 Mdot
.23693 .35627 Mdot
.23698 .15961 Mdot
.23703 .31828 Mdot
.23707 .52073 Mdot
.23712 .28823 Mdot
.23717 .57912 Mdot
.23722 .23879 Mdot
.23726 .36494 Mdot
.23731 .15162 Mdot
.23736 .01562 Mdot
.23741 .05885 Mdot
.23745 .21628 Mdot
.2375 .45419 Mdot
.23755 .54432 Mdot
.2376 .44613 Mdot
.23765 .38725 Mdot
.23769 .40997 Mdot
.23774 .10103 Mdot
.23779 .29769 Mdot
.23784 .14296 Mdot
.23788 .37271 Mdot
.23793 .1904 Mdot
.23798 .33051 Mdot
.23803 .58339 Mdot
.23807 .03114 Mdot
.23812 .04549 Mdot
.23817 .02693 Mdot
.23822 .07737 Mdot
.23826 .34623 Mdot
.23831 .0697 Mdot
.23836 .39147 Mdot
.23841 .31575 Mdot
.23845 .20932 Mdot
.2385 .06879 Mdot
.23855 .34733 Mdot
.2386 .11418 Mdot
.23865 .35845 Mdot
.23869 .1278 Mdot
.23874 .50453 Mdot
.23879 .33026 Mdot
.23884 .55181 Mdot
.23888 .04147 Mdot
.23893 .22154 Mdot
.23898 .20201 Mdot
.23903 .19381 Mdot
.23907 .4544 Mdot
.23912 .49436 Mdot
.23917 .22194 Mdot
.23922 .17738 Mdot
.23926 .42362 Mdot
.23931 .48213 Mdot
.23936 .15928 Mdot
.23941 .43447 Mdot
.23945 .36862 Mdot
.2395 .10537 Mdot
.23955 .44685 Mdot
.2396 .23986 Mdot
.23965 .31454 Mdot
.23969 .36136 Mdot
.23974 .34737 Mdot
.23979 .48473 Mdot
.23984 .20145 Mdot
.23988 .46016 Mdot
.23993 .03182 Mdot
.23998 .53625 Mdot
.24003 .17469 Mdot
.24007 .25333 Mdot
.24012 .43314 Mdot
.24017 .35715 Mdot
.24022 .32361 Mdot
.24026 .36229 Mdot
.24031 .22591 Mdot
.24036 .19448 Mdot
.24041 .50332 Mdot
.24045 .48349 Mdot
.2405 .08134 Mdot
.24055 .36334 Mdot
.2406 .1494 Mdot
.24064 .39283 Mdot
.24069 .23782 Mdot
.24074 .13819 Mdot
.24079 .43818 Mdot
.24084 .04617 Mdot
.24088 .49377 Mdot
.24093 .25679 Mdot
.24098 .25144 Mdot
.24103 .18934 Mdot
.24107 .47665 Mdot
.24112 .32387 Mdot
.24117 .09146 Mdot
.24122 .53934 Mdot
.24126 .05822 Mdot
.24131 .57004 Mdot
.24136 .37118 Mdot
.24141 .19175 Mdot
.24145 .43564 Mdot
.2415 .39027 Mdot
.24155 .47119 Mdot
.2416 .31159 Mdot
.24164 .36901 Mdot
.24169 .04165 Mdot
.24174 .3365 Mdot
.24179 .52209 Mdot
.24184 .1459 Mdot
.24188 .50678 Mdot
.24193 .50164 Mdot
.24198 .49063 Mdot
.24203 .25546 Mdot
.24207 .2647 Mdot
.24212 .26491 Mdot
.24217 .316 Mdot
.24222 .38213 Mdot
.24226 .54416 Mdot
.24231 .18815 Mdot
.24236 .37999 Mdot
.24241 .33862 Mdot
.24245 .57745 Mdot
.2425 .4203 Mdot
.24255 .20294 Mdot
.2426 .5063 Mdot
.24264 .20188 Mdot
.24269 .55244 Mdot
.24274 .49467 Mdot
.24279 .152 Mdot
.24284 .17494 Mdot
.24288 .23065 Mdot
.24293 .57591 Mdot
.24298 .02081 Mdot
.24303 .27149 Mdot
.24307 .33234 Mdot
.24312 .09999 Mdot
.24317 .36868 Mdot
.24322 .02149 Mdot
.24326 .08214 Mdot
.24331 .38732 Mdot
.24336 .58987 Mdot
.24341 .08066 Mdot
.24345 .49731 Mdot
.2435 .02204 Mdot
.24355 .26596 Mdot
.2436 .10653 Mdot
.24364 .09172 Mdot
.24369 .42242 Mdot
.24374 .36298 Mdot
.24379 .50798 Mdot
.24384 .14261 Mdot
.24388 .53108 Mdot
.24393 .22569 Mdot
.24398 .34774 Mdot
.24403 .51528 Mdot
.24407 .55849 Mdot
.24412 .21959 Mdot
.24417 .09096 Mdot
.24422 .19765 Mdot
.24426 .47321 Mdot
.24431 .45424 Mdot
.24436 .08418 Mdot
.24441 .13022 Mdot
.24445 .10061 Mdot
.2445 .4677 Mdot
.24455 .01823 Mdot
.2446 .23623 Mdot
.24464 .09328 Mdot
.24469 .21645 Mdot
.24474 .51502 Mdot
.24479 .15922 Mdot
.24484 .27418 Mdot
.24488 .45679 Mdot
.24493 .02175 Mdot
.24498 .03132 Mdot
.24503 .34643 Mdot
.24507 .2458 Mdot
.24512 .27733 Mdot
.24517 .11936 Mdot
.24522 .39126 Mdot
.24526 .04092 Mdot
.24531 .20108 Mdot
.24536 .52503 Mdot
.24541 .52137 Mdot
.24545 .19 Mdot
.2455 .13161 Mdot
.24555 .40952 Mdot
.2456 .43547 Mdot
.24564 .32563 Mdot
.24569 .12809 Mdot
.24574 .188 Mdot
.24579 .3569 Mdot
.24583 .12389 Mdot
.24588 .21639 Mdot
.24593 .04348 Mdot
.24598 .09744 Mdot
.24603 .27043 Mdot
.24607 .20935 Mdot
.24612 .02687 Mdot
.24617 .35433 Mdot
.24622 .03933 Mdot
.24626 .53534 Mdot
.24631 .51084 Mdot
.24636 .5664 Mdot
.24641 .60174 Mdot
.24645 .34896 Mdot
.2465 .58913 Mdot
.24655 .05974 Mdot
.2466 .42645 Mdot
.24664 .23206 Mdot
.24669 .19432 Mdot
.24674 .2276 Mdot
.24679 .11553 Mdot
.24683 .11868 Mdot
.24688 .02103 Mdot
.24693 .47402 Mdot
.24698 .59497 Mdot
.24703 .50562 Mdot
.24707 .58087 Mdot
.24712 .39129 Mdot
.24717 .33925 Mdot
.24722 .31098 Mdot
.24726 .56871 Mdot
.24731 .05167 Mdot
.24736 .31463 Mdot
.24741 .37897 Mdot
.24745 .07258 Mdot
.2475 .08859 Mdot
.24755 .31621 Mdot
.2476 .04472 Mdot
.24764 .08677 Mdot
.24769 .04355 Mdot
.24774 .49309 Mdot
.24779 .41598 Mdot
.24783 .49578 Mdot
.24788 .41928 Mdot
.24793 .39226 Mdot
.24798 .312 Mdot
.24803 .48946 Mdot
.24807 .54859 Mdot
.24812 .40062 Mdot
.24817 .40971 Mdot
.24822 .51191 Mdot
.24826 .172 Mdot
.24831 .07608 Mdot
.24836 .11343 Mdot
.24841 .54653 Mdot
.24845 .13505 Mdot
.2485 .36477 Mdot
.24855 .33779 Mdot
.2486 .48866 Mdot
.24864 .06117 Mdot
.24869 .06327 Mdot
.24874 .30778 Mdot
.24879 .4166 Mdot
.24883 .03232 Mdot
.24888 .1735 Mdot
.24893 .49513 Mdot
.24898 .52415 Mdot
.24903 .21637 Mdot
.24907 .38456 Mdot
.24912 .19783 Mdot
.24917 .0494 Mdot
.24922 .2711 Mdot
.24926 .58727 Mdot
.24931 .39145 Mdot
.24936 .14082 Mdot
.24941 .11381 Mdot
.24945 .5259 Mdot
.2495 .29273 Mdot
.24955 .19761 Mdot
.2496 .58209 Mdot
.24964 .17584 Mdot
.24969 .55827 Mdot
.24974 .31228 Mdot
.24979 .53563 Mdot
.24983 .12728 Mdot
.24988 .2652 Mdot
.24993 .499 Mdot
.24998 .51802 Mdot
.25002 .5571 Mdot
.25007 .3734 Mdot
.25012 .57818 Mdot
.25017 .31636 Mdot
.25022 .18725 Mdot
.25026 .19028 Mdot
.25031 .54349 Mdot
.25036 .05997 Mdot
.25041 .2033 Mdot
.25045 .40215 Mdot
.2505 .41738 Mdot
.25055 .54948 Mdot
.2506 .28072 Mdot
.25064 .12413 Mdot
.25069 .23447 Mdot
.25074 .57072 Mdot
.25079 .11959 Mdot
.25083 .16919 Mdot
.25088 .52552 Mdot
.25093 .0498 Mdot
.25098 .59564 Mdot
.25102 .50731 Mdot
.25107 .04123 Mdot
.25112 .1351 Mdot
.25117 .05324 Mdot
.25122 .14862 Mdot
.25126 .06638 Mdot
.25131 .42207 Mdot
.25136 .46932 Mdot
.25141 .56167 Mdot
.25145 .12622 Mdot
.2515 .37681 Mdot
.25155 .28073 Mdot
.2516 .17423 Mdot
.25164 .31216 Mdot
.25169 .43066 Mdot
.25174 .01472 Mdot
.25179 .06481 Mdot
.25183 .0924 Mdot
.25188 .46326 Mdot
.25193 .49845 Mdot
.25198 .49895 Mdot
.25202 .1702 Mdot
.25207 .42817 Mdot
.25212 .50614 Mdot
.25217 .59496 Mdot
.25222 .14368 Mdot
.25226 .30778 Mdot
.25231 .4676 Mdot
.25236 .46105 Mdot
.25241 .09202 Mdot
.25245 .48904 Mdot
.2525 .60161 Mdot
.25255 .5027 Mdot
.2526 .56913 Mdot
.25264 .12693 Mdot
.25269 .33559 Mdot
.25274 .34318 Mdot
.25279 .27167 Mdot
.25283 .2996 Mdot
.25288 .33558 Mdot
.25293 .29307 Mdot
.25298 .19398 Mdot
.25302 .43967 Mdot
.25307 .44046 Mdot
.25312 .39745 Mdot
.25317 .03848 Mdot
.25322 .0262 Mdot
.25326 .53764 Mdot
.25331 .40581 Mdot
.25336 .49812 Mdot
.25341 .32175 Mdot
.25345 .08475 Mdot
.2535 .54809 Mdot
.25355 .42082 Mdot
.2536 .43604 Mdot
.25364 .08647 Mdot
.25369 .0601 Mdot
.25374 .45502 Mdot
.25379 .32381 Mdot
.25383 .3542 Mdot
.25388 .32025 Mdot
.25393 .19805 Mdot
.25398 .03891 Mdot
.25402 .03333 Mdot
.25407 .04188 Mdot
.25412 .01878 Mdot
.25417 .20257 Mdot
.25422 .1962 Mdot
.25426 .24776 Mdot
.25431 .58363 Mdot
.25436 .19108 Mdot
.25441 .26188 Mdot
.25445 .44527 Mdot
.2545 .10021 Mdot
.25455 .47266 Mdot
.2546 .19184 Mdot
.25464 .50051 Mdot
.25469 .28272 Mdot
.25474 .05133 Mdot
.25479 .12008 Mdot
.25483 .45512 Mdot
.25488 .43103 Mdot
.25493 .33085 Mdot
.25498 .3692 Mdot
.25502 .14958 Mdot
.25507 .24769 Mdot
.25512 .30664 Mdot
.25517 .35058 Mdot
.25521 .1224 Mdot
.25526 .24361 Mdot
.25531 .11878 Mdot
.25536 .16909 Mdot
.25541 .47797 Mdot
.25545 .26331 Mdot
.2555 .53102 Mdot
.25555 .51054 Mdot
.2556 .04741 Mdot
.25564 .1778 Mdot
.25569 .07307 Mdot
.25574 .33341 Mdot
.25579 .15023 Mdot
.25583 .49841 Mdot
.25588 .03645 Mdot
.25593 .22804 Mdot
.25598 .29843 Mdot
.25602 .08209 Mdot
.25607 .30893 Mdot
.25612 .46216 Mdot
.25617 .16356 Mdot
.25621 .43773 Mdot
.25626 .01699 Mdot
.25631 .12629 Mdot
.25636 .05587 Mdot
.25641 .20883 Mdot
.25645 .50154 Mdot
.2565 .56052 Mdot
.25655 .18122 Mdot
.2566 .54884 Mdot
.25664 .57384 Mdot
.25669 .06468 Mdot
.25674 .14852 Mdot
.25679 .38575 Mdot
.25683 .51548 Mdot
.25688 .3346 Mdot
.25693 .60162 Mdot
.25698 .49066 Mdot
.25702 .49374 Mdot
.25707 .12126 Mdot
.25712 .3179 Mdot
.25717 .42329 Mdot
.25721 .19952 Mdot
.25726 .26243 Mdot
.25731 .16904 Mdot
.25736 .58889 Mdot
.25741 .19723 Mdot
.25745 .15085 Mdot
.2575 .12789 Mdot
.25755 .39477 Mdot
.2576 .29902 Mdot
.25764 .19366 Mdot
.25769 .54999 Mdot
.25774 .44925 Mdot
.25779 .32851 Mdot
.25783 .14368 Mdot
.25788 .41618 Mdot
.25793 .07821 Mdot
.25798 .41636 Mdot
.25802 .41241 Mdot
.25807 .41788 Mdot
.25812 .19087 Mdot
.25817 .52594 Mdot
.25821 .30586 Mdot
.25826 .11469 Mdot
.25831 .37091 Mdot
.25836 .34113 Mdot
.25841 .05814 Mdot
.25845 .54898 Mdot
.2585 .38535 Mdot
.25855 .15861 Mdot
.2586 .51062 Mdot
.25864 .4358 Mdot
.25869 .59391 Mdot
.25874 .46291 Mdot
.25879 .33167 Mdot
.25883 .48913 Mdot
.25888 .15937 Mdot
.25893 .14912 Mdot
.25898 .20269 Mdot
.25902 .08766 Mdot
.25907 .09586 Mdot
.25912 .33609 Mdot
.25917 .3936 Mdot
.25921 .2731 Mdot
.25926 .50832 Mdot
.25931 .41347 Mdot
.25936 .10245 Mdot
.25941 .17312 Mdot
.25945 .15211 Mdot
.2595 .08704 Mdot
.25955 .05902 Mdot
.2596 .22747 Mdot
.25964 .37009 Mdot
.25969 .53176 Mdot
.25974 .15173 Mdot
.25979 .39499 Mdot
.25983 .3795 Mdot
.25988 .08355 Mdot
.25993 .42339 Mdot
.25998 .50919 Mdot
.26002 .23485 Mdot
.26007 .53776 Mdot
.26012 .23541 Mdot
.26017 .43623 Mdot
.26021 .15369 Mdot
.26026 .21639 Mdot
.26031 .44513 Mdot
.26036 .17784 Mdot
.2604 .2487 Mdot
.26045 .40624 Mdot
.2605 .35739 Mdot
.26055 .01943 Mdot
.2606 .11129 Mdot
.26064 .33391 Mdot
.26069 .31308 Mdot
.26074 .39529 Mdot
.26079 .34453 Mdot
.26083 .40548 Mdot
.26088 .17606 Mdot
.26093 .01501 Mdot
.26098 .56835 Mdot
.26102 .33664 Mdot
.26107 .356 Mdot
.26112 .10915 Mdot
.26117 .34821 Mdot
.26121 .4022 Mdot
.26126 .1353 Mdot
.26131 .27624 Mdot
.26136 .20923 Mdot
.2614 .20052 Mdot
.26145 .2935 Mdot
.2615 .11311 Mdot
.26155 .56386 Mdot
.2616 .3976 Mdot
.26164 .53943 Mdot
.26169 .10838 Mdot
.26174 .46727 Mdot
.26179 .0784 Mdot
.26183 .24106 Mdot
.26188 .31642 Mdot
.26193 .13745 Mdot
.26198 .27624 Mdot
.26202 .07971 Mdot
.26207 .31612 Mdot
.26212 .17243 Mdot
.26217 .54293 Mdot
.26221 .32704 Mdot
.26226 .22168 Mdot
.26231 .42754 Mdot
.26236 .15544 Mdot
.2624 .20644 Mdot
.26245 .54876 Mdot
.2625 .23301 Mdot
.26255 .55824 Mdot
.2626 .51627 Mdot
.26264 .45037 Mdot
.26269 .27248 Mdot
.26274 .17535 Mdot
.26279 .58016 Mdot
.26283 .35669 Mdot
.26288 .40853 Mdot
.26293 .11165 Mdot
.26298 .35381 Mdot
.26302 .05498 Mdot
.26307 .28579 Mdot
.26312 .43874 Mdot
.26317 .28881 Mdot
.26321 .34219 Mdot
.26326 .12807 Mdot
.26331 .49913 Mdot
.26336 .5651 Mdot
.2634 .13523 Mdot
.26345 .30386 Mdot
.2635 .3584 Mdot
.26355 .37337 Mdot
.2636 .18979 Mdot
.26364 .08556 Mdot
.26369 .40348 Mdot
.26374 .46042 Mdot
.26379 .34275 Mdot
.26383 .4164 Mdot
.26388 .24284 Mdot
.26393 .48358 Mdot
.26398 .58938 Mdot
.26402 .02258 Mdot
.26407 .1459 Mdot
.26412 .14448 Mdot
.26417 .5491 Mdot
.26421 .34012 Mdot
.26426 .31049 Mdot
.26431 .459 Mdot
.26436 .22162 Mdot
.2644 .22675 Mdot
.26445 .41468 Mdot
.2645 .49722 Mdot
.26455 .1011 Mdot
.26459 .52622 Mdot
.26464 .071 Mdot
.26469 .13857 Mdot
.26474 .51464 Mdot
.26479 .45537 Mdot
.26483 .27084 Mdot
.26488 .28147 Mdot
.26493 .1866 Mdot
.26498 .05368 Mdot
.26502 .04271 Mdot
.26507 .40122 Mdot
.26512 .20055 Mdot
.26517 .04581 Mdot
.26521 .50014 Mdot
.26526 .27144 Mdot
.26531 .25477 Mdot
.26536 .30902 Mdot
.2654 .20436 Mdot
.26545 .41577 Mdot
.2655 .04786 Mdot
.26555 .09697 Mdot
.26559 .39301 Mdot
.26564 .52187 Mdot
.26569 .55008 Mdot
.26574 .17408 Mdot
.26579 .33672 Mdot
.26583 .39802 Mdot
.26588 .05015 Mdot
.26593 .32204 Mdot
.26598 .08058 Mdot
.26602 .13125 Mdot
.26607 .46687 Mdot
.26612 .28307 Mdot
.26617 .05258 Mdot
.26621 .33336 Mdot
.26626 .28104 Mdot
.26631 .25197 Mdot
.26636 .15577 Mdot
.2664 .07663 Mdot
.26645 .04098 Mdot
.2665 .54628 Mdot
.26655 .55473 Mdot
.26659 .26418 Mdot
.26664 .59644 Mdot
.26669 .46402 Mdot
.26674 .17643 Mdot
.26679 .34563 Mdot
.26683 .06107 Mdot
.26688 .30465 Mdot
.26693 .44304 Mdot
.26698 .55094 Mdot
.26702 .02563 Mdot
.26707 .58593 Mdot
.26712 .37716 Mdot
.26717 .4344 Mdot
.26721 .16208 Mdot
.26726 .31757 Mdot
.26731 .33929 Mdot
.26736 .11574 Mdot
.2674 .48437 Mdot
.26745 .08031 Mdot
.2675 .19823 Mdot
.26755 .05382 Mdot
.26759 .4581 Mdot
.26764 .13735 Mdot
.26769 .24682 Mdot
.26774 .39297 Mdot
.26779 .46498 Mdot
.26783 .27666 Mdot
.26788 .0851 Mdot
.26793 .06205 Mdot
.26798 .41862 Mdot
.26802 .57533 Mdot
.26807 .24539 Mdot
.26812 .11443 Mdot
.26817 .4077 Mdot
.26821 .59273 Mdot
.26826 .47155 Mdot
.26831 .28336 Mdot
.26836 .26033 Mdot
.2684 .28986 Mdot
.26845 .14697 Mdot
.2685 .18232 Mdot
.26855 .37928 Mdot
.26859 .22426 Mdot
.26864 .55207 Mdot
.26869 .14321 Mdot
.26874 .5245 Mdot
.26879 .10162 Mdot
.26883 .31995 Mdot
.26888 .35356 Mdot
.26893 .07423 Mdot
.26898 .42829 Mdot
.26902 .24956 Mdot
.26907 .30623 Mdot
.26912 .25893 Mdot
.26917 .45628 Mdot
.26921 .01888 Mdot
.26926 .2065 Mdot
.26931 .45456 Mdot
.26936 .46688 Mdot
.2694 .15065 Mdot
.26945 .52647 Mdot
.2695 .20894 Mdot
.26955 .19173 Mdot
.26959 .01839 Mdot
.26964 .35886 Mdot
.26969 .43298 Mdot
.26974 .57079 Mdot
.26978 .06964 Mdot
.26983 .23036 Mdot
.26988 .51181 Mdot
.26993 .48387 Mdot
.26998 .35302 Mdot
.27002 .48012 Mdot
.27007 .45229 Mdot
.27012 .07029 Mdot
.27017 .11816 Mdot
.27021 .1886 Mdot
.27026 .20806 Mdot
.27031 .21733 Mdot
.27036 .11399 Mdot
.2704 .58542 Mdot
.27045 .35683 Mdot
.2705 .35377 Mdot
.27055 .56666 Mdot
.27059 .07366 Mdot
.27064 .1626 Mdot
.27069 .17675 Mdot
.27074 .56298 Mdot
.27078 .31813 Mdot
.27083 .33294 Mdot
.27088 .20929 Mdot
.27093 .50804 Mdot
.27098 .10248 Mdot
.27102 .42446 Mdot
.27107 .32874 Mdot
.27112 .16974 Mdot
.27117 .22569 Mdot
.27121 .5755 Mdot
.27126 .27316 Mdot
.27131 .06628 Mdot
.27136 .05179 Mdot
.2714 .38215 Mdot
.27145 .07054 Mdot
.2715 .55562 Mdot
.27155 .06969 Mdot
.27159 .04003 Mdot
.27164 .32009 Mdot
.27169 .59228 Mdot
.27174 .59936 Mdot
.27178 .48075 Mdot
.27183 .15805 Mdot
.27188 .04401 Mdot
.27193 .29594 Mdot
.27198 .16252 Mdot
.27202 .55209 Mdot
.27207 .13929 Mdot
.27212 .20817 Mdot
.27217 .34139 Mdot
.27221 .23806 Mdot
.27226 .57288 Mdot
.27231 .58581 Mdot
.27236 .36921 Mdot
.2724 .56823 Mdot
.27245 .52131 Mdot
.2725 .54872 Mdot
.27255 .59039 Mdot
.27259 .5124 Mdot
.27264 .56902 Mdot
.27269 .49374 Mdot
.27274 .56508 Mdot
.27278 .20702 Mdot
.27283 .58006 Mdot
.27288 .4977 Mdot
.27293 .09903 Mdot
.27298 .06368 Mdot
.27302 .55076 Mdot
.27307 .21647 Mdot
.27312 .53984 Mdot
.27317 .11491 Mdot
.27321 .42618 Mdot
.27326 .02301 Mdot
.27331 .21316 Mdot
.27336 .48018 Mdot
.2734 .45662 Mdot
.27345 .04053 Mdot
.2735 .44727 Mdot
.27355 .51527 Mdot
.27359 .53863 Mdot
.27364 .09513 Mdot
.27369 .4602 Mdot
.27374 .01758 Mdot
.27378 .57293 Mdot
.27383 .20472 Mdot
.27388 .49845 Mdot
.27393 .41389 Mdot
.27397 .5962 Mdot
.27402 .31034 Mdot
.27407 .41412 Mdot
.27412 .36492 Mdot
.27417 .06014 Mdot
.27421 .10858 Mdot
.27426 .47761 Mdot
.27431 .26472 Mdot
.27436 .23729 Mdot
.2744 .10027 Mdot
.27445 .27916 Mdot
.2745 .38787 Mdot
.27455 .384 Mdot
.27459 .07445 Mdot
.27464 .43522 Mdot
.27469 .47592 Mdot
.27474 .4487 Mdot
.27478 .58264 Mdot
.27483 .57835 Mdot
.27488 .47305 Mdot
.27493 .47909 Mdot
.27497 .39263 Mdot
.27502 .09461 Mdot
.27507 .07387 Mdot
.27512 .48622 Mdot
.27517 .09699 Mdot
.27521 .28381 Mdot
.27526 .31227 Mdot
.27531 .44078 Mdot
.27536 .59174 Mdot
.2754 .40953 Mdot
.27545 .06227 Mdot
.2755 .2182 Mdot
.27555 .50618 Mdot
.27559 .14507 Mdot
.27564 .27772 Mdot
.27569 .43753 Mdot
.27574 .44645 Mdot
.27578 .31318 Mdot
.27583 .40513 Mdot
.27588 .59216 Mdot
.27593 .46714 Mdot
.27597 .33816 Mdot
.27602 .53541 Mdot
.27607 .12778 Mdot
.27612 .08922 Mdot
.27617 .25826 Mdot
.27621 .47625 Mdot
.27626 .24489 Mdot
.27631 .59555 Mdot
.27636 .57777 Mdot
.2764 .17868 Mdot
.27645 .40743 Mdot
.2765 .01851 Mdot
.27655 .18295 Mdot
.27659 .13113 Mdot
.27664 .20394 Mdot
.27669 .11566 Mdot
.27674 .05258 Mdot
.27678 .45673 Mdot
.27683 .36974 Mdot
.27688 .27253 Mdot
.27693 .34273 Mdot
.27697 .06631 Mdot
.27702 .3809 Mdot
.27707 .40873 Mdot
.27712 .01928 Mdot
.27717 .13422 Mdot
.27721 .26784 Mdot
.27726 .33422 Mdot
.27731 .36435 Mdot
.27736 .2613 Mdot
.2774 .03766 Mdot
.27745 .34199 Mdot
.2775 .3899 Mdot
.27755 .09732 Mdot
.27759 .23355 Mdot
.27764 .33819 Mdot
.27769 .22166 Mdot
.27774 .56952 Mdot
.27778 .04433 Mdot
.27783 .23724 Mdot
.27788 .18378 Mdot
.27793 .1275 Mdot
.27797 .27792 Mdot
.27802 .56803 Mdot
.27807 .44438 Mdot
.27812 .0759 Mdot
.27817 .50034 Mdot
.27821 .17401 Mdot
.27826 .43981 Mdot
.27831 .545 Mdot
.27836 .24721 Mdot
.2784 .44312 Mdot
.27845 .09017 Mdot
.2785 .29841 Mdot
.27855 .22426 Mdot
.27859 .11584 Mdot
.27864 .30359 Mdot
.27869 .2158 Mdot
.27874 .59403 Mdot
.27878 .38098 Mdot
.27883 .09664 Mdot
.27888 .24961 Mdot
.27893 .56441 Mdot
.27897 .15845 Mdot
.27902 .51618 Mdot
.27907 .13682 Mdot
.27912 .30121 Mdot
.27916 .19375 Mdot
.27921 .08651 Mdot
.27926 .07562 Mdot
.27931 .40419 Mdot
.27936 .03444 Mdot
.2794 .25003 Mdot
.27945 .13395 Mdot
.2795 .17169 Mdot
.27955 .19465 Mdot
.27959 .17457 Mdot
.27964 .43886 Mdot
.27969 .55075 Mdot
.27974 .09352 Mdot
.27978 .4743 Mdot
.27983 .23777 Mdot
.27988 .56005 Mdot
.27993 .31587 Mdot
.27997 .39236 Mdot
.28002 .59149 Mdot
.28007 .59896 Mdot
.28012 .17213 Mdot
.28016 .4795 Mdot
.28021 .46938 Mdot
.28026 .31246 Mdot
.28031 .5817 Mdot
.28036 .4077 Mdot
.2804 .40846 Mdot
.28045 .51159 Mdot
.2805 .56197 Mdot
.28055 .17238 Mdot
.28059 .28923 Mdot
.28064 .35461 Mdot
.28069 .38203 Mdot
.28074 .60114 Mdot
.28078 .45369 Mdot
.28083 .40718 Mdot
.28088 .30322 Mdot
.28093 .14155 Mdot
.28097 .23064 Mdot
.28102 .45046 Mdot
.28107 .59068 Mdot
.28112 .35251 Mdot
.28116 .24248 Mdot
.28121 .45483 Mdot
.28126 .43326 Mdot
.28131 .47634 Mdot
.28136 .37642 Mdot
.2814 .15708 Mdot
.28145 .45488 Mdot
.2815 .08335 Mdot
.28155 .57129 Mdot
.28159 .24881 Mdot
.28164 .49624 Mdot
.28169 .51429 Mdot
.28174 .29677 Mdot
.28178 .49753 Mdot
.28183 .12892 Mdot
.28188 .51648 Mdot
.28193 .4464 Mdot
.28197 .10506 Mdot
.28202 .42902 Mdot
.28207 .38964 Mdot
.28212 .23047 Mdot
.28216 .25793 Mdot
.28221 .44167 Mdot
.28226 .05184 Mdot
.28231 .59132 Mdot
.28236 .40642 Mdot
.2824 .02311 Mdot
.28245 .17883 Mdot
.2825 .22961 Mdot
.28255 .26405 Mdot
.28259 .17155 Mdot
.28264 .11019 Mdot
.28269 .26165 Mdot
.28274 .02995 Mdot
.28278 .27864 Mdot
.28283 .19922 Mdot
.28288 .5682 Mdot
.28293 .13575 Mdot
.28297 .16443 Mdot
.28302 .28606 Mdot
.28307 .13651 Mdot
.28312 .0454 Mdot
.28316 .33873 Mdot
.28321 .49975 Mdot
.28326 .50937 Mdot
.28331 .3908 Mdot
.28335 .50039 Mdot
.2834 .46262 Mdot
.28345 .52137 Mdot
.2835 .5877 Mdot
.28355 .49199 Mdot
.28359 .2985 Mdot
.28364 .30647 Mdot
.28369 .33835 Mdot
.28374 .33514 Mdot
.28378 .20302 Mdot
.28383 .05953 Mdot
.28388 .32311 Mdot
.28393 .07121 Mdot
.28397 .01851 Mdot
.28402 .09465 Mdot
.28407 .20207 Mdot
.28412 .51011 Mdot
.28416 .33577 Mdot
.28421 .56146 Mdot
.28426 .17138 Mdot
.28431 .18609 Mdot
.28435 .43935 Mdot
.2844 .06681 Mdot
.28445 .38391 Mdot
.2845 .28903 Mdot
.28455 .58006 Mdot
.28459 .14876 Mdot
.28464 .39954 Mdot
.28469 .40037 Mdot
.28474 .29627 Mdot
.28478 .44562 Mdot
.28483 .0759 Mdot
.28488 .07993 Mdot
.28493 .10796 Mdot
.28497 .40079 Mdot
.28502 .35612 Mdot
.28507 .02343 Mdot
.28512 .10416 Mdot
.28516 .32085 Mdot
.28521 .16876 Mdot
.28526 .11664 Mdot
.28531 .37171 Mdot
.28535 .36271 Mdot
.2854 .6007 Mdot
.28545 .53387 Mdot
.2855 .53569 Mdot
.28555 .31061 Mdot
.28559 .23149 Mdot
.28564 .25956 Mdot
.28569 .55896 Mdot
.28574 .17656 Mdot
.28578 .43528 Mdot
.28583 .46252 Mdot
.28588 .2774 Mdot
.28593 .33427 Mdot
.28597 .37408 Mdot
.28602 .39729 Mdot
.28607 .18415 Mdot
.28612 .5368 Mdot
.28616 .03268 Mdot
.28621 .38858 Mdot
.28626 .0947 Mdot
.28631 .23066 Mdot
.28635 .46724 Mdot
.2864 .28665 Mdot
.28645 .32631 Mdot
.2865 .47128 Mdot
.28655 .46987 Mdot
.28659 .3561 Mdot
.28664 .39395 Mdot
.28669 .17537 Mdot
.28674 .25309 Mdot
.28678 .11125 Mdot
.28683 .43831 Mdot
.28688 .60214 Mdot
.28693 .42114 Mdot
.28697 .25206 Mdot
.28702 .17562 Mdot
.28707 .28258 Mdot
.28712 .06176 Mdot
.28716 .45809 Mdot
.28721 .5948 Mdot
.28726 .3491 Mdot
.28731 .04379 Mdot
.28735 .08423 Mdot
.2874 .51481 Mdot
.28745 .13314 Mdot
.2875 .17987 Mdot
.28755 .4009 Mdot
.28759 .20321 Mdot
.28764 .26519 Mdot
.28769 .31333 Mdot
.28774 .05951 Mdot
.28778 .41259 Mdot
.28783 .10453 Mdot
.28788 .07495 Mdot
.28793 .55159 Mdot
.28797 .5776 Mdot
.28802 .10572 Mdot
.28807 .25714 Mdot
.28812 .31423 Mdot
.28816 .41668 Mdot
.28821 .42647 Mdot
.28826 .21009 Mdot
.28831 .45946 Mdot
.28835 .42521 Mdot
.2884 .09208 Mdot
.28845 .181 Mdot
.2885 .38995 Mdot
.28854 .51372 Mdot
.28859 .56226 Mdot
.28864 .01584 Mdot
.28869 .59237 Mdot
.28874 .32522 Mdot
.28878 .31177 Mdot
.28883 .30584 Mdot
.28888 .54756 Mdot
.28893 .51596 Mdot
.28897 .22195 Mdot
.28902 .2456 Mdot
.28907 .5993 Mdot
.28912 .54168 Mdot
.28916 .13094 Mdot
.28921 .59178 Mdot
.28926 .29978 Mdot
.28931 .13971 Mdot
.28935 .3078 Mdot
.2894 .39641 Mdot
.28945 .44364 Mdot
.2895 .31783 Mdot
.28954 .23043 Mdot
.28959 .23012 Mdot
.28964 .0684 Mdot
.28969 .40743 Mdot
.28974 .27149 Mdot
.28978 .22899 Mdot
.28983 .07936 Mdot
.28988 .09692 Mdot
.28993 .56304 Mdot
.28997 .52648 Mdot
.29002 .13512 Mdot
.29007 .18429 Mdot
.29012 .3558 Mdot
.29016 .29559 Mdot
.29021 .13914 Mdot
.29026 .24593 Mdot
.29031 .23957 Mdot
.29035 .30713 Mdot
.2904 .44269 Mdot
.29045 .12093 Mdot
.2905 .53509 Mdot
.29054 .51405 Mdot
.29059 .60238 Mdot
.29064 .40642 Mdot
.29069 .31937 Mdot
.29074 .29864 Mdot
.29078 .54869 Mdot
.29083 .60232 Mdot
.29088 .06259 Mdot
.29093 .08436 Mdot
.29097 .48404 Mdot
.29102 .5201 Mdot
.29107 .10287 Mdot
.29112 .16121 Mdot
.29116 .36363 Mdot
.29121 .35053 Mdot
.29126 .35039 Mdot
.29131 .46895 Mdot
.29135 .23919 Mdot
.2914 .11931 Mdot
.29145 .12554 Mdot
.2915 .17652 Mdot
.29154 .39983 Mdot
.29159 .60171 Mdot
.29164 .19377 Mdot
.29169 .2658 Mdot
.29174 .40077 Mdot
.29178 .20999 Mdot
.29183 .47773 Mdot
.29188 .57049 Mdot
.29193 .45541 Mdot
.29197 .211 Mdot
.29202 .42985 Mdot
.29207 .50083 Mdot
.29212 .5747 Mdot
.29216 .29422 Mdot
.29221 .34169 Mdot
.29226 .35433 Mdot
.29231 .22578 Mdot
.29235 .54702 Mdot
.2924 .59462 Mdot
.29245 .48871 Mdot
.2925 .58991 Mdot
.29254 .44243 Mdot
.29259 .48379 Mdot
.29264 .3269 Mdot
.29269 .20479 Mdot
.29274 .44405 Mdot
.29278 .30472 Mdot
.29283 .0758 Mdot
.29288 .40735 Mdot
.29293 .24876 Mdot
.29297 .43032 Mdot
.29302 .10864 Mdot
.29307 .55526 Mdot
.29312 .05247 Mdot
.29316 .01519 Mdot
.29321 .21113 Mdot
.29326 .58389 Mdot
.29331 .36157 Mdot
.29335 .27682 Mdot
.2934 .46012 Mdot
.29345 .37281 Mdot
.2935 .41788 Mdot
.29354 .28553 Mdot
.29359 .57474 Mdot
.29364 .38623 Mdot
.29369 .57878 Mdot
.29373 .40507 Mdot
.29378 .26255 Mdot
.29383 .19614 Mdot
.29388 .14944 Mdot
.29393 .11505 Mdot
.29397 .20145 Mdot
.29402 .39212 Mdot
.29407 .504 Mdot
.29412 .28805 Mdot
.29416 .10752 Mdot
.29421 .44019 Mdot
.29426 .46624 Mdot
.29431 .28758 Mdot
.29435 .49972 Mdot
.2944 .45963 Mdot
.29445 .11938 Mdot
.2945 .02546 Mdot
.29454 .0543 Mdot
.29459 .10152 Mdot
.29464 .30482 Mdot
.29469 .34326 Mdot
.29473 .08289 Mdot
.29478 .31862 Mdot
.29483 .32937 Mdot
.29488 .54151 Mdot
.29493 .42367 Mdot
.29497 .13719 Mdot
.29502 .19464 Mdot
.29507 .44117 Mdot
.29512 .23692 Mdot
.29516 .34839 Mdot
.29521 .29396 Mdot
.29526 .16782 Mdot
.29531 .14411 Mdot
.29535 .51152 Mdot
.2954 .43105 Mdot
.29545 .48357 Mdot
.2955 .24771 Mdot
.29554 .0666 Mdot
.29559 .32638 Mdot
.29564 .47282 Mdot
.29569 .20812 Mdot
.29573 .5684 Mdot
.29578 .03627 Mdot
.29583 .14427 Mdot
.29588 .13994 Mdot
.29593 .26449 Mdot
.29597 .31022 Mdot
.29602 .20608 Mdot
.29607 .3196 Mdot
.29612 .14201 Mdot
.29616 .13029 Mdot
.29621 .36824 Mdot
.29626 .09739 Mdot
.29631 .39695 Mdot
.29635 .43965 Mdot
.2964 .21512 Mdot
.29645 .55661 Mdot
.2965 .48875 Mdot
.29654 .02331 Mdot
.29659 .33488 Mdot
.29664 .3236 Mdot
.29669 .43685 Mdot
.29673 .30025 Mdot
.29678 .46538 Mdot
.29683 .13019 Mdot
.29688 .47177 Mdot
.29693 .27869 Mdot
.29697 .33582 Mdot
.29702 .59357 Mdot
.29707 .22199 Mdot
.29712 .57179 Mdot
.29716 .14444 Mdot
.29721 .28868 Mdot
.29726 .09469 Mdot
.29731 .45622 Mdot
.29735 .37953 Mdot
.2974 .206 Mdot
.29745 .30107 Mdot
.2975 .03128 Mdot
.29754 .17911 Mdot
.29759 .25272 Mdot
.29764 .41564 Mdot
.29769 .02268 Mdot
.29773 .44756 Mdot
.29778 .53244 Mdot
.29783 .58211 Mdot
.29788 .32576 Mdot
.29792 .5855 Mdot
.29797 .41696 Mdot
.29802 .12505 Mdot
.29807 .06177 Mdot
.29812 .26439 Mdot
.29816 .42671 Mdot
.29821 .50638 Mdot
.29826 .09331 Mdot
.29831 .13466 Mdot
.29835 .15274 Mdot
.2984 .4264 Mdot
.29845 .24042 Mdot
.2985 .35846 Mdot
.29854 .55006 Mdot
.29859 .14004 Mdot
.29864 .22385 Mdot
.29869 .19406 Mdot
.29873 .31205 Mdot
.29878 .32773 Mdot
.29883 .21588 Mdot
.29888 .34982 Mdot
.29892 .38294 Mdot
.29897 .34894 Mdot
.29902 .49345 Mdot
.29907 .36765 Mdot
.29912 .56931 Mdot
.29916 .2386 Mdot
.29921 .44638 Mdot
.29926 .11796 Mdot
.29931 .15731 Mdot
.29935 .33554 Mdot
.2994 .36778 Mdot
.29945 .58663 Mdot
.2995 .01928 Mdot
.29954 .51247 Mdot
.29959 .14208 Mdot
.29964 .24288 Mdot
.29969 .07255 Mdot
.29973 .38713 Mdot
.29978 .52155 Mdot
.29983 .06353 Mdot
.29988 .36382 Mdot
.29992 .07411 Mdot
.29997 .32039 Mdot
.30002 .31703 Mdot
.30007 .58421 Mdot
.30012 .3285 Mdot
.30016 .43027 Mdot
.30021 .55271 Mdot
.30026 .0296 Mdot
.30031 .10461 Mdot
.30035 .58721 Mdot
.3004 .44946 Mdot
.30045 .47562 Mdot
.3005 .37239 Mdot
.30054 .23414 Mdot
.30059 .46615 Mdot
.30064 .47104 Mdot
.30069 .46325 Mdot
.30073 .10677 Mdot
.30078 .23798 Mdot
.30083 .4132 Mdot
.30088 .09083 Mdot
.30092 .18854 Mdot
.30097 .18916 Mdot
.30102 .06409 Mdot
.30107 .03142 Mdot
.30112 .47148 Mdot
.30116 .47545 Mdot
.30121 .08321 Mdot
.30126 .30625 Mdot
.30131 .05592 Mdot
.30135 .52606 Mdot
.3014 .06831 Mdot
.30145 .21635 Mdot
.3015 .07204 Mdot
.30154 .09131 Mdot
.30159 .19602 Mdot
.30164 .44728 Mdot
.30169 .44122 Mdot
.30173 .22848 Mdot
.30178 .3283 Mdot
.30183 .58736 Mdot
.30188 .34916 Mdot
.30192 .59383 Mdot
.30197 .51843 Mdot
.30202 .51124 Mdot
.30207 .17533 Mdot
.30212 .41938 Mdot
.30216 .46904 Mdot
.30221 .49452 Mdot
.30226 .30718 Mdot
.30231 .54725 Mdot
.30235 .40054 Mdot
.3024 .20298 Mdot
.30245 .26596 Mdot
.3025 .0359 Mdot
.30254 .34694 Mdot
.30259 .58996 Mdot
.30264 .20864 Mdot
.30269 .54791 Mdot
.30273 .16563 Mdot
.30278 .15739 Mdot
.30283 .37074 Mdot
.30288 .33413 Mdot
.30292 .44065 Mdot
.30297 .17335 Mdot
.30302 .03628 Mdot
.30307 .34363 Mdot
.30311 .52555 Mdot
.30316 .26544 Mdot
.30321 .46428 Mdot
.30326 .52758 Mdot
.30331 .07121 Mdot
.30335 .37425 Mdot
.3034 .17181 Mdot
.30345 .58366 Mdot
.3035 .27399 Mdot
.30354 .18597 Mdot
.30359 .50917 Mdot
.30364 .56247 Mdot
.30369 .53038 Mdot
.30373 .19934 Mdot
.30378 .31524 Mdot
.30383 .02927 Mdot
.30388 .37947 Mdot
.30392 .05666 Mdot
.30397 .54783 Mdot
.30402 .29846 Mdot
.30407 .54214 Mdot
.30411 .48663 Mdot
.30416 .52625 Mdot
.30421 .55815 Mdot
.30426 .0313 Mdot
.30431 .2359 Mdot
.30435 .07668 Mdot
.3044 .04528 Mdot
.30445 .56342 Mdot
.3045 .46498 Mdot
.30454 .5082 Mdot
.30459 .06494 Mdot
.30464 .30413 Mdot
.30469 .29371 Mdot
.30473 .60235 Mdot
.30478 .1058 Mdot
.30483 .37707 Mdot
.30488 .10908 Mdot
.30492 .30182 Mdot
.30497 .09124 Mdot
.30502 .60093 Mdot
.30507 .06713 Mdot
.30511 .35732 Mdot
.30516 .3961 Mdot
.30521 .0735 Mdot
.30526 .18382 Mdot
.30531 .4344 Mdot
.30535 .44127 Mdot
.3054 .05691 Mdot
.30545 .55124 Mdot
.3055 .37242 Mdot
.30554 .4107 Mdot
.30559 .09681 Mdot
.30564 .10098 Mdot
.30569 .46755 Mdot
.30573 .36047 Mdot
.30578 .39601 Mdot
.30583 .41059 Mdot
.30588 .46852 Mdot
.30592 .26938 Mdot
.30597 .03364 Mdot
.30602 .31622 Mdot
.30607 .18141 Mdot
.30611 .19285 Mdot
.30616 .03603 Mdot
.30621 .2638 Mdot
.30626 .42741 Mdot
.30631 .40007 Mdot
.30635 .56586 Mdot
.3064 .09469 Mdot
.30645 .59634 Mdot
.3065 .56213 Mdot
.30654 .52366 Mdot
.30659 .14677 Mdot
.30664 .23863 Mdot
.30669 .16613 Mdot
.30673 .44156 Mdot
.30678 .06051 Mdot
.30683 .3744 Mdot
.30688 .40899 Mdot
.30692 .06026 Mdot
.30697 .25324 Mdot
.30702 .50921 Mdot
.30707 .15432 Mdot
.30711 .04132 Mdot
.30716 .54035 Mdot
.30721 .34251 Mdot
.30726 .5648 Mdot
.3073 .02 Mdot
.30735 .29126 Mdot
.3074 .51842 Mdot
.30745 .17944 Mdot
.3075 .05746 Mdot
.30754 .21128 Mdot
.30759 .5254 Mdot
.30764 .22064 Mdot
.30769 .13713 Mdot
.30773 .07921 Mdot
.30778 .30148 Mdot
.30783 .06921 Mdot
.30788 .2989 Mdot
.30792 .03342 Mdot
.30797 .5304 Mdot
.30802 .26355 Mdot
.30807 .25335 Mdot
.30811 .3835 Mdot
.30816 .0359 Mdot
.30821 .12393 Mdot
.30826 .22674 Mdot
.3083 .44647 Mdot
.30835 .29672 Mdot
.3084 .16246 Mdot
.30845 .22145 Mdot
.3085 .16992 Mdot
.30854 .38163 Mdot
.30859 .58635 Mdot
.30864 .17869 Mdot
.30869 .56197 Mdot
.30873 .45956 Mdot
.30878 .38042 Mdot
.30883 .05627 Mdot
.30888 .49746 Mdot
.30892 .17279 Mdot
.30897 .32592 Mdot
.30902 .3607 Mdot
.30907 .47876 Mdot
.30911 .24572 Mdot
.30916 .07708 Mdot
.30921 .12206 Mdot
.30926 .10997 Mdot
.3093 .22452 Mdot
.30935 .55647 Mdot
.3094 .49864 Mdot
.30945 .26682 Mdot
.3095 .53113 Mdot
.30954 .40872 Mdot
.30959 .2919 Mdot
.30964 .11161 Mdot
.30969 .16421 Mdot
.30973 .42569 Mdot
.30978 .12792 Mdot
.30983 .15297 Mdot
.30988 .30797 Mdot
.30992 .05998 Mdot
.30997 .08635 Mdot
.31002 .25883 Mdot
.31007 .14989 Mdot
.31011 .33739 Mdot
.31016 .32898 Mdot
.31021 .3834 Mdot
.31026 .5075 Mdot
.3103 .27502 Mdot
.31035 .22163 Mdot
.3104 .28814 Mdot
.31045 .29769 Mdot
.3105 .32187 Mdot
.31054 .32632 Mdot
.31059 .03603 Mdot
.31064 .36988 Mdot
.31069 .51648 Mdot
.31073 .04912 Mdot
.31078 .52775 Mdot
.31083 .22039 Mdot
.31088 .1055 Mdot
.31092 .52453 Mdot
.31097 .38949 Mdot
.31102 .51574 Mdot
.31107 .06023 Mdot
.31111 .45289 Mdot
.31116 .14537 Mdot
.31121 .38056 Mdot
.31126 .32617 Mdot
.3113 .13862 Mdot
.31135 .36529 Mdot
.3114 .47638 Mdot
.31145 .06586 Mdot
.3115 .52031 Mdot
.31154 .09186 Mdot
.31159 .1934 Mdot
.31164 .34731 Mdot
.31169 .2087 Mdot
.31173 .07053 Mdot
.31178 .42685 Mdot
.31183 .43415 Mdot
.31188 .17429 Mdot
.31192 .14611 Mdot
.31197 .22117 Mdot
.31202 .34336 Mdot
.31207 .25308 Mdot
.31211 .35995 Mdot
.31216 .30876 Mdot
.31221 .29784 Mdot
.31226 .40351 Mdot
.3123 .22929 Mdot
.31235 .53152 Mdot
.3124 .57499 Mdot
.31245 .27961 Mdot
.31249 .46732 Mdot
.31254 .06985 Mdot
.31259 .52384 Mdot
.31264 .36262 Mdot
.31269 .39017 Mdot
.31273 .47977 Mdot
.31278 .19123 Mdot
.31283 .16863 Mdot
.31288 .33435 Mdot
.31292 .06763 Mdot
.31297 .3604 Mdot
.31302 .59767 Mdot
.31307 .20295 Mdot
.31311 .44979 Mdot
.31316 .03175 Mdot
.31321 .3593 Mdot
.31326 .44633 Mdot
.3133 .15574 Mdot
.31335 .33724 Mdot
.3134 .55911 Mdot
.31345 .23175 Mdot
.31349 .22754 Mdot
.31354 .36557 Mdot
.31359 .29421 Mdot
.31364 .36775 Mdot
.31369 .1724 Mdot
.31373 .44506 Mdot
.31378 .53491 Mdot
.31383 .58091 Mdot
.31388 .29595 Mdot
.31392 .26853 Mdot
.31397 .38099 Mdot
.31402 .26126 Mdot
.31407 .24303 Mdot
.31411 .51146 Mdot
.31416 .38665 Mdot
.31421 .07302 Mdot
.31426 .39656 Mdot
.3143 .49441 Mdot
.31435 .04206 Mdot
.3144 .23002 Mdot
.31445 .25553 Mdot
.31449 .17188 Mdot
.31454 .08628 Mdot
.31459 .6016 Mdot
.31464 .04269 Mdot
.31469 .40964 Mdot
.31473 .39539 Mdot
.31478 .24855 Mdot
.31483 .47362 Mdot
.31488 .56791 Mdot
.31492 .46381 Mdot
.31497 .27097 Mdot
.31502 .19237 Mdot
.31507 .31408 Mdot
.31511 .09752 Mdot
.31516 .02442 Mdot
.31521 .55267 Mdot
.31526 .40595 Mdot
.3153 .31419 Mdot
.31535 .55472 Mdot
.3154 .17081 Mdot
.31545 .51486 Mdot
.31549 .28684 Mdot
.31554 .3394 Mdot
.31559 .51861 Mdot
.31564 .35769 Mdot
.31569 .21527 Mdot
.31573 .34113 Mdot
.31578 .49062 Mdot
.31583 .55137 Mdot
.31588 .4232 Mdot
.31592 .10729 Mdot
.31597 .03171 Mdot
.31602 .58679 Mdot
.31607 .56272 Mdot
.31611 .43964 Mdot
.31616 .44266 Mdot
.31621 .28742 Mdot
.31626 .47991 Mdot
.3163 .42993 Mdot
.31635 .49332 Mdot
.3164 .48479 Mdot
.31645 .18042 Mdot
.31649 .47854 Mdot
.31654 .33722 Mdot
.31659 .57325 Mdot
.31664 .49691 Mdot
.31668 .15385 Mdot
.31673 .42193 Mdot
.31678 .23027 Mdot
.31683 .29635 Mdot
.31688 .41604 Mdot
.31692 .53464 Mdot
.31697 .28223 Mdot
.31702 .47648 Mdot
.31707 .32346 Mdot
.31711 .51763 Mdot
.31716 .29876 Mdot
.31721 .51709 Mdot
.31726 .48715 Mdot
.3173 .08968 Mdot
.31735 .02605 Mdot
.3174 .05189 Mdot
.31745 .07192 Mdot
.31749 .19968 Mdot
.31754 .14458 Mdot
.31759 .4748 Mdot
.31764 .1967 Mdot
.31768 .46579 Mdot
.31773 .17465 Mdot
.31778 .58121 Mdot
.31783 .05757 Mdot
.31788 .05857 Mdot
.31792 .54771 Mdot
.31797 .29957 Mdot
.31802 .24485 Mdot
.31807 .12725 Mdot
.31811 .28019 Mdot
.31816 .42641 Mdot
.31821 .52471 Mdot
.31826 .21294 Mdot
.3183 .58476 Mdot
.31835 .51264 Mdot
.3184 .05228 Mdot
.31845 .13797 Mdot
.31849 .57342 Mdot
.31854 .47546 Mdot
.31859 .58368 Mdot
.31864 .54161 Mdot
.31868 .44354 Mdot
.31873 .01537 Mdot
.31878 .40168 Mdot
.31883 .09053 Mdot
.31888 .2836 Mdot
.31892 .03749 Mdot
.31897 .35883 Mdot
.31902 .04668 Mdot
.31907 .33922 Mdot
.31911 .34125 Mdot
.31916 .12868 Mdot
.31921 .52275 Mdot
.31926 .07373 Mdot
.3193 .51816 Mdot
.31935 .2073 Mdot
.3194 .32451 Mdot
.31945 .0923 Mdot
.31949 .02023 Mdot
.31954 .16973 Mdot
.31959 .20125 Mdot
.31964 .12221 Mdot
.31968 .1481 Mdot
.31973 .18937 Mdot
.31978 .26296 Mdot
.31983 .282 Mdot
.31988 .14743 Mdot
.31992 .39102 Mdot
.31997 .18714 Mdot
.32002 .60173 Mdot
.32007 .12465 Mdot
.32011 .0469 Mdot
.32016 .15517 Mdot
.32021 .27722 Mdot
.32026 .38673 Mdot
.3203 .52154 Mdot
.32035 .23575 Mdot
.3204 .2182 Mdot
.32045 .47189 Mdot
.32049 .32896 Mdot
.32054 .51456 Mdot
.32059 .1406 Mdot
.32064 .46637 Mdot
.32068 .17394 Mdot
.32073 .32802 Mdot
.32078 .03309 Mdot
.32083 .33299 Mdot
.32088 .58789 Mdot
.32092 .07976 Mdot
.32097 .35442 Mdot
.32102 .20026 Mdot
.32107 .21158 Mdot
.32111 .49595 Mdot
.32116 .35602 Mdot
.32121 .09032 Mdot
.32126 .17939 Mdot
.3213 .35549 Mdot
.32135 .0935 Mdot
.3214 .30691 Mdot
.32145 .26117 Mdot
.32149 .13445 Mdot
.32154 .47863 Mdot
.32159 .43834 Mdot
.32164 .53554 Mdot
.32168 .22321 Mdot
.32173 .35274 Mdot
.32178 .57529 Mdot
.32183 .37631 Mdot
.32187 .49852 Mdot
.32192 .33436 Mdot
.32197 .25701 Mdot
.32202 .39175 Mdot
.32207 .43346 Mdot
.32211 .58326 Mdot
.32216 .07146 Mdot
.32221 .19488 Mdot
.32226 .54084 Mdot
.3223 .24196 Mdot
.32235 .58447 Mdot
.3224 .0302 Mdot
.32245 .20006 Mdot
.32249 .16316 Mdot
.32254 .29227 Mdot
.32259 .37236 Mdot
.32264 .08032 Mdot
.32268 .28785 Mdot
.32273 .45725 Mdot
.32278 .44014 Mdot
.32283 .46043 Mdot
.32287 .53844 Mdot
.32292 .48529 Mdot
.32297 .07854 Mdot
.32302 .56524 Mdot
.32307 .21879 Mdot
.32311 .24298 Mdot
.32316 .29011 Mdot
.32321 .14649 Mdot
.32326 .23885 Mdot
.3233 .18623 Mdot
.32335 .10994 Mdot
.3234 .20897 Mdot
.32345 .60021 Mdot
.32349 .20509 Mdot
.32354 .09444 Mdot
.32359 .02363 Mdot
.32364 .45176 Mdot
.32368 .51615 Mdot
.32373 .32541 Mdot
.32378 .54663 Mdot
.32383 .17862 Mdot
.32387 .0736 Mdot
.32392 .48859 Mdot
.32397 .10091 Mdot
.32402 .24351 Mdot
.32407 .19164 Mdot
.32411 .42476 Mdot
.32416 .13899 Mdot
.32421 .03943 Mdot
.32426 .55198 Mdot
.3243 .14936 Mdot
.32435 .59583 Mdot
.3244 .40391 Mdot
.32445 .38045 Mdot
.32449 .05413 Mdot
.32454 .40157 Mdot
.32459 .40702 Mdot
.32464 .19007 Mdot
.32468 .56302 Mdot
.32473 .39265 Mdot
.32478 .55858 Mdot
.32483 .27725 Mdot
.32487 .25232 Mdot
.32492 .44934 Mdot
.32497 .39467 Mdot
.32502 .21835 Mdot
.32507 .36705 Mdot
.32511 .36315 Mdot
.32516 .16588 Mdot
.32521 .04142 Mdot
.32526 .54562 Mdot
.3253 .23886 Mdot
.32535 .14116 Mdot
.3254 .09277 Mdot
.32545 .41097 Mdot
.32549 .24636 Mdot
.32554 .34057 Mdot
.32559 .31564 Mdot
.32564 .37154 Mdot
.32568 .44811 Mdot
.32573 .53688 Mdot
.32578 .14028 Mdot
.32583 .41185 Mdot
.32587 .07017 Mdot
.32592 .58162 Mdot
.32597 .46635 Mdot
.32602 .17425 Mdot
.32607 .22415 Mdot
.32611 .20165 Mdot
.32616 .26271 Mdot
.32621 .41052 Mdot
.32626 .46433 Mdot
.3263 .05049 Mdot
.32635 .23599 Mdot
.3264 .46823 Mdot
.32645 .24018 Mdot
.32649 .51266 Mdot
.32654 .15793 Mdot
.32659 .07197 Mdot
.32664 .59715 Mdot
.32668 .18679 Mdot
.32673 .44562 Mdot
.32678 .30375 Mdot
.32683 .16374 Mdot
.32687 .25324 Mdot
.32692 .32005 Mdot
.32697 .49522 Mdot
.32702 .10828 Mdot
.32706 .27494 Mdot
.32711 .45702 Mdot
.32716 .33568 Mdot
.32721 .48745 Mdot
.32726 .088 Mdot
.3273 .20902 Mdot
.32735 .52849 Mdot
.3274 .03782 Mdot
.32745 .05222 Mdot
.32749 .57636 Mdot
.32754 .07497 Mdot
.32759 .40097 Mdot
.32764 .14289 Mdot
.32768 .43313 Mdot
.32773 .01771 Mdot
.32778 .40715 Mdot
.32783 .55942 Mdot
.32787 .59084 Mdot
.32792 .31729 Mdot
.32797 .25811 Mdot
.32802 .32089 Mdot
.32806 .28551 Mdot
.32811 .42539 Mdot
.32816 .16455 Mdot
.32821 .06066 Mdot
.32826 .43181 Mdot
.3283 .10442 Mdot
.32835 .28042 Mdot
.3284 .57599 Mdot
.32845 .2375 Mdot
.32849 .17925 Mdot
.32854 .25731 Mdot
.32859 .53848 Mdot
.32864 .26447 Mdot
.32868 .11899 Mdot
.32873 .45966 Mdot
.32878 .4103 Mdot
.32883 .43466 Mdot
.32887 .11598 Mdot
.32892 .06722 Mdot
.32897 .4542 Mdot
.32902 .44714 Mdot
.32906 .40202 Mdot
.32911 .41243 Mdot
.32916 .14802 Mdot
.32921 .17634 Mdot
.32926 .57995 Mdot
.3293 .26259 Mdot
.32935 .10207 Mdot
.3294 .34786 Mdot
.32945 .49024 Mdot
.32949 .5855 Mdot
.32954 .1294 Mdot
.32959 .12507 Mdot
.32964 .3257 Mdot
.32968 .3429 Mdot
.32973 .19425 Mdot
.32978 .46393 Mdot
.32983 .22142 Mdot
.32987 .48657 Mdot
.32992 .38728 Mdot
.32997 .04397 Mdot
.33002 .12014 Mdot
.33006 .43405 Mdot
.33011 .5364 Mdot
.33016 .20016 Mdot
.33021 .32145 Mdot
.33026 .03633 Mdot
.3303 .4031 Mdot
.33035 .03852 Mdot
.3304 .34482 Mdot
.33045 .37706 Mdot
.33049 .31574 Mdot
.33054 .29399 Mdot
.33059 .4579 Mdot
.33064 .39489 Mdot
.33068 .20104 Mdot
.33073 .18363 Mdot
.33078 .14692 Mdot
.33083 .0667 Mdot
.33087 .0215 Mdot
.33092 .32303 Mdot
.33097 .52883 Mdot
.33102 .18346 Mdot
.33106 .23755 Mdot
.33111 .29376 Mdot
.33116 .42339 Mdot
.33121 .35273 Mdot
.33125 .30447 Mdot
.3313 .10831 Mdot
.33135 .11666 Mdot
.3314 .3311 Mdot
.33145 .5047 Mdot
.33149 .0845 Mdot
.33154 .37516 Mdot
.33159 .55737 Mdot
.33164 .20367 Mdot
.33168 .39384 Mdot
.33173 .52058 Mdot
.33178 .17719 Mdot
.33183 .01734 Mdot
.33187 .22492 Mdot
.33192 .38837 Mdot
.33197 .1252 Mdot
.33202 .59916 Mdot
.33206 .50522 Mdot
.33211 .46287 Mdot
.33216 .54507 Mdot
.33221 .37633 Mdot
.33225 .22616 Mdot
.3323 .05419 Mdot
.33235 .20705 Mdot
.3324 .08657 Mdot
.33245 .13255 Mdot
.33249 .54086 Mdot
.33254 .47927 Mdot
.33259 .18519 Mdot
.33264 .06276 Mdot
.33268 .1804 Mdot
.33273 .52523 Mdot
.33278 .58485 Mdot
.33283 .27225 Mdot
.33287 .26315 Mdot
.33292 .36275 Mdot
.33297 .58222 Mdot
.33302 .06204 Mdot
.33306 .4781 Mdot
.33311 .25226 Mdot
.33316 .58639 Mdot
.33321 .16015 Mdot
.33325 .02993 Mdot
.3333 .31052 Mdot
.33335 .22477 Mdot
.3334 .53731 Mdot
.33345 .57907 Mdot
.33349 .11818 Mdot
.33354 .15291 Mdot
.33359 .41946 Mdot
.33364 .05292 Mdot
.33368 .24223 Mdot
.33373 .57104 Mdot
.33378 .37141 Mdot
.33383 .47584 Mdot
.33387 .32033 Mdot
.33392 .58952 Mdot
.33397 .11387 Mdot
.33402 .2274 Mdot
.33406 .5609 Mdot
.33411 .022 Mdot
.33416 .06655 Mdot
.33421 .35263 Mdot
.33425 .32335 Mdot
.3343 .03894 Mdot
.33435 .50973 Mdot
.3344 .3374 Mdot
.33445 .02754 Mdot
.33449 .41749 Mdot
.33454 .57574 Mdot
.33459 .36166 Mdot
.33464 .51269 Mdot
.33468 .27929 Mdot
.33473 .17099 Mdot
.33478 .32345 Mdot
.33483 .28517 Mdot
.33487 .31157 Mdot
.33492 .4029 Mdot
.33497 .45093 Mdot
.33502 .56816 Mdot
.33506 .32538 Mdot
.33511 .30373 Mdot
.33516 .23824 Mdot
.33521 .02197 Mdot
.33525 .31809 Mdot
.3353 .2519 Mdot
.33535 .48893 Mdot
.3354 .30194 Mdot
.33545 .29386 Mdot
.33549 .3455 Mdot
.33554 .16624 Mdot
.33559 .28911 Mdot
.33564 .47969 Mdot
.33568 .37308 Mdot
.33573 .4079 Mdot
.33578 .37974 Mdot
.33583 .21511 Mdot
.33587 .2168 Mdot
.33592 .09917 Mdot
.33597 .10929 Mdot
.33602 .50686 Mdot
.33606 .41723 Mdot
.33611 .25156 Mdot
.33616 .14445 Mdot
.33621 .19619 Mdot
.33625 .1282 Mdot
.3363 .02804 Mdot
.33635 .13719 Mdot
.3364 .48142 Mdot
.33644 .47963 Mdot
.33649 .14243 Mdot
.33654 .43857 Mdot
.33659 .20227 Mdot
.33664 .14884 Mdot
.33668 .57952 Mdot
.33673 .16417 Mdot
.33678 .32591 Mdot
.33683 .37909 Mdot
.33687 .18632 Mdot
.33692 .38776 Mdot
.33697 .12551 Mdot
.33702 .17699 Mdot
.33706 .10186 Mdot
.33711 .29318 Mdot
.33716 .22197 Mdot
.33721 .36309 Mdot
.33725 .45362 Mdot
.3373 .16344 Mdot
.33735 .0405 Mdot
.3374 .2496 Mdot
.33744 .44029 Mdot
.33749 .04096 Mdot
.33754 .1624 Mdot
.33759 .37329 Mdot
.33764 .31257 Mdot
.33768 .20571 Mdot
.33773 .56345 Mdot
.33778 .23916 Mdot
.33783 .33638 Mdot
.33787 .05625 Mdot
.33792 .25225 Mdot
.33797 .4634 Mdot
.33802 .16477 Mdot
.33806 .27181 Mdot
.33811 .14146 Mdot
.33816 .30111 Mdot
.33821 .07762 Mdot
.33825 .58196 Mdot
.3383 .52281 Mdot
.33835 .54134 Mdot
.3384 .22732 Mdot
.33844 .43323 Mdot
.33849 .49702 Mdot
.33854 .30646 Mdot
.33859 .39035 Mdot
.33864 .40698 Mdot
.33868 .34933 Mdot
.33873 .53649 Mdot
.33878 .09248 Mdot
.33883 .21598 Mdot
.33887 .3892 Mdot
.33892 .31204 Mdot
.33897 .35943 Mdot
.33902 .17444 Mdot
.33906 .15165 Mdot
.33911 .45197 Mdot
.33916 .20937 Mdot
.33921 .50595 Mdot
.33925 .02491 Mdot
.3393 .16557 Mdot
.33935 .14646 Mdot
.3394 .52731 Mdot
.33944 .10542 Mdot
.33949 .22755 Mdot
.33954 .52246 Mdot
.33959 .10879 Mdot
.33964 .21173 Mdot
.33968 .52442 Mdot
.33973 .14682 Mdot
.33978 .30514 Mdot
.33983 .46573 Mdot
.33987 .59126 Mdot
.33992 .06905 Mdot
.33997 .10387 Mdot
.34002 .09124 Mdot
.34006 .29393 Mdot
.34011 .31294 Mdot
.34016 .53276 Mdot
.34021 .54291 Mdot
.34025 .44528 Mdot
.3403 .11829 Mdot
.34035 .04152 Mdot
.3404 .53271 Mdot
.34044 .29442 Mdot
.34049 .57515 Mdot
.34054 .11753 Mdot
.34059 .44199 Mdot
.34063 .08158 Mdot
.34068 .0674 Mdot
.34073 .02344 Mdot
.34078 .24497 Mdot
.34083 .16049 Mdot
.34087 .5239 Mdot
.34092 .32163 Mdot
.34097 .38257 Mdot
.34102 .17256 Mdot
.34106 .46957 Mdot
.34111 .23246 Mdot
.34116 .30604 Mdot
.34121 .48196 Mdot
.34125 .17133 Mdot
.3413 .30303 Mdot
.34135 .36646 Mdot
.3414 .05139 Mdot
.34144 .06775 Mdot
.34149 .27622 Mdot
.34154 .43707 Mdot
.34159 .36029 Mdot
.34163 .09592 Mdot
.34168 .1734 Mdot
.34173 .5984 Mdot
.34178 .29342 Mdot
.34183 .04323 Mdot
.34187 .16466 Mdot
.34192 .36814 Mdot
.34197 .14764 Mdot
.34202 .12265 Mdot
.34206 .44636 Mdot
.34211 .5889 Mdot
.34216 .5784 Mdot
.34221 .25641 Mdot
.34225 .22861 Mdot
.3423 .29756 Mdot
.34235 .11115 Mdot
.3424 .09979 Mdot
.34244 .5289 Mdot
.34249 .53443 Mdot
.34254 .07448 Mdot
.34259 .04674 Mdot
.34263 .26739 Mdot
.34268 .11207 Mdot
.34273 .31751 Mdot
.34278 .55415 Mdot
.34283 .10871 Mdot
.34287 .11699 Mdot
.34292 .03881 Mdot
.34297 .52562 Mdot
.34302 .54737 Mdot
.34306 .35218 Mdot
.34311 .4945 Mdot
.34316 .41768 Mdot
.34321 .11572 Mdot
.34325 .3666 Mdot
.3433 .51942 Mdot
.34335 .17597 Mdot
.3434 .49044 Mdot
.34344 .08375 Mdot
.34349 .42297 Mdot
.34354 .09089 Mdot
.34359 .56486 Mdot
.34363 .15264 Mdot
.34368 .36321 Mdot
.34373 .05886 Mdot
.34378 .31218 Mdot
.34383 .05528 Mdot
.34387 .0604 Mdot
.34392 .10804 Mdot
.34397 .21818 Mdot
.34402 .54162 Mdot
.34406 .03631 Mdot
.34411 .18574 Mdot
.34416 .27413 Mdot
.34421 .20415 Mdot
.34425 .14514 Mdot
.3443 .37139 Mdot
.34435 .17312 Mdot
.3444 .44087 Mdot
.34444 .22904 Mdot
.34449 .21012 Mdot
.34454 .286 Mdot
.34459 .37183 Mdot
.34463 .40939 Mdot
.34468 .13394 Mdot
.34473 .32447 Mdot
.34478 .2339 Mdot
.34483 .06089 Mdot
.34487 .08979 Mdot
.34492 .027 Mdot
.34497 .19333 Mdot
.34502 .0152 Mdot
.34506 .58508 Mdot
.34511 .41215 Mdot
.34516 .25504 Mdot
.34521 .58222 Mdot
.34525 .41405 Mdot
.3453 .15273 Mdot
.34535 .06559 Mdot
.3454 .45179 Mdot
.34544 .05737 Mdot
.34549 .58293 Mdot
.34554 .22805 Mdot
.34559 .23746 Mdot
.34563 .45058 Mdot
.34568 .31164 Mdot
.34573 .45954 Mdot
.34578 .43139 Mdot
.34582 .33134 Mdot
.34587 .59049 Mdot
.34592 .24035 Mdot
.34597 .38521 Mdot
.34602 .25626 Mdot
.34606 .5782 Mdot
.34611 .06173 Mdot
.34616 .38472 Mdot
.34621 .2745 Mdot
.34625 .18076 Mdot
.3463 .41002 Mdot
.34635 .40582 Mdot
.3464 .46377 Mdot
.34644 .04274 Mdot
.34649 .35914 Mdot
.34654 .55736 Mdot
.34659 .42111 Mdot
.34663 .06314 Mdot
.34668 .1458 Mdot
.34673 .33461 Mdot
.34678 .57386 Mdot
.34682 .35482 Mdot
.34687 .28958 Mdot
.34692 .50654 Mdot
.34697 .25722 Mdot
.34702 .36766 Mdot
.34706 .06394 Mdot
.34711 .13604 Mdot
.34716 .01567 Mdot
.34721 .39278 Mdot
.34725 .01691 Mdot
.3473 .35465 Mdot
.34735 .3445 Mdot
.3474 .22673 Mdot
.34744 .21021 Mdot
.34749 .55216 Mdot
.34754 .48405 Mdot
.34759 .1987 Mdot
.34763 .4544 Mdot
.34768 .59813 Mdot
.34773 .07765 Mdot
.34778 .15027 Mdot
.34782 .32331 Mdot
.34787 .27823 Mdot
.34792 .10711 Mdot
.34797 .39877 Mdot
.34802 .04844 Mdot
.34806 .37501 Mdot
.34811 .45321 Mdot
.34816 .04582 Mdot
.34821 .58782 Mdot
.34825 .25368 Mdot
.3483 .45225 Mdot
.34835 .25637 Mdot
.3484 .58562 Mdot
.34844 .50235 Mdot
.34849 .12246 Mdot
.34854 .04434 Mdot
.34859 .39011 Mdot
.34863 .55352 Mdot
.34868 .24174 Mdot
.34873 .44897 Mdot
.34878 .53904 Mdot
.34882 .55872 Mdot
.34887 .1788 Mdot
.34892 .31341 Mdot
.34897 .23044 Mdot
.34902 .2952 Mdot
.34906 .0864 Mdot
.34911 .51796 Mdot
.34916 .19671 Mdot
.34921 .52351 Mdot
.34925 .23651 Mdot
.3493 .48684 Mdot
.34935 .21221 Mdot
.3494 .28455 Mdot
.34944 .38759 Mdot
.34949 .24519 Mdot
.34954 .22992 Mdot
.34959 .38552 Mdot
.34963 .27984 Mdot
.34968 .21555 Mdot
.34973 .44313 Mdot
.34978 .43533 Mdot
.34982 .05281 Mdot
.34987 .36991 Mdot
.34992 .50742 Mdot
.34997 .47994 Mdot
.35001 .47734 Mdot
.35006 .07121 Mdot
.35011 .2917 Mdot
.35016 .19945 Mdot
.35021 .40565 Mdot
.35025 .15658 Mdot
.3503 .1097 Mdot
.35035 .27926 Mdot
.3504 .18385 Mdot
.35044 .27306 Mdot
.35049 .50081 Mdot
.35054 .59804 Mdot
.35059 .39959 Mdot
.35063 .04258 Mdot
.35068 .2856 Mdot
.35073 .22723 Mdot
.35078 .13446 Mdot
.35082 .43036 Mdot
.35087 .44579 Mdot
.35092 .39522 Mdot
.35097 .09636 Mdot
.35101 .07516 Mdot
.35106 .5417 Mdot
.35111 .51861 Mdot
.35116 .22234 Mdot
.35121 .01866 Mdot
.35125 .26471 Mdot
.3513 .33386 Mdot
.35135 .42002 Mdot
.3514 .4654 Mdot
.35144 .16972 Mdot
.35149 .06931 Mdot
.35154 .25088 Mdot
.35159 .20705 Mdot
.35163 .27224 Mdot
.35168 .07459 Mdot
.35173 .45462 Mdot
.35178 .17918 Mdot
.35182 .58996 Mdot
.35187 .45069 Mdot
.35192 .33488 Mdot
.35197 .35214 Mdot
.35201 .15888 Mdot
.35206 .07017 Mdot
.35211 .25323 Mdot
.35216 .29169 Mdot
.35221 .22051 Mdot
.35225 .15489 Mdot
.3523 .04559 Mdot
.35235 .28775 Mdot
.3524 .55912 Mdot
.35244 .42435 Mdot
.35249 .2289 Mdot
.35254 .42567 Mdot
.35259 .40411 Mdot
.35263 .36975 Mdot
.35268 .58134 Mdot
.35273 .23333 Mdot
.35278 .14658 Mdot
.35282 .30987 Mdot
.35287 .14142 Mdot
.35292 .06886 Mdot
.35297 .15994 Mdot
.35301 .46251 Mdot
.35306 .40987 Mdot
.35311 .32004 Mdot
.35316 .01577 Mdot
.35321 .40704 Mdot
.35325 .17135 Mdot
.3533 .04306 Mdot
.35335 .39859 Mdot
.3534 .26686 Mdot
.35344 .14047 Mdot
.35349 .35864 Mdot
.35354 .44279 Mdot
.35359 .44583 Mdot
.35363 .5149 Mdot
.35368 .53629 Mdot
.35373 .05339 Mdot
.35378 .09078 Mdot
.35382 .53689 Mdot
.35387 .31767 Mdot
.35392 .51013 Mdot
.35397 .38424 Mdot
.35401 .41017 Mdot
.35406 .26352 Mdot
.35411 .3649 Mdot
.35416 .52506 Mdot
.35421 .01501 Mdot
.35425 .54681 Mdot
.3543 .36384 Mdot
.35435 .13273 Mdot
.3544 .44698 Mdot
.35444 .51846 Mdot
.35449 .56857 Mdot
.35454 .4692 Mdot
.35459 .32122 Mdot
.35463 .17453 Mdot
.35468 .14049 Mdot
.35473 .03808 Mdot
.35478 .40965 Mdot
.35482 .24157 Mdot
.35487 .10181 Mdot
.35492 .55062 Mdot
.35497 .47608 Mdot
.35501 .52722 Mdot
.35506 .195 Mdot
.35511 .18109 Mdot
.35516 .08062 Mdot
.3552 .2784 Mdot
.35525 .43342 Mdot
.3553 .25936 Mdot
.35535 .08032 Mdot
.3554 .33492 Mdot
.35544 .08429 Mdot
.35549 .14134 Mdot
.35554 .23667 Mdot
.35559 .41978 Mdot
.35563 .11905 Mdot
.35568 .27546 Mdot
.35573 .51877 Mdot
.35578 .25996 Mdot
.35582 .58188 Mdot
.35587 .25209 Mdot
.35592 .12383 Mdot
.35597 .0331 Mdot
.35601 .49479 Mdot
.35606 .30479 Mdot
.35611 .25108 Mdot
.35616 .10921 Mdot
.3562 .3145 Mdot
.35625 .13841 Mdot
.3563 .18516 Mdot
.35635 .43414 Mdot
.3564 .4844 Mdot
.35644 .48238 Mdot
.35649 .11955 Mdot
.35654 .11393 Mdot
.35659 .41482 Mdot
.35663 .35575 Mdot
.35668 .48621 Mdot
.35673 .29747 Mdot
.35678 .31048 Mdot
.35682 .095 Mdot
.35687 .57077 Mdot
.35692 .05222 Mdot
.35697 .33192 Mdot
.35701 .44623 Mdot
.35706 .46164 Mdot
.35711 .03383 Mdot
.35716 .44046 Mdot
.3572 .15615 Mdot
.35725 .22527 Mdot
.3573 .52794 Mdot
.35735 .14067 Mdot
.3574 .03245 Mdot
.35744 .05482 Mdot
.35749 .10851 Mdot
.35754 .25959 Mdot
.35759 .1534 Mdot
.35763 .53859 Mdot
.35768 .59791 Mdot
.35773 .4481 Mdot
.35778 .40097 Mdot
.35782 .06709 Mdot
.35787 .31515 Mdot
.35792 .15233 Mdot
.35797 .32068 Mdot
.35801 .09964 Mdot
.35806 .27764 Mdot
.35811 .42374 Mdot
.35816 .47777 Mdot
.3582 .24133 Mdot
.35825 .25852 Mdot
.3583 .58661 Mdot
.35835 .33633 Mdot
.3584 .03076 Mdot
.35844 .33391 Mdot
.35849 .46065 Mdot
.35854 .31859 Mdot
.35859 .57927 Mdot
.35863 .2401 Mdot
.35868 .21577 Mdot
.35873 .1799 Mdot
.35878 .05539 Mdot
.35882 .24552 Mdot
.35887 .371 Mdot
.35892 .38225 Mdot
.35897 .59163 Mdot
.35901 .53369 Mdot
.35906 .23337 Mdot
.35911 .07628 Mdot
.35916 .50669 Mdot
.3592 .27076 Mdot
.35925 .41296 Mdot
.3593 .20183 Mdot
.35935 .28007 Mdot
.3594 .02695 Mdot
.35944 .42967 Mdot
.35949 .46883 Mdot
.35954 .26401 Mdot
.35959 .29637 Mdot
.35963 .57235 Mdot
.35968 .16495 Mdot
.35973 .28807 Mdot
.35978 .07097 Mdot
.35982 .37128 Mdot
.35987 .58838 Mdot
.35992 .24739 Mdot
.35997 .42878 Mdot
.36001 .01499 Mdot
.36006 .22084 Mdot
.36011 .25909 Mdot
.36016 .49842 Mdot
.3602 .38494 Mdot
.36025 .15927 Mdot
.3603 .35573 Mdot
.36035 .24237 Mdot
.36039 .57531 Mdot
.36044 .56076 Mdot
.36049 .09037 Mdot
.36054 .23013 Mdot
.36059 .16034 Mdot
.36063 .10664 Mdot
.36068 .42968 Mdot
.36073 .53709 Mdot
.36078 .19132 Mdot
.36082 .54502 Mdot
.36087 .15632 Mdot
.36092 .48082 Mdot
.36097 .42337 Mdot
.36101 .55996 Mdot
.36106 .51225 Mdot
.36111 .06675 Mdot
.36116 .42308 Mdot
.3612 .35384 Mdot
.36125 .26787 Mdot
.3613 .17166 Mdot
.36135 .05285 Mdot
.36139 .20928 Mdot
.36144 .51546 Mdot
.36149 .53262 Mdot
.36154 .08086 Mdot
.36159 .25184 Mdot
.36163 .43981 Mdot
.36168 .3172 Mdot
.36173 .52384 Mdot
.36178 .15991 Mdot
.36182 .02484 Mdot
.36187 .38343 Mdot
.36192 .34723 Mdot
.36197 .21822 Mdot
.36201 .47185 Mdot
.36206 .50594 Mdot
.36211 .52719 Mdot
.36216 .26158 Mdot
.3622 .56292 Mdot
.36225 .45389 Mdot
.3623 .11881 Mdot
.36235 .51107 Mdot
.36239 .30976 Mdot
.36244 .29694 Mdot
.36249 .08068 Mdot
.36254 .3165 Mdot
.36259 .39763 Mdot
.36263 .36765 Mdot
.36268 .60314 Mdot
.36273 .07936 Mdot
.36278 .56115 Mdot
.36282 .06516 Mdot
.36287 .09401 Mdot
.36292 .52278 Mdot
.36297 .55102 Mdot
.36301 .28506 Mdot
.36306 .35011 Mdot
.36311 .31927 Mdot
.36316 .09388 Mdot
.3632 .38244 Mdot
.36325 .42625 Mdot
.3633 .07239 Mdot
.36335 .13429 Mdot
.36339 .53188 Mdot
.36344 .32214 Mdot
.36349 .16465 Mdot
.36354 .42785 Mdot
.36359 .24964 Mdot
.36363 .25617 Mdot
.36368 .45148 Mdot
.36373 .04493 Mdot
.36378 .48531 Mdot
.36382 .25635 Mdot
.36387 .38682 Mdot
.36392 .08711 Mdot
.36397 .43486 Mdot
.36401 .17705 Mdot
.36406 .46737 Mdot
.36411 .13941 Mdot
.36416 .16451 Mdot
.3642 .43027 Mdot
.36425 .16281 Mdot
.3643 .06024 Mdot
.36435 .38539 Mdot
.36439 .01873 Mdot
.36444 .10513 Mdot
.36449 .52928 Mdot
.36454 .45684 Mdot
.36458 .29992 Mdot
.36463 .5438 Mdot
.36468 .11614 Mdot
.36473 .22191 Mdot
.36478 .05846 Mdot
.36482 .10704 Mdot
.36487 .08592 Mdot
.36492 .33992 Mdot
.36497 .40543 Mdot
.36501 .32354 Mdot
.36506 .60214 Mdot
.36511 .50839 Mdot
.36516 .24309 Mdot
.3652 .4595 Mdot
.36525 .47744 Mdot
.3653 .35859 Mdot
.36535 .41614 Mdot
.36539 .31139 Mdot
.36544 .43191 Mdot
.36549 .57652 Mdot
.36554 .41212 Mdot
.36558 .22097 Mdot
.36563 .50595 Mdot
.36568 .13439 Mdot
.36573 .12691 Mdot
.36578 .28049 Mdot
.36582 .40452 Mdot
.36587 .51581 Mdot
.36592 .08316 Mdot
.36597 .18816 Mdot
.36601 .33331 Mdot
.36606 .1906 Mdot
.36611 .28106 Mdot
.36616 .46795 Mdot
.3662 .33449 Mdot
.36625 .28553 Mdot
.3663 .05268 Mdot
.36635 .02316 Mdot
.36639 .46038 Mdot
.36644 .53027 Mdot
.36649 .23986 Mdot
.36654 .3151 Mdot
.36658 .04318 Mdot
.36663 .55707 Mdot
.36668 .43107 Mdot
.36673 .10884 Mdot
.36678 .14056 Mdot
.36682 .43738 Mdot
.36687 .31887 Mdot
.36692 .43167 Mdot
.36697 .33936 Mdot
.36701 .5249 Mdot
.36706 .25041 Mdot
.36711 .25821 Mdot
.36716 .02076 Mdot
.3672 .34901 Mdot
.36725 .57268 Mdot
.3673 .39359 Mdot
.36735 .2896 Mdot
.36739 .07819 Mdot
.36744 .53471 Mdot
.36749 .38514 Mdot
.36754 .43254 Mdot
.36758 .15125 Mdot
.36763 .30955 Mdot
.36768 .08475 Mdot
.36773 .40407 Mdot
.36778 .19751 Mdot
.36782 .48181 Mdot
.36787 .57924 Mdot
.36792 .27822 Mdot
.36797 .36345 Mdot
.36801 .17765 Mdot
.36806 .16228 Mdot
.36811 .54219 Mdot
.36816 .44188 Mdot
.3682 .53056 Mdot
.36825 .50739 Mdot
.3683 .53613 Mdot
.36835 .10757 Mdot
.36839 .5612 Mdot
.36844 .12851 Mdot
.36849 .26124 Mdot
.36854 .04409 Mdot
.36858 .04121 Mdot
.36863 .3467 Mdot
.36868 .43202 Mdot
.36873 .49617 Mdot
.36878 .33498 Mdot
.36882 .27665 Mdot
.36887 .04266 Mdot
.36892 .31337 Mdot
.36897 .4565 Mdot
.36901 .30074 Mdot
.36906 .36776 Mdot
.36911 .55325 Mdot
.36916 .29356 Mdot
.3692 .15317 Mdot
.36925 .4289 Mdot
.3693 .12608 Mdot
.36935 .36633 Mdot
.36939 .24911 Mdot
.36944 .49609 Mdot
.36949 .03322 Mdot
.36954 .40845 Mdot
.36958 .13531 Mdot
.36963 .24956 Mdot
.36968 .59245 Mdot
.36973 .38195 Mdot
.36977 .39194 Mdot
.36982 .42086 Mdot
.36987 .11099 Mdot
.36992 .06168 Mdot
.36997 .12999 Mdot
.37001 .39291 Mdot
.37006 .40094 Mdot
.37011 .2085 Mdot
.37016 .43258 Mdot
.3702 .03986 Mdot
.37025 .45102 Mdot
.3703 .51827 Mdot
.37035 .29411 Mdot
.37039 .21429 Mdot
.37044 .33964 Mdot
.37049 .16665 Mdot
.37054 .05972 Mdot
.37058 .32152 Mdot
.37063 .32113 Mdot
.37068 .36152 Mdot
.37073 .52773 Mdot
.37077 .08667 Mdot
.37082 .33201 Mdot
.37087 .58289 Mdot
.37092 .1505 Mdot
.37097 .26914 Mdot
.37101 .23573 Mdot
.37106 .53592 Mdot
.37111 .03522 Mdot
.37116 .47955 Mdot
.3712 .43811 Mdot
.37125 .34213 Mdot
.3713 .20597 Mdot
.37135 .4544 Mdot
.37139 .59042 Mdot
.37144 .42719 Mdot
.37149 .51518 Mdot
.37154 .25482 Mdot
.37158 .26548 Mdot
.37163 .27525 Mdot
.37168 .47017 Mdot
.37173 .53663 Mdot
.37177 .54767 Mdot
.37182 .51706 Mdot
.37187 .54576 Mdot
.37192 .46467 Mdot
.37197 .23038 Mdot
.37201 .53749 Mdot
.37206 .40997 Mdot
.37211 .21024 Mdot
.37216 .59797 Mdot
.3722 .01627 Mdot
.37225 .38946 Mdot
.3723 .33401 Mdot
.37235 .17457 Mdot
.37239 .27747 Mdot
.37244 .19821 Mdot
.37249 .48294 Mdot
.37254 .18748 Mdot
.37258 .4536 Mdot
.37263 .28635 Mdot
.37268 .24282 Mdot
.37273 .52532 Mdot
.37277 .19306 Mdot
.37282 .41951 Mdot
.37287 .30952 Mdot
.37292 .58097 Mdot
.37297 .27933 Mdot
.37301 .47707 Mdot
.37306 .44818 Mdot
.37311 .36531 Mdot
.37316 .34517 Mdot
.3732 .08181 Mdot
.37325 .25265 Mdot
.3733 .37066 Mdot
.37335 .3436 Mdot
.37339 .29567 Mdot
.37344 .52196 Mdot
.37349 .2108 Mdot
.37354 .08084 Mdot
.37358 .11218 Mdot
.37363 .05373 Mdot
.37368 .03802 Mdot
.37373 .23056 Mdot
.37377 .42915 Mdot
.37382 .41424 Mdot
.37387 .11602 Mdot
.37392 .05221 Mdot
.37396 .02435 Mdot
.37401 .11943 Mdot
.37406 .13838 Mdot
.37411 .37621 Mdot
.37416 .1506 Mdot
.3742 .27458 Mdot
.37425 .37639 Mdot
.3743 .04575 Mdot
.37435 .0835 Mdot
.37439 .03664 Mdot
.37444 .02044 Mdot
.37449 .30548 Mdot
.37454 .39115 Mdot
.37458 .11801 Mdot
.37463 .41297 Mdot
.37468 .23934 Mdot
.37473 .29368 Mdot
.37477 .07898 Mdot
.37482 .38966 Mdot
.37487 .02349 Mdot
.37492 .46786 Mdot
.37496 .26807 Mdot
.37501 .28834 Mdot
.37506 .5746 Mdot
.37511 .45822 Mdot
.37516 .16335 Mdot
.3752 .16467 Mdot
.37525 .2131 Mdot
.3753 .32233 Mdot
.37535 .4921 Mdot
.37539 .39161 Mdot
.37544 .18206 Mdot
.37549 .25355 Mdot
.37554 .47017 Mdot
.37558 .38587 Mdot
.37563 .47991 Mdot
.37568 .46572 Mdot
.37573 .36687 Mdot
.37577 .57623 Mdot
.37582 .25528 Mdot
.37587 .18675 Mdot
.37592 .3026 Mdot
.37596 .20128 Mdot
.37601 .2465 Mdot
.37606 .32221 Mdot
.37611 .04923 Mdot
.37616 .51626 Mdot
.3762 .27522 Mdot
.37625 .46731 Mdot
.3763 .4892 Mdot
.37635 .36629 Mdot
.37639 .07683 Mdot
.37644 .15969 Mdot
.37649 .60043 Mdot
.37654 .57801 Mdot
.37658 .49809 Mdot
.37663 .50947 Mdot
.37668 .14497 Mdot
.37673 .20685 Mdot
.37677 .03289 Mdot
.37682 .05846 Mdot
.37687 .38142 Mdot
.37692 .23395 Mdot
.37696 .38094 Mdot
.37701 .47504 Mdot
.37706 .09353 Mdot
.37711 .04738 Mdot
.37716 .14916 Mdot
.3772 .16753 Mdot
.37725 .05901 Mdot
.3773 .13445 Mdot
.37735 .47726 Mdot
.37739 .30354 Mdot
.37744 .17313 Mdot
.37749 .37148 Mdot
.37754 .41514 Mdot
.37758 .15856 Mdot
.37763 .17603 Mdot
.37768 .39679 Mdot
.37773 .52037 Mdot
.37777 .25242 Mdot
.37782 .04577 Mdot
.37787 .20465 Mdot
.37792 .50219 Mdot
.37796 .20867 Mdot
.37801 .26768 Mdot
.37806 .57403 Mdot
.37811 .13596 Mdot
.37816 .33696 Mdot
.3782 .18885 Mdot
.37825 .54136 Mdot
.3783 .59013 Mdot
.37835 .18413 Mdot
.37839 .14456 Mdot
.37844 .42162 Mdot
.37849 .12757 Mdot
.37854 .48392 Mdot
.37858 .57475 Mdot
.37863 .06485 Mdot
.37868 .31575 Mdot
.37873 .34007 Mdot
.37877 .41344 Mdot
.37882 .27139 Mdot
.37887 .39871 Mdot
.37892 .10236 Mdot
.37896 .38238 Mdot
.37901 .08144 Mdot
.37906 .49984 Mdot
.37911 .49702 Mdot
.37915 .12941 Mdot
.3792 .11074 Mdot
.37925 .37859 Mdot
.3793 .17477 Mdot
.37935 .54388 Mdot
.37939 .1727 Mdot
.37944 .39179 Mdot
.37949 .59396 Mdot
.37954 .41403 Mdot
.37958 .35441 Mdot
.37963 .27893 Mdot
.37968 .12475 Mdot
.37973 .4426 Mdot
.37977 .30426 Mdot
.37982 .5665 Mdot
.37987 .38801 Mdot
.37992 .04387 Mdot
.37996 .04759 Mdot
.38001 .1825 Mdot
.38006 .30036 Mdot
.38011 .26482 Mdot
.38015 .56947 Mdot
.3802 .28599 Mdot
.38025 .40666 Mdot
.3803 .15012 Mdot
.38035 .47344 Mdot
.38039 .51072 Mdot
.38044 .2466 Mdot
.38049 .20956 Mdot
.38054 .31545 Mdot
.38058 .13364 Mdot
.38063 .25596 Mdot
.38068 .39886 Mdot
.38073 .56437 Mdot
.38077 .45803 Mdot
.38082 .14592 Mdot
.38087 .55958 Mdot
.38092 .27482 Mdot
.38096 .49486 Mdot
.38101 .36123 Mdot
.38106 .53041 Mdot
.38111 .24194 Mdot
.38115 .32706 Mdot
.3812 .07558 Mdot
.38125 .2803 Mdot
.3813 .27579 Mdot
.38135 .05578 Mdot
.38139 .27224 Mdot
.38144 .14489 Mdot
.38149 .40568 Mdot
.38154 .14839 Mdot
.38158 .04035 Mdot
.38163 .53865 Mdot
.38168 .10493 Mdot
.38173 .02946 Mdot
.38177 .38771 Mdot
.38182 .1545 Mdot
.38187 .14389 Mdot
.38192 .17475 Mdot
.38196 .2565 Mdot
.38201 .19825 Mdot
.38206 .4724 Mdot
.38211 .28322 Mdot
.38215 .4986 Mdot
.3822 .27117 Mdot
.38225 .24517 Mdot
.3823 .55949 Mdot
.38235 .43772 Mdot
.38239 .59419 Mdot
.38244 .5727 Mdot
.38249 .51842 Mdot
.38254 .18019 Mdot
.38258 .46401 Mdot
.38263 .18173 Mdot
.38268 .38474 Mdot
.38273 .15455 Mdot
.38277 .52869 Mdot
.38282 .09151 Mdot
.38287 .36999 Mdot
.38292 .37016 Mdot
.38296 .38889 Mdot
.38301 .55094 Mdot
.38306 .20994 Mdot
.38311 .12837 Mdot
.38315 .20535 Mdot
.3832 .09325 Mdot
.38325 .53004 Mdot
.3833 .2331 Mdot
.38334 .53751 Mdot
.38339 .45141 Mdot
.38344 .57388 Mdot
.38349 .3987 Mdot
.38354 .54664 Mdot
.38358 .48203 Mdot
.38363 .07017 Mdot
.38368 .23322 Mdot
.38373 .09734 Mdot
.38377 .31501 Mdot
.38382 .28876 Mdot
.38387 .09337 Mdot
.38392 .17197 Mdot
.38396 .23821 Mdot
.38401 .5221 Mdot
.38406 .32654 Mdot
.38411 .38641 Mdot
.38415 .29059 Mdot
.3842 .32687 Mdot
.38425 .21288 Mdot
.3843 .19577 Mdot
.38434 .21205 Mdot
.38439 .40015 Mdot
.38444 .5831 Mdot
.38449 .26159 Mdot
.38454 .36397 Mdot
.38458 .4296 Mdot
.38463 .19911 Mdot
.38468 .31827 Mdot
.38473 .48526 Mdot
.38477 .37414 Mdot
.38482 .56922 Mdot
.38487 .23565 Mdot
.38492 .18496 Mdot
.38496 .10009 Mdot
.38501 .49056 Mdot
.38506 .07838 Mdot
.38511 .55007 Mdot
.38515 .18131 Mdot
.3852 .17873 Mdot
.38525 .2953 Mdot
.3853 .27418 Mdot
.38534 .45777 Mdot
.38539 .56918 Mdot
.38544 .11424 Mdot
.38549 .07684 Mdot
.38554 .07233 Mdot
.38558 .5894 Mdot
.38563 .45598 Mdot
.38568 .3162 Mdot
.38573 .24605 Mdot
.38577 .405 Mdot
.38582 .15241 Mdot
.38587 .43427 Mdot
.38592 .47524 Mdot
.38596 .4391 Mdot
.38601 .52009 Mdot
.38606 .26402 Mdot
.38611 .38986 Mdot
.38615 .55187 Mdot
.3862 .45642 Mdot
.38625 .31728 Mdot
.3863 .22326 Mdot
.38634 .38784 Mdot
.38639 .17583 Mdot
.38644 .0578 Mdot
.38649 .36882 Mdot
.38654 .42199 Mdot
.38658 .0763 Mdot
.38663 .58428 Mdot
.38668 .3112 Mdot
.38673 .43591 Mdot
.38677 .22364 Mdot
.38682 .28279 Mdot
.38687 .07986 Mdot
.38692 .04562 Mdot
.38696 .08594 Mdot
.38701 .45185 Mdot
.38706 .20794 Mdot
.38711 .20984 Mdot
.38715 .16917 Mdot
.3872 .20254 Mdot
.38725 .42141 Mdot
.3873 .2613 Mdot
.38734 .31608 Mdot
.38739 .48859 Mdot
.38744 .21285 Mdot
.38749 .47678 Mdot
.38754 .15496 Mdot
.38758 .4455 Mdot
.38763 .44736 Mdot
.38768 .0695 Mdot
.38773 .09337 Mdot
.38777 .46454 Mdot
.38782 .15087 Mdot
.38787 .23692 Mdot
.38792 .47305 Mdot
.38796 .19645 Mdot
.38801 .08572 Mdot
.38806 .20601 Mdot
.38811 .40182 Mdot
.38815 .34793 Mdot
.3882 .4811 Mdot
.38825 .59949 Mdot
.3883 .24736 Mdot
.38834 .1601 Mdot
.38839 .0744 Mdot
.38844 .3529 Mdot
.38849 .53461 Mdot
.38853 .27483 Mdot
.38858 .46487 Mdot
.38863 .47945 Mdot
.38868 .39436 Mdot
.38873 .43266 Mdot
.38877 .03222 Mdot
.38882 .42466 Mdot
.38887 .3157 Mdot
.38892 .57145 Mdot
.38896 .48468 Mdot
.38901 .20245 Mdot
.38906 .44598 Mdot
.38911 .38971 Mdot
.38915 .41367 Mdot
.3892 .59977 Mdot
.38925 .05887 Mdot
.3893 .05649 Mdot
.38934 .5359 Mdot
.38939 .01498 Mdot
.38944 .41483 Mdot
.38949 .49972 Mdot
.38953 .47621 Mdot
.38958 .2654 Mdot
.38963 .48355 Mdot
.38968 .23959 Mdot
.38973 .02604 Mdot
.38977 .38928 Mdot
.38982 .1039 Mdot
.38987 .41026 Mdot
.38992 .59714 Mdot
.38996 .56795 Mdot
.39001 .39153 Mdot
.39006 .44213 Mdot
.39011 .12717 Mdot
.39015 .38021 Mdot
.3902 .54888 Mdot
.39025 .06713 Mdot
.3903 .31682 Mdot
.39034 .38377 Mdot
.39039 .50472 Mdot
.39044 .02535 Mdot
.39049 .38425 Mdot
.39053 .38349 Mdot
.39058 .10459 Mdot
.39063 .12895 Mdot
.39068 .51137 Mdot
.39073 .1328 Mdot
.39077 .22437 Mdot
.39082 .49268 Mdot
.39087 .50003 Mdot
.39092 .34684 Mdot
.39096 .13517 Mdot
.39101 .09714 Mdot
.39106 .50622 Mdot
.39111 .38222 Mdot
.39115 .34697 Mdot
.3912 .25833 Mdot
.39125 .39375 Mdot
.3913 .01672 Mdot
.39134 .40142 Mdot
.39139 .20592 Mdot
.39144 .09164 Mdot
.39149 .23628 Mdot
.39153 .50002 Mdot
.39158 .19528 Mdot
.39163 .31072 Mdot
.39168 .45611 Mdot
.39173 .41013 Mdot
.39177 .08103 Mdot
.39182 .40267 Mdot
.39187 .33802 Mdot
.39192 .20048 Mdot
.39196 .19168 Mdot
.39201 .50596 Mdot
.39206 .5945 Mdot
.39211 .08001 Mdot
.39215 .10925 Mdot
.3922 .60307 Mdot
.39225 .22699 Mdot
.3923 .33637 Mdot
.39234 .45424 Mdot
.39239 .22403 Mdot
.39244 .22498 Mdot
.39249 .53828 Mdot
.39253 .26303 Mdot
.39258 .1471 Mdot
.39263 .59203 Mdot
.39268 .05297 Mdot
.39273 .08246 Mdot
.39277 .43971 Mdot
.39282 .15063 Mdot
.39287 .24616 Mdot
.39292 .01614 Mdot
.39296 .05174 Mdot
.39301 .41593 Mdot
.39306 .06039 Mdot
.39311 .42779 Mdot
.39315 .1491 Mdot
.3932 .42476 Mdot
.39325 .5837 Mdot
.3933 .33325 Mdot
.39334 .14935 Mdot
.39339 .21248 Mdot
.39344 .26204 Mdot
.39349 .48233 Mdot
.39353 .52865 Mdot
.39358 .59083 Mdot
.39363 .32708 Mdot
.39368 .23401 Mdot
.39372 .39626 Mdot
.39377 .60213 Mdot
.39382 .28882 Mdot
.39387 .16626 Mdot
.39392 .55988 Mdot
.39396 .46621 Mdot
.39401 .05737 Mdot
.39406 .16483 Mdot
.39411 .52285 Mdot
.39415 .06498 Mdot
.3942 .60031 Mdot
.39425 .34037 Mdot
.3943 .38846 Mdot
.39434 .24355 Mdot
.39439 .03131 Mdot
.39444 .02183 Mdot
.39449 .25381 Mdot
.39453 .04578 Mdot
.39458 .3726 Mdot
.39463 .14282 Mdot
.39468 .32849 Mdot
.39472 .05827 Mdot
.39477 .06022 Mdot
.39482 .51214 Mdot
.39487 .53555 Mdot
.39492 .05947 Mdot
.39496 .37473 Mdot
.39501 .36059 Mdot
.39506 .57899 Mdot
.39511 .19659 Mdot
.39515 .33206 Mdot
.3952 .21047 Mdot
.39525 .07085 Mdot
.3953 .14632 Mdot
.39534 .33508 Mdot
.39539 .47343 Mdot
.39544 .28571 Mdot
.39549 .50609 Mdot
.39553 .31848 Mdot
.39558 .46631 Mdot
.39563 .04661 Mdot
.39568 .47503 Mdot
.39572 .54921 Mdot
.39577 .33819 Mdot
.39582 .32144 Mdot
.39587 .43146 Mdot
.39592 .50369 Mdot
.39596 .42938 Mdot
.39601 .38922 Mdot
.39606 .3867 Mdot
.39611 .14367 Mdot
.39615 .08349 Mdot
.3962 .41356 Mdot
.39625 .20482 Mdot
.3963 .41493 Mdot
.39634 .47634 Mdot
.39639 .35742 Mdot
.39644 .07321 Mdot
.39649 .09456 Mdot
.39653 .01762 Mdot
.39658 .08642 Mdot
.39663 .17044 Mdot
.39668 .3794 Mdot
.39672 .15464 Mdot
.39677 .05452 Mdot
.39682 .29874 Mdot
.39687 .43352 Mdot
.39692 .41978 Mdot
.39696 .3364 Mdot
.39701 .4706 Mdot
.39706 .53316 Mdot
.39711 .59373 Mdot
.39715 .5505 Mdot
.3972 .09861 Mdot
.39725 .40419 Mdot
.3973 .52494 Mdot
.39734 .15166 Mdot
.39739 .49712 Mdot
.39744 .59258 Mdot
.39749 .06331 Mdot
.39753 .39756 Mdot
.39758 .43862 Mdot
.39763 .51273 Mdot
.39768 .06039 Mdot
.39772 .32585 Mdot
.39777 .28288 Mdot
.39782 .14803 Mdot
.39787 .50907 Mdot
.39791 .28604 Mdot
.39796 .58747 Mdot
.39801 .31784 Mdot
.39806 .104 Mdot
.39811 .55297 Mdot
.39815 .13158 Mdot
.3982 .38801 Mdot
.39825 .1136 Mdot
.3983 .01717 Mdot
.39834 .04768 Mdot
.39839 .58714 Mdot
.39844 .19199 Mdot
.39849 .46884 Mdot
.39853 .15388 Mdot
.39858 .59789 Mdot
.39863 .14339 Mdot
.39868 .08599 Mdot
.39872 .31859 Mdot
.39877 .09986 Mdot
.39882 .09771 Mdot
.39887 .36346 Mdot
.39891 .05042 Mdot
.39896 .55515 Mdot
.39901 .19196 Mdot
.39906 .09213 Mdot
.39911 .06628 Mdot
.39915 .25203 Mdot
.3992 .10267 Mdot
.39925 .14249 Mdot
.3993 .53802 Mdot
.39934 .46734 Mdot
.39939 .59239 Mdot
.39944 .14003 Mdot
.39949 .50506 Mdot
.39953 .48353 Mdot
.39958 .41511 Mdot
.39963 .27451 Mdot
.39968 .36588 Mdot
.39972 .48897 Mdot
.39977 .28643 Mdot
.39982 .20323 Mdot
.39987 .06199 Mdot
.39991 .40381 Mdot
.39996 .20343 Mdot
.40001 .44309 Mdot
.40006 .02628 Mdot
.40011 .45198 Mdot
.40015 .02618 Mdot
.4002 .36567 Mdot
.40025 .56333 Mdot
.4003 .21467 Mdot
.40034 .52684 Mdot
.40039 .23789 Mdot
.40044 .04002 Mdot
.40049 .35065 Mdot
.40053 .53777 Mdot
.40058 .11257 Mdot
.40063 .13829 Mdot
.40068 .47044 Mdot
.40072 .13737 Mdot
.40077 .44139 Mdot
.40082 .37573 Mdot
.40087 .5848 Mdot
.40091 .45427 Mdot
.40096 .25287 Mdot
.40101 .32845 Mdot
.40106 .1957 Mdot
.40111 .26555 Mdot
.40115 .41311 Mdot
.4012 .31687 Mdot
.40125 .34704 Mdot
.4013 .25408 Mdot
.40134 .06214 Mdot
.40139 .35687 Mdot
.40144 .14708 Mdot
.40149 .33057 Mdot
.40153 .42758 Mdot
.40158 .33156 Mdot
.40163 .39976 Mdot
.40168 .39613 Mdot
.40172 .32971 Mdot
.40177 .20798 Mdot
.40182 .53264 Mdot
.40187 .27346 Mdot
.40191 .49165 Mdot
.40196 .43557 Mdot
.40201 .55117 Mdot
.40206 .42252 Mdot
.40211 .25349 Mdot
.40215 .12183 Mdot
.4022 .37018 Mdot
.40225 .17167 Mdot
.4023 .44371 Mdot
.40234 .40829 Mdot
.40239 .03785 Mdot
.40244 .52092 Mdot
.40249 .39627 Mdot
.40253 .06613 Mdot
.40258 .49409 Mdot
.40263 .20505 Mdot
.40268 .57202 Mdot
.40272 .3379 Mdot
.40277 .10903 Mdot
.40282 .41225 Mdot
.40287 .25701 Mdot
.40291 .14463 Mdot
.40296 .17972 Mdot
.40301 .1535 Mdot
.40306 .36869 Mdot
.4031 .31238 Mdot
.40315 .23187 Mdot
.4032 .33431 Mdot
.40325 .12991 Mdot
.4033 .20526 Mdot
.40334 .46502 Mdot
.40339 .17734 Mdot
.40344 .28953 Mdot
.40349 .4003 Mdot
.40353 .44188 Mdot
.40358 .25975 Mdot
.40363 .49658 Mdot
.40368 .34888 Mdot
.40372 .55112 Mdot
.40377 .06941 Mdot
.40382 .52789 Mdot
.40387 .02569 Mdot
.40391 .45679 Mdot
.40396 .26048 Mdot
.40401 .28558 Mdot
.40406 .48439 Mdot
.4041 .29179 Mdot
.40415 .12169 Mdot
.4042 .52022 Mdot
.40425 .18671 Mdot
.4043 .07462 Mdot
.40434 .3907 Mdot
.40439 .40502 Mdot
.40444 .58478 Mdot
.40449 .21293 Mdot
.40453 .22807 Mdot
.40458 .1302 Mdot
.40463 .19919 Mdot
.40468 .37437 Mdot
.40472 .57165 Mdot
.40477 .23694 Mdot
.40482 .45363 Mdot
.40487 .42658 Mdot
.40491 .51695 Mdot
.40496 .31238 Mdot
.40501 .44265 Mdot
.40506 .57311 Mdot
.4051 .27118 Mdot
.40515 .0415 Mdot
.4052 .56159 Mdot
.40525 .29603 Mdot
.4053 .1642 Mdot
.40534 .12461 Mdot
.40539 .38959 Mdot
.40544 .23612 Mdot
.40549 .37682 Mdot
.40553 .32292 Mdot
.40558 .40814 Mdot
.40563 .0379 Mdot
.40568 .16346 Mdot
.40572 .20743 Mdot
.40577 .22366 Mdot
.40582 .26685 Mdot
.40587 .19514 Mdot
.40591 .57381 Mdot
.40596 .37335 Mdot
.40601 .4436 Mdot
.40606 .28151 Mdot
.4061 .27614 Mdot
.40615 .53403 Mdot
.4062 .47382 Mdot
.40625 .02505 Mdot
.4063 .24935 Mdot
.40634 .57576 Mdot
.40639 .1925 Mdot
.40644 .46417 Mdot
.40649 .13945 Mdot
.40653 .20088 Mdot
.40658 .55971 Mdot
.40663 .10206 Mdot
.40668 .41985 Mdot
.40672 .39607 Mdot
.40677 .53652 Mdot
.40682 .54193 Mdot
.40687 .22713 Mdot
.40691 .18712 Mdot
.40696 .28437 Mdot
.40701 .3615 Mdot
.40706 .25664 Mdot
.4071 .4171 Mdot
.40715 .44409 Mdot
.4072 .0947 Mdot
.40725 .58382 Mdot
.40729 .4864 Mdot
.40734 .5736 Mdot
.40739 .08436 Mdot
.40744 .34918 Mdot
.40749 .51396 Mdot
.40753 .39581 Mdot
.40758 .22351 Mdot
.40763 .22444 Mdot
.40768 .32779 Mdot
.40772 .43943 Mdot
.40777 .13616 Mdot
.40782 .40792 Mdot
.40787 .53504 Mdot
.40791 .50624 Mdot
.40796 .19755 Mdot
.40801 .19549 Mdot
.40806 .36262 Mdot
.4081 .23657 Mdot
.40815 .43937 Mdot
.4082 .54218 Mdot
.40825 .54885 Mdot
.40829 .3958 Mdot
.40834 .35939 Mdot
.40839 .56168 Mdot
.40844 .07717 Mdot
.40849 .42553 Mdot
.40853 .28973 Mdot
.40858 .22721 Mdot
.40863 .16653 Mdot
.40868 .04443 Mdot
.40872 .08093 Mdot
.40877 .01747 Mdot
.40882 .44207 Mdot
.40887 .20833 Mdot
.40891 .54809 Mdot
.40896 .21288 Mdot
.40901 .51036 Mdot
.40906 .30542 Mdot
.4091 .36525 Mdot
.40915 .03209 Mdot
.4092 .16244 Mdot
.40925 .08355 Mdot
.40929 .5292 Mdot
.40934 .09324 Mdot
.40939 .21691 Mdot
.40944 .29108 Mdot
.40949 .18452 Mdot
.40953 .13489 Mdot
.40958 .15446 Mdot
.40963 .46887 Mdot
.40968 .49812 Mdot
.40972 .511 Mdot
.40977 .59125 Mdot
.40982 .43915 Mdot
.40987 .4319 Mdot
.40991 .50824 Mdot
.40996 .16389 Mdot
.41001 .24553 Mdot
.41006 .48713 Mdot
.4101 .31007 Mdot
.41015 .25686 Mdot
.4102 .54343 Mdot
.41025 .13659 Mdot
.41029 .29268 Mdot
.41034 .10912 Mdot
.41039 .47459 Mdot
.41044 .21071 Mdot
.41049 .21415 Mdot
.41053 .49554 Mdot
.41058 .19822 Mdot
.41063 .0409 Mdot
.41068 .09397 Mdot
.41072 .35579 Mdot
.41077 .33268 Mdot
.41082 .14611 Mdot
.41087 .18629 Mdot
.41091 .36786 Mdot
.41096 .49685 Mdot
.41101 .31753 Mdot
.41106 .28138 Mdot
.4111 .21868 Mdot
.41115 .26604 Mdot
.4112 .43373 Mdot
.41125 .57463 Mdot
.41129 .56515 Mdot
.41134 .32593 Mdot
.41139 .31185 Mdot
.41144 .29666 Mdot
.41149 .47073 Mdot
.41153 .45467 Mdot
.41158 .11585 Mdot
.41163 .09722 Mdot
.41168 .57852 Mdot
.41172 .27116 Mdot
.41177 .08966 Mdot
.41182 .01795 Mdot
.41187 .23744 Mdot
.41191 .5418 Mdot
.41196 .54689 Mdot
.41201 .43499 Mdot
.41206 .47291 Mdot
.4121 .05966 Mdot
.41215 .24406 Mdot
.4122 .16832 Mdot
.41225 .26893 Mdot
.41229 .39695 Mdot
.41234 .41365 Mdot
.41239 .19701 Mdot
.41244 .30711 Mdot
.41248 .08573 Mdot
.41253 .11651 Mdot
.41258 .50367 Mdot
.41263 .4397 Mdot
.41268 .23439 Mdot
.41272 .01536 Mdot
.41277 .42116 Mdot
.41282 .4645 Mdot
.41287 .56656 Mdot
.41291 .52902 Mdot
.41296 .41792 Mdot
.41301 .24177 Mdot
.41306 .03946 Mdot
.4131 .58546 Mdot
.41315 .58626 Mdot
.4132 .37219 Mdot
.41325 .58313 Mdot
.41329 .35611 Mdot
.41334 .43265 Mdot
.41339 .11797 Mdot
.41344 .20089 Mdot
.41348 .54579 Mdot
.41353 .25035 Mdot
.41358 .41418 Mdot
.41363 .12987 Mdot
.41368 .44399 Mdot
.41372 .35 Mdot
.41377 .57781 Mdot
.41382 .4988 Mdot
.41387 .44333 Mdot
.41391 .53216 Mdot
.41396 .12801 Mdot
.41401 .53557 Mdot
.41406 .51763 Mdot
.4141 .12895 Mdot
.41415 .48957 Mdot
.4142 .51082 Mdot
.41425 .5355 Mdot
.41429 .14602 Mdot
.41434 .13209 Mdot
.41439 .53102 Mdot
.41444 .19409 Mdot
.41448 .3167 Mdot
.41453 .02883 Mdot
.41458 .34484 Mdot
.41463 .25163 Mdot
.41468 .08106 Mdot
.41472 .21797 Mdot
.41477 .22968 Mdot
.41482 .41097 Mdot
.41487 .33439 Mdot
.41491 .24349 Mdot
.41496 .3342 Mdot
.41501 .57096 Mdot
.41506 .40555 Mdot
.4151 .13019 Mdot
.41515 .40195 Mdot
.4152 .06804 Mdot
.41525 .29131 Mdot
.41529 .24395 Mdot
.41534 .49446 Mdot
.41539 .13587 Mdot
.41544 .15999 Mdot
.41548 .12657 Mdot
.41553 .56677 Mdot
.41558 .5451 Mdot
.41563 .44662 Mdot
.41568 .11245 Mdot
.41572 .23664 Mdot
.41577 .30818 Mdot
.41582 .38026 Mdot
.41587 .4978 Mdot
.41591 .02167 Mdot
.41596 .50053 Mdot
.41601 .06058 Mdot
.41606 .26902 Mdot
.4161 .29079 Mdot
.41615 .5329 Mdot
.4162 .25836 Mdot
.41625 .15354 Mdot
.41629 .49217 Mdot
.41634 .47957 Mdot
.41639 .57038 Mdot
.41644 .51292 Mdot
.41648 .60103 Mdot
.41653 .35841 Mdot
.41658 .42509 Mdot
.41663 .40106 Mdot
.41667 .04897 Mdot
.41672 .41663 Mdot
.41677 .5818 Mdot
.41682 .30332 Mdot
.41687 .41566 Mdot
.41691 .12317 Mdot
.41696 .21625 Mdot
.41701 .40885 Mdot
.41706 .4087 Mdot
.4171 .22596 Mdot
.41715 .17037 Mdot
.4172 .15454 Mdot
.41725 .13262 Mdot
.41729 .29639 Mdot
.41734 .51534 Mdot
.41739 .01571 Mdot
.41744 .24378 Mdot
.41748 .42015 Mdot
.41753 .54829 Mdot
.41758 .10612 Mdot
.41763 .24607 Mdot
.41767 .07644 Mdot
.41772 .13791 Mdot
.41777 .30838 Mdot
.41782 .2118 Mdot
.41787 .26313 Mdot
.41791 .15943 Mdot
.41796 .01977 Mdot
.41801 .39947 Mdot
.41806 .15468 Mdot
.4181 .54651 Mdot
.41815 .21425 Mdot
.4182 .59409 Mdot
.41825 .53204 Mdot
.41829 .39084 Mdot
.41834 .07441 Mdot
.41839 .47618 Mdot
.41844 .25037 Mdot
.41848 .47882 Mdot
.41853 .07341 Mdot
.41858 .24712 Mdot
.41863 .43355 Mdot
.41867 .53386 Mdot
.41872 .57062 Mdot
.41877 .01575 Mdot
.41882 .37181 Mdot
.41887 .41066 Mdot
.41891 .27694 Mdot
.41896 .40728 Mdot
.41901 .12338 Mdot
.41906 .26593 Mdot
.4191 .27188 Mdot
.41915 .02252 Mdot
.4192 .57203 Mdot
.41925 .32275 Mdot
.41929 .07235 Mdot
.41934 .03175 Mdot
.41939 .0547 Mdot
.41944 .53523 Mdot
.41948 .60126 Mdot
.41953 .15889 Mdot
.41958 .40766 Mdot
.41963 .07111 Mdot
.41967 .54256 Mdot
.41972 .5151 Mdot
.41977 .57744 Mdot
.41982 .14058 Mdot
.41987 .57526 Mdot
.41991 .51406 Mdot
.41996 .22033 Mdot
.42001 .33325 Mdot
.42006 .31303 Mdot
.4201 .12149 Mdot
.42015 .11166 Mdot
.4202 .08203 Mdot
.42025 .05585 Mdot
.42029 .11368 Mdot
.42034 .14295 Mdot
.42039 .36261 Mdot
.42044 .58683 Mdot
.42048 .09664 Mdot
.42053 .10296 Mdot
.42058 .4307 Mdot
.42063 .5889 Mdot
.42067 .54107 Mdot
.42072 .29863 Mdot
.42077 .3743 Mdot
.42082 .06105 Mdot
.42087 .04068 Mdot
.42091 .32452 Mdot
.42096 .24843 Mdot
.42101 .08911 Mdot
.42106 .12994 Mdot
.4211 .1189 Mdot
.42115 .5185 Mdot
.4212 .3794 Mdot
.42125 .02316 Mdot
.42129 .02195 Mdot
.42134 .45118 Mdot
.42139 .33826 Mdot
.42144 .51281 Mdot
.42148 .48232 Mdot
.42153 .10328 Mdot
.42158 .35475 Mdot
.42163 .43088 Mdot
.42167 .39407 Mdot
.42172 .27591 Mdot
.42177 .36918 Mdot
.42182 .49313 Mdot
.42186 .11015 Mdot
.42191 .50493 Mdot
.42196 .32285 Mdot
.42201 .46716 Mdot
.42206 .38895 Mdot
.4221 .27121 Mdot
.42215 .24845 Mdot
.4222 .35193 Mdot
.42225 .28477 Mdot
.42229 .35603 Mdot
.42234 .47237 Mdot
.42239 .34347 Mdot
.42244 .27753 Mdot
.42248 .50818 Mdot
.42253 .14882 Mdot
.42258 .43399 Mdot
.42263 .39853 Mdot
.42267 .4196 Mdot
.42272 .39739 Mdot
.42277 .01783 Mdot
.42282 .01917 Mdot
.42286 .15841 Mdot
.42291 .04291 Mdot
.42296 .12802 Mdot
.42301 .51234 Mdot
.42306 .2568 Mdot
.4231 .32339 Mdot
.42315 .26418 Mdot
.4232 .1381 Mdot
.42325 .58891 Mdot
.42329 .08965 Mdot
.42334 .51558 Mdot
.42339 .45666 Mdot
.42344 .24759 Mdot
.42348 .22061 Mdot
.42353 .18682 Mdot
.42358 .19384 Mdot
.42363 .34274 Mdot
.42367 .0865 Mdot
.42372 .35615 Mdot
.42377 .39863 Mdot
.42382 .52646 Mdot
.42386 .29244 Mdot
.42391 .35303 Mdot
.42396 .39417 Mdot
.42401 .38276 Mdot
.42406 .26423 Mdot
.4241 .23972 Mdot
.42415 .48515 Mdot
.4242 .14067 Mdot
.42425 .54416 Mdot
.42429 .57886 Mdot
.42434 .36177 Mdot
.42439 .15508 Mdot
.42444 .46922 Mdot
.42448 .07799 Mdot
.42453 .50844 Mdot
.42458 .51082 Mdot
.42463 .26332 Mdot
.42467 .49449 Mdot
.42472 .32931 Mdot
.42477 .18279 Mdot
.42482 .19153 Mdot
.42486 .15305 Mdot
.42491 .534 Mdot
.42496 .25966 Mdot
.42501 .50242 Mdot
.42506 .40334 Mdot
.4251 .15454 Mdot
.42515 .48022 Mdot
.4252 .25289 Mdot
.42525 .17833 Mdot
.42529 .27271 Mdot
.42534 .35426 Mdot
.42539 .31206 Mdot
.42544 .2028 Mdot
.42548 .51427 Mdot
.42553 .21389 Mdot
.42558 .44616 Mdot
.42563 .13952 Mdot
.42567 .02054 Mdot
.42572 .3064 Mdot
.42577 .19755 Mdot
.42582 .24835 Mdot
.42586 .29456 Mdot
.42591 .13832 Mdot
.42596 .02074 Mdot
.42601 .11001 Mdot
.42606 .36388 Mdot
.4261 .48199 Mdot
.42615 .12164 Mdot
.4262 .30999 Mdot
.42625 .22405 Mdot
.42629 .01647 Mdot
.42634 .47207 Mdot
.42639 .14637 Mdot
.42644 .55466 Mdot
.42648 .26553 Mdot
.42653 .17473 Mdot
.42658 .5469 Mdot
.42663 .0551 Mdot
.42667 .06635 Mdot
.42672 .33189 Mdot
.42677 .42208 Mdot
.42682 .04927 Mdot
.42686 .36328 Mdot
.42691 .14904 Mdot
.42696 .18844 Mdot
.42701 .35804 Mdot
.42705 .23967 Mdot
.4271 .14302 Mdot
.42715 .09313 Mdot
.4272 .59749 Mdot
.42725 .36101 Mdot
.42729 .03608 Mdot
.42734 .38646 Mdot
.42739 .38815 Mdot
.42744 .35925 Mdot
.42748 .16733 Mdot
.42753 .2548 Mdot
.42758 .43681 Mdot
.42763 .10842 Mdot
.42767 .59593 Mdot
.42772 .31123 Mdot
.42777 .39641 Mdot
.42782 .05678 Mdot
.42786 .27875 Mdot
.42791 .49247 Mdot
.42796 .36185 Mdot
.42801 .29683 Mdot
.42805 .14442 Mdot
.4281 .31875 Mdot
.42815 .01852 Mdot
.4282 .07187 Mdot
.42825 .01611 Mdot
.42829 .24032 Mdot
.42834 .02436 Mdot
.42839 .31418 Mdot
.42844 .58335 Mdot
.42848 .45718 Mdot
.42853 .23954 Mdot
.42858 .55826 Mdot
.42863 .43073 Mdot
.42867 .21709 Mdot
.42872 .40605 Mdot
.42877 .46455 Mdot
.42882 .43813 Mdot
.42886 .50918 Mdot
.42891 .02435 Mdot
.42896 .42248 Mdot
.42901 .17409 Mdot
.42905 .03142 Mdot
.4291 .26583 Mdot
.42915 .14036 Mdot
.4292 .04438 Mdot
.42925 .31599 Mdot
.42929 .26202 Mdot
.42934 .08321 Mdot
.42939 .04298 Mdot
.42944 .09038 Mdot
.42948 .25237 Mdot
.42953 .37235 Mdot
.42958 .06295 Mdot
.42963 .23652 Mdot
.42967 .02755 Mdot
.42972 .41741 Mdot
.42977 .23554 Mdot
.42982 .03414 Mdot
.42986 .22482 Mdot
.42991 .55619 Mdot
.42996 .40074 Mdot
.43001 .12829 Mdot
.43005 .21517 Mdot
.4301 .14842 Mdot
.43015 .24136 Mdot
.4302 .11158 Mdot
.43025 .55267 Mdot
.43029 .02276 Mdot
.43034 .21169 Mdot
.43039 .39891 Mdot
.43044 .30536 Mdot
.43048 .54288 Mdot
.43053 .18343 Mdot
.43058 .32324 Mdot
.43063 .0677 Mdot
.43067 .18524 Mdot
.43072 .13519 Mdot
.43077 .10142 Mdot
.43082 .05486 Mdot
.43086 .37116 Mdot
.43091 .50297 Mdot
.43096 .08199 Mdot
.43101 .43337 Mdot
.43105 .41829 Mdot
.4311 .11694 Mdot
.43115 .55703 Mdot
.4312 .2329 Mdot
.43124 .28458 Mdot
.43129 .4789 Mdot
.43134 .46016 Mdot
.43139 .28356 Mdot
.43144 .27653 Mdot
.43148 .28192 Mdot
.43153 .07596 Mdot
.43158 .58152 Mdot
.43163 .33697 Mdot
.43167 .1132 Mdot
.43172 .35605 Mdot
.43177 .52854 Mdot
.43182 .16643 Mdot
.43186 .58134 Mdot
.43191 .26933 Mdot
.43196 .48839 Mdot
.43201 .3986 Mdot
.43205 .09307 Mdot
.4321 .20205 Mdot
.43215 .06973 Mdot
.4322 .58363 Mdot
.43224 .57946 Mdot
.43229 .24834 Mdot
.43234 .44015 Mdot
.43239 .31376 Mdot
.43244 .11526 Mdot
.43248 .3915 Mdot
.43253 .1713 Mdot
.43258 .05194 Mdot
.43263 .43667 Mdot
.43267 .33025 Mdot
.43272 .19311 Mdot
.43277 .31829 Mdot
.43282 .33818 Mdot
.43286 .57753 Mdot
.43291 .2679 Mdot
.43296 .16657 Mdot
.43301 .36017 Mdot
.43305 .3229 Mdot
.4331 .38284 Mdot
.43315 .3713 Mdot
.4332 .28181 Mdot
.43324 .13556 Mdot
.43329 .32782 Mdot
.43334 .39099 Mdot
.43339 .30567 Mdot
.43344 .49055 Mdot
.43348 .49099 Mdot
.43353 .09194 Mdot
.43358 .20512 Mdot
.43363 .11375 Mdot
.43367 .3344 Mdot
.43372 .05471 Mdot
.43377 .37177 Mdot
.43382 .38682 Mdot
.43386 .156 Mdot
.43391 .33974 Mdot
.43396 .0483 Mdot
.43401 .41262 Mdot
.43405 .49143 Mdot
.4341 .18788 Mdot
.43415 .29145 Mdot
.4342 .10442 Mdot
.43424 .1233 Mdot
.43429 .41991 Mdot
.43434 .02435 Mdot
.43439 .57219 Mdot
.43444 .39881 Mdot
.43448 .04363 Mdot
.43453 .322 Mdot
.43458 .09635 Mdot
.43463 .51115 Mdot
.43467 .55501 Mdot
.43472 .13159 Mdot
.43477 .58592 Mdot
.43482 .19146 Mdot
.43486 .51501 Mdot
.43491 .36315 Mdot
.43496 .2138 Mdot
.43501 .05016 Mdot
.43505 .18998 Mdot
.4351 .32956 Mdot
.43515 .40451 Mdot
.4352 .16206 Mdot
.43524 .0168 Mdot
.43529 .05282 Mdot
.43534 .31479 Mdot
.43539 .05346 Mdot
.43544 .20022 Mdot
.43548 .04318 Mdot
.43553 .34593 Mdot
.43558 .25798 Mdot
.43563 .1713 Mdot
.43567 .3245 Mdot
.43572 .26429 Mdot
.43577 .35016 Mdot
.43582 .21961 Mdot
.43586 .20762 Mdot
.43591 .2817 Mdot
.43596 .17341 Mdot
.43601 .30792 Mdot
.43605 .4478 Mdot
.4361 .0826 Mdot
.43615 .13795 Mdot
.4362 .13265 Mdot
.43624 .13295 Mdot
.43629 .28142 Mdot
.43634 .57922 Mdot
.43639 .13056 Mdot
.43643 .09484 Mdot
.43648 .56995 Mdot
.43653 .54046 Mdot
.43658 .53367 Mdot
.43663 .06637 Mdot
.43667 .23873 Mdot
.43672 .29719 Mdot
.43677 .37708 Mdot
.43682 .34519 Mdot
.43686 .57776 Mdot
.43691 .55036 Mdot
.43696 .17218 Mdot
.43701 .15228 Mdot
.43705 .31077 Mdot
.4371 .39166 Mdot
.43715 .46759 Mdot
.4372 .3078 Mdot
.43724 .24287 Mdot
.43729 .26842 Mdot
.43734 .34964 Mdot
.43739 .18956 Mdot
.43743 .56478 Mdot
.43748 .29252 Mdot
.43753 .23379 Mdot
.43758 .10943 Mdot
.43763 .59815 Mdot
.43767 .35538 Mdot
.43772 .30345 Mdot
.43777 .05778 Mdot
.43782 .37413 Mdot
.43786 .0729 Mdot
.43791 .52969 Mdot
.43796 .31591 Mdot
.43801 .3997 Mdot
.43805 .12586 Mdot
.4381 .37222 Mdot
.43815 .17835 Mdot
.4382 .10364 Mdot
.43824 .33752 Mdot
.43829 .50796 Mdot
.43834 .47387 Mdot
.43839 .46409 Mdot
.43843 .08382 Mdot
.43848 .17302 Mdot
.43853 .29902 Mdot
.43858 .50263 Mdot
.43863 .39462 Mdot
.43867 .54256 Mdot
.43872 .20429 Mdot
.43877 .50781 Mdot
.43882 .05394 Mdot
.43886 .25382 Mdot
.43891 .16123 Mdot
.43896 .14838 Mdot
.43901 .58437 Mdot
.43905 .32745 Mdot
.4391 .44864 Mdot
.43915 .35201 Mdot
.4392 .47322 Mdot
.43924 .55856 Mdot
.43929 .285 Mdot
.43934 .26308 Mdot
.43939 .1504 Mdot
.43943 .06531 Mdot
.43948 .41446 Mdot
.43953 .40232 Mdot
.43958 .08129 Mdot
.43963 .49561 Mdot
.43967 .13015 Mdot
.43972 .50302 Mdot
.43977 .29 Mdot
.43982 .55638 Mdot
.43986 .52918 Mdot
.43991 .59854 Mdot
.43996 .25077 Mdot
.44001 .31727 Mdot
.44005 .38266 Mdot
.4401 .46486 Mdot
.44015 .26973 Mdot
.4402 .59314 Mdot
.44024 .53735 Mdot
.44029 .12756 Mdot
.44034 .39983 Mdot
.44039 .04929 Mdot
.44043 .26705 Mdot
.44048 .4678 Mdot
.44053 .26414 Mdot
.44058 .58731 Mdot
.44062 .45592 Mdot
.44067 .08019 Mdot
.44072 .19756 Mdot
.44077 .1064 Mdot
.44082 .34049 Mdot
.44086 .1805 Mdot
.44091 .51088 Mdot
.44096 .15335 Mdot
.44101 .41464 Mdot
.44105 .18529 Mdot
.4411 .27482 Mdot
.44115 .43941 Mdot
.4412 .04668 Mdot
.44124 .32375 Mdot
.44129 .0198 Mdot
.44134 .44959 Mdot
.44139 .11266 Mdot
.44143 .2109 Mdot
.44148 .2233 Mdot
.44153 .415 Mdot
.44158 .44894 Mdot
.44162 .34642 Mdot
.44167 .56248 Mdot
.44172 .43102 Mdot
.44177 .59634 Mdot
.44182 .28095 Mdot
.44186 .37963 Mdot
.44191 .33933 Mdot
.44196 .27056 Mdot
.44201 .11516 Mdot
.44205 .47208 Mdot
.4421 .20068 Mdot
.44215 .45925 Mdot
.4422 .5332 Mdot
.44224 .21196 Mdot
.44229 .3646 Mdot
.44234 .42727 Mdot
.44239 .22416 Mdot
.44243 .20687 Mdot
.44248 .51834 Mdot
.44253 .32932 Mdot
.44258 .02797 Mdot
.44262 .5869 Mdot
.44267 .11804 Mdot
.44272 .48371 Mdot
.44277 .28487 Mdot
.44282 .03913 Mdot
.44286 .29035 Mdot
.44291 .49069 Mdot
.44296 .01863 Mdot
.44301 .26282 Mdot
.44305 .55435 Mdot
.4431 .23484 Mdot
.44315 .5068 Mdot
.4432 .39407 Mdot
.44324 .36837 Mdot
.44329 .37892 Mdot
.44334 .57692 Mdot
.44339 .19682 Mdot
.44343 .01848 Mdot
.44348 .55497 Mdot
.44353 .36747 Mdot
.44358 .59327 Mdot
.44362 .10347 Mdot
.44367 .24036 Mdot
.44372 .35421 Mdot
.44377 .02108 Mdot
.44382 .58875 Mdot
.44386 .35998 Mdot
.44391 .08405 Mdot
.44396 .58528 Mdot
.44401 .31311 Mdot
.44405 .47261 Mdot
.4441 .08013 Mdot
.44415 .33717 Mdot
.4442 .36209 Mdot
.44424 .25248 Mdot
.44429 .17666 Mdot
.44434 .54642 Mdot
.44439 .59705 Mdot
.44443 .47688 Mdot
.44448 .20306 Mdot
.44453 .36431 Mdot
.44458 .59328 Mdot
.44462 .52524 Mdot
.44467 .43891 Mdot
.44472 .37436 Mdot
.44477 .50452 Mdot
.44482 .29958 Mdot
.44486 .09941 Mdot
.44491 .36798 Mdot
.44496 .51909 Mdot
.44501 .54293 Mdot
.44505 .03006 Mdot
.4451 .38603 Mdot
.44515 .22069 Mdot
.4452 .08502 Mdot
.44524 .55326 Mdot
.44529 .06357 Mdot
.44534 .46192 Mdot
.44539 .43587 Mdot
.44543 .39131 Mdot
.44548 .12048 Mdot
.44553 .4682 Mdot
.44558 .56232 Mdot
.44562 .20295 Mdot
.44567 .3595 Mdot
.44572 .47825 Mdot
.44577 .05179 Mdot
.44581 .36736 Mdot
.44586 .58846 Mdot
.44591 .57706 Mdot
.44596 .35553 Mdot
.44601 .28266 Mdot
.44605 .23519 Mdot
.4461 .07267 Mdot
.44615 .41593 Mdot
.4462 .26731 Mdot
.44624 .45248 Mdot
.44629 .45531 Mdot
.44634 .34562 Mdot
.44639 .31738 Mdot
.44643 .40362 Mdot
.44648 .59671 Mdot
.44653 .51307 Mdot
.44658 .5294 Mdot
.44662 .29785 Mdot
.44667 .14322 Mdot
.44672 .55408 Mdot
.44677 .34115 Mdot
.44681 .54168 Mdot
.44686 .26829 Mdot
.44691 .51699 Mdot
.44696 .57712 Mdot
.44701 .55655 Mdot
.44705 .29456 Mdot
.4471 .17617 Mdot
.44715 .30916 Mdot
.4472 .33607 Mdot
.44724 .2366 Mdot
.44729 .36356 Mdot
.44734 .05656 Mdot
.44739 .48691 Mdot
.44743 .38461 Mdot
.44748 .03265 Mdot
.44753 .34251 Mdot
.44758 .098 Mdot
.44762 .39123 Mdot
.44767 .12291 Mdot
.44772 .41644 Mdot
.44777 .40347 Mdot
.44781 .26272 Mdot
.44786 .17216 Mdot
.44791 .09 Mdot
.44796 .46511 Mdot
.44801 .59776 Mdot
.44805 .25849 Mdot
.4481 .11621 Mdot
.44815 .51189 Mdot
.4482 .3179 Mdot
.44824 .09703 Mdot
.44829 .41037 Mdot
.44834 .19053 Mdot
.44839 .09602 Mdot
.44843 .3368 Mdot
.44848 .36851 Mdot
.44853 .30695 Mdot
.44858 .31473 Mdot
.44862 .31886 Mdot
.44867 .04071 Mdot
.44872 .22366 Mdot
.44877 .52682 Mdot
.44881 .21066 Mdot
.44886 .22759 Mdot
.44891 .42352 Mdot
.44896 .27881 Mdot
.44901 .0532 Mdot
.44905 .1523 Mdot
.4491 .56173 Mdot
.44915 .28438 Mdot
.4492 .39804 Mdot
.44924 .0508 Mdot
.44929 .06454 Mdot
.44934 .5698 Mdot
.44939 .31571 Mdot
.44943 .24376 Mdot
.44948 .47734 Mdot
.44953 .48849 Mdot
.44958 .58224 Mdot
.44962 .47857 Mdot
.44967 .1851 Mdot
.44972 .18847 Mdot
.44977 .27809 Mdot
.44981 .45257 Mdot
.44986 .56477 Mdot
.44991 .26498 Mdot
.44996 .08214 Mdot
.45 .23969 Mdot
.45005 .15596 Mdot
.4501 .58949 Mdot
.45015 .04365 Mdot
.4502 .10209 Mdot
.45024 .19756 Mdot
.45029 .31982 Mdot
.45034 .24894 Mdot
.45039 .066 Mdot
.45043 .14772 Mdot
.45048 .35335 Mdot
.45053 .53655 Mdot
.45058 .42557 Mdot
.45062 .27371 Mdot
.45067 .46818 Mdot
.45072 .55764 Mdot
.45077 .55033 Mdot
.45081 .10332 Mdot
.45086 .29442 Mdot
.45091 .29426 Mdot
.45096 .11247 Mdot
.451 .14188 Mdot
.45105 .04415 Mdot
.4511 .22683 Mdot
.45115 .4761 Mdot
.4512 .58924 Mdot
.45124 .05798 Mdot
.45129 .19789 Mdot
.45134 .38872 Mdot
.45139 .40639 Mdot
.45143 .34149 Mdot
.45148 .55228 Mdot
.45153 .33743 Mdot
.45158 .27338 Mdot
.45162 .59146 Mdot
.45167 .03044 Mdot
.45172 .51518 Mdot
.45177 .603 Mdot
.45181 .13798 Mdot
.45186 .07612 Mdot
.45191 .56818 Mdot
.45196 .51439 Mdot
.452 .44689 Mdot
.45205 .38519 Mdot
.4521 .47043 Mdot
.45215 .38723 Mdot
.4522 .41745 Mdot
.45224 .17307 Mdot
.45229 .59765 Mdot
.45234 .40131 Mdot
.45239 .37417 Mdot
.45243 .57851 Mdot
.45248 .22364 Mdot
.45253 .59824 Mdot
.45258 .04739 Mdot
.45262 .04093 Mdot
.45267 .48954 Mdot
.45272 .33957 Mdot
.45277 .05926 Mdot
.45281 .02521 Mdot
.45286 .57768 Mdot
.45291 .33989 Mdot
.45296 .5246 Mdot
.453 .55241 Mdot
.45305 .0242 Mdot
.4531 .42882 Mdot
.45315 .09242 Mdot
.4532 .18193 Mdot
.45324 .1571 Mdot
.45329 .0563 Mdot
.45334 .2783 Mdot
.45339 .02357 Mdot
.45343 .16278 Mdot
.45348 .25832 Mdot
.45353 .50745 Mdot
.45358 .04839 Mdot
.45362 .54247 Mdot
.45367 .2634 Mdot
.45372 .47477 Mdot
.45377 .02217 Mdot
.45381 .06764 Mdot
.45386 .52716 Mdot
.45391 .43022 Mdot
.45396 .60028 Mdot
.454 .09329 Mdot
.45405 .20198 Mdot
.4541 .50894 Mdot
.45415 .06258 Mdot
.4542 .0838 Mdot
.45424 .37649 Mdot
.45429 .43123 Mdot
.45434 .48398 Mdot
.45439 .53002 Mdot
.45443 .33489 Mdot
.45448 .16764 Mdot
.45453 .47511 Mdot
.45458 .38195 Mdot
.45462 .09128 Mdot
.45467 .26351 Mdot
.45472 .44143 Mdot
.45477 .44281 Mdot
.45481 .43121 Mdot
.45486 .39207 Mdot
.45491 .43397 Mdot
.45496 .38988 Mdot
.455 .50737 Mdot
.45505 .56518 Mdot
.4551 .43701 Mdot
.45515 .3113 Mdot
.45519 .3201 Mdot
.45524 .07095 Mdot
.45529 .38914 Mdot
.45534 .24221 Mdot
.45539 .54694 Mdot
.45543 .24304 Mdot
.45548 .50849 Mdot
.45553 .31552 Mdot
.45558 .22675 Mdot
.45562 .09011 Mdot
.45567 .04809 Mdot
.45572 .53689 Mdot
.45577 .15018 Mdot
.45581 .42992 Mdot
.45586 .20998 Mdot
.45591 .10879 Mdot
.45596 .3223 Mdot
.456 .05255 Mdot
.45605 .37933 Mdot
.4561 .32224 Mdot
.45615 .41825 Mdot
.45619 .0907 Mdot
.45624 .54564 Mdot
.45629 .02565 Mdot
.45634 .11286 Mdot
.45639 .03446 Mdot
.45643 .17121 Mdot
.45648 .38676 Mdot
.45653 .16924 Mdot
.45658 .39475 Mdot
.45662 .26605 Mdot
.45667 .08595 Mdot
.45672 .54581 Mdot
.45677 .31935 Mdot
.45681 .23267 Mdot
.45686 .15239 Mdot
.45691 .41034 Mdot
.45696 .49276 Mdot
.457 .03739 Mdot
.45705 .0583 Mdot
.4571 .10276 Mdot
.45715 .45491 Mdot
.45719 .26139 Mdot
.45724 .33939 Mdot
.45729 .28783 Mdot
.45734 .37892 Mdot
.45739 .31907 Mdot
.45743 .32845 Mdot
.45748 .18968 Mdot
.45753 .35917 Mdot
.45758 .16257 Mdot
.45762 .54502 Mdot
.45767 .03515 Mdot
.45772 .56775 Mdot
.45777 .49985 Mdot
.45781 .47378 Mdot
.45786 .09266 Mdot
.45791 .26311 Mdot
.45796 .28189 Mdot
.458 .3361 Mdot
.45805 .28564 Mdot
.4581 .37368 Mdot
.45815 .2592 Mdot
.45819 .2925 Mdot
.45824 .19759 Mdot
.45829 .5221 Mdot
.45834 .60114 Mdot
.45839 .55643 Mdot
.45843 .51308 Mdot
.45848 .15788 Mdot
.45853 .29678 Mdot
.45858 .24269 Mdot
.45862 .33811 Mdot
.45867 .40204 Mdot
.45872 .14892 Mdot
.45877 .301 Mdot
.45881 .31767 Mdot
.45886 .43761 Mdot
.45891 .2524 Mdot
.45896 .43055 Mdot
.459 .23972 Mdot
.45905 .18921 Mdot
.4591 .57384 Mdot
.45915 .10916 Mdot
.45919 .5574 Mdot
.45924 .41886 Mdot
.45929 .32935 Mdot
.45934 .41998 Mdot
.45939 .37452 Mdot
.45943 .50009 Mdot
.45948 .33154 Mdot
.45953 .46687 Mdot
.45958 .46476 Mdot
.45962 .35691 Mdot
.45967 .04947 Mdot
.45972 .23889 Mdot
.45977 .14136 Mdot
.45981 .5582 Mdot
.45986 .50387 Mdot
.45991 .54122 Mdot
.45996 .42702 Mdot
.46 .13529 Mdot
.46005 .26618 Mdot
.4601 .12538 Mdot
.46015 .20201 Mdot
.46019 .54941 Mdot
.46024 .29566 Mdot
.46029 .03093 Mdot
.46034 .24793 Mdot
.46038 .14526 Mdot
.46043 .56963 Mdot
.46048 .21428 Mdot
.46053 .47674 Mdot
.46058 .2485 Mdot
.46062 .25281 Mdot
.46067 .35073 Mdot
.46072 .02669 Mdot
.46077 .49491 Mdot
.46081 .21805 Mdot
.46086 .12655 Mdot
.46091 .48865 Mdot
.46096 .54004 Mdot
.461 .31751 Mdot
.46105 .18866 Mdot
.4611 .07634 Mdot
.46115 .41946 Mdot
.46119 .06604 Mdot
.46124 .07798 Mdot
.46129 .47766 Mdot
.46134 .47338 Mdot
.46138 .37371 Mdot
.46143 .06176 Mdot
.46148 .24443 Mdot
.46153 .34283 Mdot
.46158 .4074 Mdot
.46162 .45081 Mdot
.46167 .37101 Mdot
.46172 .10904 Mdot
.46177 .1693 Mdot
.46181 .11478 Mdot
.46186 .35903 Mdot
.46191 .21745 Mdot
.46196 .55457 Mdot
.462 .59155 Mdot
.46205 .47371 Mdot
.4621 .28073 Mdot
.46215 .25178 Mdot
.46219 .41761 Mdot
.46224 .41208 Mdot
.46229 .4646 Mdot
.46234 .20045 Mdot
.46238 .35433 Mdot
.46243 .53775 Mdot
.46248 .59454 Mdot
.46253 .43007 Mdot
.46258 .30728 Mdot
.46262 .30802 Mdot
.46267 .26642 Mdot
.46272 .03738 Mdot
.46277 .4598 Mdot
.46281 .54034 Mdot
.46286 .1721 Mdot
.46291 .47141 Mdot
.46296 .35973 Mdot
.463 .19601 Mdot
.46305 .55797 Mdot
.4631 .52016 Mdot
.46315 .3715 Mdot
.46319 .32563 Mdot
.46324 .29195 Mdot
.46329 .28309 Mdot
.46334 .55722 Mdot
.46338 .51688 Mdot
.46343 .43068 Mdot
.46348 .09735 Mdot
.46353 .21759 Mdot
.46358 .58246 Mdot
.46362 .43946 Mdot
.46367 .27061 Mdot
.46372 .51364 Mdot
.46377 .28914 Mdot
.46381 .18774 Mdot
.46386 .24794 Mdot
.46391 .06855 Mdot
.46396 .35213 Mdot
.464 .03036 Mdot
.46405 .37986 Mdot
.4641 .31215 Mdot
.46415 .17083 Mdot
.46419 .07571 Mdot
.46424 .46303 Mdot
.46429 .54398 Mdot
.46434 .44853 Mdot
.46438 .38708 Mdot
.46443 .19465 Mdot
.46448 .59009 Mdot
.46453 .53497 Mdot
.46457 .55973 Mdot
.46462 .112 Mdot
.46467 .3872 Mdot
.46472 .55584 Mdot
.46477 .13498 Mdot
.46481 .44472 Mdot
.46486 .47689 Mdot
.46491 .28141 Mdot
.46496 .55056 Mdot
.465 .21148 Mdot
.46505 .42305 Mdot
.4651 .5326 Mdot
.46515 .53491 Mdot
.46519 .43495 Mdot
.46524 .1256 Mdot
.46529 .37648 Mdot
.46534 .47391 Mdot
.46538 .57525 Mdot
.46543 .18495 Mdot
.46548 .53128 Mdot
.46553 .10154 Mdot
.46557 .39531 Mdot
.46562 .19818 Mdot
.46567 .59963 Mdot
.46572 .14513 Mdot
.46577 .29801 Mdot
.46581 .4143 Mdot
.46586 .0585 Mdot
.46591 .02486 Mdot
.46596 .45662 Mdot
.466 .54074 Mdot
.46605 .38041 Mdot
.4661 .07763 Mdot
.46615 .25985 Mdot
.46619 .1324 Mdot
.46624 .45114 Mdot
.46629 .14604 Mdot
.46634 .42823 Mdot
.46638 .02151 Mdot
.46643 .08937 Mdot
.46648 .27546 Mdot
.46653 .45631 Mdot
.46657 .43989 Mdot
.46662 .16142 Mdot
.46667 .18863 Mdot
.46672 .07571 Mdot
.46677 .25642 Mdot
.46681 .16512 Mdot
.46686 .05821 Mdot
.46691 .38102 Mdot
.46696 .44544 Mdot
.467 .12133 Mdot
.46705 .04806 Mdot
.4671 .52772 Mdot
.46715 .50803 Mdot
.46719 .34424 Mdot
.46724 .57375 Mdot
.46729 .28258 Mdot
.46734 .39033 Mdot
.46738 .49642 Mdot
.46743 .44242 Mdot
.46748 .45768 Mdot
.46753 .38354 Mdot
.46757 .42176 Mdot
.46762 .18167 Mdot
.46767 .01608 Mdot
.46772 .54697 Mdot
.46777 .27505 Mdot
.46781 .59637 Mdot
.46786 .5437 Mdot
.46791 .30527 Mdot
.46796 .12465 Mdot
.468 .55287 Mdot
.46805 .17739 Mdot
.4681 .46315 Mdot
.46815 .01803 Mdot
.46819 .51952 Mdot
.46824 .25299 Mdot
.46829 .55845 Mdot
.46834 .27711 Mdot
.46838 .54909 Mdot
.46843 .57374 Mdot
.46848 .18283 Mdot
.46853 .38402 Mdot
.46857 .12138 Mdot
.46862 .13077 Mdot
.46867 .40261 Mdot
.46872 .56558 Mdot
.46877 .54303 Mdot
.46881 .12939 Mdot
.46886 .45897 Mdot
.46891 .30523 Mdot
.46896 .54999 Mdot
.469 .18902 Mdot
.46905 .16841 Mdot
.4691 .1953 Mdot
.46915 .60045 Mdot
.46919 .02634 Mdot
.46924 .30858 Mdot
.46929 .19198 Mdot
.46934 .09564 Mdot
.46938 .37667 Mdot
.46943 .35345 Mdot
.46948 .51819 Mdot
.46953 .14987 Mdot
.46957 .40625 Mdot
.46962 .18534 Mdot
.46967 .14888 Mdot
.46972 .0432 Mdot
.46976 .2902 Mdot
.46981 .38605 Mdot
.46986 .18663 Mdot
.46991 .1035 Mdot
.46996 .17551 Mdot
.47 .53041 Mdot
.47005 .48472 Mdot
.4701 .15683 Mdot
.47015 .58982 Mdot
.47019 .37671 Mdot
.47024 .30413 Mdot
.47029 .15971 Mdot
.47034 .57819 Mdot
.47038 .08284 Mdot
.47043 .12687 Mdot
.47048 .07878 Mdot
.47053 .21623 Mdot
.47057 .33271 Mdot
.47062 .212 Mdot
.47067 .53224 Mdot
.47072 .4133 Mdot
.47076 .16208 Mdot
.47081 .07783 Mdot
.47086 .50374 Mdot
.47091 .13782 Mdot
.47096 .37936 Mdot
.471 .49453 Mdot
.47105 .41495 Mdot
.4711 .56563 Mdot
.47115 .45227 Mdot
.47119 .02452 Mdot
.47124 .27283 Mdot
.47129 .57914 Mdot
.47134 .09028 Mdot
.47138 .32371 Mdot
.47143 .12783 Mdot
.47148 .01565 Mdot
.47153 .02215 Mdot
.47157 .21155 Mdot
.47162 .06375 Mdot
.47167 .40275 Mdot
.47172 .29276 Mdot
.47176 .60287 Mdot
.47181 .13484 Mdot
.47186 .59277 Mdot
.47191 .14539 Mdot
.47196 .53975 Mdot
.472 .23443 Mdot
.47205 .46966 Mdot
.4721 .36936 Mdot
.47215 .05993 Mdot
.47219 .4228 Mdot
.47224 .50736 Mdot
.47229 .52041 Mdot
.47234 .05012 Mdot
.47238 .16468 Mdot
.47243 .53154 Mdot
.47248 .44485 Mdot
.47253 .32974 Mdot
.47257 .05156 Mdot
.47262 .5306 Mdot
.47267 .43741 Mdot
.47272 .1329 Mdot
.47276 .59113 Mdot
.47281 .14256 Mdot
.47286 .15935 Mdot
.47291 .13335 Mdot
.47296 .471 Mdot
.473 .15311 Mdot
.47305 .02867 Mdot
.4731 .19693 Mdot
.47315 .25128 Mdot
.47319 .28678 Mdot
.47324 .26263 Mdot
.47329 .15171 Mdot
.47334 .43181 Mdot
.47338 .38275 Mdot
.47343 .34554 Mdot
.47348 .1163 Mdot
.47353 .28184 Mdot
.47357 .45453 Mdot
.47362 .50402 Mdot
.47367 .38989 Mdot
.47372 .24499 Mdot
.47376 .52726 Mdot
.47381 .08133 Mdot
.47386 .27169 Mdot
.47391 .25718 Mdot
.47395 .39941 Mdot
.474 .5253 Mdot
.47405 .15305 Mdot
.4741 .38951 Mdot
.47415 .261 Mdot
.47419 .51134 Mdot
.47424 .55944 Mdot
.47429 .15293 Mdot
.47434 .57755 Mdot
.47438 .26342 Mdot
.47443 .42244 Mdot
.47448 .32445 Mdot
.47453 .20951 Mdot
.47457 .5212 Mdot
.47462 .32085 Mdot
.47467 .05732 Mdot
.47472 .35831 Mdot
.47476 .03188 Mdot
.47481 .53429 Mdot
.47486 .41566 Mdot
.47491 .43438 Mdot
.47495 .55389 Mdot
.475 .2773 Mdot
.47505 .17319 Mdot
.4751 .04968 Mdot
.47515 .04329 Mdot
.47519 .13896 Mdot
.47524 .38701 Mdot
.47529 .392 Mdot
.47534 .13528 Mdot
.47538 .18284 Mdot
.47543 .24878 Mdot
.47548 .41778 Mdot
.47553 .47519 Mdot
.47557 .36373 Mdot
.47562 .52765 Mdot
.47567 .22297 Mdot
.47572 .55731 Mdot
.47576 .05759 Mdot
.47581 .48504 Mdot
.47586 .46799 Mdot
.47591 .54014 Mdot
.47595 .12663 Mdot
.476 .08409 Mdot
.47605 .04832 Mdot
.4761 .58958 Mdot
.47615 .45265 Mdot
.47619 .51422 Mdot
.47624 .60197 Mdot
.47629 .56099 Mdot
.47634 .3284 Mdot
.47638 .14192 Mdot
.47643 .22468 Mdot
.47648 .44042 Mdot
.47653 .16027 Mdot
.47657 .49647 Mdot
.47662 .41023 Mdot
.47667 .56856 Mdot
.47672 .39986 Mdot
.47676 .57214 Mdot
.47681 .20196 Mdot
.47686 .02595 Mdot
.47691 .35698 Mdot
.47695 .10181 Mdot
.477 .3373 Mdot
.47705 .08914 Mdot
.4771 .24506 Mdot
.47715 .03243 Mdot
.47719 .30368 Mdot
.47724 .10289 Mdot
.47729 .39573 Mdot
.47734 .12153 Mdot
.47738 .30503 Mdot
.47743 .14523 Mdot
.47748 .08204 Mdot
.47753 .58293 Mdot
.47757 .09506 Mdot
.47762 .30813 Mdot
.47767 .5251 Mdot
.47772 .10117 Mdot
.47776 .28816 Mdot
.47781 .3429 Mdot
.47786 .13995 Mdot
.47791 .13236 Mdot
.47795 .1009 Mdot
.478 .33166 Mdot
.47805 .38629 Mdot
.4781 .04526 Mdot
.47815 .36693 Mdot
.47819 .25722 Mdot
.47824 .15594 Mdot
.47829 .02754 Mdot
.47834 .07796 Mdot
.47838 .16904 Mdot
.47843 .36354 Mdot
.47848 .50933 Mdot
.47853 .37625 Mdot
.47857 .03852 Mdot
.47862 .2962 Mdot
.47867 .52973 Mdot
.47872 .2959 Mdot
.47876 .33372 Mdot
.47881 .37443 Mdot
.47886 .44326 Mdot
.47891 .02245 Mdot
.47895 .59414 Mdot
.479 .24919 Mdot
.47905 .32562 Mdot
.4791 .52487 Mdot
.47914 .27719 Mdot
.47919 .46622 Mdot
.47924 .29507 Mdot
.47929 .17265 Mdot
.47934 .03468 Mdot
.47938 .32498 Mdot
.47943 .28224 Mdot
.47948 .1094 Mdot
.47953 .46896 Mdot
.47957 .56477 Mdot
.47962 .37623 Mdot
.47967 .33647 Mdot
.47972 .44515 Mdot
.47976 .28328 Mdot
.47981 .44983 Mdot
.47986 .05528 Mdot
.47991 .12614 Mdot
.47995 .51217 Mdot
.48 .02128 Mdot
.48005 .04754 Mdot
.4801 .13532 Mdot
.48014 .27769 Mdot
.48019 .29899 Mdot
.48024 .12599 Mdot
.48029 .46146 Mdot
.48034 .4148 Mdot
.48038 .01863 Mdot
.48043 .55667 Mdot
.48048 .44149 Mdot
.48053 .10452 Mdot
.48057 .33971 Mdot
.48062 .46198 Mdot
.48067 .57585 Mdot
.48072 .14308 Mdot
.48076 .5668 Mdot
.48081 .14022 Mdot
.48086 .14542 Mdot
.48091 .46313 Mdot
.48095 .13168 Mdot
.481 .09965 Mdot
.48105 .03399 Mdot
.4811 .55428 Mdot
.48114 .12511 Mdot
.48119 .06682 Mdot
.48124 .50199 Mdot
.48129 .2913 Mdot
.48134 .42945 Mdot
.48138 .54416 Mdot
.48143 .05524 Mdot
.48148 .47982 Mdot
.48153 .42554 Mdot
.48157 .59082 Mdot
.48162 .21708 Mdot
.48167 .39001 Mdot
.48172 .10053 Mdot
.48176 .14355 Mdot
.48181 .24455 Mdot
.48186 .26164 Mdot
.48191 .13705 Mdot
.48195 .01804 Mdot
.482 .11384 Mdot
.48205 .40184 Mdot
.4821 .02008 Mdot
.48214 .52172 Mdot
.48219 .09456 Mdot
.48224 .45088 Mdot
.48229 .49829 Mdot
.48234 .4696 Mdot
.48238 .1959 Mdot
.48243 .17429 Mdot
.48248 .08355 Mdot
.48253 .52877 Mdot
.48257 .15537 Mdot
.48262 .2978 Mdot
.48267 .26134 Mdot
.48272 .54127 Mdot
.48276 .54161 Mdot
.48281 .51112 Mdot
.48286 .17551 Mdot
.48291 .41243 Mdot
.48295 .31177 Mdot
.483 .26419 Mdot
.48305 .05317 Mdot
.4831 .40909 Mdot
.48314 .21263 Mdot
.48319 .46568 Mdot
.48324 .0478 Mdot
.48329 .4907 Mdot
.48333 .13278 Mdot
.48338 .02951 Mdot
.48343 .15283 Mdot
.48348 .03581 Mdot
.48353 .5402 Mdot
.48357 .45854 Mdot
.48362 .08399 Mdot
.48367 .11037 Mdot
.48372 .39955 Mdot
.48376 .17545 Mdot
.48381 .42598 Mdot
.48386 .17243 Mdot
.48391 .46126 Mdot
.48395 .26766 Mdot
.484 .26517 Mdot
.48405 .36332 Mdot
.4841 .1642 Mdot
.48414 .01818 Mdot
.48419 .22671 Mdot
.48424 .55756 Mdot
.48429 .55489 Mdot
.48433 .15582 Mdot
.48438 .19362 Mdot
.48443 .08156 Mdot
.48448 .43682 Mdot
.48453 .14103 Mdot
.48457 .0555 Mdot
.48462 .06046 Mdot
.48467 .49995 Mdot
.48472 .28581 Mdot
.48476 .57484 Mdot
.48481 .55341 Mdot
.48486 .11511 Mdot
.48491 .12507 Mdot
.48495 .16357 Mdot
.485 .3957 Mdot
.48505 .25717 Mdot
.4851 .46074 Mdot
.48514 .50172 Mdot
.48519 .04708 Mdot
.48524 .10768 Mdot
.48529 .45727 Mdot
.48533 .28971 Mdot
.48538 .09285 Mdot
.48543 .15612 Mdot
.48548 .31615 Mdot
.48553 .1108 Mdot
.48557 .026 Mdot
.48562 .32262 Mdot
.48567 .18984 Mdot
.48572 .07 Mdot
.48576 .56886 Mdot
.48581 .426 Mdot
.48586 .50735 Mdot
.48591 .09849 Mdot
.48595 .03016 Mdot
.486 .3256 Mdot
.48605 .39699 Mdot
.4861 .53825 Mdot
.48614 .23779 Mdot
.48619 .08313 Mdot
.48624 .53957 Mdot
.48629 .05124 Mdot
.48633 .20542 Mdot
.48638 .57878 Mdot
.48643 .09701 Mdot
.48648 .36486 Mdot
.48653 .12728 Mdot
.48657 .43737 Mdot
.48662 .38418 Mdot
.48667 .26877 Mdot
.48672 .11599 Mdot
.48676 .12946 Mdot
.48681 .20906 Mdot
.48686 .21347 Mdot
.48691 .15045 Mdot
.48695 .30679 Mdot
.487 .30503 Mdot
.48705 .12969 Mdot
.4871 .135 Mdot
.48714 .58452 Mdot
.48719 .51137 Mdot
.48724 .19476 Mdot
.48729 .50054 Mdot
.48733 .51609 Mdot
.48738 .57512 Mdot
.48743 .15823 Mdot
.48748 .30983 Mdot
.48753 .54064 Mdot
.48757 .49282 Mdot
.48762 .3967 Mdot
.48767 .19726 Mdot
.48772 .11798 Mdot
.48776 .12335 Mdot
.48781 .14264 Mdot
.48786 .09598 Mdot
.48791 .59184 Mdot
.48795 .51762 Mdot
.488 .53249 Mdot
.48805 .54885 Mdot
.4881 .29976 Mdot
.48814 .22729 Mdot
.48819 .41751 Mdot
.48824 .42856 Mdot
.48829 .31857 Mdot
.48833 .31925 Mdot
.48838 .23746 Mdot
.48843 .53134 Mdot
.48848 .4058 Mdot
.48852 .34745 Mdot
.48857 .09394 Mdot
.48862 .23622 Mdot
.48867 .46849 Mdot
.48872 .45795 Mdot
.48876 .30057 Mdot
.48881 .05366 Mdot
.48886 .36522 Mdot
.48891 .34932 Mdot
.48895 .17263 Mdot
.489 .56101 Mdot
.48905 .3767 Mdot
.4891 .43503 Mdot
.48914 .24346 Mdot
.48919 .02686 Mdot
.48924 .09165 Mdot
.48929 .22244 Mdot
.48933 .42928 Mdot
.48938 .20163 Mdot
.48943 .3764 Mdot
.48948 .50652 Mdot
.48952 .20652 Mdot
.48957 .27362 Mdot
.48962 .57393 Mdot
.48967 .17378 Mdot
.48972 .12729 Mdot
.48976 .05211 Mdot
.48981 .12014 Mdot
.48986 .31915 Mdot
.48991 .43005 Mdot
.48995 .60177 Mdot
.49 .35825 Mdot
.49005 .57316 Mdot
.4901 .27213 Mdot
.49014 .05548 Mdot
.49019 .58487 Mdot
.49024 .15284 Mdot
.49029 .04337 Mdot
.49033 .04332 Mdot
.49038 .50793 Mdot
.49043 .53373 Mdot
.49048 .21742 Mdot
.49052 .44502 Mdot
.49057 .14623 Mdot
.49062 .04192 Mdot
.49067 .02561 Mdot
.49072 .18611 Mdot
.49076 .17563 Mdot
.49081 .47146 Mdot
.49086 .50164 Mdot
.49091 .14871 Mdot
.49095 .0702 Mdot
.491 .16702 Mdot
.49105 .08629 Mdot
.4911 .15026 Mdot
.49114 .31527 Mdot
.49119 .19719 Mdot
.49124 .41749 Mdot
.49129 .10949 Mdot
.49133 .33373 Mdot
.49138 .05906 Mdot
.49143 .38883 Mdot
.49148 .08088 Mdot
.49152 .42912 Mdot
.49157 .12865 Mdot
.49162 .18612 Mdot
.49167 .23918 Mdot
.49172 .2976 Mdot
.49176 .10145 Mdot
.49181 .17522 Mdot
.49186 .06779 Mdot
.49191 .13667 Mdot
.49195 .23331 Mdot
.492 .27691 Mdot
.49205 .5224 Mdot
.4921 .08118 Mdot
.49214 .081 Mdot
.49219 .20532 Mdot
.49224 .38686 Mdot
.49229 .36923 Mdot
.49233 .48713 Mdot
.49238 .39116 Mdot
.49243 .29207 Mdot
.49248 .05021 Mdot
.49252 .44279 Mdot
.49257 .01704 Mdot
.49262 .22591 Mdot
.49267 .22441 Mdot
.49272 .32884 Mdot
.49276 .43424 Mdot
.49281 .59005 Mdot
.49286 .53014 Mdot
.49291 .2421 Mdot
.49295 .27373 Mdot
.493 .53697 Mdot
.49305 .40818 Mdot
.4931 .0235 Mdot
.49314 .60015 Mdot
.49319 .02927 Mdot
.49324 .3417 Mdot
.49329 .54583 Mdot
.49333 .40954 Mdot
.49338 .24574 Mdot
.49343 .57579 Mdot
.49348 .0734 Mdot
.49352 .03309 Mdot
.49357 .55699 Mdot
.49362 .54028 Mdot
.49367 .23394 Mdot
.49371 .03076 Mdot
.49376 .3458 Mdot
.49381 .33058 Mdot
.49386 .50843 Mdot
.49391 .19984 Mdot
.49395 .35907 Mdot
.494 .40376 Mdot
.49405 .28104 Mdot
.4941 .52944 Mdot
.49414 .42543 Mdot
.49419 .59891 Mdot
.49424 .27225 Mdot
.49429 .53261 Mdot
.49433 .41086 Mdot
.49438 .27192 Mdot
.49443 .32974 Mdot
.49448 .13778 Mdot
.49452 .17983 Mdot
.49457 .29946 Mdot
.49462 .27105 Mdot
.49467 .1194 Mdot
.49471 .22616 Mdot
.49476 .3625 Mdot
.49481 .05181 Mdot
.49486 .10334 Mdot
.49491 .48369 Mdot
.49495 .04663 Mdot
.495 .14671 Mdot
.49505 .50682 Mdot
.4951 .13932 Mdot
.49514 .24619 Mdot
.49519 .469 Mdot
.49524 .58071 Mdot
.49529 .31722 Mdot
.49533 .2506 Mdot
.49538 .21146 Mdot
.49543 .06281 Mdot
.49548 .50968 Mdot
.49552 .58201 Mdot
.49557 .48504 Mdot
.49562 .52836 Mdot
.49567 .34457 Mdot
.49571 .29726 Mdot
.49576 .2287 Mdot
.49581 .42367 Mdot
.49586 .13312 Mdot
.49591 .53808 Mdot
.49595 .1916 Mdot
.496 .33503 Mdot
.49605 .25276 Mdot
.4961 .50617 Mdot
.49614 .0596 Mdot
.49619 .43153 Mdot
.49624 .12814 Mdot
.49629 .27468 Mdot
.49633 .19393 Mdot
.49638 .45415 Mdot
.49643 .41425 Mdot
.49648 .03879 Mdot
.49652 .5858 Mdot
.49657 .40604 Mdot
.49662 .50789 Mdot
.49667 .06011 Mdot
.49671 .11547 Mdot
.49676 .48101 Mdot
.49681 .17803 Mdot
.49686 .36618 Mdot
.49691 .49009 Mdot
.49695 .07205 Mdot
.497 .05963 Mdot
.49705 .43142 Mdot
.4971 .3132 Mdot
.49714 .34034 Mdot
.49719 .4102 Mdot
.49724 .52858 Mdot
.49729 .2683 Mdot
.49733 .51213 Mdot
.49738 .29676 Mdot
.49743 .26861 Mdot
.49748 .08908 Mdot
.49752 .0727 Mdot
.49757 .48584 Mdot
.49762 .24452 Mdot
.49767 .1066 Mdot
.49771 .26998 Mdot
.49776 .58127 Mdot
.49781 .19912 Mdot
.49786 .59446 Mdot
.4979 .3923 Mdot
.49795 .41795 Mdot
.498 .43627 Mdot
.49805 .11908 Mdot
.4981 .33495 Mdot
.49814 .37303 Mdot
.49819 .01956 Mdot
.49824 .40921 Mdot
.49829 .59794 Mdot
.49833 .56616 Mdot
.49838 .0943 Mdot
.49843 .15562 Mdot
.49848 .10051 Mdot
.49852 .2841 Mdot
.49857 .42902 Mdot
.49862 .08125 Mdot
.49867 .04253 Mdot
.49871 .40159 Mdot
.49876 .1992 Mdot
.49881 .57797 Mdot
.49886 .37587 Mdot
.4989 .42365 Mdot
.49895 .01479 Mdot
.499 .58684 Mdot
.49905 .5869 Mdot
.4991 .02041 Mdot
.49914 .18185 Mdot
.49919 .48247 Mdot
.49924 .26665 Mdot
.49929 .25071 Mdot
.49933 .177 Mdot
.49938 .08797 Mdot
.49943 .27204 Mdot
.49948 .28787 Mdot
.49952 .09741 Mdot
.49957 .53567 Mdot
.49962 .18624 Mdot
.49967 .01848 Mdot
.49971 .27172 Mdot
.49976 .46913 Mdot
.49981 .15842 Mdot
.49986 .22021 Mdot
.4999 .08722 Mdot
.49995 .49449 Mdot
.5 .38587 Mdot
.50005 .39989 Mdot
.5001 .08714 Mdot
.50014 .51097 Mdot
.50019 .4023 Mdot
.50024 .39419 Mdot
.50029 .50862 Mdot
.50033 .04322 Mdot
.50038 .15035 Mdot
.50043 .1582 Mdot
.50048 .34632 Mdot
.50052 .55858 Mdot
.50057 .48164 Mdot
.50062 .47365 Mdot
.50067 .26362 Mdot
.50071 .03761 Mdot
.50076 .31011 Mdot
.50081 .46988 Mdot
.50086 .59523 Mdot
.5009 .1718 Mdot
.50095 .1664 Mdot
.501 .26437 Mdot
.50105 .52272 Mdot
.5011 .28064 Mdot
.50114 .38385 Mdot
.50119 .4678 Mdot
.50124 .45029 Mdot
.50129 .37299 Mdot
.50133 .58488 Mdot
.50138 .08832 Mdot
.50143 .545 Mdot
.50148 .34448 Mdot
.50152 .44923 Mdot
.50157 .53345 Mdot
.50162 .21338 Mdot
.50167 .38923 Mdot
.50171 .57092 Mdot
.50176 .07451 Mdot
.50181 .55309 Mdot
.50186 .36633 Mdot
.5019 .27552 Mdot
.50195 .20796 Mdot
.502 .56118 Mdot
.50205 .20924 Mdot
.5021 .12382 Mdot
.50214 .54692 Mdot
.50219 .05317 Mdot
.50224 .53193 Mdot
.50229 .3433 Mdot
.50233 .09382 Mdot
.50238 .20621 Mdot
.50243 .17364 Mdot
.50248 .36174 Mdot
.50252 .02021 Mdot
.50257 .26454 Mdot
.50262 .43249 Mdot
.50267 .51583 Mdot
.50271 .09008 Mdot
.50276 .06586 Mdot
.50281 .05796 Mdot
.50286 .54824 Mdot
.5029 .03028 Mdot
.50295 .1161 Mdot
.503 .29495 Mdot
.50305 .28743 Mdot
.50309 .42564 Mdot
.50314 .15825 Mdot
.50319 .10042 Mdot
.50324 .17832 Mdot
.50329 .48205 Mdot
.50333 .11978 Mdot
.50338 .17182 Mdot
.50343 .43835 Mdot
.50348 .40294 Mdot
.50352 .51689 Mdot
.50357 .6015 Mdot
.50362 .09131 Mdot
.50367 .39744 Mdot
.50371 .26706 Mdot
.50376 .18373 Mdot
.50381 .1788 Mdot
.50386 .32207 Mdot
.5039 .21591 Mdot
.50395 .14048 Mdot
.504 .23389 Mdot
.50405 .3065 Mdot
.50409 .11451 Mdot
.50414 .44885 Mdot
.50419 .54978 Mdot
.50424 .48418 Mdot
.50429 .55959 Mdot
.50433 .36313 Mdot
.50438 .38618 Mdot
.50443 .01684 Mdot
.50448 .45452 Mdot
.50452 .20602 Mdot
.50457 .55116 Mdot
.50462 .21722 Mdot
.50467 .54095 Mdot
.50471 .20784 Mdot
.50476 .47455 Mdot
.50481 .4231 Mdot
.50486 .2886 Mdot
.5049 .03882 Mdot
.50495 .31046 Mdot
.505 .11575 Mdot
.50505 .0874 Mdot
.50509 .50167 Mdot
.50514 .09127 Mdot
.50519 .41257 Mdot
.50524 .57621 Mdot
.50529 .06753 Mdot
.50533 .14481 Mdot
.50538 .53172 Mdot
.50543 .03132 Mdot
.50548 .30773 Mdot
.50552 .36196 Mdot
.50557 .52959 Mdot
.50562 .18013 Mdot
.50567 .11642 Mdot
.50571 .41413 Mdot
.50576 .32708 Mdot
.50581 .2425 Mdot
.50586 .51191 Mdot
.5059 .54291 Mdot
.50595 .5073 Mdot
.506 .55723 Mdot
.50605 .4878 Mdot
.50609 .24716 Mdot
.50614 .40626 Mdot
.50619 .48454 Mdot
.50624 .58945 Mdot
.50629 .1706 Mdot
.50633 .59702 Mdot
.50638 .51165 Mdot
.50643 .53663 Mdot
.50648 .04049 Mdot
.50652 .08 Mdot
.50657 .49504 Mdot
.50662 .24361 Mdot
.50667 .28185 Mdot
.50671 .15374 Mdot
.50676 .32962 Mdot
.50681 .14191 Mdot
.50686 .47104 Mdot
.5069 .42998 Mdot
.50695 .10183 Mdot
.507 .23333 Mdot
.50705 .53146 Mdot
.50709 .526 Mdot
.50714 .14793 Mdot
.50719 .34885 Mdot
.50724 .29901 Mdot
.50728 .13445 Mdot
.50733 .26672 Mdot
.50738 .36273 Mdot
.50743 .14312 Mdot
.50748 .14076 Mdot
.50752 .35839 Mdot
.50757 .42942 Mdot
.50762 .11734 Mdot
.50767 .07546 Mdot
.50771 .46668 Mdot
.50776 .20052 Mdot
.50781 .43881 Mdot
.50786 .52505 Mdot
.5079 .15176 Mdot
.50795 .07332 Mdot
.508 .57109 Mdot
.50805 .10978 Mdot
.50809 .06464 Mdot
.50814 .44332 Mdot
.50819 .05434 Mdot
.50824 .1871 Mdot
.50828 .52004 Mdot
.50833 .10917 Mdot
.50838 .35865 Mdot
.50843 .06736 Mdot
.50848 .26803 Mdot
.50852 .34977 Mdot
.50857 .23024 Mdot
.50862 .52993 Mdot
.50867 .51297 Mdot
.50871 .52367 Mdot
.50876 .12761 Mdot
.50881 .46918 Mdot
.50886 .061 Mdot
.5089 .33787 Mdot
.50895 .29213 Mdot
.509 .54745 Mdot
.50905 .51256 Mdot
.50909 .27926 Mdot
.50914 .32436 Mdot
.50919 .45238 Mdot
.50924 .46263 Mdot
.50928 .43926 Mdot
.50933 .28473 Mdot
.50938 .27999 Mdot
.50943 .54591 Mdot
.50948 .3448 Mdot
.50952 .5294 Mdot
.50957 .22734 Mdot
.50962 .29259 Mdot
.50967 .59835 Mdot
.50971 .31387 Mdot
.50976 .30073 Mdot
.50981 .38294 Mdot
.50986 .08939 Mdot
.5099 .20096 Mdot
.50995 .43488 Mdot
.51 .33665 Mdot
.51005 .35484 Mdot
.51009 .51216 Mdot
.51014 .49076 Mdot
.51019 .42741 Mdot
.51024 .0903 Mdot
.51028 .20251 Mdot
.51033 .05309 Mdot
.51038 .5681 Mdot
.51043 .25436 Mdot
.51048 .52111 Mdot
.51052 .37642 Mdot
.51057 .0369 Mdot
.51062 .51289 Mdot
.51067 .59503 Mdot
.51071 .1638 Mdot
.51076 .34764 Mdot
.51081 .51786 Mdot
.51086 .29588 Mdot
.5109 .46639 Mdot
.51095 .56803 Mdot
.511 .44318 Mdot
.51105 .10962 Mdot
.51109 .04622 Mdot
.51114 .24609 Mdot
.51119 .10305 Mdot
.51124 .20078 Mdot
.51128 .15878 Mdot
.51133 .42201 Mdot
.51138 .02746 Mdot
.51143 .6016 Mdot
.51148 .1204 Mdot
.51152 .45723 Mdot
.51157 .37643 Mdot
.51162 .0952 Mdot
.51167 .34731 Mdot
.51171 .43503 Mdot
.51176 .46687 Mdot
.51181 .10349 Mdot
.51186 .19822 Mdot
.5119 .1021 Mdot
.51195 .55233 Mdot
.512 .41094 Mdot
.51205 .33515 Mdot
.51209 .1374 Mdot
.51214 .12386 Mdot
.51219 .31602 Mdot
.51224 .30364 Mdot
.51228 .49464 Mdot
.51233 .03552 Mdot
.51238 .12995 Mdot
.51243 .15957 Mdot
.51247 .08734 Mdot
.51252 .02276 Mdot
.51257 .13168 Mdot
.51262 .05387 Mdot
.51267 .23344 Mdot
.51271 .24966 Mdot
.51276 .05119 Mdot
.51281 .30989 Mdot
.51286 .40173 Mdot
.5129 .38612 Mdot
.51295 .55102 Mdot
.513 .12639 Mdot
.51305 .31434 Mdot
.51309 .43711 Mdot
.51314 .15479 Mdot
.51319 .39456 Mdot
.51324 .19164 Mdot
.51328 .32796 Mdot
.51333 .4421 Mdot
.51338 .10562 Mdot
.51343 .30033 Mdot
.51347 .30715 Mdot
.51352 .32686 Mdot
.51357 .54938 Mdot
.51362 .22769 Mdot
.51367 .2991 Mdot
.51371 .20989 Mdot
.51376 .51021 Mdot
.51381 .59758 Mdot
.51386 .06415 Mdot
.5139 .17341 Mdot
.51395 .21503 Mdot
.514 .21055 Mdot
.51405 .28136 Mdot
.51409 .22571 Mdot
.51414 .10335 Mdot
.51419 .49954 Mdot
.51424 .44757 Mdot
.51428 .08563 Mdot
.51433 .31212 Mdot
.51438 .32261 Mdot
.51443 .13432 Mdot
.51447 .24686 Mdot
.51452 .2212 Mdot
.51457 .03699 Mdot
.51462 .43049 Mdot
.51467 .52333 Mdot
.51471 .27515 Mdot
.51476 .41262 Mdot
.51481 .1461 Mdot
.51486 .32815 Mdot
.5149 .36826 Mdot
.51495 .41837 Mdot
.515 .09666 Mdot
.51505 .16944 Mdot
.51509 .16794 Mdot
.51514 .22253 Mdot
.51519 .41863 Mdot
.51524 .54706 Mdot
.51528 .0793 Mdot
.51533 .32631 Mdot
.51538 .57438 Mdot
.51543 .47614 Mdot
.51547 .37051 Mdot
.51552 .01841 Mdot
.51557 .45477 Mdot
.51562 .244 Mdot
.51567 .16402 Mdot
.51571 .58475 Mdot
.51576 .03899 Mdot
.51581 .324 Mdot
.51586 .49219 Mdot
.5159 .18683 Mdot
.51595 .49621 Mdot
.516 .59918 Mdot
.51605 .13864 Mdot
.51609 .37179 Mdot
.51614 .41425 Mdot
.51619 .44444 Mdot
.51624 .57402 Mdot
.51628 .16397 Mdot
.51633 .59895 Mdot
.51638 .50071 Mdot
.51643 .50943 Mdot
.51647 .44098 Mdot
.51652 .03927 Mdot
.51657 .03927 Mdot
.51662 .15363 Mdot
.51667 .43728 Mdot
.51671 .18783 Mdot
.51676 .3986 Mdot
.51681 .59294 Mdot
.51686 .45586 Mdot
.5169 .16355 Mdot
.51695 .08931 Mdot
.517 .11545 Mdot
.51705 .28374 Mdot
.51709 .27067 Mdot
.51714 .09346 Mdot
.51719 .58014 Mdot
.51724 .51528 Mdot
.51728 .45974 Mdot
.51733 .25235 Mdot
.51738 .02082 Mdot
.51743 .36602 Mdot
.51747 .46412 Mdot
.51752 .35497 Mdot
.51757 .11472 Mdot
.51762 .52836 Mdot
.51766 .43955 Mdot
.51771 .33041 Mdot
.51776 .56441 Mdot
.51781 .10579 Mdot
.51786 .26643 Mdot
.5179 .53513 Mdot
.51795 .5748 Mdot
.518 .25325 Mdot
.51805 .11759 Mdot
.51809 .46053 Mdot
.51814 .47406 Mdot
.51819 .57284 Mdot
.51824 .45025 Mdot
.51828 .38177 Mdot
.51833 .49724 Mdot
.51838 .07227 Mdot
.51843 .59384 Mdot
.51847 .14413 Mdot
.51852 .49113 Mdot
.51857 .30958 Mdot
.51862 .14443 Mdot
.51866 .39248 Mdot
.51871 .39112 Mdot
.51876 .38454 Mdot
.51881 .30821 Mdot
.51886 .07678 Mdot
.5189 .43004 Mdot
.51895 .29347 Mdot
.519 .05648 Mdot
.51905 .14498 Mdot
.51909 .45856 Mdot
.51914 .05492 Mdot
.51919 .54221 Mdot
.51924 .28778 Mdot
.51928 .58783 Mdot
.51933 .08541 Mdot
.51938 .10667 Mdot
.51943 .50933 Mdot
.51947 .1053 Mdot
.51952 .02785 Mdot
.51957 .11615 Mdot
.51962 .37992 Mdot
.51966 .21749 Mdot
.51971 .3216 Mdot
.51976 .57505 Mdot
.51981 .59076 Mdot
.51986 .42969 Mdot
.5199 .54038 Mdot
.51995 .28155 Mdot
.52 .52868 Mdot
.52005 .60298 Mdot
.52009 .26162 Mdot
.52014 .23977 Mdot
.52019 .39841 Mdot
.52024 .15912 Mdot
.52028 .22141 Mdot
.52033 .30089 Mdot
.52038 .12534 Mdot
.52043 .17462 Mdot
.52047 .15071 Mdot
.52052 .20893 Mdot
.52057 .21933 Mdot
.52062 .08403 Mdot
.52066 .13757 Mdot
.52071 .10748 Mdot
.52076 .44274 Mdot
.52081 .46986 Mdot
.52086 .41929 Mdot
.5209 .13576 Mdot
.52095 .45531 Mdot
.521 .05488 Mdot
.52105 .48224 Mdot
.52109 .45754 Mdot
.52114 .52995 Mdot
.52119 .05522 Mdot
.52124 .23532 Mdot
.52128 .23247 Mdot
.52133 .14625 Mdot
.52138 .49942 Mdot
.52143 .02862 Mdot
.52147 .53491 Mdot
.52152 .03562 Mdot
.52157 .33952 Mdot
.52162 .48124 Mdot
.52166 .34069 Mdot
.52171 .41961 Mdot
.52176 .2702 Mdot
.52181 .35838 Mdot
.52185 .24792 Mdot
.5219 .5802 Mdot
.52195 .40366 Mdot
.522 .54241 Mdot
.52205 .12687 Mdot
.52209 .1396 Mdot
.52214 .36349 Mdot
.52219 .07489 Mdot
.52224 .27265 Mdot
.52228 .21297 Mdot
.52233 .32298 Mdot
.52238 .44289 Mdot
.52243 .05489 Mdot
.52247 .08143 Mdot
.52252 .42688 Mdot
.52257 .42898 Mdot
.52262 .1233 Mdot
.52266 .06052 Mdot
.52271 .10207 Mdot
.52276 .55107 Mdot
.52281 .38593 Mdot
.52285 .24423 Mdot
.5229 .4352 Mdot
.52295 .2074 Mdot
.523 .15272 Mdot
.52305 .26736 Mdot
.52309 .04625 Mdot
.52314 .26831 Mdot
.52319 .04056 Mdot
.52324 .14247 Mdot
.52328 .28608 Mdot
.52333 .20813 Mdot
.52338 .37123 Mdot
.52343 .53283 Mdot
.52347 .56643 Mdot
.52352 .36856 Mdot
.52357 .33105 Mdot
.52362 .4661 Mdot
.52366 .15426 Mdot
.52371 .54291 Mdot
.52376 .22246 Mdot
.52381 .42029 Mdot
.52385 .06689 Mdot
.5239 .59516 Mdot
.52395 .43985 Mdot
.524 .19077 Mdot
.52405 .23502 Mdot
.52409 .40248 Mdot
.52414 .30184 Mdot
.52419 .52673 Mdot
.52424 .20348 Mdot
.52428 .14888 Mdot
.52433 .27599 Mdot
.52438 .39897 Mdot
.52443 .52073 Mdot
.52447 .54407 Mdot
.52452 .50809 Mdot
.52457 .46947 Mdot
.52462 .55762 Mdot
.52466 .19022 Mdot
.52471 .19175 Mdot
.52476 .01807 Mdot
.52481 .41808 Mdot
.52485 .25064 Mdot
.5249 .57262 Mdot
.52495 .20111 Mdot
.525 .36589 Mdot
.52505 .2588 Mdot
.52509 .14747 Mdot
.52514 .02505 Mdot
.52519 .14558 Mdot
.52524 .45965 Mdot
.52528 .44896 Mdot
.52533 .10164 Mdot
.52538 .54542 Mdot
.52543 .32548 Mdot
.52547 .18768 Mdot
.52552 .306 Mdot
.52557 .0394 Mdot
.52562 .38473 Mdot
.52566 .28292 Mdot
.52571 .43985 Mdot
.52576 .0851 Mdot
.52581 .20922 Mdot
.52585 .10588 Mdot
.5259 .43649 Mdot
.52595 .27035 Mdot
.526 .56191 Mdot
.52605 .13659 Mdot
.52609 .25009 Mdot
.52614 .50779 Mdot
.52619 .31781 Mdot
.52624 .59244 Mdot
.52628 .23975 Mdot
.52633 .37692 Mdot
.52638 .46149 Mdot
.52643 .15819 Mdot
.52647 .15282 Mdot
.52652 .43482 Mdot
.52657 .15072 Mdot
.52662 .57384 Mdot
.52666 .45015 Mdot
.52671 .41013 Mdot
.52676 .36931 Mdot
.52681 .30563 Mdot
.52685 .02501 Mdot
.5269 .33973 Mdot
.52695 .1748 Mdot
.527 .21445 Mdot
.52704 .19184 Mdot
.52709 .08409 Mdot
.52714 .21622 Mdot
.52719 .09257 Mdot
.52724 .54507 Mdot
.52728 .17962 Mdot
.52733 .50173 Mdot
.52738 .10345 Mdot
.52743 .32003 Mdot
.52747 .40603 Mdot
.52752 .05495 Mdot
.52757 .54858 Mdot
.52762 .18191 Mdot
.52766 .57454 Mdot
.52771 .50756 Mdot
.52776 .57807 Mdot
.52781 .33509 Mdot
.52785 .17912 Mdot
.5279 .15296 Mdot
.52795 .28715 Mdot
.528 .32479 Mdot
.52804 .44271 Mdot
.52809 .58148 Mdot
.52814 .08741 Mdot
.52819 .14766 Mdot
.52824 .37334 Mdot
.52828 .37997 Mdot
.52833 .59817 Mdot
.52838 .20591 Mdot
.52843 .20842 Mdot
.52847 .48156 Mdot
.52852 .50943 Mdot
.52857 .48921 Mdot
.52862 .40572 Mdot
.52866 .44132 Mdot
.52871 .56417 Mdot
.52876 .322 Mdot
.52881 .43451 Mdot
.52885 .53708 Mdot
.5289 .58943 Mdot
.52895 .59024 Mdot
.529 .2701 Mdot
.52904 .39883 Mdot
.52909 .31699 Mdot
.52914 .28016 Mdot
.52919 .43071 Mdot
.52924 .42068 Mdot
.52928 .24428 Mdot
.52933 .14721 Mdot
.52938 .07208 Mdot
.52943 .05542 Mdot
.52947 .24944 Mdot
.52952 .54462 Mdot
.52957 .46698 Mdot
.52962 .17718 Mdot
.52966 .34333 Mdot
.52971 .07012 Mdot
.52976 .07597 Mdot
.52981 .33919 Mdot
.52985 .38248 Mdot
.5299 .35144 Mdot
.52995 .24479 Mdot
.53 .40544 Mdot
.53004 .39638 Mdot
.53009 .36453 Mdot
.53014 .57802 Mdot
.53019 .02131 Mdot
.53024 .0941 Mdot
.53028 .09908 Mdot
.53033 .16201 Mdot
.53038 .20396 Mdot
.53043 .45314 Mdot
.53047 .5552 Mdot
.53052 .10464 Mdot
.53057 .16325 Mdot
.53062 .21841 Mdot
.53066 .02529 Mdot
.53071 .24099 Mdot
.53076 .58939 Mdot
.53081 .4784 Mdot
.53085 .55849 Mdot
.5309 .17972 Mdot
.53095 .26491 Mdot
.531 .11063 Mdot
.53104 .22176 Mdot
.53109 .53826 Mdot
.53114 .46279 Mdot
.53119 .31758 Mdot
.53123 .46055 Mdot
.53128 .56357 Mdot
.53133 .45619 Mdot
.53138 .23818 Mdot
.53143 .37618 Mdot
.53147 .41626 Mdot
.53152 .26694 Mdot
.53157 .38837 Mdot
.53162 .42431 Mdot
.53166 .32633 Mdot
.53171 .11839 Mdot
.53176 .18466 Mdot
.53181 .41373 Mdot
.53185 .10005 Mdot
.5319 .13232 Mdot
.53195 .30958 Mdot
.532 .45857 Mdot
.53204 .52365 Mdot
.53209 .47074 Mdot
.53214 .21366 Mdot
.53219 .25152 Mdot
.53223 .58872 Mdot
.53228 .02266 Mdot
.53233 .49941 Mdot
.53238 .39429 Mdot
.53243 .03986 Mdot
.53247 .16979 Mdot
.53252 .27594 Mdot
.53257 .03282 Mdot
.53262 .22692 Mdot
.53266 .50618 Mdot
.53271 .4909 Mdot
.53276 .21183 Mdot
.53281 .50391 Mdot
.53285 .4025 Mdot
.5329 .32094 Mdot
.53295 .40142 Mdot
.533 .41857 Mdot
.53304 .28488 Mdot
.53309 .02607 Mdot
.53314 .54618 Mdot
.53319 .49824 Mdot
.53323 .41747 Mdot
.53328 .41573 Mdot
.53333 .30936 Mdot
.53338 .51285 Mdot
.53343 .40952 Mdot
.53347 .51965 Mdot
.53352 .5184 Mdot
.53357 .4877 Mdot
.53362 .25444 Mdot
.53366 .25842 Mdot
.53371 .50029 Mdot
.53376 .27549 Mdot
.53381 .35158 Mdot
.53385 .37085 Mdot
.5339 .30317 Mdot
.53395 .37491 Mdot
.534 .55241 Mdot
.53404 .06461 Mdot
.53409 .50507 Mdot
.53414 .55966 Mdot
.53419 .28223 Mdot
.53423 .05325 Mdot
.53428 .56222 Mdot
.53433 .07613 Mdot
.53438 .46809 Mdot
.53443 .24084 Mdot
.53447 .26757 Mdot
.53452 .1666 Mdot
.53457 .07328 Mdot
.53462 .32452 Mdot
.53466 .3525 Mdot
.53471 .28222 Mdot
.53476 .42217 Mdot
.53481 .0808 Mdot
.53485 .45553 Mdot
.5349 .02144 Mdot
.53495 .08529 Mdot
.535 .31328 Mdot
.53504 .16707 Mdot
.53509 .24985 Mdot
.53514 .13621 Mdot
.53519 .26338 Mdot
.53523 .26533 Mdot
.53528 .29352 Mdot
.53533 .45731 Mdot
.53538 .22484 Mdot
.53543 .30643 Mdot
.53547 .2321 Mdot
.53552 .59255 Mdot
.53557 .58732 Mdot
.53562 .05357 Mdot
.53566 .08021 Mdot
.53571 .53398 Mdot
.53576 .27751 Mdot
.53581 .3044 Mdot
.53585 .40132 Mdot
.5359 .12652 Mdot
.53595 .21142 Mdot
.536 .4522 Mdot
.53604 .39459 Mdot
.53609 .05594 Mdot
.53614 .50146 Mdot
.53619 .29983 Mdot
.53623 .15944 Mdot
.53628 .52305 Mdot
.53633 .25279 Mdot
.53638 .04921 Mdot
.53642 .46925 Mdot
.53647 .08045 Mdot
.53652 .04266 Mdot
.53657 .3461 Mdot
.53662 .25186 Mdot
.53666 .09122 Mdot
.53671 .05867 Mdot
.53676 .30724 Mdot
.53681 .18635 Mdot
.53685 .16057 Mdot
.5369 .38448 Mdot
.53695 .01754 Mdot
.537 .38836 Mdot
.53704 .04875 Mdot
.53709 .18777 Mdot
.53714 .16867 Mdot
.53719 .5971 Mdot
.53723 .59614 Mdot
.53728 .28963 Mdot
.53733 .47217 Mdot
.53738 .45236 Mdot
.53742 .0878 Mdot
.53747 .05155 Mdot
.53752 .43766 Mdot
.53757 .58644 Mdot
.53762 .02207 Mdot
.53766 .02359 Mdot
.53771 .10627 Mdot
.53776 .34929 Mdot
.53781 .53417 Mdot
.53785 .56825 Mdot
.5379 .40236 Mdot
.53795 .17765 Mdot
.538 .38831 Mdot
.53804 .19848 Mdot
.53809 .39952 Mdot
.53814 .39261 Mdot
.53819 .35426 Mdot
.53823 .02542 Mdot
.53828 .24556 Mdot
.53833 .39884 Mdot
.53838 .36145 Mdot
.53842 .33911 Mdot
.53847 .37672 Mdot
.53852 .5498 Mdot
.53857 .28835 Mdot
.53862 .30227 Mdot
.53866 .54238 Mdot
.53871 .56669 Mdot
.53876 .28099 Mdot
.53881 .29338 Mdot
.53885 .45082 Mdot
.5389 .2321 Mdot
.53895 .35015 Mdot
.539 .32846 Mdot
.53904 .06317 Mdot
.53909 .06916 Mdot
.53914 .56517 Mdot
.53919 .14468 Mdot
.53923 .26697 Mdot
.53928 .27987 Mdot
.53933 .22561 Mdot
.53938 .13397 Mdot
.53942 .03612 Mdot
.53947 .48436 Mdot
.53952 .46749 Mdot
.53957 .39819 Mdot
.53962 .26272 Mdot
.53966 .53788 Mdot
.53971 .19385 Mdot
.53976 .11063 Mdot
.53981 .32367 Mdot
.53985 .57452 Mdot
.5399 .51618 Mdot
.53995 .42057 Mdot
.54 .47617 Mdot
.54004 .35713 Mdot
.54009 .18074 Mdot
.54014 .10682 Mdot
.54019 .42771 Mdot
.54023 .30268 Mdot
.54028 .21889 Mdot
.54033 .56547 Mdot
.54038 .17545 Mdot
.54042 .03752 Mdot
.54047 .59661 Mdot
.54052 .4462 Mdot
.54057 .15404 Mdot
.54061 .15649 Mdot
.54066 .14382 Mdot
.54071 .06272 Mdot
.54076 .49464 Mdot
.54081 .22193 Mdot
.54085 .5533 Mdot
.5409 .55542 Mdot
.54095 .18568 Mdot
.541 .25073 Mdot
.54104 .05183 Mdot
.54109 .14956 Mdot
.54114 .31283 Mdot
.54119 .49693 Mdot
.54123 .47442 Mdot
.54128 .05745 Mdot
.54133 .48845 Mdot
.54138 .20895 Mdot
.54142 .27024 Mdot
.54147 .09531 Mdot
.54152 .32771 Mdot
.54157 .18614 Mdot
.54161 .27696 Mdot
.54166 .25243 Mdot
.54171 .18838 Mdot
.54176 .04437 Mdot
.54181 .14784 Mdot
.54185 .20442 Mdot
.5419 .29707 Mdot
.54195 .42576 Mdot
.542 .19787 Mdot
.54204 .25232 Mdot
.54209 .1261 Mdot
.54214 .18974 Mdot
.54219 .16074 Mdot
.54223 .11746 Mdot
.54228 .41659 Mdot
.54233 .29614 Mdot
.54238 .28965 Mdot
.54242 .07472 Mdot
.54247 .53147 Mdot
.54252 .10189 Mdot
.54257 .03412 Mdot
.54261 .58274 Mdot
.54266 .21847 Mdot
.54271 .51908 Mdot
.54276 .36049 Mdot
.54281 .34501 Mdot
.54285 .0448 Mdot
.5429 .48942 Mdot
.54295 .22735 Mdot
.543 .15531 Mdot
.54304 .35105 Mdot
.54309 .07836 Mdot
.54314 .0442 Mdot
.54319 .50631 Mdot
.54323 .23966 Mdot
.54328 .49195 Mdot
.54333 .48678 Mdot
.54338 .40356 Mdot
.54342 .42639 Mdot
.54347 .21052 Mdot
.54352 .21184 Mdot
.54357 .34354 Mdot
.54361 .49825 Mdot
.54366 .12333 Mdot
.54371 .19243 Mdot
.54376 .36413 Mdot
.54381 .29448 Mdot
.54385 .20758 Mdot
.5439 .43527 Mdot
.54395 .03382 Mdot
.544 .26439 Mdot
.54404 .32149 Mdot
.54409 .22263 Mdot
.54414 .48184 Mdot
.54419 .51666 Mdot
.54423 .25784 Mdot
.54428 .19314 Mdot
.54433 .57885 Mdot
.54438 .29171 Mdot
.54442 .36921 Mdot
.54447 .30969 Mdot
.54452 .19 Mdot
.54457 .46864 Mdot
.54461 .1734 Mdot
.54466 .11256 Mdot
.54471 .44979 Mdot
.54476 .57372 Mdot
.54481 .06478 Mdot
.54485 .52345 Mdot
.5449 .10037 Mdot
.54495 .29394 Mdot
.545 .46052 Mdot
.54504 .10288 Mdot
.54509 .08126 Mdot
.54514 .04426 Mdot
.54519 .15374 Mdot
.54523 .48358 Mdot
.54528 .20274 Mdot
.54533 .13092 Mdot
.54538 .49923 Mdot
.54542 .30515 Mdot
.54547 .22722 Mdot
.54552 .44254 Mdot
.54557 .14473 Mdot
.54561 .59878 Mdot
.54566 .05192 Mdot
.54571 .57723 Mdot
.54576 .57465 Mdot
.5458 .50093 Mdot
.54585 .20546 Mdot
.5459 .01822 Mdot
.54595 .52458 Mdot
.546 .58081 Mdot
.54604 .1198 Mdot
.54609 .3276 Mdot
.54614 .07877 Mdot
.54619 .49264 Mdot
.54623 .05325 Mdot
.54628 .29805 Mdot
.54633 .52835 Mdot
.54638 .02377 Mdot
.54642 .45383 Mdot
.54647 .18183 Mdot
.54652 .04383 Mdot
.54657 .32195 Mdot
.54661 .24132 Mdot
.54666 .34262 Mdot
.54671 .50242 Mdot
.54676 .32649 Mdot
.5468 .20411 Mdot
.54685 .36871 Mdot
.5469 .5311 Mdot
.54695 .42888 Mdot
.547 .60197 Mdot
.54704 .3652 Mdot
.54709 .02123 Mdot
.54714 .4514 Mdot
.54719 .49689 Mdot
.54723 .05231 Mdot
.54728 .54579 Mdot
.54733 .56208 Mdot
.54738 .45835 Mdot
.54742 .35759 Mdot
.54747 .03214 Mdot
.54752 .55303 Mdot
.54757 .01923 Mdot
.54761 .19046 Mdot
.54766 .59164 Mdot
.54771 .24579 Mdot
.54776 .38124 Mdot
.5478 .45117 Mdot
.54785 .10393 Mdot
.5479 .52262 Mdot
.54795 .19184 Mdot
.548 .09717 Mdot
.54804 .17616 Mdot
.54809 .10845 Mdot
.54814 .19319 Mdot
.54819 .33529 Mdot
.54823 .16964 Mdot
.54828 .26038 Mdot
.54833 .29963 Mdot
.54838 .29769 Mdot
.54842 .22718 Mdot
.54847 .30162 Mdot
.54852 .44461 Mdot
.54857 .54343 Mdot
.54861 .20974 Mdot
.54866 .35192 Mdot
.54871 .44008 Mdot
.54876 .36768 Mdot
.5488 .22143 Mdot
.54885 .12084 Mdot
.5489 .07355 Mdot
.54895 .51983 Mdot
.549 .13221 Mdot
.54904 .20154 Mdot
.54909 .48503 Mdot
.54914 .43738 Mdot
.54919 .55937 Mdot
.54923 .1078 Mdot
.54928 .30655 Mdot
.54933 .1168 Mdot
.54938 .40444 Mdot
.54942 .45075 Mdot
.54947 .02162 Mdot
.54952 .42243 Mdot
.54957 .19197 Mdot
.54961 .16384 Mdot
.54966 .18034 Mdot
.54971 .48233 Mdot
.54976 .58555 Mdot
.5498 .41525 Mdot
.54985 .34359 Mdot
.5499 .12936 Mdot
.54995 .37883 Mdot
.55 .30912 Mdot
.55004 .28475 Mdot
.55009 .21285 Mdot
.55014 .26133 Mdot
.55019 .12229 Mdot
.55023 .40304 Mdot
.55028 .3788 Mdot
.55033 .30529 Mdot
.55038 .02919 Mdot
.55042 .1112 Mdot
.55047 .27671 Mdot
.55052 .50417 Mdot
.55057 .18176 Mdot
.55061 .10429 Mdot
.55066 .4576 Mdot
.55071 .32691 Mdot
.55076 .03263 Mdot
.5508 .52727 Mdot
.55085 .5786 Mdot
.5509 .34469 Mdot
.55095 .2207 Mdot
.55099 .19839 Mdot
.55104 .46396 Mdot
.55109 .56918 Mdot
.55114 .51491 Mdot
.55119 .51697 Mdot
.55123 .26582 Mdot
.55128 .32256 Mdot
.55133 .40733 Mdot
.55138 .12864 Mdot
.55142 .49035 Mdot
.55147 .03198 Mdot
.55152 .39285 Mdot
.55157 .03214 Mdot
.55161 .22835 Mdot
.55166 .13113 Mdot
.55171 .22579 Mdot
.55176 .53118 Mdot
.5518 .37407 Mdot
.55185 .40755 Mdot
.5519 .20787 Mdot
.55195 .01862 Mdot
.55199 .39879 Mdot
.55204 .07757 Mdot
.55209 .59049 Mdot
.55214 .42355 Mdot
.55219 .53816 Mdot
.55223 .11171 Mdot
.55228 .09029 Mdot
.55233 .50991 Mdot
.55238 .28705 Mdot
.55242 .39248 Mdot
.55247 .28628 Mdot
.55252 .39598 Mdot
.55257 .40003 Mdot
.55261 .37521 Mdot
.55266 .49676 Mdot
.55271 .37854 Mdot
.55276 .18639 Mdot
.5528 .25878 Mdot
.55285 .28568 Mdot
.5529 .45069 Mdot
.55295 .41564 Mdot
.55299 .45456 Mdot
.55304 .09251 Mdot
.55309 .44678 Mdot
.55314 .03156 Mdot
.55319 .3917 Mdot
.55323 .10535 Mdot
.55328 .03794 Mdot
.55333 .09673 Mdot
.55338 .2947 Mdot
.55342 .02977 Mdot
.55347 .13136 Mdot
.55352 .41301 Mdot
.55357 .50555 Mdot
.55361 .34681 Mdot
.55366 .33871 Mdot
.55371 .02769 Mdot
.55376 .14505 Mdot
.5538 .45337 Mdot
.55385 .56349 Mdot
.5539 .44463 Mdot
.55395 .48959 Mdot
.55399 .1824 Mdot
.55404 .12751 Mdot
.55409 .04369 Mdot
.55414 .04974 Mdot
.55419 .1046 Mdot
.55423 .28405 Mdot
.55428 .02684 Mdot
.55433 .26137 Mdot
.55438 .60257 Mdot
.55442 .26082 Mdot
.55447 .53344 Mdot
.55452 .56999 Mdot
.55457 .58752 Mdot
.55461 .14417 Mdot
.55466 .13514 Mdot
.55471 .07915 Mdot
.55476 .25542 Mdot
.5548 .40879 Mdot
.55485 .12216 Mdot
.5549 .53743 Mdot
.55495 .40537 Mdot
.55499 .44862 Mdot
.55504 .28086 Mdot
.55509 .06254 Mdot
.55514 .23767 Mdot
.55518 .33583 Mdot
.55523 .25188 Mdot
.55528 .02751 Mdot
.55533 .14778 Mdot
.55538 .06649 Mdot
.55542 .23974 Mdot
.55547 .36946 Mdot
.55552 .14853 Mdot
.55557 .40899 Mdot
.55561 .30963 Mdot
.55566 .4028 Mdot
.55571 .16434 Mdot
.55576 .27953 Mdot
.5558 .1892 Mdot
.55585 .33835 Mdot
.5559 .51225 Mdot
.55595 .47407 Mdot
.55599 .08175 Mdot
.55604 .40425 Mdot
.55609 .12159 Mdot
.55614 .04016 Mdot
.55618 .40421 Mdot
.55623 .35642 Mdot
.55628 .48725 Mdot
.55633 .30765 Mdot
.55638 .16705 Mdot
.55642 .34362 Mdot
.55647 .35417 Mdot
.55652 .25588 Mdot
.55657 .53063 Mdot
.55661 .57748 Mdot
.55666 .22035 Mdot
.55671 .45021 Mdot
.55676 .2357 Mdot
.5568 .1894 Mdot
.55685 .07072 Mdot
.5569 .18539 Mdot
.55695 .06121 Mdot
.55699 .45437 Mdot
.55704 .16179 Mdot
.55709 .31464 Mdot
.55714 .58279 Mdot
.55718 .06482 Mdot
.55723 .0549 Mdot
.55728 .28919 Mdot
.55733 .19328 Mdot
.55738 .31173 Mdot
.55742 .17098 Mdot
.55747 .58486 Mdot
.55752 .04094 Mdot
.55757 .57143 Mdot
.55761 .42013 Mdot
.55766 .3437 Mdot
.55771 .11364 Mdot
.55776 .59728 Mdot
.5578 .21449 Mdot
.55785 .49681 Mdot
.5579 .48126 Mdot
.55795 .42259 Mdot
.55799 .15848 Mdot
.55804 .32613 Mdot
.55809 .43476 Mdot
.55814 .57155 Mdot
.55818 .60002 Mdot
.55823 .0262 Mdot
.55828 .45529 Mdot
.55833 .52143 Mdot
.55838 .55983 Mdot
.55842 .34034 Mdot
.55847 .27672 Mdot
.55852 .22441 Mdot
.55857 .40356 Mdot
.55861 .3588 Mdot
.55866 .25048 Mdot
.55871 .2563 Mdot
.55876 .58675 Mdot
.5588 .02981 Mdot
.55885 .15155 Mdot
.5589 .26235 Mdot
.55895 .38697 Mdot
.55899 .13632 Mdot
.55904 .27361 Mdot
.55909 .44309 Mdot
.55914 .2432 Mdot
.55918 .41351 Mdot
.55923 .44218 Mdot
.55928 .47487 Mdot
.55933 .2465 Mdot
.55938 .40202 Mdot
.55942 .59022 Mdot
.55947 .55676 Mdot
.55952 .29 Mdot
.55957 .07639 Mdot
.55961 .32821 Mdot
.55966 .34706 Mdot
.55971 .48977 Mdot
.55976 .32092 Mdot
.5598 .09243 Mdot
.55985 .10547 Mdot
.5599 .50634 Mdot
.55995 .30582 Mdot
.55999 .54421 Mdot
.56004 .44644 Mdot
.56009 .13408 Mdot
.56014 .18421 Mdot
.56018 .2853 Mdot
.56023 .01806 Mdot
.56028 .49421 Mdot
.56033 .37402 Mdot
.56037 .44645 Mdot
.56042 .14652 Mdot
.56047 .26241 Mdot
.56052 .57533 Mdot
.56057 .45955 Mdot
.56061 .19309 Mdot
.56066 .57573 Mdot
.56071 .51364 Mdot
.56076 .14606 Mdot
.5608 .44935 Mdot
.56085 .10067 Mdot
.5609 .20743 Mdot
.56095 .06833 Mdot
.56099 .35859 Mdot
.56104 .19765 Mdot
.56109 .50493 Mdot
.56114 .12745 Mdot
.56118 .51548 Mdot
.56123 .07828 Mdot
.56128 .33544 Mdot
.56133 .44547 Mdot
.56137 .51212 Mdot
.56142 .1874 Mdot
.56147 .56474 Mdot
.56152 .60235 Mdot
.56157 .38031 Mdot
.56161 .52831 Mdot
.56166 .59274 Mdot
.56171 .1575 Mdot
.56176 .20193 Mdot
.5618 .55591 Mdot
.56185 .09381 Mdot
.5619 .02616 Mdot
.56195 .35591 Mdot
.56199 .46994 Mdot
.56204 .4897 Mdot
.56209 .56115 Mdot
.56214 .60064 Mdot
.56218 .287 Mdot
.56223 .58809 Mdot
.56228 .44841 Mdot
.56233 .09987 Mdot
.56237 .22343 Mdot
.56242 .26737 Mdot
.56247 .01765 Mdot
.56252 .19107 Mdot
.56257 .05074 Mdot
.56261 .30595 Mdot
.56266 .01862 Mdot
.56271 .41408 Mdot
.56276 .12575 Mdot
.5628 .31653 Mdot
.56285 .46444 Mdot
.5629 .22686 Mdot
.56295 .17317 Mdot
.56299 .23744 Mdot
.56304 .453 Mdot
.56309 .47428 Mdot
.56314 .30656 Mdot
.56318 .35106 Mdot
.56323 .49517 Mdot
.56328 .47696 Mdot
.56333 .03426 Mdot
.56337 .3663 Mdot
.56342 .06147 Mdot
.56347 .3918 Mdot
.56352 .41416 Mdot
.56357 .11364 Mdot
.56361 .05853 Mdot
.56366 .21544 Mdot
.56371 .37812 Mdot
.56376 .41102 Mdot
.5638 .05461 Mdot
.56385 .40468 Mdot
.5639 .26708 Mdot
.56395 .10919 Mdot
.56399 .19349 Mdot
.56404 .19253 Mdot
.56409 .10861 Mdot
.56414 .47508 Mdot
.56418 .34382 Mdot
.56423 .32158 Mdot
.56428 .40538 Mdot
.56433 .13872 Mdot
.56437 .45198 Mdot
.56442 .44794 Mdot
.56447 .38583 Mdot
.56452 .37575 Mdot
.56456 .40522 Mdot
.56461 .07085 Mdot
.56466 .57499 Mdot
.56471 .27682 Mdot
.56476 .3614 Mdot
.5648 .45873 Mdot
.56485 .21158 Mdot
.5649 .46913 Mdot
.56495 .3215 Mdot
.56499 .06876 Mdot
.56504 .54783 Mdot
.56509 .37465 Mdot
.56514 .14271 Mdot
.56518 .47956 Mdot
.56523 .45393 Mdot
.56528 .5029 Mdot
.56533 .40221 Mdot
.56537 .17269 Mdot
.56542 .06326 Mdot
.56547 .37889 Mdot
.56552 .55356 Mdot
.56556 .32808 Mdot
.56561 .28076 Mdot
.56566 .01784 Mdot
.56571 .16305 Mdot
.56576 .27194 Mdot
.5658 .30909 Mdot
.56585 .34435 Mdot
.5659 .40498 Mdot
.56595 .41653 Mdot
.56599 .11222 Mdot
.56604 .47854 Mdot
.56609 .09819 Mdot
.56614 .36248 Mdot
.56618 .16771 Mdot
.56623 .1186 Mdot
.56628 .5588 Mdot
.56633 .48625 Mdot
.56637 .31711 Mdot
.56642 .21902 Mdot
.56647 .1713 Mdot
.56652 .32826 Mdot
.56656 .26856 Mdot
.56661 .44346 Mdot
.56666 .22107 Mdot
.56671 .01489 Mdot
.56676 .59113 Mdot
.5668 .44033 Mdot
.56685 .07273 Mdot
.5669 .34628 Mdot
.56695 .29675 Mdot
.56699 .11069 Mdot
.56704 .27108 Mdot
.56709 .53307 Mdot
.56714 .19924 Mdot
.56718 .23548 Mdot
.56723 .1876 Mdot
.56728 .1853 Mdot
.56733 .04624 Mdot
.56737 .13159 Mdot
.56742 .23212 Mdot
.56747 .30238 Mdot
.56752 .33245 Mdot
.56756 .51589 Mdot
.56761 .07553 Mdot
.56766 .57744 Mdot
.56771 .0786 Mdot
.56776 .08714 Mdot
.5678 .45779 Mdot
.56785 .57726 Mdot
.5679 .0908 Mdot
.56795 .25013 Mdot
.56799 .39977 Mdot
.56804 .24569 Mdot
.56809 .39738 Mdot
.56814 .15415 Mdot
.56818 .1434 Mdot
.56823 .31595 Mdot
.56828 .21285 Mdot
.56833 .52199 Mdot
.56837 .55913 Mdot
.56842 .14536 Mdot
.56847 .18132 Mdot
.56852 .40511 Mdot
.56856 .34172 Mdot
.56861 .44631 Mdot
.56866 .45219 Mdot
.56871 .49254 Mdot
.56876 .2809 Mdot
.5688 .4722 Mdot
.56885 .3883 Mdot
.5689 .42011 Mdot
.56895 .42644 Mdot
.56899 .49827 Mdot
.56904 .31221 Mdot
.56909 .18469 Mdot
.56914 .04138 Mdot
.56918 .26728 Mdot
.56923 .51815 Mdot
.56928 .04525 Mdot
.56933 .50131 Mdot
.56937 .55466 Mdot
.56942 .32001 Mdot
.56947 .12659 Mdot
.56952 .5455 Mdot
.56956 .42401 Mdot
.56961 .1534 Mdot
.56966 .3248 Mdot
.56971 .21849 Mdot
.56975 .58102 Mdot
.5698 .30453 Mdot
.56985 .43559 Mdot
.5699 .54091 Mdot
.56995 .12353 Mdot
.56999 .51956 Mdot
.57004 .03018 Mdot
.57009 .12918 Mdot
.57014 .22859 Mdot
.57018 .22206 Mdot
.57023 .44881 Mdot
.57028 .1025 Mdot
.57033 .56464 Mdot
.57037 .30723 Mdot
.57042 .41827 Mdot
.57047 .20452 Mdot
.57052 .02468 Mdot
.57056 .59054 Mdot
.57061 .30639 Mdot
.57066 .26234 Mdot
.57071 .204 Mdot
.57075 .45185 Mdot
.5708 .58491 Mdot
.57085 .05856 Mdot
.5709 .2263 Mdot
.57095 .16203 Mdot
.57099 .16403 Mdot
.57104 .12097 Mdot
.57109 .11748 Mdot
.57114 .2458 Mdot
.57118 .14856 Mdot
.57123 .59512 Mdot
.57128 .49221 Mdot
.57133 .03846 Mdot
.57137 .30307 Mdot
.57142 .50733 Mdot
.57147 .5309 Mdot
.57152 .33455 Mdot
.57156 .48813 Mdot
.57161 .31752 Mdot
.57166 .52092 Mdot
.57171 .34733 Mdot
.57175 .19645 Mdot
.5718 .06989 Mdot
.57185 .33163 Mdot
.5719 .4988 Mdot
.57195 .21487 Mdot
.57199 .02604 Mdot
.57204 .12003 Mdot
.57209 .35148 Mdot
.57214 .06554 Mdot
.57218 .50839 Mdot
.57223 .01727 Mdot
.57228 .12038 Mdot
.57233 .52031 Mdot
.57237 .51659 Mdot
.57242 .12838 Mdot
.57247 .09663 Mdot
.57252 .23194 Mdot
.57256 .02397 Mdot
.57261 .20081 Mdot
.57266 .36541 Mdot
.57271 .34714 Mdot
.57275 .30977 Mdot
.5728 .28322 Mdot
.57285 .03278 Mdot
.5729 .16539 Mdot
.57295 .25459 Mdot
.57299 .55491 Mdot
.57304 .13731 Mdot
.57309 .55385 Mdot
.57314 .24326 Mdot
.57318 .44959 Mdot
.57323 .38916 Mdot
.57328 .50302 Mdot
.57333 .33819 Mdot
.57337 .44703 Mdot
.57342 .28348 Mdot
.57347 .58604 Mdot
.57352 .42492 Mdot
.57356 .33335 Mdot
.57361 .20156 Mdot
.57366 .36881 Mdot
.57371 .41566 Mdot
.57375 .14725 Mdot
.5738 .43947 Mdot
.57385 .03638 Mdot
.5739 .1206 Mdot
.57394 .46736 Mdot
.57399 .4214 Mdot
.57404 .47431 Mdot
.57409 .46934 Mdot
.57414 .51577 Mdot
.57418 .2988 Mdot
.57423 .52379 Mdot
.57428 .24079 Mdot
.57433 .08089 Mdot
.57437 .51297 Mdot
.57442 .03547 Mdot
.57447 .50593 Mdot
.57452 .23718 Mdot
.57456 .2442 Mdot
.57461 .05276 Mdot
.57466 .09571 Mdot
.57471 .50716 Mdot
.57475 .05735 Mdot
.5748 .28728 Mdot
.57485 .28337 Mdot
.5749 .37462 Mdot
.57494 .2212 Mdot
.57499 .2656 Mdot
.57504 .17748 Mdot
.57509 .51059 Mdot
.57514 .40313 Mdot
.57518 .39462 Mdot
.57523 .31147 Mdot
.57528 .59815 Mdot
.57533 .11904 Mdot
.57537 .47416 Mdot
.57542 .08538 Mdot
.57547 .53197 Mdot
.57552 .20939 Mdot
.57556 .45339 Mdot
.57561 .18278 Mdot
.57566 .30949 Mdot
.57571 .56852 Mdot
.57575 .41534 Mdot
.5758 .10177 Mdot
.57585 .40566 Mdot
.5759 .52588 Mdot
.57594 .14277 Mdot
.57599 .42172 Mdot
.57604 .04575 Mdot
.57609 .31939 Mdot
.57614 .4805 Mdot
.57618 .25895 Mdot
.57623 .13849 Mdot
.57628 .51959 Mdot
.57633 .10059 Mdot
.57637 .55081 Mdot
.57642 .14367 Mdot
.57647 .41526 Mdot
.57652 .22976 Mdot
.57656 .48014 Mdot
.57661 .21503 Mdot
.57666 .22058 Mdot
.57671 .37969 Mdot
.57675 .31207 Mdot
.5768 .50886 Mdot
.57685 .25538 Mdot
.5769 .56767 Mdot
.57694 .22501 Mdot
.57699 .11791 Mdot
.57704 .33282 Mdot
.57709 .43961 Mdot
.57714 .40661 Mdot
.57718 .08687 Mdot
.57723 .02813 Mdot
.57728 .56244 Mdot
.57733 .16237 Mdot
.57737 .55171 Mdot
.57742 .11187 Mdot
.57747 .47656 Mdot
.57752 .21488 Mdot
.57756 .42275 Mdot
.57761 .29993 Mdot
.57766 .26151 Mdot
.57771 .33807 Mdot
.57775 .22243 Mdot
.5778 .09406 Mdot
.57785 .48515 Mdot
.5779 .04071 Mdot
.57794 .3169 Mdot
.57799 .44201 Mdot
.57804 .5208 Mdot
.57809 .41903 Mdot
.57814 .21369 Mdot
.57818 .12389 Mdot
.57823 .0959 Mdot
.57828 .02713 Mdot
.57833 .14153 Mdot
.57837 .11047 Mdot
.57842 .13679 Mdot
.57847 .46808 Mdot
.57852 .19315 Mdot
.57856 .60192 Mdot
.57861 .26356 Mdot
.57866 .26791 Mdot
.57871 .37373 Mdot
.57875 .3167 Mdot
.5788 .01676 Mdot
.57885 .53316 Mdot
.5789 .166 Mdot
.57894 .23735 Mdot
.57899 .13494 Mdot
.57904 .50716 Mdot
.57909 .45243 Mdot
.57913 .39867 Mdot
.57918 .21746 Mdot
.57923 .10284 Mdot
.57928 .25345 Mdot
.57933 .28948 Mdot
.57937 .13627 Mdot
.57942 .09043 Mdot
.57947 .12662 Mdot
.57952 .19373 Mdot
.57956 .6028 Mdot
.57961 .22567 Mdot
.57966 .5368 Mdot
.57971 .19513 Mdot
.57975 .35395 Mdot
.5798 .56109 Mdot
.57985 .17778 Mdot
.5799 .48175 Mdot
.57994 .3519 Mdot
.57999 .04263 Mdot
.58004 .02649 Mdot
.58009 .25911 Mdot
.58013 .23167 Mdot
.58018 .13879 Mdot
.58023 .17738 Mdot
.58028 .46376 Mdot
.58033 .02892 Mdot
.58037 .05066 Mdot
.58042 .52726 Mdot
.58047 .18899 Mdot
.58052 .49598 Mdot
.58056 .56356 Mdot
.58061 .41535 Mdot
.58066 .59859 Mdot
.58071 .49651 Mdot
.58075 .3526 Mdot
.5808 .48187 Mdot
.58085 .41817 Mdot
.5809 .15726 Mdot
.58094 .39483 Mdot
.58099 .3188 Mdot
.58104 .53974 Mdot
.58109 .40869 Mdot
.58113 .36691 Mdot
.58118 .30701 Mdot
.58123 .29535 Mdot
.58128 .19172 Mdot
.58133 .24282 Mdot
.58137 .14434 Mdot
.58142 .43491 Mdot
.58147 .17751 Mdot
.58152 .20687 Mdot
.58156 .2204 Mdot
.58161 .26063 Mdot
.58166 .28486 Mdot
.58171 .24664 Mdot
.58175 .40838 Mdot
.5818 .26537 Mdot
.58185 .39168 Mdot
.5819 .49737 Mdot
.58194 .52983 Mdot
.58199 .45053 Mdot
.58204 .24912 Mdot
.58209 .11725 Mdot
.58213 .22575 Mdot
.58218 .51411 Mdot
.58223 .44376 Mdot
.58228 .35366 Mdot
.58233 .52206 Mdot
.58237 .23348 Mdot
.58242 .26674 Mdot
.58247 .12555 Mdot
.58252 .39243 Mdot
.58256 .40189 Mdot
.58261 .10394 Mdot
.58266 .522 Mdot
.58271 .18674 Mdot
.58275 .15597 Mdot
.5828 .42241 Mdot
.58285 .29007 Mdot
.5829 .38168 Mdot
.58294 .49392 Mdot
.58299 .04544 Mdot
.58304 .39602 Mdot
.58309 .45517 Mdot
.58313 .05809 Mdot
.58318 .39965 Mdot
.58323 .29348 Mdot
.58328 .24413 Mdot
.58333 .14731 Mdot
.58337 .55922 Mdot
.58342 .54314 Mdot
.58347 .3254 Mdot
.58352 .51716 Mdot
.58356 .30718 Mdot
.58361 .4323 Mdot
.58366 .5363 Mdot
.58371 .12998 Mdot
.58375 .21795 Mdot
.5838 .51363 Mdot
.58385 .36427 Mdot
.5839 .57734 Mdot
.58394 .39887 Mdot
.58399 .23827 Mdot
.58404 .58591 Mdot
.58409 .09813 Mdot
.58413 .36814 Mdot
.58418 .44558 Mdot
.58423 .14545 Mdot
.58428 .05474 Mdot
.58432 .57181 Mdot
.58437 .16681 Mdot
.58442 .50464 Mdot
.58447 .51076 Mdot
.58452 .02731 Mdot
.58456 .22699 Mdot
.58461 .19395 Mdot
.58466 .59693 Mdot
.58471 .32345 Mdot
.58475 .39802 Mdot
.5848 .26097 Mdot
.58485 .48166 Mdot
.5849 .1202 Mdot
.58494 .48771 Mdot
.58499 .50003 Mdot
.58504 .50765 Mdot
.58509 .32466 Mdot
.58513 .26415 Mdot
.58518 .51744 Mdot
.58523 .42423 Mdot
.58528 .55985 Mdot
.58532 .4219 Mdot
.58537 .3867 Mdot
.58542 .3842 Mdot
.58547 .59136 Mdot
.58552 .2698 Mdot
.58556 .48539 Mdot
.58561 .47677 Mdot
.58566 .57876 Mdot
.58571 .05752 Mdot
.58575 .30615 Mdot
.5858 .48316 Mdot
.58585 .27002 Mdot
.5859 .26283 Mdot
.58594 .05988 Mdot
.58599 .01621 Mdot
.58604 .16453 Mdot
.58609 .37844 Mdot
.58613 .16318 Mdot
.58618 .11188 Mdot
.58623 .44319 Mdot
.58628 .12899 Mdot
.58632 .24906 Mdot
.58637 .29097 Mdot
.58642 .48667 Mdot
.58647 .31042 Mdot
.58652 .46569 Mdot
.58656 .5101 Mdot
.58661 .49863 Mdot
.58666 .05532 Mdot
.58671 .58362 Mdot
.58675 .04804 Mdot
.5868 .52319 Mdot
.58685 .60113 Mdot
.5869 .29218 Mdot
.58694 .1682 Mdot
.58699 .26788 Mdot
.58704 .35302 Mdot
.58709 .247 Mdot
.58713 .1667 Mdot
.58718 .11806 Mdot
.58723 .5779 Mdot
.58728 .09853 Mdot
.58732 .06953 Mdot
.58737 .27819 Mdot
.58742 .46362 Mdot
.58747 .45279 Mdot
.58752 .38188 Mdot
.58756 .39485 Mdot
.58761 .16791 Mdot
.58766 .59043 Mdot
.58771 .47511 Mdot
.58775 .49954 Mdot
.5878 .1273 Mdot
.58785 .02152 Mdot
.5879 .44177 Mdot
.58794 .57967 Mdot
.58799 .12949 Mdot
.58804 .33267 Mdot
.58809 .28828 Mdot
.58813 .3265 Mdot
.58818 .3798 Mdot
.58823 .10037 Mdot
.58828 .13628 Mdot
.58832 .22315 Mdot
.58837 .40522 Mdot
.58842 .01655 Mdot
.58847 .08146 Mdot
.58851 .54829 Mdot
.58856 .54492 Mdot
.58861 .16708 Mdot
.58866 .3029 Mdot
.58871 .16815 Mdot
.58875 .39172 Mdot
.5888 .17997 Mdot
.58885 .43112 Mdot
.5889 .27194 Mdot
.58894 .27913 Mdot
.58899 .17316 Mdot
.58904 .59268 Mdot
.58909 .29559 Mdot
.58913 .16435 Mdot
.58918 .44382 Mdot
.58923 .31911 Mdot
.58928 .57242 Mdot
.58932 .38788 Mdot
.58937 .35815 Mdot
.58942 .19754 Mdot
.58947 .36398 Mdot
.58951 .58599 Mdot
.58956 .35631 Mdot
.58961 .13078 Mdot
.58966 .41901 Mdot
.58971 .05577 Mdot
.58975 .20394 Mdot
.5898 .43121 Mdot
.58985 .26557 Mdot
.5899 .26738 Mdot
.58994 .03868 Mdot
.58999 .01479 Mdot
.59004 .59696 Mdot
.59009 .59157 Mdot
.59013 .46885 Mdot
.59018 .02544 Mdot
.59023 .31607 Mdot
.59028 .44193 Mdot
.59032 .03974 Mdot
.59037 .30966 Mdot
.59042 .34698 Mdot
.59047 .06876 Mdot
.59051 .28492 Mdot
.59056 .12683 Mdot
.59061 .58633 Mdot
.59066 .0861 Mdot
.59071 .53193 Mdot
.59075 .59937 Mdot
.5908 .18203 Mdot
.59085 .04503 Mdot
.5909 .34269 Mdot
.59094 .18287 Mdot
.59099 .51978 Mdot
.59104 .38098 Mdot
.59109 .31872 Mdot
.59113 .18279 Mdot
.59118 .52615 Mdot
.59123 .39273 Mdot
.59128 .45319 Mdot
.59132 .17206 Mdot
.59137 .22478 Mdot
.59142 .55412 Mdot
.59147 .42816 Mdot
.59151 .46573 Mdot
.59156 .48112 Mdot
.59161 .50007 Mdot
.59166 .15795 Mdot
.59171 .35361 Mdot
.59175 .49812 Mdot
.5918 .42868 Mdot
.59185 .22935 Mdot
.5919 .35756 Mdot
.59194 .3308 Mdot
.59199 .39836 Mdot
.59204 .48998 Mdot
.59209 .1894 Mdot
.59213 .41435 Mdot
.59218 .03209 Mdot
.59223 .18598 Mdot
.59228 .02132 Mdot
.59232 .49152 Mdot
.59237 .24269 Mdot
.59242 .33611 Mdot
.59247 .45258 Mdot
.59251 .28145 Mdot
.59256 .2919 Mdot
.59261 .51128 Mdot
.59266 .59018 Mdot
.59271 .40365 Mdot
.59275 .39515 Mdot
.5928 .36804 Mdot
.59285 .25128 Mdot
.5929 .50886 Mdot
.59294 .5698 Mdot
.59299 .1534 Mdot
.59304 .49704 Mdot
.59309 .19277 Mdot
.59313 .18614 Mdot
.59318 .26674 Mdot
.59323 .32236 Mdot
.59328 .38175 Mdot
.59332 .16876 Mdot
.59337 .09548 Mdot
.59342 .31575 Mdot
.59347 .49355 Mdot
.59351 .52939 Mdot
.59356 .36269 Mdot
.59361 .46649 Mdot
.59366 .2268 Mdot
.5937 .2522 Mdot
.59375 .45474 Mdot
.5938 .47964 Mdot
.59385 .42648 Mdot
.5939 .46037 Mdot
.59394 .1014 Mdot
.59399 .24306 Mdot
.59404 .52094 Mdot
.59409 .4939 Mdot
.59413 .55133 Mdot
.59418 .34934 Mdot
.59423 .34289 Mdot
.59428 .32247 Mdot
.59432 .29929 Mdot
.59437 .0417 Mdot
.59442 .56447 Mdot
.59447 .16842 Mdot
.59451 .21853 Mdot
.59456 .32927 Mdot
.59461 .08563 Mdot
.59466 .24235 Mdot
.5947 .45916 Mdot
.59475 .46611 Mdot
.5948 .46215 Mdot
.59485 .59347 Mdot
.5949 .01914 Mdot
.59494 .5898 Mdot
.59499 .05038 Mdot
.59504 .14781 Mdot
.59509 .52106 Mdot
.59513 .36144 Mdot
.59518 .13276 Mdot
.59523 .25723 Mdot
.59528 .57305 Mdot
.59532 .02681 Mdot
.59537 .3932 Mdot
.59542 .53809 Mdot
.59547 .28847 Mdot
.59551 .58844 Mdot
.59556 .43206 Mdot
.59561 .38438 Mdot
.59566 .08465 Mdot
.5957 .27387 Mdot
.59575 .36114 Mdot
.5958 .15674 Mdot
.59585 .22881 Mdot
.5959 .41109 Mdot
.59594 .50232 Mdot
.59599 .16659 Mdot
.59604 .22439 Mdot
.59609 .42462 Mdot
.59613 .46665 Mdot
.59618 .03349 Mdot
.59623 .30665 Mdot
.59628 .07788 Mdot
.59632 .34859 Mdot
.59637 .37959 Mdot
.59642 .33693 Mdot
.59647 .06578 Mdot
.59651 .55872 Mdot
.59656 .44483 Mdot
.59661 .06317 Mdot
.59666 .08067 Mdot
.5967 .14136 Mdot
.59675 .07516 Mdot
.5968 .58184 Mdot
.59685 .41012 Mdot
.5969 .38355 Mdot
.59694 .52175 Mdot
.59699 .36774 Mdot
.59704 .60236 Mdot
.59709 .48455 Mdot
.59713 .36987 Mdot
.59718 .15806 Mdot
.59723 .19245 Mdot
.59728 .03262 Mdot
.59732 .35108 Mdot
.59737 .45473 Mdot
.59742 .12928 Mdot
.59747 .28735 Mdot
.59751 .57482 Mdot
.59756 .13251 Mdot
.59761 .0782 Mdot
.59766 .33196 Mdot
.5977 .14469 Mdot
.59775 .08405 Mdot
.5978 .60086 Mdot
.59785 .2053 Mdot
.59789 .08423 Mdot
.59794 .10554 Mdot
.59799 .20544 Mdot
.59804 .42508 Mdot
.59809 .16581 Mdot
.59813 .34113 Mdot
.59818 .20641 Mdot
.59823 .54385 Mdot
.59828 .39926 Mdot
.59832 .19778 Mdot
.59837 .02867 Mdot
.59842 .52595 Mdot
.59847 .06289 Mdot
.59851 .34638 Mdot
.59856 .50271 Mdot
.59861 .25331 Mdot
.59866 .0914 Mdot
.5987 .22858 Mdot
.59875 .43922 Mdot
.5988 .52467 Mdot
.59885 .55004 Mdot
.59889 .15923 Mdot
.59894 .44168 Mdot
.59899 .33408 Mdot
.59904 .48051 Mdot
.59909 .0684 Mdot
.59913 .25095 Mdot
.59918 .51232 Mdot
.59923 .32941 Mdot
.59928 .3306 Mdot
.59932 .05925 Mdot
.59937 .57179 Mdot
.59942 .53347 Mdot
.59947 .14753 Mdot
.59951 .04529 Mdot
.59956 .06055 Mdot
.59961 .48529 Mdot
.59966 .40448 Mdot
.5997 .1459 Mdot
.59975 .41057 Mdot
.5998 .4086 Mdot
.59985 .19061 Mdot
.59989 .31001 Mdot
.59994 .48922 Mdot
.59999 .46189 Mdot
.60004 .04609 Mdot
.60009 .47166 Mdot
.60013 .16985 Mdot
.60018 .5847 Mdot
.60023 .58101 Mdot
.60028 .23542 Mdot
.60032 .26086 Mdot
.60037 .27 Mdot
.60042 .26511 Mdot
.60047 .19088 Mdot
.60051 .2924 Mdot
.60056 .33986 Mdot
.60061 .13229 Mdot
.60066 .1603 Mdot
.6007 .24656 Mdot
.60075 .45789 Mdot
.6008 .33114 Mdot
.60085 .0291 Mdot
.60089 .43931 Mdot
.60094 .06401 Mdot
.60099 .15524 Mdot
.60104 .32242 Mdot
.60109 .55342 Mdot
.60113 .20544 Mdot
.60118 .12386 Mdot
.60123 .45409 Mdot
.60128 .39827 Mdot
.60132 .22407 Mdot
.60137 .14618 Mdot
.60142 .23338 Mdot
.60147 .15212 Mdot
.60151 .55739 Mdot
.60156 .48439 Mdot
.60161 .05721 Mdot
.60166 .46304 Mdot
.6017 .23224 Mdot
.60175 .36681 Mdot
.6018 .50023 Mdot
.60185 .23119 Mdot
.60189 .37767 Mdot
.60194 .05038 Mdot
.60199 .48584 Mdot
.60204 .39521 Mdot
.60209 .32837 Mdot
.60213 .49847 Mdot
.60218 .17813 Mdot
.60223 .44512 Mdot
.60228 .13764 Mdot
.60232 .38931 Mdot
.60237 .32737 Mdot
.60242 .06156 Mdot
.60247 .5169 Mdot
.60251 .25784 Mdot
.60256 .1087 Mdot
.60261 .51276 Mdot
.60266 .56283 Mdot
.6027 .37677 Mdot
.60275 .0662 Mdot
.6028 .06443 Mdot
.60285 .3453 Mdot
.60289 .02467 Mdot
.60294 .16929 Mdot
.60299 .43656 Mdot
.60304 .57096 Mdot
.60308 .57762 Mdot
.60313 .28678 Mdot
.60318 .05606 Mdot
.60323 .25729 Mdot
.60328 .09386 Mdot
.60332 .12336 Mdot
.60337 .21427 Mdot
.60342 .13436 Mdot
.60347 .30788 Mdot
.60351 .39932 Mdot
.60356 .16742 Mdot
.60361 .22079 Mdot
.60366 .06474 Mdot
.6037 .30533 Mdot
.60375 .25799 Mdot
.6038 .26128 Mdot
.60385 .2913 Mdot
.60389 .25384 Mdot
.60394 .20826 Mdot
.60399 .5193 Mdot
.60404 .28133 Mdot
.60408 .09926 Mdot
.60413 .37503 Mdot
.60418 .55167 Mdot
.60423 .30704 Mdot
.60428 .41581 Mdot
.60432 .33367 Mdot
.60437 .30909 Mdot
.60442 .22789 Mdot
.60447 .30716 Mdot
.60451 .13411 Mdot
.60456 .18943 Mdot
.60461 .52334 Mdot
.60466 .51117 Mdot
.6047 .57001 Mdot
.60475 .57197 Mdot
.6048 .4733 Mdot
.60485 .22055 Mdot
.60489 .32673 Mdot
.60494 .32539 Mdot
.60499 .19671 Mdot
.60504 .57004 Mdot
.60508 .13318 Mdot
.60513 .40942 Mdot
.60518 .5187 Mdot
.60523 .48549 Mdot
.60528 .36148 Mdot
.60532 .46107 Mdot
.60537 .22637 Mdot
.60542 .08439 Mdot
.60547 .04251 Mdot
.60551 .16669 Mdot
.60556 .60181 Mdot
.60561 .38055 Mdot
.60566 .51173 Mdot
.6057 .58058 Mdot
.60575 .09318 Mdot
.6058 .4727 Mdot
.60585 .54504 Mdot
.60589 .02333 Mdot
.60594 .2232 Mdot
.60599 .26685 Mdot
.60604 .23302 Mdot
.60608 .30126 Mdot
.60613 .0412 Mdot
.60618 .30014 Mdot
.60623 .11455 Mdot
.60628 .49517 Mdot
.60632 .12582 Mdot
.60637 .41798 Mdot
.60642 .3564 Mdot
.60647 .04881 Mdot
.60651 .50277 Mdot
.60656 .3483 Mdot
.60661 .32859 Mdot
.60666 .48544 Mdot
.6067 .50429 Mdot
.60675 .57108 Mdot
.6068 .42019 Mdot
.60685 .50818 Mdot
.60689 .42582 Mdot
.60694 .11309 Mdot
.60699 .47847 Mdot
.60704 .49956 Mdot
.60708 .21733 Mdot
.60713 .44956 Mdot
.60718 .26016 Mdot
.60723 .21301 Mdot
.60727 .19084 Mdot
.60732 .16413 Mdot
.60737 .16032 Mdot
.60742 .32117 Mdot
.60747 .07973 Mdot
.60751 .34947 Mdot
.60756 .40724 Mdot
.60761 .28707 Mdot
.60766 .18028 Mdot
.6077 .01588 Mdot
.60775 .09336 Mdot
.6078 .40496 Mdot
.60785 .27932 Mdot
.60789 .04813 Mdot
.60794 .2765 Mdot
.60799 .5001 Mdot
.60804 .45682 Mdot
.60808 .53836 Mdot
.60813 .40135 Mdot
.60818 .01525 Mdot
.60823 .2542 Mdot
.60827 .10352 Mdot
.60832 .1559 Mdot
.60837 .40556 Mdot
.60842 .07807 Mdot
.60847 .54271 Mdot
.60851 .59891 Mdot
.60856 .0991 Mdot
.60861 .60167 Mdot
.60866 .20795 Mdot
.6087 .20638 Mdot
.60875 .41535 Mdot
.6088 .4361 Mdot
.60885 .20678 Mdot
.60889 .12773 Mdot
.60894 .0251 Mdot
.60899 .17149 Mdot
.60904 .17336 Mdot
.60908 .45455 Mdot
.60913 .12833 Mdot
.60918 .318 Mdot
.60923 .23832 Mdot
.60927 .06791 Mdot
.60932 .12779 Mdot
.60937 .0785 Mdot
.60942 .14951 Mdot
.60947 .51533 Mdot
.60951 .32555 Mdot
.60956 .01514 Mdot
.60961 .21013 Mdot
.60966 .51974 Mdot
.6097 .24116 Mdot
.60975 .01679 Mdot
.6098 .01688 Mdot
.60985 .32808 Mdot
.60989 .42914 Mdot
.60994 .18402 Mdot
.60999 .41343 Mdot
.61004 .21506 Mdot
.61008 .41874 Mdot
.61013 .02724 Mdot
.61018 .25478 Mdot
.61023 .36383 Mdot
.61027 .30513 Mdot
.61032 .31257 Mdot
.61037 .03117 Mdot
.61042 .31063 Mdot
.61047 .19205 Mdot
.61051 .24877 Mdot
.61056 .48498 Mdot
.61061 .39862 Mdot
.61066 .46982 Mdot
.6107 .24834 Mdot
.61075 .28956 Mdot
.6108 .4822 Mdot
.61085 .24337 Mdot
.61089 .24626 Mdot
.61094 .28738 Mdot
.61099 .16884 Mdot
.61104 .41756 Mdot
.61108 .07695 Mdot
.61113 .47728 Mdot
.61118 .5571 Mdot
.61123 .60214 Mdot
.61127 .06443 Mdot
.61132 .23721 Mdot
.61137 .20798 Mdot
.61142 .31172 Mdot
.61147 .35519 Mdot
.61151 .22075 Mdot
.61156 .50068 Mdot
.61161 .13438 Mdot
.61166 .12112 Mdot
.6117 .3391 Mdot
.61175 .11676 Mdot
.6118 .26789 Mdot
.61185 .4761 Mdot
.61189 .06425 Mdot
.61194 .23788 Mdot
.61199 .03923 Mdot
.61204 .24455 Mdot
.61208 .38019 Mdot
.61213 .08376 Mdot
.61218 .225 Mdot
.61223 .18231 Mdot
.61227 .50624 Mdot
.61232 .12998 Mdot
.61237 .22618 Mdot
.61242 .13259 Mdot
.61246 .28374 Mdot
.61251 .52532 Mdot
.61256 .51778 Mdot
.61261 .38073 Mdot
.61266 .07769 Mdot
.6127 .03936 Mdot
.61275 .39811 Mdot
.6128 .27431 Mdot
.61285 .34192 Mdot
.61289 .52592 Mdot
.61294 .14493 Mdot
.61299 .40154 Mdot
.61304 .29237 Mdot
.61308 .30275 Mdot
.61313 .12041 Mdot
.61318 .17169 Mdot
.61323 .51551 Mdot
.61327 .2337 Mdot
.61332 .49874 Mdot
.61337 .59271 Mdot
.61342 .02397 Mdot
.61346 .11843 Mdot
.61351 .28726 Mdot
.61356 .47483 Mdot
.61361 .34356 Mdot
.61366 .19643 Mdot
.6137 .3728 Mdot
.61375 .10882 Mdot
.6138 .28057 Mdot
.61385 .17178 Mdot
.61389 .57802 Mdot
.61394 .43783 Mdot
.61399 .54198 Mdot
.61404 .24919 Mdot
.61408 .4478 Mdot
.61413 .051 Mdot
.61418 .26432 Mdot
.61423 .54977 Mdot
.61427 .3421 Mdot
.61432 .48263 Mdot
.61437 .35214 Mdot
.61442 .33077 Mdot
.61446 .44669 Mdot
.61451 .49324 Mdot
.61456 .34287 Mdot
.61461 .22705 Mdot
.61466 .17413 Mdot
.6147 .03312 Mdot
.61475 .60264 Mdot
.6148 .04533 Mdot
.61485 .40466 Mdot
.61489 .52763 Mdot
.61494 .33677 Mdot
.61499 .47687 Mdot
.61504 .42996 Mdot
.61508 .10451 Mdot
.61513 .39811 Mdot
.61518 .24239 Mdot
.61523 .58549 Mdot
.61527 .06822 Mdot
.61532 .14851 Mdot
.61537 .29595 Mdot
.61542 .2581 Mdot
.61546 .18891 Mdot
.61551 .39969 Mdot
.61556 .5685 Mdot
.61561 .41473 Mdot
.61566 .29899 Mdot
.6157 .07153 Mdot
.61575 .35616 Mdot
.6158 .25531 Mdot
.61585 .28058 Mdot
.61589 .07222 Mdot
.61594 .32554 Mdot
.61599 .45398 Mdot
.61604 .35627 Mdot
.61608 .33877 Mdot
.61613 .45199 Mdot
.61618 .03873 Mdot
.61623 .26647 Mdot
.61627 .54399 Mdot
.61632 .2243 Mdot
.61637 .05656 Mdot
.61642 .21297 Mdot
.61646 .41019 Mdot
.61651 .53168 Mdot
.61656 .40179 Mdot
.61661 .03877 Mdot
.61666 .0252 Mdot
.6167 .5665 Mdot
.61675 .59038 Mdot
.6168 .3431 Mdot
.61685 .557 Mdot
.61689 .22505 Mdot
.61694 .34978 Mdot
.61699 .07723 Mdot
.61704 .49949 Mdot
.61708 .50284 Mdot
.61713 .49913 Mdot
.61718 .32428 Mdot
.61723 .17542 Mdot
.61727 .06556 Mdot
.61732 .47511 Mdot
.61737 .07252 Mdot
.61742 .23476 Mdot
.61746 .44458 Mdot
.61751 .43326 Mdot
.61756 .46288 Mdot
.61761 .4279 Mdot
.61765 .51623 Mdot
.6177 .04617 Mdot
.61775 .43882 Mdot
.6178 .4174 Mdot
.61785 .55305 Mdot
.61789 .05911 Mdot
.61794 .11042 Mdot
.61799 .46373 Mdot
.61804 .34271 Mdot
.61808 .31265 Mdot
.61813 .0479 Mdot
.61818 .56757 Mdot
.61823 .4432 Mdot
.61827 .41685 Mdot
.61832 .32694 Mdot
.61837 .40686 Mdot
.61842 .39235 Mdot
.61846 .54506 Mdot
.61851 .26913 Mdot
.61856 .1868 Mdot
.61861 .5511 Mdot
.61865 .12651 Mdot
.6187 .40957 Mdot
.61875 .36223 Mdot
.6188 .04958 Mdot
.61885 .09505 Mdot
.61889 .57408 Mdot
.61894 .54816 Mdot
.61899 .09985 Mdot
.61904 .05065 Mdot
.61908 .47837 Mdot
.61913 .09913 Mdot
.61918 .36047 Mdot
.61923 .34132 Mdot
.61927 .44518 Mdot
.61932 .13489 Mdot
.61937 .52059 Mdot
.61942 .5278 Mdot
.61946 .13295 Mdot
.61951 .33136 Mdot
.61956 .14295 Mdot
.61961 .58606 Mdot
.61965 .46715 Mdot
.6197 .15926 Mdot
.61975 .19518 Mdot
.6198 .47426 Mdot
.61985 .07228 Mdot
.61989 .40036 Mdot
.61994 .16031 Mdot
.61999 .39391 Mdot
.62004 .10153 Mdot
.62008 .45553 Mdot
.62013 .07517 Mdot
.62018 .35797 Mdot
.62023 .22648 Mdot
.62027 .3711 Mdot
.62032 .31802 Mdot
.62037 .03136 Mdot
.62042 .38463 Mdot
.62046 .25092 Mdot
.62051 .40075 Mdot
.62056 .10689 Mdot
.62061 .26639 Mdot
.62065 .52288 Mdot
.6207 .27251 Mdot
.62075 .12416 Mdot
.6208 .40256 Mdot
.62085 .37833 Mdot
.62089 .09204 Mdot
.62094 .25323 Mdot
.62099 .34499 Mdot
.62104 .5813 Mdot
.62108 .53505 Mdot
.62113 .46264 Mdot
.62118 .25817 Mdot
.62123 .14048 Mdot
.62127 .4746 Mdot
.62132 .11937 Mdot
.62137 .04639 Mdot
.62142 .3727 Mdot
.62146 .17128 Mdot
.62151 .10272 Mdot
.62156 .26509 Mdot
.62161 .13649 Mdot
.62165 .37385 Mdot
.6217 .59915 Mdot
.62175 .60203 Mdot
.6218 .21693 Mdot
.62184 .11605 Mdot
.62189 .4897 Mdot
.62194 .21417 Mdot
.62199 .44193 Mdot
.62204 .03872 Mdot
.62208 .25119 Mdot
.62213 .47251 Mdot
.62218 .46396 Mdot
.62223 .107 Mdot
.62227 .39187 Mdot
.62232 .22906 Mdot
.62237 .33819 Mdot
.62242 .23573 Mdot
.62246 .28721 Mdot
.62251 .19737 Mdot
.62256 .56881 Mdot
.62261 .07916 Mdot
.62265 .1992 Mdot
.6227 .53561 Mdot
.62275 .44703 Mdot
.6228 .30863 Mdot
.62284 .20337 Mdot
.62289 .53691 Mdot
.62294 .2448 Mdot
.62299 .20729 Mdot
.62304 .31699 Mdot
.62308 .33745 Mdot
.62313 .4062 Mdot
.62318 .18327 Mdot
.62323 .08052 Mdot
.62327 .46826 Mdot
.62332 .54557 Mdot
.62337 .09098 Mdot
.62342 .29197 Mdot
.62346 .25391 Mdot
.62351 .22209 Mdot
.62356 .45858 Mdot
.62361 .01947 Mdot
.62365 .07125 Mdot
.6237 .2566 Mdot
.62375 .39413 Mdot
.6238 .42359 Mdot
.62384 .13896 Mdot
.62389 .4129 Mdot
.62394 .10021 Mdot
.62399 .23493 Mdot
.62404 .20538 Mdot
.62408 .1828 Mdot
.62413 .49625 Mdot
.62418 .52126 Mdot
.62423 .47125 Mdot
.62427 .37993 Mdot
.62432 .32769 Mdot
.62437 .45546 Mdot
.62442 .0177 Mdot
.62446 .43769 Mdot
.62451 .25142 Mdot
.62456 .1782 Mdot
.62461 .36711 Mdot
.62465 .2303 Mdot
.6247 .39616 Mdot
.62475 .17344 Mdot
.6248 .31057 Mdot
.62484 .57703 Mdot
.62489 .01674 Mdot
.62494 .35317 Mdot
.62499 .18632 Mdot
.62504 .17884 Mdot
.62508 .51985 Mdot
.62513 .13295 Mdot
.62518 .58427 Mdot
.62523 .59936 Mdot
.62527 .03831 Mdot
.62532 .21501 Mdot
.62537 .12773 Mdot
.62542 .23414 Mdot
.62546 .31395 Mdot
.62551 .36288 Mdot
.62556 .12473 Mdot
.62561 .39978 Mdot
.62565 .07724 Mdot
.6257 .19939 Mdot
.62575 .36094 Mdot
.6258 .18418 Mdot
.62584 .2844 Mdot
.62589 .04066 Mdot
.62594 .06508 Mdot
.62599 .21048 Mdot
.62604 .28237 Mdot
.62608 .29082 Mdot
.62613 .48208 Mdot
.62618 .04635 Mdot
.62623 .36584 Mdot
.62627 .17258 Mdot
.62632 .50114 Mdot
.62637 .05032 Mdot
.62642 .34224 Mdot
.62646 .5609 Mdot
.62651 .38812 Mdot
.62656 .41951 Mdot
.62661 .043 Mdot
.62665 .21273 Mdot
.6267 .2781 Mdot
.62675 .03444 Mdot
.6268 .56908 Mdot
.62684 .02804 Mdot
.62689 .52048 Mdot
.62694 .45358 Mdot
.62699 .29939 Mdot
.62703 .59071 Mdot
.62708 .47011 Mdot
.62713 .25781 Mdot
.62718 .03173 Mdot
.62723 .31459 Mdot
.62727 .59135 Mdot
.62732 .22616 Mdot
.62737 .26922 Mdot
.62742 .15672 Mdot
.62746 .10492 Mdot
.62751 .19055 Mdot
.62756 .5303 Mdot
.62761 .19915 Mdot
.62765 .32012 Mdot
.6277 .37437 Mdot
.62775 .50202 Mdot
.6278 .58974 Mdot
.62784 .05673 Mdot
.62789 .35464 Mdot
.62794 .53626 Mdot
.62799 .57641 Mdot
.62803 .13958 Mdot
.62808 .50439 Mdot
.62813 .25158 Mdot
.62818 .58903 Mdot
.62823 .27279 Mdot
.62827 .26129 Mdot
.62832 .23455 Mdot
.62837 .28914 Mdot
.62842 .28477 Mdot
.62846 .04984 Mdot
.62851 .56866 Mdot
.62856 .14713 Mdot
.62861 .19456 Mdot
.62865 .46261 Mdot
.6287 .05307 Mdot
.62875 .55131 Mdot
.6288 .47776 Mdot
.62884 .10295 Mdot
.62889 .15438 Mdot
.62894 .56489 Mdot
.62899 .43574 Mdot
.62903 .35163 Mdot
.62908 .22144 Mdot
.62913 .59181 Mdot
.62918 .31087 Mdot
.62923 .45056 Mdot
.62927 .57319 Mdot
.62932 .01749 Mdot
.62937 .05279 Mdot
.62942 .20398 Mdot
.62946 .35335 Mdot
.62951 .33168 Mdot
.62956 .37135 Mdot
.62961 .16885 Mdot
.62965 .38801 Mdot
.6297 .19925 Mdot
.62975 .1915 Mdot
.6298 .30956 Mdot
.62984 .34965 Mdot
.62989 .25127 Mdot
.62994 .31707 Mdot
.62999 .22132 Mdot
.63003 .20998 Mdot
.63008 .2897 Mdot
.63013 .48465 Mdot
.63018 .47302 Mdot
.63023 .59186 Mdot
.63027 .30122 Mdot
.63032 .18849 Mdot
.63037 .03716 Mdot
.63042 .03338 Mdot
.63046 .29843 Mdot
.63051 .15041 Mdot
.63056 .43651 Mdot
.63061 .28336 Mdot
.63065 .57008 Mdot
.6307 .38239 Mdot
.63075 .28237 Mdot
.6308 .49867 Mdot
.63084 .38554 Mdot
.63089 .2056 Mdot
.63094 .57613 Mdot
.63099 .16373 Mdot
.63103 .14898 Mdot
.63108 .49186 Mdot
.63113 .36952 Mdot
.63118 .55707 Mdot
.63122 .4626 Mdot
.63127 .02192 Mdot
.63132 .49983 Mdot
.63137 .56853 Mdot
.63142 .17609 Mdot
.63146 .43675 Mdot
.63151 .47738 Mdot
.63156 .54986 Mdot
.63161 .48098 Mdot
.63165 .30104 Mdot
.6317 .05558 Mdot
.63175 .28121 Mdot
.6318 .51422 Mdot
.63184 .52197 Mdot
.63189 .37654 Mdot
.63194 .38587 Mdot
.63199 .1434 Mdot
.63203 .33108 Mdot
.63208 .40373 Mdot
.63213 .23685 Mdot
.63218 .59775 Mdot
.63222 .44254 Mdot
.63227 .04891 Mdot
.63232 .2831 Mdot
.63237 .14986 Mdot
.63242 .43534 Mdot
.63246 .15241 Mdot
.63251 .31789 Mdot
.63256 .57709 Mdot
.63261 .60191 Mdot
.63265 .27835 Mdot
.6327 .37135 Mdot
.63275 .11082 Mdot
.6328 .31558 Mdot
.63284 .23748 Mdot
.63289 .10485 Mdot
.63294 .19992 Mdot
.63299 .39693 Mdot
.63303 .46427 Mdot
.63308 .3223 Mdot
.63313 .07123 Mdot
.63318 .08056 Mdot
.63322 .07525 Mdot
.63327 .10017 Mdot
.63332 .07681 Mdot
.63337 .24134 Mdot
.63342 .04105 Mdot
.63346 .4204 Mdot
.63351 .53028 Mdot
.63356 .40933 Mdot
.63361 .49197 Mdot
.63365 .11721 Mdot
.6337 .55651 Mdot
.63375 .41074 Mdot
.6338 .22832 Mdot
.63384 .34919 Mdot
.63389 .4604 Mdot
.63394 .10987 Mdot
.63399 .59417 Mdot
.63403 .25905 Mdot
.63408 .27518 Mdot
.63413 .31627 Mdot
.63418 .14461 Mdot
.63422 .54007 Mdot
.63427 .21866 Mdot
.63432 .25042 Mdot
.63437 .08406 Mdot
.63442 .45461 Mdot
.63446 .15656 Mdot
.63451 .02379 Mdot
.63456 .05773 Mdot
.63461 .04892 Mdot
.63465 .22961 Mdot
.6347 .21779 Mdot
.63475 .16909 Mdot
.6348 .53503 Mdot
.63484 .27642 Mdot
.63489 .41037 Mdot
.63494 .54409 Mdot
.63499 .20056 Mdot
.63503 .41935 Mdot
.63508 .3152 Mdot
.63513 .55325 Mdot
.63518 .54483 Mdot
.63522 .15888 Mdot
.63527 .60226 Mdot
.63532 .42335 Mdot
.63537 .01947 Mdot
.63542 .54354 Mdot
.63546 .36654 Mdot
.63551 .35399 Mdot
.63556 .16819 Mdot
.63561 .40169 Mdot
.63565 .35746 Mdot
.6357 .31097 Mdot
.63575 .13397 Mdot
.6358 .1868 Mdot
.63584 .15438 Mdot
.63589 .15659 Mdot
.63594 .20226 Mdot
.63599 .5137 Mdot
.63603 .34734 Mdot
.63608 .21583 Mdot
.63613 .01642 Mdot
.63618 .10906 Mdot
.63622 .04685 Mdot
.63627 .26591 Mdot
.63632 .07491 Mdot
.63637 .5535 Mdot
.63641 .04792 Mdot
.63646 .44589 Mdot
.63651 .07014 Mdot
.63656 .02467 Mdot
.63661 .2847 Mdot
.63665 .10661 Mdot
.6367 .50528 Mdot
.63675 .2263 Mdot
.6368 .53057 Mdot
.63684 .39896 Mdot
.63689 .38602 Mdot
.63694 .05421 Mdot
.63699 .39089 Mdot
.63703 .25708 Mdot
.63708 .19846 Mdot
.63713 .14384 Mdot
.63718 .05826 Mdot
.63722 .05595 Mdot
.63727 .19675 Mdot
.63732 .04949 Mdot
.63737 .02611 Mdot
.63741 .39337 Mdot
.63746 .13655 Mdot
.63751 .09931 Mdot
.63756 .58152 Mdot
.63761 .5508 Mdot
.63765 .08112 Mdot
.6377 .08935 Mdot
.63775 .31153 Mdot
.6378 .4589 Mdot
.63784 .17916 Mdot
.63789 .46637 Mdot
.63794 .38429 Mdot
.63799 .07464 Mdot
.63803 .39647 Mdot
.63808 .42687 Mdot
.63813 .59672 Mdot
.63818 .42089 Mdot
.63822 .21272 Mdot
.63827 .29774 Mdot
.63832 .55317 Mdot
.63837 .37965 Mdot
.63841 .03068 Mdot
.63846 .26296 Mdot
.63851 .54177 Mdot
.63856 .58961 Mdot
.63861 .49745 Mdot
.63865 .17835 Mdot
.6387 .56357 Mdot
.63875 .05351 Mdot
.6388 .43104 Mdot
.63884 .10371 Mdot
.63889 .26676 Mdot
.63894 .19794 Mdot
.63899 .26659 Mdot
.63903 .24066 Mdot
.63908 .4858 Mdot
.63913 .138 Mdot
.63918 .47344 Mdot
.63922 .41712 Mdot
.63927 .4924 Mdot
.63932 .32044 Mdot
.63937 .27543 Mdot
.63941 .13409 Mdot
.63946 .54255 Mdot
.63951 .54412 Mdot
.63956 .25946 Mdot
.63961 .47446 Mdot
.63965 .01549 Mdot
.6397 .55784 Mdot
.63975 .36534 Mdot
.6398 .31082 Mdot
.63984 .05525 Mdot
.63989 .51903 Mdot
.63994 .53762 Mdot
.63999 .22181 Mdot
.64003 .39181 Mdot
.64008 .3358 Mdot
.64013 .28574 Mdot
.64018 .58448 Mdot
.64022 .50934 Mdot
.64027 .2125 Mdot
.64032 .41563 Mdot
.64037 .18207 Mdot
.64041 .03165 Mdot
.64046 .49539 Mdot
.64051 .15491 Mdot
.64056 .06268 Mdot
.6406 .09242 Mdot
.64065 .5546 Mdot
.6407 .49877 Mdot
.64075 .19155 Mdot
.6408 .09164 Mdot
.64084 .60009 Mdot
.64089 .14815 Mdot
.64094 .48405 Mdot
.64099 .0511 Mdot
.64103 .09577 Mdot
.64108 .21385 Mdot
.64113 .27695 Mdot
.64118 .26261 Mdot
.64122 .36329 Mdot
.64127 .53144 Mdot
.64132 .2958 Mdot
.64137 .35659 Mdot
.64141 .1655 Mdot
.64146 .13052 Mdot
.64151 .12844 Mdot
.64156 .33965 Mdot
.6416 .27344 Mdot
.64165 .57894 Mdot
.6417 .08047 Mdot
.64175 .26194 Mdot
.6418 .32216 Mdot
.64184 .09487 Mdot
.64189 .49224 Mdot
.64194 .18501 Mdot
.64199 .3254 Mdot
.64203 .55005 Mdot
.64208 .0229 Mdot
.64213 .14862 Mdot
.64218 .24434 Mdot
.64222 .35091 Mdot
.64227 .34928 Mdot
.64232 .48933 Mdot
.64237 .48437 Mdot
.64241 .4228 Mdot
.64246 .06819 Mdot
.64251 .14745 Mdot
.64256 .33358 Mdot
.6426 .30699 Mdot
.64265 .54307 Mdot
.6427 .41113 Mdot
.64275 .07486 Mdot
.6428 .33138 Mdot
.64284 .47731 Mdot
.64289 .1639 Mdot
.64294 .35602 Mdot
.64299 .25121 Mdot
.64303 .58839 Mdot
.64308 .58222 Mdot
.64313 .04533 Mdot
.64318 .30449 Mdot
.64322 .5802 Mdot
.64327 .44831 Mdot
.64332 .40431 Mdot
.64337 .5569 Mdot
.64341 .24564 Mdot
.64346 .5623 Mdot
.64351 .52326 Mdot
.64356 .14881 Mdot
.6436 .19216 Mdot
.64365 .42956 Mdot
.6437 .20439 Mdot
.64375 .44515 Mdot
.6438 .25241 Mdot
.64384 .03315 Mdot
.64389 .14424 Mdot
.64394 .12848 Mdot
.64399 .37842 Mdot
.64403 .47257 Mdot
.64408 .39155 Mdot
.64413 .4806 Mdot
.64418 .39335 Mdot
.64422 .49368 Mdot
.64427 .36092 Mdot
.64432 .19082 Mdot
.64437 .41648 Mdot
.64441 .06008 Mdot
.64446 .55994 Mdot
.64451 .23724 Mdot
.64456 .18555 Mdot
.6446 .1011 Mdot
.64465 .05138 Mdot
.6447 .10314 Mdot
.64475 .59671 Mdot
.6448 .27486 Mdot
.64484 .45032 Mdot
.64489 .26131 Mdot
.64494 .35901 Mdot
.64499 .25643 Mdot
.64503 .32078 Mdot
.64508 .14754 Mdot
.64513 .58391 Mdot
.64518 .38718 Mdot
.64522 .53256 Mdot
.64527 .27027 Mdot
.64532 .20526 Mdot
.64537 .49682 Mdot
.64541 .18635 Mdot
.64546 .09416 Mdot
.64551 .39211 Mdot
.64556 .45145 Mdot
.6456 .22974 Mdot
.64565 .46024 Mdot
.6457 .22127 Mdot
.64575 .36506 Mdot
.64579 .19307 Mdot
.64584 .37181 Mdot
.64589 .22789 Mdot
.64594 .10491 Mdot
.64599 .34608 Mdot
.64603 .12521 Mdot
.64608 .47221 Mdot
.64613 .45181 Mdot
.64618 .04 Mdot
.64622 .581 Mdot
.64627 .49162 Mdot
.64632 .07934 Mdot
.64637 .11076 Mdot
.64641 .32544 Mdot
.64646 .30107 Mdot
.64651 .18584 Mdot
.64656 .52774 Mdot
.6466 .24599 Mdot
.64665 .51228 Mdot
.6467 .33771 Mdot
.64675 .31271 Mdot
.64679 .38908 Mdot
.64684 .30572 Mdot
.64689 .57597 Mdot
.64694 .13435 Mdot
.64699 .03197 Mdot
.64703 .09254 Mdot
.64708 .48577 Mdot
.64713 .3916 Mdot
.64718 .51008 Mdot
.64722 .22366 Mdot
.64727 .04867 Mdot
.64732 .36631 Mdot
.64737 .53241 Mdot
.64741 .33536 Mdot
.64746 .57266 Mdot
.64751 .27026 Mdot
.64756 .22168 Mdot
.6476 .049 Mdot
.64765 .40153 Mdot
.6477 .34584 Mdot
.64775 .57901 Mdot
.64779 .14004 Mdot
.64784 .07853 Mdot
.64789 .04784 Mdot
.64794 .20464 Mdot
.64799 .43765 Mdot
.64803 .10588 Mdot
.64808 .51681 Mdot
.64813 .18738 Mdot
.64818 .35982 Mdot
.64822 .22343 Mdot
.64827 .13992 Mdot
.64832 .28062 Mdot
.64837 .15087 Mdot
.64841 .18946 Mdot
.64846 .37693 Mdot
.64851 .35153 Mdot
.64856 .41884 Mdot
.6486 .22013 Mdot
.64865 .12138 Mdot
.6487 .14457 Mdot
.64875 .38455 Mdot
.64879 .42193 Mdot
.64884 .37887 Mdot
.64889 .16888 Mdot
.64894 .25921 Mdot
.64899 .35811 Mdot
.64903 .34574 Mdot
.64908 .56757 Mdot
.64913 .42489 Mdot
.64918 .26694 Mdot
.64922 .43225 Mdot
.64927 .3949 Mdot
.64932 .07977 Mdot
.64937 .05822 Mdot
.64941 .30704 Mdot
.64946 .12899 Mdot
.64951 .53223 Mdot
.64956 .47208 Mdot
.6496 .53344 Mdot
.64965 .38079 Mdot
.6497 .12809 Mdot
.64975 .26666 Mdot
.64979 .42676 Mdot
.64984 .25093 Mdot
.64989 .34687 Mdot
.64994 .44806 Mdot
.64999 .0626 Mdot
.65003 .09676 Mdot
.65008 .10236 Mdot
.65013 .10466 Mdot
.65018 .32019 Mdot
.65022 .13251 Mdot
.65027 .2808 Mdot
.65032 .44104 Mdot
.65037 .49126 Mdot
.65041 .34093 Mdot
.65046 .21573 Mdot
.65051 .39754 Mdot
.65056 .19893 Mdot
.6506 .22665 Mdot
.65065 .28684 Mdot
.6507 .52879 Mdot
.65075 .26882 Mdot
.65079 .44918 Mdot
.65084 .17345 Mdot
.65089 .27684 Mdot
.65094 .44538 Mdot
.65098 .21296 Mdot
.65103 .42991 Mdot
.65108 .43211 Mdot
.65113 .39749 Mdot
.65118 .13091 Mdot
.65122 .34225 Mdot
.65127 .34216 Mdot
.65132 .092 Mdot
.65137 .60173 Mdot
.65141 .07616 Mdot
.65146 .50444 Mdot
.65151 .20407 Mdot
.65156 .2755 Mdot
.6516 .46375 Mdot
.65165 .12161 Mdot
.6517 .01984 Mdot
.65175 .06357 Mdot
.65179 .19162 Mdot
.65184 .19615 Mdot
.65189 .35435 Mdot
.65194 .21771 Mdot
.65198 .03288 Mdot
.65203 .52264 Mdot
.65208 .5123 Mdot
.65213 .01945 Mdot
.65218 .2063 Mdot
.65222 .10524 Mdot
.65227 .12952 Mdot
.65232 .49186 Mdot
.65237 .46738 Mdot
.65241 .36641 Mdot
.65246 .05223 Mdot
.65251 .49346 Mdot
.65256 .40593 Mdot
.6526 .46529 Mdot
.65265 .45149 Mdot
.6527 .23266 Mdot
.65275 .5455 Mdot
.65279 .35838 Mdot
.65284 .44635 Mdot
.65289 .18381 Mdot
.65294 .36859 Mdot
.65298 .17694 Mdot
.65303 .10671 Mdot
.65308 .56943 Mdot
.65313 .35042 Mdot
.65318 .25763 Mdot
.65322 .19773 Mdot
.65327 .56468 Mdot
.65332 .15883 Mdot
.65337 .16709 Mdot
.65341 .08292 Mdot
.65346 .08753 Mdot
.65351 .29478 Mdot
.65356 .40401 Mdot
.6536 .0454 Mdot
.65365 .1974 Mdot
.6537 .49218 Mdot
.65375 .54205 Mdot
.65379 .19724 Mdot
.65384 .56806 Mdot
.65389 .55 Mdot
.65394 .19837 Mdot
.65398 .35422 Mdot
.65403 .39896 Mdot
.65408 .19612 Mdot
.65413 .03614 Mdot
.65418 .26222 Mdot
.65422 .43286 Mdot
.65427 .44902 Mdot
.65432 .38184 Mdot
.65437 .0792 Mdot
.65441 .4715 Mdot
.65446 .3049 Mdot
.65451 .22946 Mdot
.65456 .5996 Mdot
.6546 .39868 Mdot
.65465 .02483 Mdot
.6547 .42877 Mdot
.65475 .56891 Mdot
.65479 .21599 Mdot
.65484 .13598 Mdot
.65489 .49004 Mdot
.65494 .38638 Mdot
.65498 .25126 Mdot
.65503 .18931 Mdot
.65508 .30638 Mdot
.65513 .04687 Mdot
.65517 .45563 Mdot
.65522 .59652 Mdot
.65527 .28494 Mdot
.65532 .38798 Mdot
.65537 .03748 Mdot
.65541 .16221 Mdot
.65546 .50643 Mdot
.65551 .32349 Mdot
.65556 .1693 Mdot
.6556 .46063 Mdot
.65565 .29168 Mdot
.6557 .32721 Mdot
.65575 .37395 Mdot
.65579 .45051 Mdot
.65584 .46624 Mdot
.65589 .36163 Mdot
.65594 .17266 Mdot
.65598 .32924 Mdot
.65603 .57952 Mdot
.65608 .57857 Mdot
.65613 .52473 Mdot
.65617 .15464 Mdot
.65622 .28786 Mdot
.65627 .54641 Mdot
.65632 .08381 Mdot
.65637 .16144 Mdot
.65641 .01762 Mdot
.65646 .17314 Mdot
.65651 .06104 Mdot
.65656 .60256 Mdot
.6566 .11452 Mdot
.65665 .45298 Mdot
.6567 .49507 Mdot
.65675 .15664 Mdot
.65679 .42616 Mdot
.65684 .14048 Mdot
.65689 .13583 Mdot
.65694 .30946 Mdot
.65698 .56324 Mdot
.65703 .38217 Mdot
.65708 .56649 Mdot
.65713 .58355 Mdot
.65717 .58704 Mdot
.65722 .40692 Mdot
.65727 .05647 Mdot
.65732 .44362 Mdot
.65737 .3139 Mdot
.65741 .46384 Mdot
.65746 .57599 Mdot
.65751 .29689 Mdot
.65756 .31099 Mdot
.6576 .3054 Mdot
.65765 .52966 Mdot
.6577 .29765 Mdot
.65775 .21118 Mdot
.65779 .45575 Mdot
.65784 .0493 Mdot
.65789 .15572 Mdot
.65794 .38835 Mdot
.65798 .32998 Mdot
.65803 .5168 Mdot
.65808 .44959 Mdot
.65813 .42843 Mdot
.65817 .55113 Mdot
.65822 .55363 Mdot
.65827 .46937 Mdot
.65832 .44471 Mdot
.65837 .15892 Mdot
.65841 .51187 Mdot
.65846 .04045 Mdot
.65851 .14552 Mdot
.65856 .29841 Mdot
.6586 .5392 Mdot
.65865 .34689 Mdot
.6587 .43786 Mdot
.65875 .59633 Mdot
.65879 .02425 Mdot
.65884 .06395 Mdot
.65889 .24139 Mdot
.65894 .15529 Mdot
.65898 .57827 Mdot
.65903 .51155 Mdot
.65908 .45636 Mdot
.65913 .42863 Mdot
.65917 .07618 Mdot
.65922 .07667 Mdot
.65927 .04264 Mdot
.65932 .48082 Mdot
.65937 .12587 Mdot
.65941 .21063 Mdot
.65946 .20126 Mdot
.65951 .33661 Mdot
.65956 .21733 Mdot
.6596 .18489 Mdot
.65965 .07045 Mdot
.6597 .05291 Mdot
.65975 .28145 Mdot
.65979 .44132 Mdot
.65984 .23591 Mdot
.65989 .05991 Mdot
.65994 .27191 Mdot
.65998 .39208 Mdot
.66003 .59785 Mdot
.66008 .50794 Mdot
.66013 .29697 Mdot
.66017 .48386 Mdot
.66022 .15619 Mdot
.66027 .09402 Mdot
.66032 .23549 Mdot
.66036 .42189 Mdot
.66041 .12826 Mdot
.66046 .21652 Mdot
.66051 .12433 Mdot
.66056 .22596 Mdot
.6606 .53033 Mdot
.66065 .48323 Mdot
.6607 .51033 Mdot
.66075 .05578 Mdot
.66079 .47459 Mdot
.66084 .44503 Mdot
.66089 .24358 Mdot
.66094 .21778 Mdot
.66098 .25339 Mdot
.66103 .39983 Mdot
.66108 .57499 Mdot
.66113 .42903 Mdot
.66117 .25886 Mdot
.66122 .49521 Mdot
.66127 .29273 Mdot
.66132 .5485 Mdot
.66136 .11738 Mdot
.66141 .4159 Mdot
.66146 .07195 Mdot
.66151 .14131 Mdot
.66156 .59244 Mdot
.6616 .21409 Mdot
.66165 .55094 Mdot
.6617 .51868 Mdot
.66175 .07683 Mdot
.66179 .33418 Mdot
.66184 .05532 Mdot
.66189 .4776 Mdot
.66194 .20556 Mdot
.66198 .49248 Mdot
.66203 .41507 Mdot
.66208 .27453 Mdot
.66213 .5555 Mdot
.66217 .10736 Mdot
.66222 .4434 Mdot
.66227 .44883 Mdot
.66232 .31135 Mdot
.66236 .21547 Mdot
.66241 .16538 Mdot
.66246 .50365 Mdot
.66251 .20868 Mdot
.66256 .4029 Mdot
.6626 .10814 Mdot
.66265 .37705 Mdot
.6627 .21956 Mdot
.66275 .20352 Mdot
.66279 .16052 Mdot
.66284 .4617 Mdot
.66289 .15744 Mdot
.66294 .47267 Mdot
.66298 .11991 Mdot
.66303 .58742 Mdot
.66308 .5552 Mdot
.66313 .58352 Mdot
.66317 .30816 Mdot
.66322 .32761 Mdot
.66327 .60303 Mdot
.66332 .49087 Mdot
.66336 .46809 Mdot
.66341 .48211 Mdot
.66346 .30638 Mdot
.66351 .29011 Mdot
.66356 .31742 Mdot
.6636 .58178 Mdot
.66365 .11241 Mdot
.6637 .49053 Mdot
.66375 .22399 Mdot
.66379 .21944 Mdot
.66384 .49618 Mdot
.66389 .30172 Mdot
.66394 .07817 Mdot
.66398 .36106 Mdot
.66403 .35344 Mdot
.66408 .43238 Mdot
.66413 .56159 Mdot
.66417 .37697 Mdot
.66422 .40156 Mdot
.66427 .45219 Mdot
.66432 .26814 Mdot
.66436 .06407 Mdot
.66441 .40186 Mdot
.66446 .56465 Mdot
.66451 .40338 Mdot
.66455 .18529 Mdot
.6646 .11019 Mdot
.66465 .28925 Mdot
.6647 .10067 Mdot
.66475 .20684 Mdot
.66479 .6011 Mdot
.66484 .40204 Mdot
.66489 .48001 Mdot
.66494 .59073 Mdot
.66498 .11963 Mdot
.66503 .11503 Mdot
.66508 .41654 Mdot
.66513 .24437 Mdot
.66517 .36952 Mdot
.66522 .28597 Mdot
.66527 .45827 Mdot
.66532 .47073 Mdot
.66536 .57128 Mdot
.66541 .4371 Mdot
.66546 .20484 Mdot
.66551 .42137 Mdot
.66555 .18412 Mdot
.6656 .47578 Mdot
.66565 .40479 Mdot
.6657 .25079 Mdot
.66575 .08864 Mdot
.66579 .20123 Mdot
.66584 .31883 Mdot
.66589 .05866 Mdot
.66594 .09087 Mdot
.66598 .40252 Mdot
.66603 .44215 Mdot
.66608 .07126 Mdot
.66613 .57456 Mdot
.66617 .3022 Mdot
.66622 .04032 Mdot
.66627 .43021 Mdot
.66632 .21975 Mdot
.66636 .03094 Mdot
.66641 .18537 Mdot
.66646 .56281 Mdot
.66651 .2518 Mdot
.66655 .19716 Mdot
.6666 .58385 Mdot
.66665 .15614 Mdot
.6667 .08239 Mdot
.66675 .32471 Mdot
.66679 .19377 Mdot
.66684 .50868 Mdot
.66689 .59707 Mdot
.66694 .13818 Mdot
.66698 .47827 Mdot
.66703 .46473 Mdot
.66708 .52091 Mdot
.66713 .33899 Mdot
.66717 .05083 Mdot
.66722 .40818 Mdot
.66727 .54968 Mdot
.66732 .0515 Mdot
.66736 .02523 Mdot
.66741 .58129 Mdot
.66746 .34464 Mdot
.66751 .03528 Mdot
.66755 .44318 Mdot
.6676 .03319 Mdot
.66765 .10754 Mdot
.6677 .44144 Mdot
.66775 .46265 Mdot
.66779 .48037 Mdot
.66784 .03987 Mdot
.66789 .13144 Mdot
.66794 .28359 Mdot
.66798 .57502 Mdot
.66803 .04612 Mdot
.66808 .59658 Mdot
.66813 .40864 Mdot
.66817 .125 Mdot
.66822 .12853 Mdot
.66827 .2723 Mdot
.66832 .37252 Mdot
.66836 .32015 Mdot
.66841 .18218 Mdot
.66846 .2355 Mdot
.66851 .362 Mdot
.66855 .34218 Mdot
.6686 .44087 Mdot
.66865 .21493 Mdot
.6687 .52215 Mdot
.66875 .3237 Mdot
.66879 .34803 Mdot
.66884 .37682 Mdot
.66889 .0742 Mdot
.66894 .44665 Mdot
.66898 .32287 Mdot
.66903 .26008 Mdot
.66908 .39394 Mdot
.66913 .47496 Mdot
.66917 .29146 Mdot
.66922 .26683 Mdot
.66927 .58862 Mdot
.66932 .36467 Mdot
.66936 .17764 Mdot
.66941 .59785 Mdot
.66946 .23081 Mdot
.66951 .05923 Mdot
.66955 .59878 Mdot
.6696 .37706 Mdot
.66965 .47213 Mdot
.6697 .32038 Mdot
.66974 .17263 Mdot
.66979 .17683 Mdot
.66984 .55331 Mdot
.66989 .6 Mdot
.66994 .42792 Mdot
.66998 .40334 Mdot
.67003 .49381 Mdot
.67008 .16806 Mdot
.67013 .11975 Mdot
.67017 .15796 Mdot
.67022 .11458 Mdot
.67027 .29642 Mdot
.67032 .43162 Mdot
.67036 .49446 Mdot
.67041 .12929 Mdot
.67046 .53508 Mdot
.67051 .26869 Mdot
.67055 .49994 Mdot
.6706 .50181 Mdot
.67065 .49056 Mdot
.6707 .27323 Mdot
.67074 .13759 Mdot
.67079 .04439 Mdot
.67084 .18489 Mdot
.67089 .11531 Mdot
.67094 .56408 Mdot
.67098 .09441 Mdot
.67103 .18821 Mdot
.67108 .29072 Mdot
.67113 .17545 Mdot
.67117 .20392 Mdot
.67122 .03486 Mdot
.67127 .18567 Mdot
.67132 .03219 Mdot
.67136 .10405 Mdot
.67141 .34176 Mdot
.67146 .35738 Mdot
.67151 .14106 Mdot
.67155 .57808 Mdot
.6716 .41001 Mdot
.67165 .1034 Mdot
.6717 .24445 Mdot
.67174 .09099 Mdot
.67179 .52278 Mdot
.67184 .4335 Mdot
.67189 .12157 Mdot
.67194 .06131 Mdot
.67198 .3526 Mdot
.67203 .33289 Mdot
.67208 .16082 Mdot
.67213 .57023 Mdot
.67217 .1791 Mdot
.67222 .05688 Mdot
.67227 .58869 Mdot
.67232 .38102 Mdot
.67236 .15894 Mdot
.67241 .47454 Mdot
.67246 .57121 Mdot
.67251 .29168 Mdot
.67255 .42051 Mdot
.6726 .13187 Mdot
.67265 .44486 Mdot
.6727 .31692 Mdot
.67274 .02521 Mdot
.67279 .04317 Mdot
.67284 .21512 Mdot
.67289 .24065 Mdot
.67294 .10575 Mdot
.67298 .213 Mdot
.67303 .10826 Mdot
.67308 .19405 Mdot
.67313 .35648 Mdot
.67317 .48343 Mdot
.67322 .55077 Mdot
.67327 .22715 Mdot
.67332 .19209 Mdot
.67336 .44126 Mdot
.67341 .56541 Mdot
.67346 .44945 Mdot
.67351 .04785 Mdot
.67355 .57005 Mdot
.6736 .59752 Mdot
.67365 .17248 Mdot
.6737 .23067 Mdot
.67374 .45289 Mdot
.67379 .16737 Mdot
.67384 .45888 Mdot
.67389 .22018 Mdot
.67393 .42442 Mdot
.67398 .55557 Mdot
.67403 .23294 Mdot
.67408 .12913 Mdot
.67413 .22613 Mdot
.67417 .46202 Mdot
.67422 .0536 Mdot
.67427 .37598 Mdot
.67432 .34602 Mdot
.67436 .51457 Mdot
.67441 .42978 Mdot
.67446 .1986 Mdot
.67451 .50809 Mdot
.67455 .55249 Mdot
.6746 .58366 Mdot
.67465 .16545 Mdot
.6747 .54136 Mdot
.67474 .55829 Mdot
.67479 .42588 Mdot
.67484 .5381 Mdot
.67489 .10318 Mdot
.67493 .40563 Mdot
.67498 .57033 Mdot
.67503 .33263 Mdot
.67508 .28209 Mdot
.67513 .45338 Mdot
.67517 .35209 Mdot
.67522 .21821 Mdot
.67527 .07067 Mdot
.67532 .59469 Mdot
.67536 .3132 Mdot
.67541 .44556 Mdot
.67546 .32797 Mdot
.67551 .09483 Mdot
.67555 .48674 Mdot
.6756 .26167 Mdot
.67565 .42321 Mdot
.6757 .14566 Mdot
.67574 .50641 Mdot
.67579 .11093 Mdot
.67584 .48518 Mdot
.67589 .19069 Mdot
.67593 .09523 Mdot
.67598 .17616 Mdot
.67603 .3967 Mdot
.67608 .38839 Mdot
.67613 .12823 Mdot
.67617 .44685 Mdot
.67622 .12932 Mdot
.67627 .53833 Mdot
.67632 .37946 Mdot
.67636 .24335 Mdot
.67641 .07336 Mdot
.67646 .54696 Mdot
.67651 .08098 Mdot
.67655 .40111 Mdot
.6766 .34871 Mdot
.67665 .46685 Mdot
.6767 .19757 Mdot
.67674 .15414 Mdot
.67679 .52882 Mdot
.67684 .3359 Mdot
.67689 .29449 Mdot
.67693 .05792 Mdot
.67698 .05835 Mdot
.67703 .15991 Mdot
.67708 .21396 Mdot
.67713 .48509 Mdot
.67717 .26498 Mdot
.67722 .37485 Mdot
.67727 .10044 Mdot
.67732 .05295 Mdot
.67736 .15037 Mdot
.67741 .43985 Mdot
.67746 .3243 Mdot
.67751 .41293 Mdot
.67755 .09172 Mdot
.6776 .49621 Mdot
.67765 .25803 Mdot
.6777 .02652 Mdot
.67774 .34633 Mdot
.67779 .04407 Mdot
.67784 .07518 Mdot
.67789 .47571 Mdot
.67793 .42084 Mdot
.67798 .3115 Mdot
.67803 .38402 Mdot
.67808 .43249 Mdot
.67813 .37719 Mdot
.67817 .1663 Mdot
.67822 .18476 Mdot
.67827 .55073 Mdot
.67832 .12692 Mdot
.67836 .39477 Mdot
.67841 .09903 Mdot
.67846 .5125 Mdot
.67851 .57987 Mdot
.67855 .55824 Mdot
.6786 .37805 Mdot
.67865 .11428 Mdot
.6787 .50286 Mdot
.67874 .07674 Mdot
.67879 .13473 Mdot
.67884 .10247 Mdot
.67889 .17124 Mdot
.67893 .04738 Mdot
.67898 .07426 Mdot
.67903 .23009 Mdot
.67908 .35373 Mdot
.67912 .3392 Mdot
.67917 .29357 Mdot
.67922 .40092 Mdot
.67927 .57987 Mdot
.67932 .18761 Mdot
.67936 .12351 Mdot
.67941 .45351 Mdot
.67946 .46766 Mdot
.67951 .39617 Mdot
.67955 .03919 Mdot
.6796 .54433 Mdot
.67965 .49111 Mdot
.6797 .44125 Mdot
.67974 .26447 Mdot
.67979 .44476 Mdot
.67984 .59157 Mdot
.67989 .37922 Mdot
.67993 .14445 Mdot
.67998 .357 Mdot
.68003 .43504 Mdot
.68008 .34655 Mdot
.68012 .0849 Mdot
.68017 .14163 Mdot
.68022 .09602 Mdot
.68027 .02206 Mdot
.68032 .39465 Mdot
.68036 .34404 Mdot
.68041 .11948 Mdot
.68046 .43777 Mdot
.68051 .28585 Mdot
.68055 .49385 Mdot
.6806 .25514 Mdot
.68065 .05631 Mdot
.6807 .26136 Mdot
.68074 .55284 Mdot
.68079 .36735 Mdot
.68084 .21839 Mdot
.68089 .60022 Mdot
.68093 .12279 Mdot
.68098 .37911 Mdot
.68103 .44249 Mdot
.68108 .47048 Mdot
.68112 .36911 Mdot
.68117 .54739 Mdot
.68122 .11065 Mdot
.68127 .40029 Mdot
.68132 .24219 Mdot
.68136 .46608 Mdot
.68141 .1033 Mdot
.68146 .02035 Mdot
.68151 .50148 Mdot
.68155 .36131 Mdot
.6816 .26885 Mdot
.68165 .33782 Mdot
.6817 .02234 Mdot
.68174 .12088 Mdot
.68179 .22725 Mdot
.68184 .09117 Mdot
.68189 .07282 Mdot
.68193 .35685 Mdot
.68198 .02357 Mdot
.68203 .09427 Mdot
.68208 .55335 Mdot
.68212 .58107 Mdot
.68217 .1844 Mdot
.68222 .22712 Mdot
.68227 .19895 Mdot
.68232 .04839 Mdot
.68236 .08846 Mdot
.68241 .43015 Mdot
.68246 .56008 Mdot
.68251 .18563 Mdot
.68255 .58849 Mdot
.6826 .42451 Mdot
.68265 .07331 Mdot
.6827 .42765 Mdot
.68274 .33435 Mdot
.68279 .1014 Mdot
.68284 .06568 Mdot
.68289 .32148 Mdot
.68293 .12181 Mdot
.68298 .02493 Mdot
.68303 .59618 Mdot
.68308 .56796 Mdot
.68312 .11295 Mdot
.68317 .53398 Mdot
.68322 .05754 Mdot
.68327 .59021 Mdot
.68332 .53187 Mdot
.68336 .32157 Mdot
.68341 .46192 Mdot
.68346 .55654 Mdot
.68351 .45812 Mdot
.68355 .49475 Mdot
.6836 .50516 Mdot
.68365 .38561 Mdot
.6837 .47295 Mdot
.68374 .08494 Mdot
.68379 .44657 Mdot
.68384 .56129 Mdot
.68389 .15331 Mdot
.68393 .58687 Mdot
.68398 .3956 Mdot
.68403 .25452 Mdot
.68408 .04621 Mdot
.68412 .57665 Mdot
.68417 .40274 Mdot
.68422 .28989 Mdot
.68427 .53658 Mdot
.68431 .05737 Mdot
.68436 .35991 Mdot
.68441 .303 Mdot
.68446 .01942 Mdot
.68451 .33912 Mdot
.68455 .50132 Mdot
.6846 .34979 Mdot
.68465 .16463 Mdot
.6847 .4477 Mdot
.68474 .59948 Mdot
.68479 .5675 Mdot
.68484 .295 Mdot
.68489 .37746 Mdot
.68493 .16762 Mdot
.68498 .02092 Mdot
.68503 .1564 Mdot
.68508 .39392 Mdot
.68512 .37534 Mdot
.68517 .36973 Mdot
.68522 .1249 Mdot
.68527 .42059 Mdot
.68531 .57593 Mdot
.68536 .09455 Mdot
.68541 .19164 Mdot
.68546 .37793 Mdot
.68551 .23072 Mdot
.68555 .39487 Mdot
.6856 .18693 Mdot
.68565 .05351 Mdot
.6857 .33273 Mdot
.68574 .05979 Mdot
.68579 .03701 Mdot
.68584 .20914 Mdot
.68589 .33658 Mdot
.68593 .09561 Mdot
.68598 .34533 Mdot
.68603 .435 Mdot
.68608 .18367 Mdot
.68612 .0894 Mdot
.68617 .20364 Mdot
.68622 .05579 Mdot
.68627 .41166 Mdot
.68631 .32299 Mdot
.68636 .09345 Mdot
.68641 .23852 Mdot
.68646 .43906 Mdot
.68651 .24315 Mdot
.68655 .50513 Mdot
.6866 .46392 Mdot
.68665 .22304 Mdot
.6867 .45161 Mdot
.68674 .33291 Mdot
.68679 .42512 Mdot
.68684 .49363 Mdot
.68689 .40653 Mdot
.68693 .31061 Mdot
.68698 .23069 Mdot
.68703 .17176 Mdot
.68708 .32563 Mdot
.68712 .5686 Mdot
.68717 .39902 Mdot
.68722 .59141 Mdot
.68727 .25094 Mdot
.68731 .37967 Mdot
.68736 .35794 Mdot
.68741 .19446 Mdot
.68746 .53127 Mdot
.68751 .30092 Mdot
.68755 .13412 Mdot
.6876 .35873 Mdot
.68765 .30283 Mdot
.6877 .39911 Mdot
.68774 .27352 Mdot
.68779 .15039 Mdot
.68784 .45454 Mdot
.68789 .08091 Mdot
.68793 .45173 Mdot
.68798 .26009 Mdot
.68803 .06272 Mdot
.68808 .37363 Mdot
.68812 .23575 Mdot
.68817 .10304 Mdot
.68822 .34042 Mdot
.68827 .40835 Mdot
.68831 .44006 Mdot
.68836 .11495 Mdot
.68841 .10419 Mdot
.68846 .0434 Mdot
.6885 .09683 Mdot
.68855 .52382 Mdot
.6886 .17625 Mdot
.68865 .3458 Mdot
.6887 .56603 Mdot
.68874 .1798 Mdot
.68879 .47674 Mdot
.68884 .55001 Mdot
.68889 .30722 Mdot
.68893 .04412 Mdot
.68898 .03691 Mdot
.68903 .48381 Mdot
.68908 .45881 Mdot
.68912 .38736 Mdot
.68917 .57751 Mdot
.68922 .12489 Mdot
.68927 .23777 Mdot
.68931 .29903 Mdot
.68936 .2518 Mdot
.68941 .31986 Mdot
.68946 .40104 Mdot
.6895 .19878 Mdot
.68955 .16231 Mdot
.6896 .29118 Mdot
.68965 .31892 Mdot
.6897 .27828 Mdot
.68974 .58939 Mdot
.68979 .5487 Mdot
.68984 .35621 Mdot
.68989 .11319 Mdot
.68993 .12736 Mdot
.68998 .60202 Mdot
.69003 .0637 Mdot
.69008 .08378 Mdot
.69012 .10516 Mdot
.69017 .13292 Mdot
.69022 .20821 Mdot
.69027 .29975 Mdot
.69031 .13097 Mdot
.69036 .02274 Mdot
.69041 .57377 Mdot
.69046 .01543 Mdot
.6905 .4825 Mdot
.69055 .30621 Mdot
.6906 .18744 Mdot
.69065 .41998 Mdot
.6907 .3349 Mdot
.69074 .02974 Mdot
.69079 .47184 Mdot
.69084 .1564 Mdot
.69089 .34883 Mdot
.69093 .08436 Mdot
.69098 .13034 Mdot
.69103 .05792 Mdot
.69108 .23618 Mdot
.69112 .08567 Mdot
.69117 .08135 Mdot
.69122 .57746 Mdot
.69127 .14573 Mdot
.69131 .55607 Mdot
.69136 .47647 Mdot
.69141 .29242 Mdot
.69146 .02947 Mdot
.6915 .54804 Mdot
.69155 .50603 Mdot
.6916 .2917 Mdot
.69165 .1503 Mdot
.6917 .25654 Mdot
.69174 .3333 Mdot
.69179 .47505 Mdot
.69184 .41873 Mdot
.69189 .24151 Mdot
.69193 .46478 Mdot
.69198 .33335 Mdot
.69203 .08461 Mdot
.69208 .17186 Mdot
.69212 .34915 Mdot
.69217 .29014 Mdot
.69222 .45175 Mdot
.69227 .1009 Mdot
.69231 .2825 Mdot
.69236 .316 Mdot
.69241 .32072 Mdot
.69246 .14815 Mdot
.6925 .40936 Mdot
.69255 .03829 Mdot
.6926 .30596 Mdot
.69265 .20344 Mdot
.6927 .50666 Mdot
.69274 .34992 Mdot
.69279 .17037 Mdot
.69284 .55023 Mdot
.69289 .18807 Mdot
.69293 .4782 Mdot
.69298 .35497 Mdot
.69303 .32343 Mdot
.69308 .32661 Mdot
.69312 .15955 Mdot
.69317 .28507 Mdot
.69322 .16628 Mdot
.69327 .58079 Mdot
.69331 .47274 Mdot
.69336 .43665 Mdot
.69341 .08009 Mdot
.69346 .313 Mdot
.6935 .17144 Mdot
.69355 .13063 Mdot
.6936 .53526 Mdot
.69365 .50697 Mdot
.69369 .14786 Mdot
.69374 .428 Mdot
.69379 .34652 Mdot
.69384 .01501 Mdot
.69389 .40127 Mdot
.69393 .27234 Mdot
.69398 .39962 Mdot
.69403 .43027 Mdot
.69408 .5264 Mdot
.69412 .52069 Mdot
.69417 .0909 Mdot
.69422 .11836 Mdot
.69427 .38156 Mdot
.69431 .25032 Mdot
.69436 .52795 Mdot
.69441 .14089 Mdot
.69446 .51214 Mdot
.6945 .417 Mdot
.69455 .46257 Mdot
.6946 .43122 Mdot
.69465 .35541 Mdot
.69469 .30107 Mdot
.69474 .53064 Mdot
.69479 .52758 Mdot
.69484 .22226 Mdot
.69489 .4764 Mdot
.69493 .19882 Mdot
.69498 .52727 Mdot
.69503 .42432 Mdot
.69508 .21877 Mdot
.69512 .40253 Mdot
.69517 .11171 Mdot
.69522 .50124 Mdot
.69527 .30141 Mdot
.69531 .32633 Mdot
.69536 .59668 Mdot
.69541 .1344 Mdot
.69546 .06579 Mdot
.6955 .40171 Mdot
.69555 .47049 Mdot
.6956 .22558 Mdot
.69565 .25212 Mdot
.69569 .54246 Mdot
.69574 .05398 Mdot
.69579 .47349 Mdot
.69584 .55437 Mdot
.69589 .02653 Mdot
.69593 .12973 Mdot
.69598 .26594 Mdot
.69603 .09268 Mdot
.69608 .43104 Mdot
.69612 .20578 Mdot
.69617 .44495 Mdot
.69622 .47723 Mdot
.69627 .04322 Mdot
.69631 .10877 Mdot
.69636 .54703 Mdot
.69641 .19053 Mdot
.69646 .32021 Mdot
.6965 .11542 Mdot
.69655 .42734 Mdot
.6966 .13945 Mdot
.69665 .52182 Mdot
.69669 .24826 Mdot
.69674 .21647 Mdot
.69679 .49065 Mdot
.69684 .58268 Mdot
.69689 .20899 Mdot
.69693 .34631 Mdot
.69698 .53961 Mdot
.69703 .57086 Mdot
.69708 .09397 Mdot
.69712 .09508 Mdot
.69717 .46163 Mdot
.69722 .15453 Mdot
.69727 .49152 Mdot
.69731 .25345 Mdot
.69736 .58772 Mdot
.69741 .12603 Mdot
.69746 .39745 Mdot
.6975 .30975 Mdot
.69755 .4119 Mdot
.6976 .40914 Mdot
.69765 .29673 Mdot
.69769 .48573 Mdot
.69774 .28716 Mdot
.69779 .49065 Mdot
.69784 .06318 Mdot
.69788 .28397 Mdot
.69793 .39983 Mdot
.69798 .51129 Mdot
.69803 .45752 Mdot
.69808 .54099 Mdot
.69812 .46355 Mdot
.69817 .54376 Mdot
.69822 .37826 Mdot
.69827 .46062 Mdot
.69831 .01662 Mdot
.69836 .40393 Mdot
.69841 .49007 Mdot
.69846 .22188 Mdot
.6985 .03222 Mdot
.69855 .29261 Mdot
.6986 .10733 Mdot
.69865 .51545 Mdot
.69869 .22365 Mdot
.69874 .48679 Mdot
.69879 .41392 Mdot
.69884 .04443 Mdot
.69888 .53982 Mdot
.69893 .59947 Mdot
.69898 .36545 Mdot
.69903 .36378 Mdot
.69908 .1547 Mdot
.69912 .10289 Mdot
.69917 .51125 Mdot
.69922 .42612 Mdot
.69927 .29447 Mdot
.69931 .16246 Mdot
.69936 .1477 Mdot
.69941 .56882 Mdot
.69946 .29256 Mdot
.6995 .36186 Mdot
.69955 .26096 Mdot
.6996 .36165 Mdot
.69965 .27505 Mdot
.69969 .08395 Mdot
.69974 .16834 Mdot
.69979 .44953 Mdot
.69984 .06611 Mdot
.69988 .20048 Mdot
.69993 .35774 Mdot
.69998 .41981 Mdot
.70003 .12962 Mdot
.70008 .20434 Mdot
.70012 .59562 Mdot
.70017 .07074 Mdot
.70022 .57825 Mdot
.70027 .11615 Mdot
.70031 .09907 Mdot
.70036 .24795 Mdot
.70041 .29848 Mdot
.70046 .55702 Mdot
.7005 .55469 Mdot
.70055 .28245 Mdot
.7006 .02063 Mdot
.70065 .20987 Mdot
.70069 .30845 Mdot
.70074 .52413 Mdot
.70079 .34891 Mdot
.70084 .14063 Mdot
.70088 .15482 Mdot
.70093 .08931 Mdot
.70098 .29751 Mdot
.70103 .54347 Mdot
.70108 .4004 Mdot
.70112 .27282 Mdot
.70117 .1826 Mdot
.70122 .35385 Mdot
.70127 .40811 Mdot
.70131 .21679 Mdot
.70136 .20768 Mdot
.70141 .2524 Mdot
.70146 .32375 Mdot
.7015 .57217 Mdot
.70155 .51252 Mdot
.7016 .29871 Mdot
.70165 .37238 Mdot
.70169 .30442 Mdot
.70174 .5066 Mdot
.70179 .10355 Mdot
.70184 .07864 Mdot
.70188 .38362 Mdot
.70193 .1724 Mdot
.70198 .56624 Mdot
.70203 .52715 Mdot
.70208 .30902 Mdot
.70212 .47822 Mdot
.70217 .03748 Mdot
.70222 .14146 Mdot
.70227 .05091 Mdot
.70231 .31033 Mdot
.70236 .28696 Mdot
.70241 .33667 Mdot
.70246 .43744 Mdot
.7025 .11736 Mdot
.70255 .04927 Mdot
.7026 .02763 Mdot
.70265 .4686 Mdot
.70269 .20816 Mdot
.70274 .35388 Mdot
.70279 .25857 Mdot
.70284 .17888 Mdot
.70288 .30489 Mdot
.70293 .26504 Mdot
.70298 .19464 Mdot
.70303 .39859 Mdot
.70307 .1472 Mdot
.70312 .30213 Mdot
.70317 .27081 Mdot
.70322 .10427 Mdot
.70327 .27231 Mdot
.70331 .27936 Mdot
.70336 .14407 Mdot
.70341 .06808 Mdot
.70346 .56531 Mdot
.7035 .59572 Mdot
.70355 .41072 Mdot
.7036 .23396 Mdot
.70365 .46266 Mdot
.70369 .56117 Mdot
.70374 .39781 Mdot
.70379 .36869 Mdot
.70384 .2692 Mdot
.70388 .22199 Mdot
.70393 .15394 Mdot
.70398 .20452 Mdot
.70403 .56764 Mdot
.70407 .56027 Mdot
.70412 .56263 Mdot
.70417 .40926 Mdot
.70422 .43515 Mdot
.70427 .27285 Mdot
.70431 .30652 Mdot
.70436 .31969 Mdot
.70441 .17755 Mdot
.70446 .59682 Mdot
.7045 .17716 Mdot
.70455 .26633 Mdot
.7046 .21556 Mdot
.70465 .01581 Mdot
.70469 .36976 Mdot
.70474 .04707 Mdot
.70479 .35623 Mdot
.70484 .05797 Mdot
.70488 .57528 Mdot
.70493 .2817 Mdot
.70498 .10174 Mdot
.70503 .4393 Mdot
.70507 .43605 Mdot
.70512 .09189 Mdot
.70517 .13743 Mdot
.70522 .48235 Mdot
.70527 .47675 Mdot
.70531 .28596 Mdot
.70536 .3056 Mdot
.70541 .22421 Mdot
.70546 .18493 Mdot
.7055 .56959 Mdot
.70555 .14277 Mdot
.7056 .23071 Mdot
.70565 .02248 Mdot
.70569 .31797 Mdot
.70574 .53053 Mdot
.70579 .22961 Mdot
.70584 .25604 Mdot
.70588 .28561 Mdot
.70593 .189 Mdot
.70598 .18635 Mdot
.70603 .28408 Mdot
.70607 .01862 Mdot
.70612 .10197 Mdot
.70617 .35038 Mdot
.70622 .45135 Mdot
.70627 .53005 Mdot
.70631 .56787 Mdot
.70636 .47135 Mdot
.70641 .57793 Mdot
.70646 .2588 Mdot
.7065 .27698 Mdot
.70655 .26186 Mdot
.7066 .40771 Mdot
.70665 .29253 Mdot
.70669 .14892 Mdot
.70674 .04585 Mdot
.70679 .39994 Mdot
.70684 .57789 Mdot
.70688 .22172 Mdot
.70693 .41957 Mdot
.70698 .15861 Mdot
.70703 .30698 Mdot
.70707 .04742 Mdot
.70712 .24793 Mdot
.70717 .47785 Mdot
.70722 .30307 Mdot
.70726 .54878 Mdot
.70731 .50087 Mdot
.70736 .04121 Mdot
.70741 .37635 Mdot
.70746 .58423 Mdot
.7075 .04423 Mdot
.70755 .0666 Mdot
.7076 .13226 Mdot
.70765 .32196 Mdot
.70769 .3857 Mdot
.70774 .26222 Mdot
.70779 .44305 Mdot
.70784 .18775 Mdot
.70788 .35455 Mdot
.70793 .46561 Mdot
.70798 .46849 Mdot
.70803 .56936 Mdot
.70807 .53831 Mdot
.70812 .32171 Mdot
.70817 .17621 Mdot
.70822 .53664 Mdot
.70826 .30509 Mdot
.70831 .44718 Mdot
.70836 .47646 Mdot
.70841 .59119 Mdot
.70846 .40754 Mdot
.7085 .42069 Mdot
.70855 .11482 Mdot
.7086 .02167 Mdot
.70865 .37803 Mdot
.70869 .3688 Mdot
.70874 .58589 Mdot
.70879 .30303 Mdot
.70884 .59565 Mdot
.70888 .12129 Mdot
.70893 .15755 Mdot
.70898 .12999 Mdot
.70903 .25581 Mdot
.70907 .259 Mdot
.70912 .29238 Mdot
.70917 .16396 Mdot
.70922 .32083 Mdot
.70926 .54062 Mdot
.70931 .13088 Mdot
.70936 .23065 Mdot
.70941 .03045 Mdot
.70946 .10815 Mdot
.7095 .25774 Mdot
.70955 .24278 Mdot
.7096 .22623 Mdot
.70965 .29079 Mdot
.70969 .15763 Mdot
.70974 .23582 Mdot
.70979 .45153 Mdot
.70984 .52532 Mdot
.70988 .17506 Mdot
.70993 .53611 Mdot
.70998 .4592 Mdot
.71003 .41874 Mdot
.71007 .03222 Mdot
.71012 .42083 Mdot
.71017 .2181 Mdot
.71022 .17444 Mdot
.71026 .34316 Mdot
.71031 .27157 Mdot
.71036 .50059 Mdot
.71041 .23715 Mdot
.71046 .22699 Mdot
.7105 .05563 Mdot
.71055 .48486 Mdot
.7106 .14371 Mdot
.71065 .57258 Mdot
.71069 .41617 Mdot
.71074 .27334 Mdot
.71079 .45625 Mdot
.71084 .42966 Mdot
.71088 .19506 Mdot
.71093 .42513 Mdot
.71098 .53426 Mdot
.71103 .26931 Mdot
.71107 .26227 Mdot
.71112 .56926 Mdot
.71117 .13023 Mdot
.71122 .2518 Mdot
.71126 .44477 Mdot
.71131 .36587 Mdot
.71136 .55911 Mdot
.71141 .51196 Mdot
.71146 .1879 Mdot
.7115 .4686 Mdot
.71155 .33667 Mdot
.7116 .29967 Mdot
.71165 .14698 Mdot
.71169 .58707 Mdot
.71174 .20768 Mdot
.71179 .33042 Mdot
.71184 .33413 Mdot
.71188 .32845 Mdot
.71193 .35475 Mdot
.71198 .50408 Mdot
.71203 .15378 Mdot
.71207 .50664 Mdot
.71212 .42382 Mdot
.71217 .24948 Mdot
.71222 .49483 Mdot
.71226 .5407 Mdot
.71231 .3083 Mdot
.71236 .60101 Mdot
.71241 .06477 Mdot
.71245 .18954 Mdot
.7125 .35252 Mdot
.71255 .10376 Mdot
.7126 .4802 Mdot
.71265 .32426 Mdot
.71269 .03055 Mdot
.71274 .40741 Mdot
.71279 .34793 Mdot
.71284 .34051 Mdot
.71288 .4262 Mdot
.71293 .0917 Mdot
.71298 .02851 Mdot
.71303 .02677 Mdot
.71307 .08616 Mdot
.71312 .19094 Mdot
.71317 .47806 Mdot
.71322 .12346 Mdot
.71326 .26566 Mdot
.71331 .54478 Mdot
.71336 .58655 Mdot
.71341 .18608 Mdot
.71345 .56068 Mdot
.7135 .5471 Mdot
.71355 .53648 Mdot
.7136 .59987 Mdot
.71365 .22287 Mdot
.71369 .45804 Mdot
.71374 .071 Mdot
.71379 .29032 Mdot
.71384 .20703 Mdot
.71388 .06534 Mdot
.71393 .32639 Mdot
.71398 .55313 Mdot
.71403 .38416 Mdot
.71407 .57696 Mdot
.71412 .31259 Mdot
.71417 .54107 Mdot
.71422 .31271 Mdot
.71426 .40073 Mdot
.71431 .43786 Mdot
.71436 .43232 Mdot
.71441 .06176 Mdot
.71445 .45927 Mdot
.7145 .45463 Mdot
.71455 .26095 Mdot
.7146 .1044 Mdot
.71465 .5155 Mdot
.71469 .52148 Mdot
.71474 .26441 Mdot
.71479 .48485 Mdot
.71484 .07217 Mdot
.71488 .46519 Mdot
.71493 .57741 Mdot
.71498 .29253 Mdot
.71503 .02154 Mdot
.71507 .15351 Mdot
.71512 .03899 Mdot
.71517 .51169 Mdot
.71522 .0479 Mdot
.71526 .44424 Mdot
.71531 .10125 Mdot
.71536 .2137 Mdot
.71541 .2505 Mdot
.71545 .02109 Mdot
.7155 .27225 Mdot
.71555 .16665 Mdot
.7156 .39455 Mdot
.71565 .16978 Mdot
.71569 .02601 Mdot
.71574 .07696 Mdot
.71579 .48238 Mdot
.71584 .25163 Mdot
.71588 .36493 Mdot
.71593 .19544 Mdot
.71598 .42492 Mdot
.71603 .38977 Mdot
.71607 .39084 Mdot
.71612 .50624 Mdot
.71617 .41809 Mdot
.71622 .25097 Mdot
.71626 .36656 Mdot
.71631 .59787 Mdot
.71636 .38489 Mdot
.71641 .41005 Mdot
.71645 .28002 Mdot
.7165 .39888 Mdot
.71655 .14911 Mdot
.7166 .40367 Mdot
.71665 .02248 Mdot
.71669 .24694 Mdot
.71674 .35788 Mdot
.71679 .2486 Mdot
.71684 .5998 Mdot
.71688 .18469 Mdot
.71693 .47883 Mdot
.71698 .60029 Mdot
.71703 .24958 Mdot
.71707 .59258 Mdot
.71712 .06862 Mdot
.71717 .22524 Mdot
.71722 .46206 Mdot
.71726 .10105 Mdot
.71731 .25386 Mdot
.71736 .57759 Mdot
.71741 .11021 Mdot
.71745 .10651 Mdot
.7175 .47229 Mdot
.71755 .18225 Mdot
.7176 .43351 Mdot
.71764 .31096 Mdot
.71769 .33789 Mdot
.71774 .3819 Mdot
.71779 .42574 Mdot
.71784 .07873 Mdot
.71788 .58334 Mdot
.71793 .14802 Mdot
.71798 .42927 Mdot
.71803 .49736 Mdot
.71807 .11921 Mdot
.71812 .15105 Mdot
.71817 .1944 Mdot
.71822 .50811 Mdot
.71826 .0653 Mdot
.71831 .52914 Mdot
.71836 .33567 Mdot
.71841 .42177 Mdot
.71845 .41476 Mdot
.7185 .55487 Mdot
.71855 .24017 Mdot
.7186 .32997 Mdot
.71864 .5458 Mdot
.71869 .38733 Mdot
.71874 .40998 Mdot
.71879 .03372 Mdot
.71884 .22261 Mdot
.71888 .02013 Mdot
.71893 .58756 Mdot
.71898 .55832 Mdot
.71903 .2426 Mdot
.71907 .47544 Mdot
.71912 .173 Mdot
.71917 .07566 Mdot
.71922 .13809 Mdot
.71926 .3391 Mdot
.71931 .58192 Mdot
.71936 .17087 Mdot
.71941 .0875 Mdot
.71945 .41329 Mdot
.7195 .26096 Mdot
.71955 .35243 Mdot
.7196 .27606 Mdot
.71964 .46175 Mdot
.71969 .0355 Mdot
.71974 .03718 Mdot
.71979 .33359 Mdot
.71984 .08913 Mdot
.71988 .22885 Mdot
.71993 .01817 Mdot
.71998 .12569 Mdot
.72003 .0837 Mdot
.72007 .24462 Mdot
.72012 .06318 Mdot
.72017 .48641 Mdot
.72022 .21158 Mdot
.72026 .08633 Mdot
.72031 .59084 Mdot
.72036 .36303 Mdot
.72041 .4758 Mdot
.72045 .10773 Mdot
.7205 .43468 Mdot
.72055 .29024 Mdot
.7206 .07722 Mdot
.72064 .4501 Mdot
.72069 .09695 Mdot
.72074 .02888 Mdot
.72079 .2188 Mdot
.72084 .4293 Mdot
.72088 .07449 Mdot
.72093 .29861 Mdot
.72098 .14438 Mdot
.72103 .21516 Mdot
.72107 .07103 Mdot
.72112 .18763 Mdot
.72117 .07539 Mdot
.72122 .57386 Mdot
.72126 .02256 Mdot
.72131 .30455 Mdot
.72136 .46713 Mdot
.72141 .50224 Mdot
.72145 .03504 Mdot
.7215 .54484 Mdot
.72155 .59466 Mdot
.7216 .40922 Mdot
.72164 .20369 Mdot
.72169 .26931 Mdot
.72174 .53214 Mdot
.72179 .56245 Mdot
.72183 .12145 Mdot
.72188 .25514 Mdot
.72193 .32806 Mdot
.72198 .14786 Mdot
.72203 .06167 Mdot
.72207 .55985 Mdot
.72212 .19838 Mdot
.72217 .53603 Mdot
.72222 .59397 Mdot
.72226 .38693 Mdot
.72231 .1377 Mdot
.72236 .56549 Mdot
.72241 .58612 Mdot
.72245 .09709 Mdot
.7225 .2739 Mdot
.72255 .07796 Mdot
.7226 .56579 Mdot
.72264 .15557 Mdot
.72269 .28257 Mdot
.72274 .27206 Mdot
.72279 .37681 Mdot
.72283 .48959 Mdot
.72288 .35375 Mdot
.72293 .31294 Mdot
.72298 .27007 Mdot
.72303 .24915 Mdot
.72307 .0404 Mdot
.72312 .17978 Mdot
.72317 .22311 Mdot
.72322 .29262 Mdot
.72326 .44534 Mdot
.72331 .24708 Mdot
.72336 .23246 Mdot
.72341 .50902 Mdot
.72345 .32235 Mdot
.7235 .28491 Mdot
.72355 .24967 Mdot
.7236 .42664 Mdot
.72364 .06316 Mdot
.72369 .22166 Mdot
.72374 .28721 Mdot
.72379 .28577 Mdot
.72383 .38392 Mdot
.72388 .55293 Mdot
.72393 .51373 Mdot
.72398 .39951 Mdot
.72403 .04488 Mdot
.72407 .2547 Mdot
.72412 .25837 Mdot
.72417 .16507 Mdot
.72422 .01919 Mdot
.72426 .08962 Mdot
.72431 .04997 Mdot
.72436 .47577 Mdot
.72441 .17717 Mdot
.72445 .44587 Mdot
.7245 .42083 Mdot
.72455 .57008 Mdot
.7246 .45815 Mdot
.72464 .17567 Mdot
.72469 .18586 Mdot
.72474 .15815 Mdot
.72479 .4097 Mdot
.72483 .55733 Mdot
.72488 .50198 Mdot
.72493 .47571 Mdot
.72498 .04049 Mdot
.72503 .01911 Mdot
.72507 .59158 Mdot
.72512 .0909 Mdot
.72517 .59894 Mdot
.72522 .36774 Mdot
.72526 .34793 Mdot
.72531 .52916 Mdot
.72536 .59446 Mdot
.72541 .29282 Mdot
.72545 .31267 Mdot
.7255 .0681 Mdot
.72555 .432 Mdot
.7256 .45028 Mdot
.72564 .49517 Mdot
.72569 .10135 Mdot
.72574 .57718 Mdot
.72579 .28932 Mdot
.72583 .32401 Mdot
.72588 .54652 Mdot
.72593 .18219 Mdot
.72598 .33531 Mdot
.72603 .42535 Mdot
.72607 .08552 Mdot
.72612 .1564 Mdot
.72617 .33091 Mdot
.72622 .4371 Mdot
.72626 .59794 Mdot
.72631 .16079 Mdot
.72636 .5665 Mdot
.72641 .10388 Mdot
.72645 .08349 Mdot
.7265 .16965 Mdot
.72655 .28839 Mdot
.7266 .39454 Mdot
.72664 .0301 Mdot
.72669 .34097 Mdot
.72674 .44144 Mdot
.72679 .5027 Mdot
.72683 .53208 Mdot
.72688 .36712 Mdot
.72693 .16683 Mdot
.72698 .19339 Mdot
.72702 .58889 Mdot
.72707 .19964 Mdot
.72712 .43484 Mdot
.72717 .37137 Mdot
.72722 .51807 Mdot
.72726 .05795 Mdot
.72731 .11864 Mdot
.72736 .53759 Mdot
.72741 .52345 Mdot
.72745 .50048 Mdot
.7275 .15546 Mdot
.72755 .44842 Mdot
.7276 .45467 Mdot
.72764 .34554 Mdot
.72769 .4704 Mdot
.72774 .06859 Mdot
.72779 .43927 Mdot
.72783 .01928 Mdot
.72788 .04367 Mdot
.72793 .16922 Mdot
.72798 .51052 Mdot
.72802 .25548 Mdot
.72807 .48017 Mdot
.72812 .57915 Mdot
.72817 .52496 Mdot
.72822 .07055 Mdot
.72826 .06004 Mdot
.72831 .22249 Mdot
.72836 .02159 Mdot
.72841 .02731 Mdot
.72845 .54473 Mdot
.7285 .28823 Mdot
.72855 .10147 Mdot
.7286 .13015 Mdot
.72864 .40398 Mdot
.72869 .44313 Mdot
.72874 .25013 Mdot
.72879 .38793 Mdot
.72883 .5369 Mdot
.72888 .38925 Mdot
.72893 .41418 Mdot
.72898 .38336 Mdot
.72902 .50793 Mdot
.72907 .23473 Mdot
.72912 .50698 Mdot
.72917 .14259 Mdot
.72922 .04247 Mdot
.72926 .25891 Mdot
.72931 .58535 Mdot
.72936 .08675 Mdot
.72941 .58575 Mdot
.72945 .05112 Mdot
.7295 .57846 Mdot
.72955 .07415 Mdot
.7296 .05573 Mdot
.72964 .36622 Mdot
.72969 .49171 Mdot
.72974 .54733 Mdot
.72979 .25508 Mdot
.72983 .52642 Mdot
.72988 .25629 Mdot
.72993 .17411 Mdot
.72998 .32151 Mdot
.73002 .15188 Mdot
.73007 .44544 Mdot
.73012 .39407 Mdot
.73017 .4169 Mdot
.73022 .52047 Mdot
.73026 .54178 Mdot
.73031 .26619 Mdot
.73036 .38914 Mdot
.73041 .27628 Mdot
.73045 .55975 Mdot
.7305 .19415 Mdot
.73055 .40671 Mdot
.7306 .23986 Mdot
.73064 .58461 Mdot
.73069 .1347 Mdot
.73074 .36569 Mdot
.73079 .47697 Mdot
.73083 .10762 Mdot
.73088 .1907 Mdot
.73093 .12532 Mdot
.73098 .55387 Mdot
.73102 .45465 Mdot
.73107 .0313 Mdot
.73112 .40714 Mdot
.73117 .4167 Mdot
.73121 .02393 Mdot
.73126 .24055 Mdot
.73131 .59357 Mdot
.73136 .49955 Mdot
.73141 .08547 Mdot
.73145 .57769 Mdot
.7315 .21914 Mdot
.73155 .23798 Mdot
.7316 .12904 Mdot
.73164 .39825 Mdot
.73169 .41575 Mdot
.73174 .60145 Mdot
.73179 .14775 Mdot
.73183 .27825 Mdot
.73188 .06476 Mdot
.73193 .13919 Mdot
.73198 .05485 Mdot
.73202 .10226 Mdot
.73207 .54277 Mdot
.73212 .18864 Mdot
.73217 .20352 Mdot
.73221 .08567 Mdot
.73226 .15034 Mdot
.73231 .37527 Mdot
.73236 .1943 Mdot
.73241 .44845 Mdot
.73245 .16009 Mdot
.7325 .47904 Mdot
.73255 .12353 Mdot
.7326 .47408 Mdot
.73264 .54428 Mdot
.73269 .25577 Mdot
.73274 .59782 Mdot
.73279 .09054 Mdot
.73283 .14324 Mdot
.73288 .25764 Mdot
.73293 .46477 Mdot
.73298 .41561 Mdot
.73302 .09319 Mdot
.73307 .13316 Mdot
.73312 .42463 Mdot
.73317 .32806 Mdot
.73321 .15374 Mdot
.73326 .54785 Mdot
.73331 .23583 Mdot
.73336 .25709 Mdot
.73341 .01812 Mdot
.73345 .18729 Mdot
.7335 .05624 Mdot
.73355 .41197 Mdot
.7336 .46135 Mdot
.73364 .31157 Mdot
.73369 .53603 Mdot
.73374 .54121 Mdot
.73379 .52039 Mdot
.73383 .07051 Mdot
.73388 .54154 Mdot
.73393 .46538 Mdot
.73398 .39186 Mdot
.73402 .41619 Mdot
.73407 .09147 Mdot
.73412 .06447 Mdot
.73417 .31338 Mdot
.73421 .29774 Mdot
.73426 .27017 Mdot
.73431 .33974 Mdot
.73436 .17435 Mdot
.73441 .35322 Mdot
.73445 .04905 Mdot
.7345 .09736 Mdot
.73455 .17094 Mdot
.7346 .18064 Mdot
.73464 .59614 Mdot
.73469 .28871 Mdot
.73474 .31291 Mdot
.73479 .4724 Mdot
.73483 .07482 Mdot
.73488 .35083 Mdot
.73493 .39584 Mdot
.73498 .41659 Mdot
.73502 .13661 Mdot
.73507 .48877 Mdot
.73512 .01869 Mdot
.73517 .01511 Mdot
.73521 .05984 Mdot
.73526 .43901 Mdot
.73531 .30863 Mdot
.73536 .3207 Mdot
.73541 .393 Mdot
.73545 .11398 Mdot
.7355 .149 Mdot
.73555 .57081 Mdot
.7356 .35866 Mdot
.73564 .03133 Mdot
.73569 .58139 Mdot
.73574 .40488 Mdot
.73579 .36585 Mdot
.73583 .34594 Mdot
.73588 .28318 Mdot
.73593 .53581 Mdot
.73598 .30574 Mdot
.73602 .59844 Mdot
.73607 .49067 Mdot
.73612 .13392 Mdot
.73617 .18384 Mdot
.73621 .12438 Mdot
.73626 .48668 Mdot
.73631 .13352 Mdot
.73636 .13871 Mdot
.7364 .28869 Mdot
.73645 .19276 Mdot
.7365 .41614 Mdot
.73655 .34904 Mdot
.7366 .18942 Mdot
.73664 .05847 Mdot
.73669 .44866 Mdot
.73674 .5937 Mdot
.73679 .1728 Mdot
.73683 .08041 Mdot
.73688 .05849 Mdot
.73693 .24256 Mdot
.73698 .43018 Mdot
.73702 .40055 Mdot
.73707 .12601 Mdot
.73712 .54015 Mdot
.73717 .43507 Mdot
.73721 .51321 Mdot
.73726 .59542 Mdot
.73731 .37101 Mdot
.73736 .3254 Mdot
.7374 .04124 Mdot
.73745 .47661 Mdot
.7375 .24701 Mdot
.73755 .05142 Mdot
.7376 .45181 Mdot
.73764 .07518 Mdot
.73769 .50129 Mdot
.73774 .46532 Mdot
.73779 .40804 Mdot
.73783 .22984 Mdot
.73788 .51091 Mdot
.73793 .30723 Mdot
.73798 .34234 Mdot
.73802 .18606 Mdot
.73807 .28306 Mdot
.73812 .48037 Mdot
.73817 .54512 Mdot
.73821 .07475 Mdot
.73826 .34624 Mdot
.73831 .06001 Mdot
.73836 .04661 Mdot
.7384 .08266 Mdot
.73845 .57855 Mdot
.7385 .33794 Mdot
.73855 .02008 Mdot
.7386 .20937 Mdot
.73864 .34625 Mdot
.73869 .30123 Mdot
.73874 .1716 Mdot
.73879 .1489 Mdot
.73883 .44828 Mdot
.73888 .43923 Mdot
.73893 .36688 Mdot
.73898 .52239 Mdot
.73902 .54069 Mdot
.73907 .14671 Mdot
.73912 .03925 Mdot
.73917 .35104 Mdot
.73921 .27234 Mdot
.73926 .26966 Mdot
.73931 .09746 Mdot
.73936 .291 Mdot
.7394 .52943 Mdot
.73945 .22436 Mdot
.7395 .06556 Mdot
.73955 .22304 Mdot
.7396 .55421 Mdot
.73964 .48975 Mdot
.73969 .06018 Mdot
.73974 .02838 Mdot
.73979 .22267 Mdot
.73983 .20323 Mdot
.73988 .49191 Mdot
.73993 .4828 Mdot
.73998 .37771 Mdot
.74002 .36732 Mdot
.74007 .13973 Mdot
.74012 .56374 Mdot
.74017 .44035 Mdot
.74021 .23532 Mdot
.74026 .1152 Mdot
.74031 .22741 Mdot
.74036 .18272 Mdot
.7404 .56898 Mdot
.74045 .03245 Mdot
.7405 .53974 Mdot
.74055 .25661 Mdot
.74059 .35933 Mdot
.74064 .57022 Mdot
.74069 .3314 Mdot
.74074 .30573 Mdot
.74079 .47291 Mdot
.74083 .52474 Mdot
.74088 .31773 Mdot
.74093 .09777 Mdot
.74098 .28439 Mdot
.74102 .04754 Mdot
.74107 .43825 Mdot
.74112 .32338 Mdot
.74117 .52039 Mdot
.74121 .51113 Mdot
.74126 .47784 Mdot
.74131 .48636 Mdot
.74136 .29977 Mdot
.7414 .41065 Mdot
.74145 .26514 Mdot
.7415 .31835 Mdot
.74155 .33412 Mdot
.74159 .39291 Mdot
.74164 .32873 Mdot
.74169 .07645 Mdot
.74174 .57811 Mdot
.74179 .42602 Mdot
.74183 .60066 Mdot
.74188 .37405 Mdot
.74193 .11991 Mdot
.74198 .5046 Mdot
.74202 .29764 Mdot
.74207 .29099 Mdot
.74212 .43885 Mdot
.74217 .47177 Mdot
.74221 .46271 Mdot
.74226 .57093 Mdot
.74231 .52179 Mdot
.74236 .56396 Mdot
.7424 .58819 Mdot
.74245 .09928 Mdot
.7425 .23673 Mdot
.74255 .16802 Mdot
.74259 .33776 Mdot
.74264 .38425 Mdot
.74269 .50593 Mdot
.74274 .37843 Mdot
.74279 .02374 Mdot
.74283 .32251 Mdot
.74288 .53115 Mdot
.74293 .55574 Mdot
.74298 .0264 Mdot
.74302 .55178 Mdot
.74307 .42594 Mdot
.74312 .06585 Mdot
.74317 .33209 Mdot
.74321 .2755 Mdot
.74326 .59041 Mdot
.74331 .19741 Mdot
.74336 .47271 Mdot
.7434 .3079 Mdot
.74345 .08333 Mdot
.7435 .23678 Mdot
.74355 .48784 Mdot
.74359 .22333 Mdot
.74364 .44993 Mdot
.74369 .08347 Mdot
.74374 .16479 Mdot
.74379 .44241 Mdot
.74383 .54732 Mdot
.74388 .30836 Mdot
.74393 .15576 Mdot
.74398 .13461 Mdot
.74402 .03088 Mdot
.74407 .35594 Mdot
.74412 .14406 Mdot
.74417 .18615 Mdot
.74421 .20826 Mdot
.74426 .3048 Mdot
.74431 .4153 Mdot
.74436 .51397 Mdot
.7444 .22118 Mdot
.74445 .1221 Mdot
.7445 .54591 Mdot
.74455 .22078 Mdot
.74459 .15256 Mdot
.74464 .48865 Mdot
.74469 .07278 Mdot
.74474 .60077 Mdot
.74479 .30595 Mdot
.74483 .4199 Mdot
.74488 .51132 Mdot
.74493 .17308 Mdot
.74498 .36196 Mdot
.74502 .12625 Mdot
.74507 .37027 Mdot
.74512 .05317 Mdot
.74517 .34579 Mdot
.74521 .37363 Mdot
.74526 .24091 Mdot
.74531 .47035 Mdot
.74536 .15223 Mdot
.7454 .08354 Mdot
.74545 .42894 Mdot
.7455 .5597 Mdot
.74555 .53438 Mdot
.74559 .56476 Mdot
.74564 .48635 Mdot
.74569 .35363 Mdot
.74574 .39653 Mdot
.74578 .09082 Mdot
.74583 .42828 Mdot
.74588 .35618 Mdot
.74593 .10529 Mdot
.74598 .27425 Mdot
.74602 .52028 Mdot
.74607 .19781 Mdot
.74612 .34666 Mdot
.74617 .16271 Mdot
.74621 .16473 Mdot
.74626 .15935 Mdot
.74631 .01558 Mdot
.74636 .3924 Mdot
.7464 .52714 Mdot
.74645 .29232 Mdot
.7465 .46668 Mdot
.74655 .32357 Mdot
.74659 .11291 Mdot
.74664 .33595 Mdot
.74669 .53562 Mdot
.74674 .36214 Mdot
.74678 .22988 Mdot
.74683 .58565 Mdot
.74688 .1538 Mdot
.74693 .28603 Mdot
.74698 .40492 Mdot
.74702 .24418 Mdot
.74707 .06322 Mdot
.74712 .02649 Mdot
.74717 .48797 Mdot
.74721 .06108 Mdot
.74726 .31988 Mdot
.74731 .4671 Mdot
.74736 .33795 Mdot
.7474 .50506 Mdot
.74745 .31901 Mdot
.7475 .08941 Mdot
.74755 .41414 Mdot
.74759 .22744 Mdot
.74764 .45566 Mdot
.74769 .36916 Mdot
.74774 .31594 Mdot
.74778 .49482 Mdot
.74783 .52337 Mdot
.74788 .02174 Mdot
.74793 .10077 Mdot
.74798 .51249 Mdot
.74802 .38428 Mdot
.74807 .33903 Mdot
.74812 .29917 Mdot
.74817 .28302 Mdot
.74821 .33577 Mdot
.74826 .32725 Mdot
.74831 .41453 Mdot
.74836 .23666 Mdot
.7484 .03059 Mdot
.74845 .46347 Mdot
.7485 .09129 Mdot
.74855 .33493 Mdot
.74859 .3149 Mdot
.74864 .38877 Mdot
.74869 .28048 Mdot
.74874 .1222 Mdot
.74878 .46257 Mdot
.74883 .03432 Mdot
.74888 .56787 Mdot
.74893 .23071 Mdot
.74898 .54253 Mdot
.74902 .02729 Mdot
.74907 .48181 Mdot
.74912 .32154 Mdot
.74917 .17296 Mdot
.74921 .29158 Mdot
.74926 .19734 Mdot
.74931 .05322 Mdot
.74936 .44051 Mdot
.7494 .56765 Mdot
.74945 .38614 Mdot
.7495 .41989 Mdot
.74955 .42463 Mdot
.74959 .11889 Mdot
.74964 .30956 Mdot
.74969 .09967 Mdot
.74974 .12443 Mdot
.74978 .33344 Mdot
.74983 .04379 Mdot
.74988 .5808 Mdot
.74993 .26519 Mdot
.74998 .31383 Mdot
.75002 .07925 Mdot
.75007 .3648 Mdot
.75012 .32599 Mdot
.75017 .30125 Mdot
.75021 .20077 Mdot
.75026 .05797 Mdot
.75031 .16774 Mdot
.75036 .02438 Mdot
.7504 .01813 Mdot
.75045 .01946 Mdot
.7505 .33055 Mdot
.75055 .06005 Mdot
.75059 .23532 Mdot
.75064 .2029 Mdot
.75069 .50925 Mdot
.75074 .54449 Mdot
.75078 .52908 Mdot
.75083 .11794 Mdot
.75088 .39952 Mdot
.75093 .22576 Mdot
.75097 .5 Mdot
.75102 .14047 Mdot
.75107 .14904 Mdot
.75112 .51525 Mdot
.75117 .43547 Mdot
.75121 .37899 Mdot
.75126 .42637 Mdot
.75131 .22871 Mdot
.75136 .24941 Mdot
.7514 .33573 Mdot
.75145 .27334 Mdot
.7515 .21904 Mdot
.75155 .24599 Mdot
.75159 .33098 Mdot
.75164 .54611 Mdot
.75169 .1737 Mdot
.75174 .02538 Mdot
.75178 .14279 Mdot
.75183 .05157 Mdot
.75188 .23254 Mdot
.75193 .09963 Mdot
.75197 .03956 Mdot
.75202 .25537 Mdot
.75207 .02149 Mdot
.75212 .20295 Mdot
.75217 .50242 Mdot
.75221 .12104 Mdot
.75226 .10956 Mdot
.75231 .3708 Mdot
.75236 .13814 Mdot
.7524 .29799 Mdot
.75245 .48418 Mdot
.7525 .1361 Mdot
.75255 .40573 Mdot
.75259 .03936 Mdot
.75264 .27984 Mdot
.75269 .49344 Mdot
.75274 .08946 Mdot
.75278 .09658 Mdot
.75283 .12085 Mdot
.75288 .48276 Mdot
.75293 .55 Mdot
.75297 .05972 Mdot
.75302 .49164 Mdot
.75307 .39785 Mdot
.75312 .52514 Mdot
.75317 .40767 Mdot
.75321 .48486 Mdot
.75326 .20961 Mdot
.75331 .03743 Mdot
.75336 .30134 Mdot
.7534 .39001 Mdot
.75345 .44213 Mdot
.7535 .50262 Mdot
.75355 .01806 Mdot
.75359 .50916 Mdot
.75364 .32074 Mdot
.75369 .1116 Mdot
.75374 .58203 Mdot
.75378 .24403 Mdot
.75383 .43063 Mdot
.75388 .03684 Mdot
.75393 .50016 Mdot
.75397 .13789 Mdot
.75402 .55119 Mdot
.75407 .09017 Mdot
.75412 .45515 Mdot
.75417 .24957 Mdot
.75421 .16805 Mdot
.75426 .16835 Mdot
.75431 .06218 Mdot
.75436 .36803 Mdot
.7544 .56176 Mdot
.75445 .14563 Mdot
.7545 .36416 Mdot
.75455 .58134 Mdot
.75459 .13434 Mdot
.75464 .24634 Mdot
.75469 .36081 Mdot
.75474 .08689 Mdot
.75478 .41693 Mdot
.75483 .14945 Mdot
.75488 .38211 Mdot
.75493 .44618 Mdot
.75497 .58963 Mdot
.75502 .12731 Mdot
.75507 .48527 Mdot
.75512 .32301 Mdot
.75516 .05315 Mdot
.75521 .05185 Mdot
.75526 .04484 Mdot
.75531 .08815 Mdot
.75536 .48843 Mdot
.7554 .48682 Mdot
.75545 .58598 Mdot
.7555 .32344 Mdot
.75555 .52999 Mdot
.75559 .3559 Mdot
.75564 .23653 Mdot
.75569 .34542 Mdot
.75574 .41035 Mdot
.75578 .12427 Mdot
.75583 .47905 Mdot
.75588 .27324 Mdot
.75593 .59675 Mdot
.75597 .57815 Mdot
.75602 .11165 Mdot
.75607 .43039 Mdot
.75612 .02183 Mdot
.75616 .46555 Mdot
.75621 .2297 Mdot
.75626 .12209 Mdot
.75631 .57201 Mdot
.75636 .42841 Mdot
.7564 .19957 Mdot
.75645 .04865 Mdot
.7565 .09829 Mdot
.75655 .54491 Mdot
.75659 .21692 Mdot
.75664 .32854 Mdot
.75669 .17163 Mdot
.75674 .20373 Mdot
.75678 .58371 Mdot
.75683 .58644 Mdot
.75688 .3646 Mdot
.75693 .09416 Mdot
.75697 .11937 Mdot
.75702 .3279 Mdot
.75707 .37117 Mdot
.75712 .11934 Mdot
.75716 .02243 Mdot
.75721 .50084 Mdot
.75726 .36405 Mdot
.75731 .25712 Mdot
.75736 .39606 Mdot
.7574 .39346 Mdot
.75745 .39537 Mdot
.7575 .43204 Mdot
.75755 .21119 Mdot
.75759 .35952 Mdot
.75764 .31179 Mdot
.75769 .49045 Mdot
.75774 .5976 Mdot
.75778 .0457 Mdot
.75783 .15487 Mdot
.75788 .30144 Mdot
.75793 .0286 Mdot
.75797 .06258 Mdot
.75802 .39359 Mdot
.75807 .22198 Mdot
.75812 .51255 Mdot
.75816 .338 Mdot
.75821 .03713 Mdot
.75826 .11735 Mdot
.75831 .50483 Mdot
.75836 .44049 Mdot
.7584 .27641 Mdot
.75845 .46355 Mdot
.7585 .12348 Mdot
.75855 .06173 Mdot
.75859 .48437 Mdot
.75864 .04622 Mdot
.75869 .51562 Mdot
.75874 .30553 Mdot
.75878 .18729 Mdot
.75883 .15909 Mdot
.75888 .52134 Mdot
.75893 .27455 Mdot
.75897 .04713 Mdot
.75902 .46098 Mdot
.75907 .50745 Mdot
.75912 .22667 Mdot
.75916 .25686 Mdot
.75921 .25371 Mdot
.75926 .59822 Mdot
.75931 .49199 Mdot
.75936 .23444 Mdot
.7594 .15107 Mdot
.75945 .1081 Mdot
.7595 .06621 Mdot
.75955 .56135 Mdot
.75959 .29084 Mdot
.75964 .58795 Mdot
.75969 .01919 Mdot
.75974 .0917 Mdot
.75978 .25933 Mdot
.75983 .08704 Mdot
.75988 .31698 Mdot
.75993 .50773 Mdot
.75997 .11495 Mdot
.76002 .16903 Mdot
.76007 .05715 Mdot
.76012 .47531 Mdot
.76016 .2573 Mdot
.76021 .2649 Mdot
.76026 .4338 Mdot
.76031 .23316 Mdot
.76035 .0183 Mdot
.7604 .27 Mdot
.76045 .54514 Mdot
.7605 .60205 Mdot
.76055 .47056 Mdot
.76059 .17661 Mdot
.76064 .49363 Mdot
.76069 .0554 Mdot
.76074 .19443 Mdot
.76078 .19199 Mdot
.76083 .48915 Mdot
.76088 .56703 Mdot
.76093 .53842 Mdot
.76097 .11965 Mdot
.76102 .18687 Mdot
.76107 .07401 Mdot
.76112 .43818 Mdot
.76116 .55395 Mdot
.76121 .14443 Mdot
.76126 .20202 Mdot
.76131 .19559 Mdot
.76135 .30376 Mdot
.7614 .31396 Mdot
.76145 .57218 Mdot
.7615 .19199 Mdot
.76155 .04846 Mdot
.76159 .37215 Mdot
.76164 .57346 Mdot
.76169 .32476 Mdot
.76174 .47518 Mdot
.76178 .48184 Mdot
.76183 .53276 Mdot
.76188 .14504 Mdot
.76193 .2979 Mdot
.76197 .59602 Mdot
.76202 .56905 Mdot
.76207 .20995 Mdot
.76212 .19295 Mdot
.76216 .42386 Mdot
.76221 .50975 Mdot
.76226 .3751 Mdot
.76231 .24233 Mdot
.76235 .29413 Mdot
.7624 .32244 Mdot
.76245 .19422 Mdot
.7625 .54189 Mdot
.76255 .5835 Mdot
.76259 .35359 Mdot
.76264 .01693 Mdot
.76269 .50814 Mdot
.76274 .22606 Mdot
.76278 .38346 Mdot
.76283 .2955 Mdot
.76288 .04767 Mdot
.76293 .34754 Mdot
.76297 .45402 Mdot
.76302 .16517 Mdot
.76307 .3531 Mdot
.76312 .35485 Mdot
.76316 .48829 Mdot
.76321 .55854 Mdot
.76326 .17485 Mdot
.76331 .53432 Mdot
.76335 .58186 Mdot
.7634 .19815 Mdot
.76345 .53585 Mdot
.7635 .2549 Mdot
.76355 .27413 Mdot
.76359 .01864 Mdot
.76364 .59728 Mdot
.76369 .27473 Mdot
.76374 .52387 Mdot
.76378 .01642 Mdot
.76383 .10385 Mdot
.76388 .06337 Mdot
.76393 .15512 Mdot
.76397 .32424 Mdot
.76402 .07089 Mdot
.76407 .31915 Mdot
.76412 .30442 Mdot
.76416 .17379 Mdot
.76421 .32112 Mdot
.76426 .56763 Mdot
.76431 .41945 Mdot
.76435 .21857 Mdot
.7644 .16097 Mdot
.76445 .04801 Mdot
.7645 .44091 Mdot
.76454 .03512 Mdot
.76459 .22845 Mdot
.76464 .39644 Mdot
.76469 .18149 Mdot
.76474 .03119 Mdot
.76478 .23449 Mdot
.76483 .13642 Mdot
.76488 .26095 Mdot
.76493 .02948 Mdot
.76497 .14535 Mdot
.76502 .08776 Mdot
.76507 .12054 Mdot
.76512 .30856 Mdot
.76516 .08917 Mdot
.76521 .37193 Mdot
.76526 .41945 Mdot
.76531 .14948 Mdot
.76535 .37138 Mdot
.7654 .40763 Mdot
.76545 .60332 Mdot
.7655 .53424 Mdot
.76554 .22512 Mdot
.76559 .37432 Mdot
.76564 .17711 Mdot
.76569 .51382 Mdot
.76574 .59999 Mdot
.76578 .58121 Mdot
.76583 .59895 Mdot
.76588 .49734 Mdot
.76593 .38021 Mdot
.76597 .45949 Mdot
.76602 .3527 Mdot
.76607 .48257 Mdot
.76612 .24956 Mdot
.76616 .38644 Mdot
.76621 .24687 Mdot
.76626 .18872 Mdot
.76631 .1751 Mdot
.76635 .02922 Mdot
.7664 .43074 Mdot
.76645 .05394 Mdot
.7665 .40704 Mdot
.76654 .22491 Mdot
.76659 .43075 Mdot
.76664 .12303 Mdot
.76669 .19663 Mdot
.76674 .45392 Mdot
.76678 .26835 Mdot
.76683 .21253 Mdot
.76688 .19997 Mdot
.76693 .47603 Mdot
.76697 .27273 Mdot
.76702 .31851 Mdot
.76707 .42309 Mdot
.76712 .03125 Mdot
.76716 .52335 Mdot
.76721 .43927 Mdot
.76726 .18823 Mdot
.76731 .24813 Mdot
.76735 .29119 Mdot
.7674 .26526 Mdot
.76745 .02784 Mdot
.7675 .23362 Mdot
.76754 .46377 Mdot
.76759 .22603 Mdot
.76764 .22413 Mdot
.76769 .02342 Mdot
.76774 .04773 Mdot
.76778 .11771 Mdot
.76783 .0422 Mdot
.76788 .17283 Mdot
.76793 .38271 Mdot
.76797 .50851 Mdot
.76802 .44556 Mdot
.76807 .30012 Mdot
.76812 .12469 Mdot
.76816 .2047 Mdot
.76821 .03718 Mdot
.76826 .28357 Mdot
.76831 .20467 Mdot
.76835 .36876 Mdot
.7684 .45227 Mdot
.76845 .05015 Mdot
.7685 .5168 Mdot
.76854 .1182 Mdot
.76859 .43914 Mdot
.76864 .41985 Mdot
.76869 .06773 Mdot
.76874 .4955 Mdot
.76878 .22972 Mdot
.76883 .41114 Mdot
.76888 .03471 Mdot
.76893 .3925 Mdot
.76897 .20223 Mdot
.76902 .25302 Mdot
.76907 .25533 Mdot
.76912 .48732 Mdot
.76916 .36 Mdot
.76921 .55623 Mdot
.76926 .14534 Mdot
.76931 .29732 Mdot
.76935 .33753 Mdot
.7694 .28737 Mdot
.76945 .544 Mdot
.7695 .53189 Mdot
.76954 .48858 Mdot
.76959 .25193 Mdot
.76964 .04191 Mdot
.76969 .4284 Mdot
.76973 .06415 Mdot
.76978 .4354 Mdot
.76983 .57751 Mdot
.76988 .53623 Mdot
.76993 .43775 Mdot
.76997 .03897 Mdot
.77002 .5575 Mdot
.77007 .15844 Mdot
.77012 .25022 Mdot
.77016 .38927 Mdot
.77021 .31688 Mdot
.77026 .27445 Mdot
.77031 .49355 Mdot
.77035 .43637 Mdot
.7704 .18625 Mdot
.77045 .58045 Mdot
.7705 .17073 Mdot
.77054 .16371 Mdot
.77059 .24557 Mdot
.77064 .06327 Mdot
.77069 .28547 Mdot
.77073 .51511 Mdot
.77078 .21837 Mdot
.77083 .23819 Mdot
.77088 .23603 Mdot
.77093 .09442 Mdot
.77097 .24419 Mdot
.77102 .30529 Mdot
.77107 .40161 Mdot
.77112 .07016 Mdot
.77116 .29001 Mdot
.77121 .16156 Mdot
.77126 .16609 Mdot
.77131 .28421 Mdot
.77135 .57645 Mdot
.7714 .49044 Mdot
.77145 .27587 Mdot
.7715 .45117 Mdot
.77154 .40491 Mdot
.77159 .51331 Mdot
.77164 .11985 Mdot
.77169 .30217 Mdot
.77173 .17405 Mdot
.77178 .46476 Mdot
.77183 .4377 Mdot
.77188 .39039 Mdot
.77193 .55901 Mdot
.77197 .24127 Mdot
.77202 .21638 Mdot
.77207 .31068 Mdot
.77212 .32953 Mdot
.77216 .5393 Mdot
.77221 .4181 Mdot
.77226 .25523 Mdot
.77231 .05423 Mdot
.77235 .39245 Mdot
.7724 .26671 Mdot
.77245 .57434 Mdot
.7725 .0811 Mdot
.77254 .50534 Mdot
.77259 .59417 Mdot
.77264 .13788 Mdot
.77269 .27952 Mdot
.77273 .59535 Mdot
.77278 .48903 Mdot
.77283 .43904 Mdot
.77288 .12018 Mdot
.77293 .1453 Mdot
.77297 .06603 Mdot
.77302 .06336 Mdot
.77307 .1645 Mdot
.77312 .50735 Mdot
.77316 .45298 Mdot
.77321 .35601 Mdot
.77326 .4383 Mdot
.77331 .57137 Mdot
.77335 .04959 Mdot
.7734 .11548 Mdot
.77345 .39878 Mdot
.7735 .19363 Mdot
.77354 .3862 Mdot
.77359 .14446 Mdot
.77364 .33238 Mdot
.77369 .29162 Mdot
.77373 .39536 Mdot
.77378 .02129 Mdot
.77383 .06757 Mdot
.77388 .2996 Mdot
.77392 .50966 Mdot
.77397 .18558 Mdot
.77402 .55072 Mdot
.77407 .16901 Mdot
.77412 .45833 Mdot
.77416 .13693 Mdot
.77421 .40093 Mdot
.77426 .26498 Mdot
.77431 .02006 Mdot
.77435 .38425 Mdot
.7744 .56596 Mdot
.77445 .29693 Mdot
.7745 .5738 Mdot
.77454 .28348 Mdot
.77459 .18189 Mdot
.77464 .11801 Mdot
.77469 .2023 Mdot
.77473 .15372 Mdot
.77478 .45283 Mdot
.77483 .42971 Mdot
.77488 .41027 Mdot
.77492 .14714 Mdot
.77497 .39997 Mdot
.77502 .14482 Mdot
.77507 .50394 Mdot
.77512 .56488 Mdot
.77516 .45257 Mdot
.77521 .57914 Mdot
.77526 .06032 Mdot
.77531 .44266 Mdot
.77535 .06635 Mdot
.7754 .32887 Mdot
.77545 .05496 Mdot
.7755 .07312 Mdot
.77554 .10372 Mdot
.77559 .04665 Mdot
.77564 .08449 Mdot
.77569 .39297 Mdot
.77573 .52515 Mdot
.77578 .53197 Mdot
.77583 .48551 Mdot
.77588 .25396 Mdot
.77592 .08703 Mdot
.77597 .11697 Mdot
.77602 .08995 Mdot
.77607 .12153 Mdot
.77612 .29039 Mdot
.77616 .57547 Mdot
.77621 .18934 Mdot
.77626 .15997 Mdot
.77631 .44114 Mdot
.77635 .59966 Mdot
.7764 .14373 Mdot
.77645 .32064 Mdot
.7765 .38949 Mdot
.77654 .2855 Mdot
.77659 .10347 Mdot
.77664 .26223 Mdot
.77669 .30048 Mdot
.77673 .25356 Mdot
.77678 .03369 Mdot
.77683 .47259 Mdot
.77688 .37866 Mdot
.77692 .32491 Mdot
.77697 .1515 Mdot
.77702 .23334 Mdot
.77707 .30634 Mdot
.77712 .22265 Mdot
.77716 .07626 Mdot
.77721 .12652 Mdot
.77726 .03066 Mdot
.77731 .2505 Mdot
.77735 .49024 Mdot
.7774 .56987 Mdot
.77745 .19285 Mdot
.7775 .25417 Mdot
.77754 .36122 Mdot
.77759 .26394 Mdot
.77764 .40668 Mdot
.77769 .57199 Mdot
.77773 .27246 Mdot
.77778 .01642 Mdot
.77783 .1209 Mdot
.77788 .33315 Mdot
.77792 .25348 Mdot
.77797 .14715 Mdot
.77802 .34557 Mdot
.77807 .02295 Mdot
.77812 .11669 Mdot
.77816 .51713 Mdot
.77821 .05394 Mdot
.77826 .40362 Mdot
.77831 .05514 Mdot
.77835 .40532 Mdot
.7784 .03799 Mdot
.77845 .16783 Mdot
.7785 .16822 Mdot
.77854 .43877 Mdot
.77859 .44847 Mdot
.77864 .51699 Mdot
.77869 .41033 Mdot
.77873 .18954 Mdot
.77878 .0565 Mdot
.77883 .54832 Mdot
.77888 .15258 Mdot
.77892 .18783 Mdot
.77897 .53892 Mdot
.77902 .22988 Mdot
.77907 .50242 Mdot
.77911 .05539 Mdot
.77916 .20805 Mdot
.77921 .22164 Mdot
.77926 .40044 Mdot
.77931 .14158 Mdot
.77935 .16882 Mdot
.7794 .42135 Mdot
.77945 .36001 Mdot
.7795 .33959 Mdot
.77954 .14553 Mdot
.77959 .26822 Mdot
.77964 .20649 Mdot
.77969 .50414 Mdot
.77973 .30039 Mdot
.77978 .35456 Mdot
.77983 .39949 Mdot
.77988 .32931 Mdot
.77992 .2586 Mdot
.77997 .40956 Mdot
.78002 .26163 Mdot
.78007 .15619 Mdot
.78011 .32301 Mdot
.78016 .19439 Mdot
.78021 .36253 Mdot
.78026 .1155 Mdot
.78031 .12966 Mdot
.78035 .57607 Mdot
.7804 .56541 Mdot
.78045 .57725 Mdot
.7805 .56417 Mdot
.78054 .16943 Mdot
.78059 .22011 Mdot
.78064 .25237 Mdot
.78069 .43334 Mdot
.78073 .50454 Mdot
.78078 .02833 Mdot
.78083 .35155 Mdot
.78088 .14766 Mdot
.78092 .16468 Mdot
.78097 .23216 Mdot
.78102 .03695 Mdot
.78107 .49239 Mdot
.78111 .35845 Mdot
.78116 .57386 Mdot
.78121 .48409 Mdot
.78126 .18409 Mdot
.78131 .17877 Mdot
.78135 .22603 Mdot
.7814 .38329 Mdot
.78145 .06913 Mdot
.7815 .20602 Mdot
.78154 .26394 Mdot
.78159 .40937 Mdot
.78164 .10829 Mdot
.78169 .05129 Mdot
.78173 .05854 Mdot
.78178 .17171 Mdot
.78183 .27827 Mdot
.78188 .15008 Mdot
.78192 .04492 Mdot
.78197 .42349 Mdot
.78202 .14532 Mdot
.78207 .58873 Mdot
.78211 .41609 Mdot
.78216 .40125 Mdot
.78221 .25626 Mdot
.78226 .24499 Mdot
.78231 .44556 Mdot
.78235 .52049 Mdot
.7824 .08688 Mdot
.78245 .08093 Mdot
.7825 .23423 Mdot
.78254 .1519 Mdot
.78259 .03246 Mdot
.78264 .47824 Mdot
.78269 .57361 Mdot
.78273 .34586 Mdot
.78278 .52749 Mdot
.78283 .44165 Mdot
.78288 .52978 Mdot
.78292 .18886 Mdot
.78297 .26393 Mdot
.78302 .30628 Mdot
.78307 .49957 Mdot
.78311 .36869 Mdot
.78316 .13332 Mdot
.78321 .32088 Mdot
.78326 .09819 Mdot
.78331 .57077 Mdot
.78335 .48038 Mdot
.7834 .0906 Mdot
.78345 .25596 Mdot
.7835 .06499 Mdot
.78354 .40821 Mdot
.78359 .02437 Mdot
.78364 .03644 Mdot
.78369 .51641 Mdot
.78373 .39046 Mdot
.78378 .14946 Mdot
.78383 .06615 Mdot
.78388 .18526 Mdot
.78392 .46629 Mdot
.78397 .31114 Mdot
.78402 .13969 Mdot
.78407 .59973 Mdot
.78411 .21707 Mdot
.78416 .01957 Mdot
.78421 .24345 Mdot
.78426 .24575 Mdot
.7843 .09846 Mdot
.78435 .30202 Mdot
.7844 .15996 Mdot
.78445 .2783 Mdot
.7845 .22141 Mdot
.78454 .22613 Mdot
.78459 .50733 Mdot
.78464 .22802 Mdot
.78469 .41653 Mdot
.78473 .21647 Mdot
.78478 .4856 Mdot
.78483 .31493 Mdot
.78488 .04078 Mdot
.78492 .08171 Mdot
.78497 .43415 Mdot
.78502 .14438 Mdot
.78507 .17782 Mdot
.78511 .3739 Mdot
.78516 .30917 Mdot
.78521 .14798 Mdot
.78526 .56407 Mdot
.7853 .36904 Mdot
.78535 .08043 Mdot
.7854 .50556 Mdot
.78545 .48032 Mdot
.7855 .08172 Mdot
.78554 .52379 Mdot
.78559 .24196 Mdot
.78564 .27362 Mdot
.78569 .45892 Mdot
.78573 .03117 Mdot
.78578 .02865 Mdot
.78583 .46041 Mdot
.78588 .25716 Mdot
.78592 .1489 Mdot
.78597 .31704 Mdot
.78602 .43434 Mdot
.78607 .19015 Mdot
.78611 .31808 Mdot
.78616 .18737 Mdot
.78621 .27124 Mdot
.78626 .41958 Mdot
.7863 .02362 Mdot
.78635 .0541 Mdot
.7864 .31049 Mdot
.78645 .06525 Mdot
.7865 .54652 Mdot
.78654 .15187 Mdot
.78659 .4335 Mdot
.78664 .58686 Mdot
.78669 .03743 Mdot
.78673 .51323 Mdot
.78678 .17459 Mdot
.78683 .14265 Mdot
.78688 .02097 Mdot
.78692 .49929 Mdot
.78697 .3175 Mdot
.78702 .48882 Mdot
.78707 .47539 Mdot
.78711 .19696 Mdot
.78716 .48648 Mdot
.78721 .31337 Mdot
.78726 .17202 Mdot
.7873 .0243 Mdot
.78735 .22996 Mdot
.7874 .49712 Mdot
.78745 .16311 Mdot
.7875 .57353 Mdot
.78754 .52279 Mdot
.78759 .44657 Mdot
.78764 .21992 Mdot
.78769 .43637 Mdot
.78773 .104 Mdot
.78778 .46304 Mdot
.78783 .1972 Mdot
.78788 .52646 Mdot
.78792 .53273 Mdot
.78797 .3351 Mdot
.78802 .19094 Mdot
.78807 .04188 Mdot
.78811 .22994 Mdot
.78816 .44961 Mdot
.78821 .31887 Mdot
.78826 .44825 Mdot
.7883 .34678 Mdot
.78835 .15095 Mdot
.7884 .16156 Mdot
.78845 .43865 Mdot
.78849 .13153 Mdot
.78854 .25716 Mdot
.78859 .60177 Mdot
.78864 .46845 Mdot
.78869 .21207 Mdot
.78873 .41391 Mdot
.78878 .39656 Mdot
.78883 .0468 Mdot
.78888 .12278 Mdot
.78892 .55419 Mdot
.78897 .21407 Mdot
.78902 .12366 Mdot
.78907 .19337 Mdot
.78911 .2338 Mdot
.78916 .03784 Mdot
.78921 .09649 Mdot
.78926 .56676 Mdot
.7893 .38752 Mdot
.78935 .32229 Mdot
.7894 .25157 Mdot
.78945 .23469 Mdot
.78949 .25128 Mdot
.78954 .17544 Mdot
.78959 .41624 Mdot
.78964 .11786 Mdot
.78969 .59745 Mdot
.78973 .17699 Mdot
.78978 .55111 Mdot
.78983 .50912 Mdot
.78988 .19825 Mdot
.78992 .38376 Mdot
.78997 .51903 Mdot
.79002 .40106 Mdot
.79007 .24738 Mdot
.79011 .18439 Mdot
.79016 .41007 Mdot
.79021 .2224 Mdot
.79026 .02829 Mdot
.7903 .16126 Mdot
.79035 .32829 Mdot
.7904 .25897 Mdot
.79045 .2441 Mdot
.79049 .44229 Mdot
.79054 .09143 Mdot
.79059 .03899 Mdot
.79064 .59614 Mdot
.79069 .28156 Mdot
.79073 .27851 Mdot
.79078 .52445 Mdot
.79083 .60201 Mdot
.79088 .11928 Mdot
.79092 .33072 Mdot
.79097 .03004 Mdot
.79102 .41847 Mdot
.79107 .33884 Mdot
.79111 .41502 Mdot
.79116 .2323 Mdot
.79121 .1858 Mdot
.79126 .16916 Mdot
.7913 .01966 Mdot
.79135 .02462 Mdot
.7914 .17222 Mdot
.79145 .02261 Mdot
.79149 .29469 Mdot
.79154 .36898 Mdot
.79159 .53145 Mdot
.79164 .18364 Mdot
.79169 .21797 Mdot
.79173 .34469 Mdot
.79178 .53863 Mdot
.79183 .50541 Mdot
.79188 .54279 Mdot
.79192 .42357 Mdot
.79197 .53994 Mdot
.79202 .40084 Mdot
.79207 .22678 Mdot
.79211 .40824 Mdot
.79216 .13618 Mdot
.79221 .07671 Mdot
.79226 .41509 Mdot
.7923 .19064 Mdot
.79235 .55371 Mdot
.7924 .51087 Mdot
.79245 .41014 Mdot
.79249 .18074 Mdot
.79254 .39621 Mdot
.79259 .50297 Mdot
.79264 .13016 Mdot
.79269 .41509 Mdot
.79273 .46809 Mdot
.79278 .33404 Mdot
.79283 .51551 Mdot
.79288 .0851 Mdot
.79292 .53278 Mdot
.79297 .43195 Mdot
.79302 .57604 Mdot
.79307 .26486 Mdot
.79311 .59616 Mdot
.79316 .04582 Mdot
.79321 .36397 Mdot
.79326 .45994 Mdot
.7933 .47468 Mdot
.79335 .57244 Mdot
.7934 .55221 Mdot
.79345 .28401 Mdot
.79349 .5243 Mdot
.79354 .07627 Mdot
.79359 .15678 Mdot
.79364 .11798 Mdot
.79368 .1428 Mdot
.79373 .17662 Mdot
.79378 .04133 Mdot
.79383 .30622 Mdot
.79388 .27804 Mdot
.79392 .44591 Mdot
.79397 .12915 Mdot
.79402 .23583 Mdot
.79407 .34859 Mdot
.79411 .02866 Mdot
.79416 .15643 Mdot
.79421 .57429 Mdot
.79426 .35575 Mdot
.7943 .58617 Mdot
.79435 .39579 Mdot
.7944 .12906 Mdot
.79445 .48439 Mdot
.79449 .02844 Mdot
.79454 .44691 Mdot
.79459 .44838 Mdot
.79464 .56342 Mdot
.79468 .5555 Mdot
.79473 .30484 Mdot
.79478 .34511 Mdot
.79483 .43533 Mdot
.79488 .39358 Mdot
.79492 .27822 Mdot
.79497 .0536 Mdot
.79502 .172 Mdot
.79507 .551 Mdot
.79511 .16378 Mdot
.79516 .42109 Mdot
.79521 .42674 Mdot
.79526 .53705 Mdot
.7953 .02205 Mdot
.79535 .45013 Mdot
.7954 .08569 Mdot
.79545 .5542 Mdot
.79549 .22959 Mdot
.79554 .33577 Mdot
.79559 .20462 Mdot
.79564 .54047 Mdot
.79568 .38601 Mdot
.79573 .49072 Mdot
.79578 .24452 Mdot
.79583 .5883 Mdot
.79588 .09588 Mdot
.79592 .16032 Mdot
.79597 .41252 Mdot
.79602 .20942 Mdot
.79607 .42099 Mdot
.79611 .12144 Mdot
.79616 .25523 Mdot
.79621 .26175 Mdot
.79626 .27192 Mdot
.7963 .30367 Mdot
.79635 .43182 Mdot
.7964 .32803 Mdot
.79645 .26458 Mdot
.79649 .45687 Mdot
.79654 .36084 Mdot
.79659 .37715 Mdot
.79664 .04969 Mdot
.79668 .1358 Mdot
.79673 .17092 Mdot
.79678 .44001 Mdot
.79683 .26701 Mdot
.79688 .24841 Mdot
.79692 .52972 Mdot
.79697 .45504 Mdot
.79702 .18584 Mdot
.79707 .10279 Mdot
.79711 .13191 Mdot
.79716 .26033 Mdot
.79721 .36817 Mdot
.79726 .58468 Mdot
.7973 .48001 Mdot
.79735 .6019 Mdot
.7974 .11096 Mdot
.79745 .29572 Mdot
.79749 .0629 Mdot
.79754 .28859 Mdot
.79759 .44971 Mdot
.79764 .44218 Mdot
.79768 .30539 Mdot
.79773 .51476 Mdot
.79778 .41473 Mdot
.79783 .32108 Mdot
.79787 .14918 Mdot
.79792 .08946 Mdot
.79797 .16243 Mdot
.79802 .08738 Mdot
.79807 .22278 Mdot
.79811 .23775 Mdot
.79816 .57991 Mdot
.79821 .58792 Mdot
.79826 .10557 Mdot
.7983 .58075 Mdot
.79835 .22645 Mdot
.7984 .01795 Mdot
.79845 .22889 Mdot
.79849 .58217 Mdot
.79854 .1302 Mdot
.79859 .32555 Mdot
.79864 .1807 Mdot
.79868 .30829 Mdot
.79873 .28381 Mdot
.79878 .4867 Mdot
.79883 .47863 Mdot
.79887 .39685 Mdot
.79892 .47241 Mdot
.79897 .18033 Mdot
.79902 .34416 Mdot
.79907 .3221 Mdot
.79911 .32469 Mdot
.79916 .10765 Mdot
.79921 .13609 Mdot
.79926 .09906 Mdot
.7993 .3481 Mdot
.79935 .12306 Mdot
.7994 .04523 Mdot
.79945 .12164 Mdot
.79949 .13636 Mdot
.79954 .11982 Mdot
.79959 .41967 Mdot
.79964 .1428 Mdot
.79968 .02087 Mdot
.79973 .3976 Mdot
.79978 .25368 Mdot
.79983 .43783 Mdot
.79987 .34039 Mdot
.79992 .51422 Mdot
.79997 .37838 Mdot
.80002 .05569 Mdot
.80007 .4713 Mdot
.80011 .3486 Mdot
.80016 .04892 Mdot
.80021 .33691 Mdot
.80026 .16132 Mdot
.8003 .25565 Mdot
.80035 .51615 Mdot
.8004 .25256 Mdot
.80045 .41655 Mdot
.80049 .1473 Mdot
.80054 .48563 Mdot
.80059 .14563 Mdot
.80064 .2949 Mdot
.80068 .04218 Mdot
.80073 .08068 Mdot
.80078 .01754 Mdot
.80083 .28874 Mdot
.80087 .24791 Mdot
.80092 .43032 Mdot
.80097 .18303 Mdot
.80102 .55168 Mdot
.80107 .33702 Mdot
.80111 .06665 Mdot
.80116 .14205 Mdot
.80121 .09508 Mdot
.80126 .59175 Mdot
.8013 .03244 Mdot
.80135 .40847 Mdot
.8014 .53708 Mdot
.80145 .3508 Mdot
.80149 .11961 Mdot
.80154 .17062 Mdot
.80159 .13524 Mdot
.80164 .21821 Mdot
.80168 .2373 Mdot
.80173 .0397 Mdot
.80178 .44367 Mdot
.80183 .19074 Mdot
.80187 .17133 Mdot
.80192 .03687 Mdot
.80197 .16964 Mdot
.80202 .54615 Mdot
.80207 .34434 Mdot
.80211 .45716 Mdot
.80216 .22129 Mdot
.80221 .22384 Mdot
.80226 .29239 Mdot
.8023 .32982 Mdot
.80235 .14092 Mdot
.8024 .23542 Mdot
.80245 .27466 Mdot
.80249 .52468 Mdot
.80254 .20716 Mdot
.80259 .48795 Mdot
.80264 .16976 Mdot
.80268 .36877 Mdot
.80273 .08663 Mdot
.80278 .28444 Mdot
.80283 .53578 Mdot
.80287 .34378 Mdot
.80292 .24629 Mdot
.80297 .10841 Mdot
.80302 .37915 Mdot
.80306 .32162 Mdot
.80311 .09136 Mdot
.80316 .16558 Mdot
.80321 .04952 Mdot
.80326 .46779 Mdot
.8033 .4734 Mdot
.80335 .54506 Mdot
.8034 .36046 Mdot
.80345 .15268 Mdot
.80349 .34719 Mdot
.80354 .32435 Mdot
.80359 .10051 Mdot
.80364 .23133 Mdot
.80368 .15474 Mdot
.80373 .43973 Mdot
.80378 .53408 Mdot
.80383 .46589 Mdot
.80387 .08282 Mdot
.80392 .16999 Mdot
.80397 .60162 Mdot
.80402 .13682 Mdot
.80406 .43986 Mdot
.80411 .07629 Mdot
.80416 .23718 Mdot
.80421 .41852 Mdot
.80426 .36321 Mdot
.8043 .51403 Mdot
.80435 .20236 Mdot
.8044 .55405 Mdot
.80445 .49314 Mdot
.80449 .57229 Mdot
.80454 .44523 Mdot
.80459 .41608 Mdot
.80464 .16066 Mdot
.80468 .26265 Mdot
.80473 .35943 Mdot
.80478 .19946 Mdot
.80483 .02063 Mdot
.80487 .42625 Mdot
.80492 .42868 Mdot
.80497 .33689 Mdot
.80502 .54114 Mdot
.80506 .27097 Mdot
.80511 .43038 Mdot
.80516 .21479 Mdot
.80521 .11599 Mdot
.80526 .20938 Mdot
.8053 .20792 Mdot
.80535 .39959 Mdot
.8054 .3561 Mdot
.80545 .29868 Mdot
.80549 .02027 Mdot
.80554 .44886 Mdot
.80559 .46629 Mdot
.80564 .32971 Mdot
.80568 .17836 Mdot
.80573 .04749 Mdot
.80578 .32034 Mdot
.80583 .08176 Mdot
.80587 .42226 Mdot
.80592 .45136 Mdot
.80597 .31442 Mdot
.80602 .25884 Mdot
.80606 .5969 Mdot
.80611 .12917 Mdot
.80616 .37661 Mdot
.80621 .59119 Mdot
.80626 .18123 Mdot
.8063 .51771 Mdot
.80635 .27533 Mdot
.8064 .39652 Mdot
.80645 .57664 Mdot
.80649 .13283 Mdot
.80654 .52255 Mdot
.80659 .11255 Mdot
.80664 .57108 Mdot
.80668 .28729 Mdot
.80673 .07097 Mdot
.80678 .38617 Mdot
.80683 .40742 Mdot
.80687 .25451 Mdot
.80692 .35396 Mdot
.80697 .31912 Mdot
.80702 .58849 Mdot
.80706 .40647 Mdot
.80711 .05424 Mdot
.80716 .07499 Mdot
.80721 .59491 Mdot
.80725 .29201 Mdot
.8073 .28096 Mdot
.80735 .08712 Mdot
.8074 .42839 Mdot
.80745 .37762 Mdot
.80749 .02034 Mdot
.80754 .29392 Mdot
.80759 .45508 Mdot
.80764 .2595 Mdot
.80768 .10111 Mdot
.80773 .19608 Mdot
.80778 .48733 Mdot
.80783 .57554 Mdot
.80787 .04485 Mdot
.80792 .41324 Mdot
.80797 .09461 Mdot
.80802 .33574 Mdot
.80806 .29422 Mdot
.80811 .10883 Mdot
.80816 .10945 Mdot
.80821 .53259 Mdot
.80825 .25469 Mdot
.8083 .04855 Mdot
.80835 .11787 Mdot
.8084 .25529 Mdot
.80845 .57705 Mdot
.80849 .56476 Mdot
.80854 .2928 Mdot
.80859 .481 Mdot
.80864 .57142 Mdot
.80868 .28554 Mdot
.80873 .44105 Mdot
.80878 .2362 Mdot
.80883 .48502 Mdot
.80887 .10417 Mdot
.80892 .55705 Mdot
.80897 .26399 Mdot
.80902 .45487 Mdot
.80906 .29426 Mdot
.80911 .47714 Mdot
.80916 .53157 Mdot
.80921 .17536 Mdot
.80925 .20014 Mdot
.8093 .3824 Mdot
.80935 .60231 Mdot
.8094 .524 Mdot
.80945 .16629 Mdot
.80949 .27924 Mdot
.80954 .36172 Mdot
.80959 .55028 Mdot
.80964 .20486 Mdot
.80968 .58976 Mdot
.80973 .48405 Mdot
.80978 .58218 Mdot
.80983 .52264 Mdot
.80987 .16342 Mdot
.80992 .26256 Mdot
.80997 .11188 Mdot
.81002 .43318 Mdot
.81006 .2097 Mdot
.81011 .60189 Mdot
.81016 .26033 Mdot
.81021 .15363 Mdot
.81025 .33588 Mdot
.8103 .08503 Mdot
.81035 .09968 Mdot
.8104 .55682 Mdot
.81045 .55681 Mdot
.81049 .08605 Mdot
.81054 .179 Mdot
.81059 .40523 Mdot
.81064 .29228 Mdot
.81068 .32765 Mdot
.81073 .23205 Mdot
.81078 .21508 Mdot
.81083 .30584 Mdot
.81087 .44692 Mdot
.81092 .25319 Mdot
.81097 .29577 Mdot
.81102 .15712 Mdot
.81106 .19907 Mdot
.81111 .15603 Mdot
.81116 .46592 Mdot
.81121 .55075 Mdot
.81125 .20051 Mdot
.8113 .49902 Mdot
.81135 .327 Mdot
.8114 .22958 Mdot
.81145 .13019 Mdot
.81149 .41406 Mdot
.81154 .37351 Mdot
.81159 .27609 Mdot
.81164 .05885 Mdot
.81168 .24976 Mdot
.81173 .5716 Mdot
.81178 .58714 Mdot
.81183 .33453 Mdot
.81187 .03242 Mdot
.81192 .37123 Mdot
.81197 .29602 Mdot
.81202 .49093 Mdot
.81206 .38256 Mdot
.81211 .09017 Mdot
.81216 .1536 Mdot
.81221 .30656 Mdot
.81225 .24124 Mdot
.8123 .22758 Mdot
.81235 .20618 Mdot
.8124 .12077 Mdot
.81244 .34554 Mdot
.81249 .5039 Mdot
.81254 .57992 Mdot
.81259 .5939 Mdot
.81264 .53481 Mdot
.81268 .1451 Mdot
.81273 .31854 Mdot
.81278 .54976 Mdot
.81283 .29975 Mdot
.81287 .17682 Mdot
.81292 .33472 Mdot
.81297 .22994 Mdot
.81302 .28204 Mdot
.81306 .40891 Mdot
.81311 .05341 Mdot
.81316 .34234 Mdot
.81321 .50281 Mdot
.81325 .33345 Mdot
.8133 .50314 Mdot
.81335 .05048 Mdot
.8134 .27628 Mdot
.81344 .12059 Mdot
.81349 .31167 Mdot
.81354 .53304 Mdot
.81359 .53406 Mdot
.81364 .22001 Mdot
.81368 .33507 Mdot
.81373 .54246 Mdot
.81378 .60258 Mdot
.81383 .08962 Mdot
.81387 .03124 Mdot
.81392 .59603 Mdot
.81397 .31753 Mdot
.81402 .51613 Mdot
.81406 .29985 Mdot
.81411 .3808 Mdot
.81416 .0502 Mdot
.81421 .12193 Mdot
.81425 .26115 Mdot
.8143 .05317 Mdot
.81435 .15072 Mdot
.8144 .3918 Mdot
.81444 .36134 Mdot
.81449 .01739 Mdot
.81454 .47777 Mdot
.81459 .28592 Mdot
.81464 .06438 Mdot
.81468 .08768 Mdot
.81473 .54703 Mdot
.81478 .08062 Mdot
.81483 .33263 Mdot
.81487 .14854 Mdot
.81492 .54778 Mdot
.81497 .59432 Mdot
.81502 .3161 Mdot
.81506 .15584 Mdot
.81511 .24496 Mdot
.81516 .0929 Mdot
.81521 .03096 Mdot
.81525 .37837 Mdot
.8153 .20946 Mdot
.81535 .5743 Mdot
.8154 .37313 Mdot
.81544 .33991 Mdot
.81549 .07345 Mdot
.81554 .19721 Mdot
.81559 .0265 Mdot
.81564 .33722 Mdot
.81568 .19901 Mdot
.81573 .51461 Mdot
.81578 .56545 Mdot
.81583 .26425 Mdot
.81587 .2553 Mdot
.81592 .4487 Mdot
.81597 .24753 Mdot
.81602 .13042 Mdot
.81606 .31084 Mdot
.81611 .4577 Mdot
.81616 .53476 Mdot
.81621 .57791 Mdot
.81625 .0806 Mdot
.8163 .37951 Mdot
.81635 .51851 Mdot
.8164 .21426 Mdot
.81644 .47446 Mdot
.81649 .40854 Mdot
.81654 .16008 Mdot
.81659 .47768 Mdot
.81664 .41572 Mdot
.81668 .22605 Mdot
.81673 .14829 Mdot
.81678 .15516 Mdot
.81683 .23143 Mdot
.81687 .31476 Mdot
.81692 .18616 Mdot
.81697 .49423 Mdot
.81702 .57945 Mdot
.81706 .46939 Mdot
.81711 .54196 Mdot
.81716 .37852 Mdot
.81721 .28332 Mdot
.81725 .0264 Mdot
.8173 .02191 Mdot
.81735 .40393 Mdot
.8174 .21743 Mdot
.81744 .25021 Mdot
.81749 .10672 Mdot
.81754 .20438 Mdot
.81759 .34629 Mdot
.81763 .44499 Mdot
.81768 .54996 Mdot
.81773 .33003 Mdot
.81778 .5339 Mdot
.81783 .23365 Mdot
.81787 .41638 Mdot
.81792 .18958 Mdot
.81797 .31718 Mdot
.81802 .52221 Mdot
.81806 .24493 Mdot
.81811 .29867 Mdot
.81816 .34105 Mdot
.81821 .06753 Mdot
.81825 .3063 Mdot
.8183 .52347 Mdot
.81835 .07244 Mdot
.8184 .05584 Mdot
.81844 .2991 Mdot
.81849 .13425 Mdot
.81854 .45834 Mdot
.81859 .40896 Mdot
.81863 .20709 Mdot
.81868 .5332 Mdot
.81873 .12676 Mdot
.81878 .5673 Mdot
.81883 .26045 Mdot
.81887 .21788 Mdot
.81892 .19619 Mdot
.81897 .34835 Mdot
.81902 .44739 Mdot
.81906 .04301 Mdot
.81911 .48233 Mdot
.81916 .42947 Mdot
.81921 .21717 Mdot
.81925 .34767 Mdot
.8193 .15599 Mdot
.81935 .37664 Mdot
.8194 .51419 Mdot
.81944 .42752 Mdot
.81949 .09825 Mdot
.81954 .33551 Mdot
.81959 .2298 Mdot
.81963 .30797 Mdot
.81968 .24324 Mdot
.81973 .52988 Mdot
.81978 .03742 Mdot
.81983 .3781 Mdot
.81987 .13119 Mdot
.81992 .5659 Mdot
.81997 .3803 Mdot
.82002 .17493 Mdot
.82006 .53833 Mdot
.82011 .23226 Mdot
.82016 .53623 Mdot
.82021 .14663 Mdot
.82025 .07071 Mdot
.8203 .40612 Mdot
.82035 .33377 Mdot
.8204 .40229 Mdot
.82044 .51804 Mdot
.82049 .04419 Mdot
.82054 .4229 Mdot
.82059 .5781 Mdot
.82063 .4345 Mdot
.82068 .312 Mdot
.82073 .20781 Mdot
.82078 .28483 Mdot
.82083 .20597 Mdot
.82087 .38545 Mdot
.82092 .1851 Mdot
.82097 .51005 Mdot
.82102 .08948 Mdot
.82106 .42287 Mdot
.82111 .40813 Mdot
.82116 .34983 Mdot
.82121 .15448 Mdot
.82125 .20532 Mdot
.8213 .47522 Mdot
.82135 .2179 Mdot
.8214 .09848 Mdot
.82144 .40252 Mdot
.82149 .15616 Mdot
.82154 .41894 Mdot
.82159 .18376 Mdot
.82163 .37305 Mdot
.82168 .33658 Mdot
.82173 .44417 Mdot
.82178 .35259 Mdot
.82182 .07576 Mdot
.82187 .14348 Mdot
.82192 .17404 Mdot
.82197 .16133 Mdot
.82202 .29363 Mdot
.82206 .56171 Mdot
.82211 .26732 Mdot
.82216 .08656 Mdot
.82221 .47408 Mdot
.82225 .16829 Mdot
.8223 .52081 Mdot
.82235 .53541 Mdot
.8224 .28347 Mdot
.82244 .29639 Mdot
.82249 .31762 Mdot
.82254 .45164 Mdot
.82259 .48427 Mdot
.82263 .15493 Mdot
.82268 .50201 Mdot
.82273 .28258 Mdot
.82278 .12594 Mdot
.82282 .42167 Mdot
.82287 .07255 Mdot
.82292 .53332 Mdot
.82297 .06489 Mdot
.82302 .2929 Mdot
.82306 .50183 Mdot
.82311 .38669 Mdot
.82316 .37458 Mdot
.82321 .33452 Mdot
.82325 .24922 Mdot
.8233 .31484 Mdot
.82335 .50383 Mdot
.8234 .18094 Mdot
.82344 .33174 Mdot
.82349 .38276 Mdot
.82354 .23506 Mdot
.82359 .48788 Mdot
.82363 .02883 Mdot
.82368 .53445 Mdot
.82373 .35411 Mdot
.82378 .34766 Mdot
.82382 .13015 Mdot
.82387 .26658 Mdot
.82392 .24288 Mdot
.82397 .52931 Mdot
.82402 .07231 Mdot
.82406 .33658 Mdot
.82411 .1927 Mdot
.82416 .25112 Mdot
.82421 .1738 Mdot
.82425 .55321 Mdot
.8243 .42145 Mdot
.82435 .51992 Mdot
.8244 .5279 Mdot
.82444 .25308 Mdot
.82449 .52095 Mdot
.82454 .35369 Mdot
.82459 .21087 Mdot
.82463 .47364 Mdot
.82468 .3006 Mdot
.82473 .46913 Mdot
.82478 .19676 Mdot
.82482 .54251 Mdot
.82487 .54981 Mdot
.82492 .13618 Mdot
.82497 .08132 Mdot
.82502 .29065 Mdot
.82506 .32163 Mdot
.82511 .21019 Mdot
.82516 .02372 Mdot
.82521 .55739 Mdot
.82525 .14364 Mdot
.8253 .5624 Mdot
.82535 .45325 Mdot
.8254 .01888 Mdot
.82544 .32552 Mdot
.82549 .05718 Mdot
.82554 .52867 Mdot
.82559 .36913 Mdot
.82563 .40789 Mdot
.82568 .30682 Mdot
.82573 .3325 Mdot
.82578 .49882 Mdot
.82582 .12201 Mdot
.82587 .44102 Mdot
.82592 .15046 Mdot
.82597 .55963 Mdot
.82602 .17552 Mdot
.82606 .31955 Mdot
.82611 .08385 Mdot
.82616 .28369 Mdot
.82621 .45722 Mdot
.82625 .12407 Mdot
.8263 .07483 Mdot
.82635 .32963 Mdot
.8264 .32829 Mdot
.82644 .165 Mdot
.82649 .22491 Mdot
.82654 .32545 Mdot
.82659 .01748 Mdot
.82663 .12252 Mdot
.82668 .29956 Mdot
.82673 .55965 Mdot
.82678 .21291 Mdot
.82682 .41902 Mdot
.82687 .57039 Mdot
.82692 .07554 Mdot
.82697 .10561 Mdot
.82701 .58133 Mdot
.82706 .43464 Mdot
.82711 .11923 Mdot
.82716 .53341 Mdot
.82721 .27648 Mdot
.82725 .3655 Mdot
.8273 .43887 Mdot
.82735 .09091 Mdot
.8274 .16712 Mdot
.82744 .30538 Mdot
.82749 .12395 Mdot
.82754 .36594 Mdot
.82759 .01684 Mdot
.82763 .09518 Mdot
.82768 .40182 Mdot
.82773 .36317 Mdot
.82778 .49764 Mdot
.82782 .39894 Mdot
.82787 .4455 Mdot
.82792 .16497 Mdot
.82797 .09333 Mdot
.82801 .43188 Mdot
.82806 .38467 Mdot
.82811 .07406 Mdot
.82816 .11533 Mdot
.82821 .60056 Mdot
.82825 .28015 Mdot
.8283 .14397 Mdot
.82835 .44217 Mdot
.8284 .24977 Mdot
.82844 .4446 Mdot
.82849 .06778 Mdot
.82854 .28975 Mdot
.82859 .54772 Mdot
.82863 .33536 Mdot
.82868 .30516 Mdot
.82873 .28762 Mdot
.82878 .46725 Mdot
.82882 .53686 Mdot
.82887 .54531 Mdot
.82892 .3933 Mdot
.82897 .08302 Mdot
.82901 .10607 Mdot
.82906 .39505 Mdot
.82911 .31468 Mdot
.82916 .25447 Mdot
.82921 .32472 Mdot
.82925 .3357 Mdot
.8293 .21406 Mdot
.82935 .25723 Mdot
.8294 .05929 Mdot
.82944 .20643 Mdot
.82949 .37522 Mdot
.82954 .02216 Mdot
.82959 .21801 Mdot
.82963 .15336 Mdot
.82968 .10018 Mdot
.82973 .07777 Mdot
.82978 .48597 Mdot
.82982 .45153 Mdot
.82987 .41588 Mdot
.82992 .21385 Mdot
.82997 .55243 Mdot
.83001 .50955 Mdot
.83006 .03728 Mdot
.83011 .14554 Mdot
.83016 .46107 Mdot
.83021 .1292 Mdot
.83025 .32592 Mdot
.8303 .4944 Mdot
.83035 .15106 Mdot
.8304 .39683 Mdot
.83044 .12657 Mdot
.83049 .25188 Mdot
.83054 .10648 Mdot
.83059 .20511 Mdot
.83063 .35468 Mdot
.83068 .24442 Mdot
.83073 .4918 Mdot
.83078 .06646 Mdot
.83082 .26921 Mdot
.83087 .18136 Mdot
.83092 .02053 Mdot
.83097 .21826 Mdot
.83101 .45666 Mdot
.83106 .57084 Mdot
.83111 .07142 Mdot
.83116 .31204 Mdot
.8312 .43408 Mdot
.83125 .44001 Mdot
.8313 .21367 Mdot
.83135 .19754 Mdot
.8314 .12287 Mdot
.83144 .54894 Mdot
.83149 .07733 Mdot
.83154 .40403 Mdot
.83159 .59962 Mdot
.83163 .31177 Mdot
.83168 .57417 Mdot
.83173 .21363 Mdot
.83178 .25966 Mdot
.83182 .08205 Mdot
.83187 .09709 Mdot
.83192 .16187 Mdot
.83197 .59377 Mdot
.83201 .50401 Mdot
.83206 .09126 Mdot
.83211 .54694 Mdot
.83216 .15182 Mdot
.8322 .5365 Mdot
.83225 .03455 Mdot
.8323 .24962 Mdot
.83235 .32106 Mdot
.8324 .1112 Mdot
.83244 .4242 Mdot
.83249 .06679 Mdot
.83254 .2129 Mdot
.83259 .16559 Mdot
.83263 .36158 Mdot
.83268 .26608 Mdot
.83273 .2166 Mdot
.83278 .45715 Mdot
.83282 .39074 Mdot
.83287 .06716 Mdot
.83292 .56027 Mdot
.83297 .38981 Mdot
.83301 .30836 Mdot
.83306 .50861 Mdot
.83311 .56983 Mdot
.83316 .48912 Mdot
.8332 .2318 Mdot
.83325 .56499 Mdot
.8333 .43271 Mdot
.83335 .55595 Mdot
.8334 .21196 Mdot
.83344 .33008 Mdot
.83349 .12636 Mdot
.83354 .45945 Mdot
.83359 .39108 Mdot
.83363 .27801 Mdot
.83368 .51678 Mdot
.83373 .30857 Mdot
.83378 .04421 Mdot
.83382 .02664 Mdot
.83387 .31489 Mdot
.83392 .45474 Mdot
.83397 .2568 Mdot
.83401 .5628 Mdot
.83406 .35794 Mdot
.83411 .07964 Mdot
.83416 .55176 Mdot
.8342 .06889 Mdot
.83425 .39144 Mdot
.8343 .19385 Mdot
.83435 .33467 Mdot
.8344 .10723 Mdot
.83444 .56205 Mdot
.83449 .24123 Mdot
.83454 .13742 Mdot
.83459 .38047 Mdot
.83463 .4504 Mdot
.83468 .3851 Mdot
.83473 .34966 Mdot
.83478 .11717 Mdot
.83482 .53695 Mdot
.83487 .09124 Mdot
.83492 .32017 Mdot
.83497 .10524 Mdot
.83501 .23677 Mdot
.83506 .23982 Mdot
.83511 .07808 Mdot
.83516 .14577 Mdot
.8352 .48215 Mdot
.83525 .17488 Mdot
.8353 .12964 Mdot
.83535 .09158 Mdot
.8354 .10542 Mdot
.83544 .58436 Mdot
.83549 .3983 Mdot
.83554 .58768 Mdot
.83559 .14669 Mdot
.83563 .35785 Mdot
.83568 .27559 Mdot
.83573 .22192 Mdot
.83578 .29961 Mdot
.83582 .57607 Mdot
.83587 .52925 Mdot
.83592 .11946 Mdot
.83597 .36599 Mdot
.83601 .49954 Mdot
.83606 .22379 Mdot
.83611 .02893 Mdot
.83616 .14393 Mdot
.8362 .27443 Mdot
.83625 .16042 Mdot
.8363 .48649 Mdot
.83635 .26511 Mdot
.83639 .11426 Mdot
.83644 .04549 Mdot
.83649 .40962 Mdot
.83654 .1744 Mdot
.83659 .13322 Mdot
.83663 .25052 Mdot
.83668 .42526 Mdot
.83673 .04241 Mdot
.83678 .3787 Mdot
.83682 .57825 Mdot
.83687 .21805 Mdot
.83692 .34612 Mdot
.83697 .40595 Mdot
.83701 .06371 Mdot
.83706 .11329 Mdot
.83711 .58346 Mdot
.83716 .50974 Mdot
.8372 .44325 Mdot
.83725 .09907 Mdot
.8373 .45423 Mdot
.83735 .25001 Mdot
.83739 .29753 Mdot
.83744 .21591 Mdot
.83749 .20383 Mdot
.83754 .15047 Mdot
.83759 .26675 Mdot
.83763 .40962 Mdot
.83768 .04414 Mdot
.83773 .03196 Mdot
.83778 .03094 Mdot
.83782 .58768 Mdot
.83787 .01644 Mdot
.83792 .25658 Mdot
.83797 .05601 Mdot
.83801 .38435 Mdot
.83806 .27364 Mdot
.83811 .45396 Mdot
.83816 .59563 Mdot
.8382 .28576 Mdot
.83825 .29351 Mdot
.8383 .54755 Mdot
.83835 .16709 Mdot
.83839 .2014 Mdot
.83844 .44261 Mdot
.83849 .31224 Mdot
.83854 .47288 Mdot
.83859 .58881 Mdot
.83863 .25349 Mdot
.83868 .17648 Mdot
.83873 .22084 Mdot
.83878 .1939 Mdot
.83882 .22405 Mdot
.83887 .15924 Mdot
.83892 .20461 Mdot
.83897 .20954 Mdot
.83901 .22232 Mdot
.83906 .50598 Mdot
.83911 .1633 Mdot
.83916 .42852 Mdot
.8392 .552 Mdot
.83925 .06673 Mdot
.8393 .171 Mdot
.83935 .15747 Mdot
.83939 .27319 Mdot
.83944 .12251 Mdot
.83949 .01862 Mdot
.83954 .5594 Mdot
.83959 .43391 Mdot
.83963 .4136 Mdot
.83968 .14906 Mdot
.83973 .57391 Mdot
.83978 .19513 Mdot
.83982 .25182 Mdot
.83987 .53154 Mdot
.83992 .39472 Mdot
.83997 .57441 Mdot
.84001 .10729 Mdot
.84006 .34164 Mdot
.84011 .19989 Mdot
.84016 .3668 Mdot
.8402 .20464 Mdot
.84025 .19305 Mdot
.8403 .3747 Mdot
.84035 .41813 Mdot
.84039 .15262 Mdot
.84044 .03676 Mdot
.84049 .23194 Mdot
.84054 .15964 Mdot
.84058 .04481 Mdot
.84063 .03286 Mdot
.84068 .27586 Mdot
.84073 .32905 Mdot
.84078 .23454 Mdot
.84082 .48712 Mdot
.84087 .30528 Mdot
.84092 .14863 Mdot
.84097 .58605 Mdot
.84101 .55891 Mdot
.84106 .51388 Mdot
.84111 .17754 Mdot
.84116 .49346 Mdot
.8412 .23197 Mdot
.84125 .3287 Mdot
.8413 .41407 Mdot
.84135 .30353 Mdot
.84139 .05363 Mdot
.84144 .55733 Mdot
.84149 .59927 Mdot
.84154 .16562 Mdot
.84158 .03158 Mdot
.84163 .3401 Mdot
.84168 .45434 Mdot
.84173 .13552 Mdot
.84178 .60204 Mdot
.84182 .07894 Mdot
.84187 .13999 Mdot
.84192 .5043 Mdot
.84197 .12963 Mdot
.84201 .37699 Mdot
.84206 .59469 Mdot
.84211 .52158 Mdot
.84216 .17404 Mdot
.8422 .46644 Mdot
.84225 .43186 Mdot
.8423 .04282 Mdot
.84235 .5454 Mdot
.84239 .15245 Mdot
.84244 .03249 Mdot
.84249 .34262 Mdot
.84254 .50647 Mdot
.84258 .19845 Mdot
.84263 .03655 Mdot
.84268 .1917 Mdot
.84273 .48961 Mdot
.84278 .46168 Mdot
.84282 .18554 Mdot
.84287 .07089 Mdot
.84292 .49089 Mdot
.84297 .39745 Mdot
.84301 .06025 Mdot
.84306 .16992 Mdot
.84311 .37597 Mdot
.84316 .03516 Mdot
.8432 .06888 Mdot
.84325 .25167 Mdot
.8433 .21663 Mdot
.84335 .17205 Mdot
.84339 .24036 Mdot
.84344 .22355 Mdot
.84349 .27456 Mdot
.84354 .03431 Mdot
.84358 .22257 Mdot
.84363 .48426 Mdot
.84368 .37141 Mdot
.84373 .43919 Mdot
.84378 .20073 Mdot
.84382 .30726 Mdot
.84387 .48513 Mdot
.84392 .58083 Mdot
.84397 .0299 Mdot
.84401 .25107 Mdot
.84406 .59757 Mdot
.84411 .1981 Mdot
.84416 .57298 Mdot
.8442 .09586 Mdot
.84425 .23631 Mdot
.8443 .17764 Mdot
.84435 .5188 Mdot
.84439 .44752 Mdot
.84444 .03439 Mdot
.84449 .0203 Mdot
.84454 .29315 Mdot
.84458 .23868 Mdot
.84463 .36315 Mdot
.84468 .58931 Mdot
.84473 .08529 Mdot
.84478 .35775 Mdot
.84482 .59506 Mdot
.84487 .16484 Mdot
.84492 .48789 Mdot
.84497 .0652 Mdot
.84501 .12464 Mdot
.84506 .18733 Mdot
.84511 .4727 Mdot
.84516 .41745 Mdot
.8452 .13039 Mdot
.84525 .59255 Mdot
.8453 .50304 Mdot
.84535 .3363 Mdot
.84539 .49741 Mdot
.84544 .42962 Mdot
.84549 .58757 Mdot
.84554 .4921 Mdot
.84558 .47773 Mdot
.84563 .42403 Mdot
.84568 .30912 Mdot
.84573 .26812 Mdot
.84577 .12929 Mdot
.84582 .43804 Mdot
.84587 .23854 Mdot
.84592 .5137 Mdot
.84597 .13755 Mdot
.84601 .28791 Mdot
.84606 .35398 Mdot
.84611 .4632 Mdot
.84616 .02763 Mdot
.8462 .11529 Mdot
.84625 .48461 Mdot
.8463 .06046 Mdot
.84635 .50056 Mdot
.84639 .12606 Mdot
.84644 .58489 Mdot
.84649 .32749 Mdot
.84654 .01786 Mdot
.84658 .29977 Mdot
.84663 .60064 Mdot
.84668 .43872 Mdot
.84673 .14346 Mdot
.84677 .47907 Mdot
.84682 .30623 Mdot
.84687 .18531 Mdot
.84692 .02888 Mdot
.84697 .05574 Mdot
.84701 .0824 Mdot
.84706 .27494 Mdot
.84711 .49465 Mdot
.84716 .37115 Mdot
.8472 .33174 Mdot
.84725 .41506 Mdot
.8473 .48174 Mdot
.84735 .27056 Mdot
.84739 .45046 Mdot
.84744 .3693 Mdot
.84749 .5845 Mdot
.84754 .15921 Mdot
.84758 .4689 Mdot
.84763 .05652 Mdot
.84768 .58135 Mdot
.84773 .46276 Mdot
.84777 .47158 Mdot
.84782 .22112 Mdot
.84787 .45259 Mdot
.84792 .58702 Mdot
.84797 .18006 Mdot
.84801 .05053 Mdot
.84806 .43842 Mdot
.84811 .546 Mdot
.84816 .11237 Mdot
.8482 .37891 Mdot
.84825 .54709 Mdot
.8483 .18955 Mdot
.84835 .38395 Mdot
.84839 .56718 Mdot
.84844 .08007 Mdot
.84849 .52231 Mdot
.84854 .53682 Mdot
.84858 .21259 Mdot
.84863 .09889 Mdot
.84868 .37781 Mdot
.84873 .08263 Mdot
.84877 .17077 Mdot
.84882 .12087 Mdot
.84887 .51837 Mdot
.84892 .21438 Mdot
.84897 .55297 Mdot
.84901 .2716 Mdot
.84906 .53468 Mdot
.84911 .04903 Mdot
.84916 .51716 Mdot
.8492 .43651 Mdot
.84925 .59201 Mdot
.8493 .53999 Mdot
.84935 .15295 Mdot
.84939 .49274 Mdot
.84944 .41716 Mdot
.84949 .17074 Mdot
.84954 .1891 Mdot
.84958 .42738 Mdot
.84963 .49817 Mdot
.84968 .23725 Mdot
.84973 .57983 Mdot
.84977 .3432 Mdot
.84982 .13507 Mdot
.84987 .16933 Mdot
.84992 .42377 Mdot
.84997 .23704 Mdot
.85001 .22002 Mdot
.85006 .55827 Mdot
.85011 .47412 Mdot
.85016 .56876 Mdot
.8502 .28867 Mdot
.85025 .52395 Mdot
.8503 .56029 Mdot
.85035 .14696 Mdot
.85039 .29998 Mdot
.85044 .58729 Mdot
.85049 .42204 Mdot
.85054 .25755 Mdot
.85058 .48615 Mdot
.85063 .43126 Mdot
.85068 .24766 Mdot
.85073 .43349 Mdot
.85077 .5913 Mdot
.85082 .20872 Mdot
.85087 .27115 Mdot
.85092 .105 Mdot
.85096 .47094 Mdot
.85101 .0541 Mdot
.85106 .4507 Mdot
.85111 .47128 Mdot
.85116 .26563 Mdot
.8512 .09915 Mdot
.85125 .57991 Mdot
.8513 .50585 Mdot
.85135 .58029 Mdot
.85139 .17853 Mdot
.85144 .03433 Mdot
.85149 .37359 Mdot
.85154 .29501 Mdot
.85158 .19456 Mdot
.85163 .21561 Mdot
.85168 .13075 Mdot
.85173 .41219 Mdot
.85177 .36663 Mdot
.85182 .57128 Mdot
.85187 .30059 Mdot
.85192 .42422 Mdot
.85196 .17262 Mdot
.85201 .31484 Mdot
.85206 .2103 Mdot
.85211 .5566 Mdot
.85216 .13322 Mdot
.8522 .46746 Mdot
.85225 .34235 Mdot
.8523 .30568 Mdot
.85235 .04878 Mdot
.85239 .49088 Mdot
.85244 .43983 Mdot
.85249 .32871 Mdot
.85254 .47357 Mdot
.85258 .47125 Mdot
.85263 .08094 Mdot
.85268 .04841 Mdot
.85273 .29372 Mdot
.85277 .27035 Mdot
.85282 .55351 Mdot
.85287 .23954 Mdot
.85292 .53042 Mdot
.85296 .30239 Mdot
.85301 .26763 Mdot
.85306 .41865 Mdot
.85311 .37251 Mdot
.85316 .59087 Mdot
.8532 .07203 Mdot
.85325 .46538 Mdot
.8533 .25399 Mdot
.85335 .13812 Mdot
.85339 .33301 Mdot
.85344 .17441 Mdot
.85349 .21992 Mdot
.85354 .25057 Mdot
.85358 .49651 Mdot
.85363 .44902 Mdot
.85368 .34967 Mdot
.85373 .38264 Mdot
.85377 .43028 Mdot
.85382 .41532 Mdot
.85387 .07066 Mdot
.85392 .127 Mdot
.85396 .48009 Mdot
.85401 .19048 Mdot
.85406 .14357 Mdot
.85411 .42793 Mdot
.85416 .22717 Mdot
.8542 .37515 Mdot
.85425 .37439 Mdot
.8543 .44038 Mdot
.85435 .16984 Mdot
.85439 .5131 Mdot
.85444 .1351 Mdot
.85449 .31697 Mdot
.85454 .44015 Mdot
.85458 .3534 Mdot
.85463 .51851 Mdot
.85468 .08112 Mdot
.85473 .54697 Mdot
.85477 .50771 Mdot
.85482 .18354 Mdot
.85487 .3018 Mdot
.85492 .1314 Mdot
.85496 .1071 Mdot
.85501 .12759 Mdot
.85506 .18951 Mdot
.85511 .25464 Mdot
.85515 .51995 Mdot
.8552 .58734 Mdot
.85525 .3649 Mdot
.8553 .04218 Mdot
.85535 .1595 Mdot
.85539 .22766 Mdot
.85544 .52784 Mdot
.85549 .47567 Mdot
.85554 .24973 Mdot
.85558 .10727 Mdot
.85563 .22558 Mdot
.85568 .05022 Mdot
.85573 .49965 Mdot
.85577 .19209 Mdot
.85582 .15917 Mdot
.85587 .10658 Mdot
.85592 .59527 Mdot
.85596 .02326 Mdot
.85601 .46069 Mdot
.85606 .57851 Mdot
.85611 .50287 Mdot
.85615 .49899 Mdot
.8562 .28589 Mdot
.85625 .33858 Mdot
.8563 .58625 Mdot
.85635 .51498 Mdot
.85639 .52432 Mdot
.85644 .31111 Mdot
.85649 .44146 Mdot
.85654 .30202 Mdot
.85658 .5998 Mdot
.85663 .43876 Mdot
.85668 .20644 Mdot
.85673 .20946 Mdot
.85677 .38893 Mdot
.85682 .40325 Mdot
.85687 .31012 Mdot
.85692 .03208 Mdot
.85696 .24447 Mdot
.85701 .31138 Mdot
.85706 .31818 Mdot
.85711 .02353 Mdot
.85715 .3871 Mdot
.8572 .3362 Mdot
.85725 .41863 Mdot
.8573 .12786 Mdot
.85735 .11591 Mdot
.85739 .60095 Mdot
.85744 .4357 Mdot
.85749 .21621 Mdot
.85754 .19492 Mdot
.85758 .30455 Mdot
.85763 .59757 Mdot
.85768 .51752 Mdot
.85773 .19845 Mdot
.85777 .46911 Mdot
.85782 .40583 Mdot
.85787 .32277 Mdot
.85792 .41285 Mdot
.85796 .08057 Mdot
.85801 .11042 Mdot
.85806 .3054 Mdot
.85811 .18309 Mdot
.85815 .37252 Mdot
.8582 .39556 Mdot
.85825 .29657 Mdot
.8583 .39931 Mdot
.85835 .05103 Mdot
.85839 .58026 Mdot
.85844 .18342 Mdot
.85849 .29811 Mdot
.85854 .0534 Mdot
.85858 .15926 Mdot
.85863 .57053 Mdot
.85868 .11789 Mdot
.85873 .35218 Mdot
.85877 .16502 Mdot
.85882 .06772 Mdot
.85887 .52277 Mdot
.85892 .48639 Mdot
.85896 .36252 Mdot
.85901 .34828 Mdot
.85906 .12463 Mdot
.85911 .42053 Mdot
.85915 .26681 Mdot
.8592 .05759 Mdot
.85925 .54487 Mdot
.8593 .06273 Mdot
.85935 .47457 Mdot
.85939 .36434 Mdot
.85944 .16027 Mdot
.85949 .02641 Mdot
.85954 .49764 Mdot
.85958 .19564 Mdot
.85963 .46548 Mdot
.85968 .57633 Mdot
.85973 .35308 Mdot
.85977 .22843 Mdot
.85982 .3623 Mdot
.85987 .23886 Mdot
.85992 .20277 Mdot
.85996 .17542 Mdot
.86001 .44286 Mdot
.86006 .35579 Mdot
.86011 .44357 Mdot
.86015 .43047 Mdot
.8602 .33293 Mdot
.86025 .53858 Mdot
.8603 .19147 Mdot
.86034 .38758 Mdot
.86039 .39139 Mdot
.86044 .49056 Mdot
.86049 .32022 Mdot
.86054 .03795 Mdot
.86058 .24583 Mdot
.86063 .47886 Mdot
.86068 .42591 Mdot
.86073 .44564 Mdot
.86077 .38367 Mdot
.86082 .50586 Mdot
.86087 .08754 Mdot
.86092 .23191 Mdot
.86096 .03608 Mdot
.86101 .28171 Mdot
.86106 .4881 Mdot
.86111 .0712 Mdot
.86115 .19654 Mdot
.8612 .52925 Mdot
.86125 .05924 Mdot
.8613 .24406 Mdot
.86134 .46694 Mdot
.86139 .59399 Mdot
.86144 .47109 Mdot
.86149 .45981 Mdot
.86154 .09026 Mdot
.86158 .11814 Mdot
.86163 .16558 Mdot
.86168 .43657 Mdot
.86173 .44776 Mdot
.86177 .2426 Mdot
.86182 .34299 Mdot
.86187 .59426 Mdot
.86192 .0788 Mdot
.86196 .34006 Mdot
.86201 .27016 Mdot
.86206 .37705 Mdot
.86211 .05743 Mdot
.86215 .07306 Mdot
.8622 .38539 Mdot
.86225 .32056 Mdot
.8623 .46421 Mdot
.86234 .14713 Mdot
.86239 .34086 Mdot
.86244 .0912 Mdot
.86249 .6006 Mdot
.86254 .15646 Mdot
.86258 .47309 Mdot
.86263 .23472 Mdot
.86268 .52505 Mdot
.86273 .05303 Mdot
.86277 .32223 Mdot
.86282 .40148 Mdot
.86287 .092 Mdot
.86292 .41376 Mdot
.86296 .58256 Mdot
.86301 .41054 Mdot
.86306 .02791 Mdot
.86311 .08841 Mdot
.86315 .32711 Mdot
.8632 .0482 Mdot
.86325 .5738 Mdot
.8633 .03006 Mdot
.86334 .54505 Mdot
.86339 .33097 Mdot
.86344 .12429 Mdot
.86349 .48625 Mdot
.86354 .2189 Mdot
.86358 .25448 Mdot
.86363 .12701 Mdot
.86368 .34449 Mdot
.86373 .34913 Mdot
.86377 .03446 Mdot
.86382 .20529 Mdot
.86387 .30617 Mdot
.86392 .04161 Mdot
.86396 .23631 Mdot
.86401 .128 Mdot
.86406 .49573 Mdot
.86411 .06237 Mdot
.86415 .42909 Mdot
.8642 .1148 Mdot
.86425 .42203 Mdot
.8643 .33858 Mdot
.86434 .3956 Mdot
.86439 .14433 Mdot
.86444 .40669 Mdot
.86449 .39686 Mdot
.86453 .07934 Mdot
.86458 .03475 Mdot
.86463 .52376 Mdot
.86468 .19267 Mdot
.86473 .42819 Mdot
.86477 .51106 Mdot
.86482 .19398 Mdot
.86487 .44687 Mdot
.86492 .40843 Mdot
.86496 .32048 Mdot
.86501 .49114 Mdot
.86506 .41997 Mdot
.86511 .18683 Mdot
.86515 .20719 Mdot
.8652 .59873 Mdot
.86525 .37231 Mdot
.8653 .36106 Mdot
.86534 .10709 Mdot
.86539 .1914 Mdot
.86544 .04843 Mdot
.86549 .56879 Mdot
.86553 .56609 Mdot
.86558 .38804 Mdot
.86563 .2549 Mdot
.86568 .50415 Mdot
.86573 .54605 Mdot
.86577 .46761 Mdot
.86582 .07693 Mdot
.86587 .09067 Mdot
.86592 .0497 Mdot
.86596 .28834 Mdot
.86601 .23339 Mdot
.86606 .28556 Mdot
.86611 .33254 Mdot
.86615 .40053 Mdot
.8662 .41674 Mdot
.86625 .11344 Mdot
.8663 .14007 Mdot
.86634 .40512 Mdot
.86639 .05914 Mdot
.86644 .35571 Mdot
.86649 .04768 Mdot
.86653 .22843 Mdot
.86658 .02542 Mdot
.86663 .39024 Mdot
.86668 .08491 Mdot
.86673 .44371 Mdot
.86677 .37385 Mdot
.86682 .48942 Mdot
.86687 .14219 Mdot
.86692 .57943 Mdot
.86696 .31162 Mdot
.86701 .41345 Mdot
.86706 .1072 Mdot
.86711 .3058 Mdot
.86715 .09294 Mdot
.8672 .1426 Mdot
.86725 .37798 Mdot
.8673 .5086 Mdot
.86734 .27953 Mdot
.86739 .04386 Mdot
.86744 .25262 Mdot
.86749 .11819 Mdot
.86753 .23509 Mdot
.86758 .29148 Mdot
.86763 .21965 Mdot
.86768 .49308 Mdot
.86773 .22438 Mdot
.86777 .50457 Mdot
.86782 .14945 Mdot
.86787 .06408 Mdot
.86792 .45386 Mdot
.86796 .02986 Mdot
.86801 .02197 Mdot
.86806 .08798 Mdot
.86811 .15695 Mdot
.86815 .21973 Mdot
.8682 .51809 Mdot
.86825 .3855 Mdot
.8683 .07871 Mdot
.86834 .09184 Mdot
.86839 .15482 Mdot
.86844 .48023 Mdot
.86849 .40251 Mdot
.86853 .06269 Mdot
.86858 .50552 Mdot
.86863 .37675 Mdot
.86868 .18213 Mdot
.86873 .37453 Mdot
.86877 .30057 Mdot
.86882 .48699 Mdot
.86887 .56107 Mdot
.86892 .47329 Mdot
.86896 .16583 Mdot
.86901 .43762 Mdot
.86906 .12192 Mdot
.86911 .45814 Mdot
.86915 .15858 Mdot
.8692 .36435 Mdot
.86925 .5683 Mdot
.8693 .25312 Mdot
.86934 .24381 Mdot
.86939 .58217 Mdot
.86944 .50429 Mdot
.86949 .17598 Mdot
.86953 .1037 Mdot
.86958 .11665 Mdot
.86963 .11649 Mdot
.86968 .128 Mdot
.86972 .20151 Mdot
.86977 .34323 Mdot
.86982 .53769 Mdot
.86987 .3568 Mdot
.86992 .50426 Mdot
.86996 .45957 Mdot
.87001 .57994 Mdot
.87006 .48683 Mdot
.87011 .35313 Mdot
.87015 .03666 Mdot
.8702 .47273 Mdot
.87025 .0434 Mdot
.8703 .20927 Mdot
.87034 .27564 Mdot
.87039 .50775 Mdot
.87044 .39361 Mdot
.87049 .56878 Mdot
.87053 .29679 Mdot
.87058 .01817 Mdot
.87063 .23234 Mdot
.87068 .47979 Mdot
.87072 .19485 Mdot
.87077 .505 Mdot
.87082 .11904 Mdot
.87087 .29299 Mdot
.87092 .45494 Mdot
.87096 .57064 Mdot
.87101 .36557 Mdot
.87106 .39206 Mdot
.87111 .5987 Mdot
.87115 .59403 Mdot
.8712 .48206 Mdot
.87125 .05363 Mdot
.8713 .57675 Mdot
.87134 .13601 Mdot
.87139 .45337 Mdot
.87144 .44769 Mdot
.87149 .31582 Mdot
.87153 .23158 Mdot
.87158 .07446 Mdot
.87163 .48224 Mdot
.87168 .03374 Mdot
.87172 .22813 Mdot
.87177 .44545 Mdot
.87182 .01716 Mdot
.87187 .44222 Mdot
.87192 .32645 Mdot
.87196 .34111 Mdot
.87201 .32749 Mdot
.87206 .5906 Mdot
.87211 .35914 Mdot
.87215 .57887 Mdot
.8722 .53876 Mdot
.87225 .59522 Mdot
.8723 .36844 Mdot
.87234 .11151 Mdot
.87239 .49983 Mdot
.87244 .03318 Mdot
.87249 .24714 Mdot
.87253 .26147 Mdot
.87258 .06685 Mdot
.87263 .32068 Mdot
.87268 .03026 Mdot
.87272 .20172 Mdot
.87277 .18794 Mdot
.87282 .30165 Mdot
.87287 .40546 Mdot
.87292 .35959 Mdot
.87296 .18549 Mdot
.87301 .46276 Mdot
.87306 .09372 Mdot
.87311 .03319 Mdot
.87315 .46132 Mdot
.8732 .47549 Mdot
.87325 .33791 Mdot
.8733 .05765 Mdot
.87334 .52589 Mdot
.87339 .48359 Mdot
.87344 .57279 Mdot
.87349 .54946 Mdot
.87353 .04077 Mdot
.87358 .46512 Mdot
.87363 .34037 Mdot
.87368 .30269 Mdot
.87372 .57724 Mdot
.87377 .15915 Mdot
.87382 .32482 Mdot
.87387 .11568 Mdot
.87391 .40401 Mdot
.87396 .46082 Mdot
.87401 .52268 Mdot
.87406 .35942 Mdot
.87411 .23323 Mdot
.87415 .60138 Mdot
.8742 .44367 Mdot
.87425 .34094 Mdot
.8743 .37523 Mdot
.87434 .1406 Mdot
.87439 .12048 Mdot
.87444 .298 Mdot
.87449 .45267 Mdot
.87453 .26033 Mdot
.87458 .15101 Mdot
.87463 .35187 Mdot
.87468 .42661 Mdot
.87472 .39853 Mdot
.87477 .41396 Mdot
.87482 .06389 Mdot
.87487 .4527 Mdot
.87491 .2541 Mdot
.87496 .10386 Mdot
.87501 .55153 Mdot
.87506 .06339 Mdot
.87511 .39661 Mdot
.87515 .1845 Mdot
.8752 .20682 Mdot
.87525 .43348 Mdot
.8753 .39855 Mdot
.87534 .34415 Mdot
.87539 .46921 Mdot
.87544 .07296 Mdot
.87549 .27266 Mdot
.87553 .23839 Mdot
.87558 .18591 Mdot
.87563 .22362 Mdot
.87568 .02704 Mdot
.87572 .10209 Mdot
.87577 .43737 Mdot
.87582 .40033 Mdot
.87587 .23184 Mdot
.87591 .29145 Mdot
.87596 .38819 Mdot
.87601 .55096 Mdot
.87606 .58107 Mdot
.87611 .2023 Mdot
.87615 .43999 Mdot
.8762 .50228 Mdot
.87625 .19917 Mdot
.8763 .03251 Mdot
.87634 .24788 Mdot
.87639 .0835 Mdot
.87644 .40394 Mdot
.87649 .29168 Mdot
.87653 .382 Mdot
.87658 .02525 Mdot
.87663 .14599 Mdot
.87668 .068 Mdot
.87672 .21079 Mdot
.87677 .40496 Mdot
.87682 .13365 Mdot
.87687 .56924 Mdot
.87691 .37675 Mdot
.87696 .01934 Mdot
.87701 .50514 Mdot
.87706 .2925 Mdot
.87711 .59188 Mdot
.87715 .07171 Mdot
.8772 .5274 Mdot
.87725 .1049 Mdot
.8773 .1666 Mdot
.87734 .17275 Mdot
.87739 .34294 Mdot
.87744 .0871 Mdot
.87749 .52204 Mdot
.87753 .10396 Mdot
.87758 .54232 Mdot
.87763 .39874 Mdot
.87768 .15475 Mdot
.87772 .09342 Mdot
.87777 .41104 Mdot
.87782 .34545 Mdot
.87787 .54728 Mdot
.87791 .29178 Mdot
.87796 .2921 Mdot
.87801 .37954 Mdot
.87806 .18524 Mdot
.87811 .28715 Mdot
.87815 .39029 Mdot
.8782 .10175 Mdot
.87825 .19668 Mdot
.8783 .23015 Mdot
.87834 .46622 Mdot
.87839 .60017 Mdot
.87844 .04479 Mdot
.87849 .07211 Mdot
.87853 .13799 Mdot
.87858 .52778 Mdot
.87863 .12608 Mdot
.87868 .57147 Mdot
.87872 .19899 Mdot
.87877 .14374 Mdot
.87882 .57466 Mdot
.87887 .49276 Mdot
.87891 .39128 Mdot
.87896 .40162 Mdot
.87901 .04209 Mdot
.87906 .21569 Mdot
.8791 .11388 Mdot
.87915 .03679 Mdot
.8792 .46018 Mdot
.87925 .53187 Mdot
.8793 .32692 Mdot
.87934 .53837 Mdot
.87939 .2782 Mdot
.87944 .31642 Mdot
.87949 .46403 Mdot
.87953 .54152 Mdot
.87958 .24812 Mdot
.87963 .25902 Mdot
.87968 .34075 Mdot
.87972 .02845 Mdot
.87977 .13675 Mdot
.87982 .29087 Mdot
.87987 .15647 Mdot
.87991 .48803 Mdot
.87996 .16542 Mdot
.88001 .40144 Mdot
.88006 .36852 Mdot
.8801 .10112 Mdot
.88015 .13804 Mdot
.8802 .20045 Mdot
.88025 .26934 Mdot
.8803 .07904 Mdot
.88034 .28118 Mdot
.88039 .27191 Mdot
.88044 .54575 Mdot
.88049 .14399 Mdot
.88053 .01769 Mdot
.88058 .55882 Mdot
.88063 .09642 Mdot
.88068 .20579 Mdot
.88072 .37289 Mdot
.88077 .31451 Mdot
.88082 .35899 Mdot
.88087 .19205 Mdot
.88091 .25085 Mdot
.88096 .03834 Mdot
.88101 .21723 Mdot
.88106 .30734 Mdot
.8811 .10015 Mdot
.88115 .24023 Mdot
.8812 .45204 Mdot
.88125 .22093 Mdot
.8813 .56544 Mdot
.88134 .05448 Mdot
.88139 .19741 Mdot
.88144 .1566 Mdot
.88149 .29896 Mdot
.88153 .3859 Mdot
.88158 .25499 Mdot
.88163 .02732 Mdot
.88168 .29598 Mdot
.88172 .4304 Mdot
.88177 .17327 Mdot
.88182 .42485 Mdot
.88187 .52641 Mdot
.88191 .13061 Mdot
.88196 .4176 Mdot
.88201 .2475 Mdot
.88206 .29027 Mdot
.8821 .10697 Mdot
.88215 .21508 Mdot
.8822 .54349 Mdot
.88225 .20483 Mdot
.8823 .47007 Mdot
.88234 .36636 Mdot
.88239 .33727 Mdot
.88244 .24272 Mdot
.88249 .43029 Mdot
.88253 .18366 Mdot
.88258 .19537 Mdot
.88263 .54708 Mdot
.88268 .0591 Mdot
.88272 .532 Mdot
.88277 .18277 Mdot
.88282 .26581 Mdot
.88287 .23203 Mdot
.88291 .37344 Mdot
.88296 .36125 Mdot
.88301 .34272 Mdot
.88306 .11613 Mdot
.8831 .55916 Mdot
.88315 .12845 Mdot
.8832 .06717 Mdot
.88325 .02387 Mdot
.8833 .3588 Mdot
.88334 .18829 Mdot
.88339 .46566 Mdot
.88344 .15712 Mdot
.88349 .59576 Mdot
.88353 .45435 Mdot
.88358 .23766 Mdot
.88363 .33016 Mdot
.88368 .42681 Mdot
.88372 .27368 Mdot
.88377 .2939 Mdot
.88382 .28576 Mdot
.88387 .49813 Mdot
.88391 .10562 Mdot
.88396 .0428 Mdot
.88401 .06844 Mdot
.88406 .1394 Mdot
.8841 .3477 Mdot
.88415 .3034 Mdot
.8842 .55564 Mdot
.88425 .18356 Mdot
.88429 .23396 Mdot
.88434 .25094 Mdot
.88439 .54648 Mdot
.88444 .42809 Mdot
.88449 .06037 Mdot
.88453 .3886 Mdot
.88458 .40406 Mdot
.88463 .43565 Mdot
.88468 .20935 Mdot
.88472 .16565 Mdot
.88477 .08862 Mdot
.88482 .02356 Mdot
.88487 .53899 Mdot
.88491 .47508 Mdot
.88496 .40618 Mdot
.88501 .12875 Mdot
.88506 .44807 Mdot
.8851 .44699 Mdot
.88515 .35245 Mdot
.8852 .59268 Mdot
.88525 .11508 Mdot
.88529 .1583 Mdot
.88534 .40014 Mdot
.88539 .42383 Mdot
.88544 .48445 Mdot
.88549 .51068 Mdot
.88553 .45699 Mdot
.88558 .59907 Mdot
.88563 .43878 Mdot
.88568 .13679 Mdot
.88572 .06763 Mdot
.88577 .17813 Mdot
.88582 .24414 Mdot
.88587 .57446 Mdot
.88591 .58234 Mdot
.88596 .16928 Mdot
.88601 .30848 Mdot
.88606 .11409 Mdot
.8861 .19086 Mdot
.88615 .05523 Mdot
.8862 .46373 Mdot
.88625 .27043 Mdot
.88629 .44174 Mdot
.88634 .06587 Mdot
.88639 .36336 Mdot
.88644 .12683 Mdot
.88649 .05631 Mdot
.88653 .24536 Mdot
.88658 .48223 Mdot
.88663 .21947 Mdot
.88668 .20265 Mdot
.88672 .24962 Mdot
.88677 .05816 Mdot
.88682 .09739 Mdot
.88687 .14973 Mdot
.88691 .0862 Mdot
.88696 .41735 Mdot
.88701 .12625 Mdot
.88706 .17072 Mdot
.8871 .52025 Mdot
.88715 .12358 Mdot
.8872 .02687 Mdot
.88725 .58318 Mdot
.88729 .47972 Mdot
.88734 .26318 Mdot
.88739 .35977 Mdot
.88744 .15615 Mdot
.88749 .42856 Mdot
.88753 .50315 Mdot
.88758 .24765 Mdot
.88763 .11454 Mdot
.88768 .1979 Mdot
.88772 .03562 Mdot
.88777 .04288 Mdot
.88782 .51522 Mdot
.88787 .55161 Mdot
.88791 .58078 Mdot
.88796 .54881 Mdot
.88801 .3802 Mdot
.88806 .48012 Mdot
.8881 .17815 Mdot
.88815 .43727 Mdot
.8882 .22419 Mdot
.88825 .5632 Mdot
.88829 .06927 Mdot
.88834 .42511 Mdot
.88839 .24434 Mdot
.88844 .09819 Mdot
.88848 .40942 Mdot
.88853 .08004 Mdot
.88858 .1029 Mdot
.88863 .27295 Mdot
.88868 .5096 Mdot
.88872 .43572 Mdot
.88877 .59168 Mdot
.88882 .08976 Mdot
.88887 .48869 Mdot
.88891 .40755 Mdot
.88896 .09117 Mdot
.88901 .14147 Mdot
.88906 .51123 Mdot
.8891 .46206 Mdot
.88915 .3143 Mdot
.8892 .26468 Mdot
.88925 .3478 Mdot
.88929 .0395 Mdot
.88934 .10482 Mdot
.88939 .3048 Mdot
.88944 .29323 Mdot
.88948 .21772 Mdot
.88953 .46381 Mdot
.88958 .22132 Mdot
.88963 .48713 Mdot
.88968 .15239 Mdot
.88972 .37562 Mdot
.88977 .55169 Mdot
.88982 .58085 Mdot
.88987 .31999 Mdot
.88991 .38727 Mdot
.88996 .47664 Mdot
.89001 .10687 Mdot
.89006 .51576 Mdot
.8901 .31081 Mdot
.89015 .34988 Mdot
.8902 .19896 Mdot
.89025 .06841 Mdot
.89029 .59983 Mdot
.89034 .09991 Mdot
.89039 .45449 Mdot
.89044 .04361 Mdot
.89048 .50973 Mdot
.89053 .39843 Mdot
.89058 .17597 Mdot
.89063 .42922 Mdot
.89068 .06063 Mdot
.89072 .19182 Mdot
.89077 .29217 Mdot
.89082 .29154 Mdot
.89087 .28833 Mdot
.89091 .24345 Mdot
.89096 .31464 Mdot
.89101 .57487 Mdot
.89106 .50439 Mdot
.8911 .37013 Mdot
.89115 .22247 Mdot
.8912 .07382 Mdot
.89125 .2083 Mdot
.89129 .03496 Mdot
.89134 .03822 Mdot
.89139 .02012 Mdot
.89144 .21179 Mdot
.89148 .53838 Mdot
.89153 .18705 Mdot
.89158 .57984 Mdot
.89163 .30539 Mdot
.89168 .15465 Mdot
.89172 .02579 Mdot
.89177 .16533 Mdot
.89182 .25947 Mdot
.89187 .56616 Mdot
.89191 .33695 Mdot
.89196 .47712 Mdot
.89201 .57446 Mdot
.89206 .33742 Mdot
.8921 .03702 Mdot
.89215 .50557 Mdot
.8922 .08478 Mdot
.89225 .57062 Mdot
.89229 .41787 Mdot
.89234 .44645 Mdot
.89239 .47981 Mdot
.89244 .55037 Mdot
.89248 .39436 Mdot
.89253 .44104 Mdot
.89258 .28273 Mdot
.89263 .0267 Mdot
.89268 .22202 Mdot
.89272 .46453 Mdot
.89277 .58067 Mdot
.89282 .47537 Mdot
.89287 .21094 Mdot
.89291 .31391 Mdot
.89296 .33591 Mdot
.89301 .51253 Mdot
.89306 .47732 Mdot
.8931 .44012 Mdot
.89315 .36477 Mdot
.8932 .18982 Mdot
.89325 .45501 Mdot
.89329 .53788 Mdot
.89334 .2947 Mdot
.89339 .22253 Mdot
.89344 .05185 Mdot
.89348 .10613 Mdot
.89353 .41822 Mdot
.89358 .27549 Mdot
.89363 .26081 Mdot
.89367 .26842 Mdot
.89372 .1502 Mdot
.89377 .2635 Mdot
.89382 .0535 Mdot
.89387 .40722 Mdot
.89391 .17286 Mdot
.89396 .39146 Mdot
.89401 .44588 Mdot
.89406 .10802 Mdot
.8941 .44028 Mdot
.89415 .48225 Mdot
.8942 .57189 Mdot
.89425 .27122 Mdot
.89429 .09021 Mdot
.89434 .30714 Mdot
.89439 .13159 Mdot
.89444 .33667 Mdot
.89448 .39884 Mdot
.89453 .09931 Mdot
.89458 .09445 Mdot
.89463 .24525 Mdot
.89467 .58394 Mdot
.89472 .42715 Mdot
.89477 .43697 Mdot
.89482 .58015 Mdot
.89487 .44845 Mdot
.89491 .17836 Mdot
.89496 .39818 Mdot
.89501 .18764 Mdot
.89506 .2903 Mdot
.8951 .39022 Mdot
.89515 .55562 Mdot
.8952 .09434 Mdot
.89525 .45335 Mdot
.89529 .5113 Mdot
.89534 .58706 Mdot
.89539 .42644 Mdot
.89544 .37784 Mdot
.89548 .21887 Mdot
.89553 .47018 Mdot
.89558 .10448 Mdot
.89563 .58233 Mdot
.89567 .13427 Mdot
.89572 .39043 Mdot
.89577 .46256 Mdot
.89582 .60172 Mdot
.89587 .31045 Mdot
.89591 .55679 Mdot
.89596 .48573 Mdot
.89601 .16798 Mdot
.89606 .1468 Mdot
.8961 .17333 Mdot
.89615 .3128 Mdot
.8962 .481 Mdot
.89625 .3599 Mdot
.89629 .22103 Mdot
.89634 .23317 Mdot
.89639 .04236 Mdot
.89644 .45193 Mdot
.89648 .2373 Mdot
.89653 .41005 Mdot
.89658 .26785 Mdot
.89663 .24776 Mdot
.89667 .37045 Mdot
.89672 .32028 Mdot
.89677 .28884 Mdot
.89682 .1282 Mdot
.89687 .58334 Mdot
.89691 .46105 Mdot
.89696 .29045 Mdot
.89701 .42108 Mdot
.89706 .04125 Mdot
.8971 .57864 Mdot
.89715 .13718 Mdot
.8972 .28899 Mdot
.89725 .47125 Mdot
.89729 .28055 Mdot
.89734 .25951 Mdot
.89739 .53242 Mdot
.89744 .26493 Mdot
.89748 .06209 Mdot
.89753 .23185 Mdot
.89758 .0952 Mdot
.89763 .04234 Mdot
.89767 .25537 Mdot
.89772 .56733 Mdot
.89777 .45076 Mdot
.89782 .27522 Mdot
.89786 .53841 Mdot
.89791 .2932 Mdot
.89796 .33727 Mdot
.89801 .2952 Mdot
.89806 .09208 Mdot
.8981 .01745 Mdot
.89815 .51952 Mdot
.8982 .26866 Mdot
.89825 .11676 Mdot
.89829 .4836 Mdot
.89834 .24524 Mdot
.89839 .40073 Mdot
.89844 .43954 Mdot
.89848 .2388 Mdot
.89853 .31614 Mdot
.89858 .1505 Mdot
.89863 .39215 Mdot
.89867 .02165 Mdot
.89872 .23565 Mdot
.89877 .12287 Mdot
.89882 .1515 Mdot
.89886 .05765 Mdot
.89891 .38822 Mdot
.89896 .45098 Mdot
.89901 .21641 Mdot
.89906 .36778 Mdot
.8991 .06565 Mdot
.89915 .17049 Mdot
.8992 .13904 Mdot
.89925 .36503 Mdot
.89929 .14946 Mdot
.89934 .50516 Mdot
.89939 .03699 Mdot
.89944 .48476 Mdot
.89948 .50755 Mdot
.89953 .11914 Mdot
.89958 .20078 Mdot
.89963 .26067 Mdot
.89967 .20612 Mdot
.89972 .57196 Mdot
.89977 .41195 Mdot
.89982 .25373 Mdot
.89986 .57379 Mdot
.89991 .4638 Mdot
.89996 .27516 Mdot
.90001 .21078 Mdot
.90006 .20028 Mdot
.9001 .02753 Mdot
.90015 .07346 Mdot
.9002 .44633 Mdot
.90025 .14933 Mdot
.90029 .46036 Mdot
.90034 .53774 Mdot
.90039 .09601 Mdot
.90044 .6032 Mdot
.90048 .55853 Mdot
.90053 .51546 Mdot
.90058 .21457 Mdot
.90063 .11035 Mdot
.90067 .4541 Mdot
.90072 .32939 Mdot
.90077 .55723 Mdot
.90082 .50756 Mdot
.90086 .48546 Mdot
.90091 .52077 Mdot
.90096 .31821 Mdot
.90101 .5371 Mdot
.90106 .03637 Mdot
.9011 .26032 Mdot
.90115 .12213 Mdot
.9012 .35153 Mdot
.90125 .02355 Mdot
.90129 .20157 Mdot
.90134 .27913 Mdot
.90139 .21691 Mdot
.90144 .16651 Mdot
.90148 .26715 Mdot
.90153 .19783 Mdot
.90158 .21704 Mdot
.90163 .21131 Mdot
.90167 .35502 Mdot
.90172 .58658 Mdot
.90177 .12139 Mdot
.90182 .36053 Mdot
.90186 .04034 Mdot
.90191 .04406 Mdot
.90196 .21715 Mdot
.90201 .47839 Mdot
.90206 .1229 Mdot
.9021 .32918 Mdot
.90215 .28337 Mdot
.9022 .45673 Mdot
.90225 .46591 Mdot
.90229 .22175 Mdot
.90234 .53517 Mdot
.90239 .44789 Mdot
.90244 .27905 Mdot
.90248 .54595 Mdot
.90253 .33296 Mdot
.90258 .29608 Mdot
.90263 .0266 Mdot
.90267 .36283 Mdot
.90272 .13063 Mdot
.90277 .09949 Mdot
.90282 .27491 Mdot
.90286 .37958 Mdot
.90291 .02395 Mdot
.90296 .34228 Mdot
.90301 .24928 Mdot
.90305 .35023 Mdot
.9031 .41012 Mdot
.90315 .46721 Mdot
.9032 .14109 Mdot
.90325 .03576 Mdot
.90329 .14146 Mdot
.90334 .02519 Mdot
.90339 .2785 Mdot
.90344 .41733 Mdot
.90348 .20962 Mdot
.90353 .18063 Mdot
.90358 .60278 Mdot
.90363 .47471 Mdot
.90367 .47998 Mdot
.90372 .48787 Mdot
.90377 .59088 Mdot
.90382 .12659 Mdot
.90386 .36405 Mdot
.90391 .40309 Mdot
.90396 .33068 Mdot
.90401 .35033 Mdot
.90405 .35481 Mdot
.9041 .07552 Mdot
.90415 .09612 Mdot
.9042 .01482 Mdot
.90425 .54801 Mdot
.90429 .21163 Mdot
.90434 .55836 Mdot
.90439 .58238 Mdot
.90444 .42126 Mdot
.90448 .20115 Mdot
.90453 .29456 Mdot
.90458 .17976 Mdot
.90463 .22636 Mdot
.90467 .03524 Mdot
.90472 .2951 Mdot
.90477 .30838 Mdot
.90482 .3497 Mdot
.90486 .15069 Mdot
.90491 .30755 Mdot
.90496 .1965 Mdot
.90501 .58898 Mdot
.90505 .35093 Mdot
.9051 .58019 Mdot
.90515 .44949 Mdot
.9052 .24888 Mdot
.90525 .29012 Mdot
.90529 .49878 Mdot
.90534 .44938 Mdot
.90539 .30419 Mdot
.90544 .09319 Mdot
.90548 .54375 Mdot
.90553 .47032 Mdot
.90558 .48625 Mdot
.90563 .49536 Mdot
.90567 .2639 Mdot
.90572 .30527 Mdot
.90577 .27461 Mdot
.90582 .47483 Mdot
.90586 .57212 Mdot
.90591 .60022 Mdot
.90596 .52823 Mdot
.90601 .33885 Mdot
.90605 .27928 Mdot
.9061 .41843 Mdot
.90615 .54258 Mdot
.9062 .59125 Mdot
.90625 .30242 Mdot
.90629 .57227 Mdot
.90634 .30841 Mdot
.90639 .31584 Mdot
.90644 .40697 Mdot
.90648 .1376 Mdot
.90653 .01893 Mdot
.90658 .23736 Mdot
.90663 .46654 Mdot
.90667 .2706 Mdot
.90672 .136 Mdot
.90677 .34532 Mdot
.90682 .21736 Mdot
.90686 .56866 Mdot
.90691 .46472 Mdot
.90696 .47381 Mdot
.90701 .24856 Mdot
.90705 .57177 Mdot
.9071 .53982 Mdot
.90715 .14967 Mdot
.9072 .57261 Mdot
.90724 .16804 Mdot
.90729 .60057 Mdot
.90734 .16175 Mdot
.90739 .2849 Mdot
.90744 .1991 Mdot
.90748 .30687 Mdot
.90753 .44924 Mdot
.90758 .48125 Mdot
.90763 .07621 Mdot
.90767 .30265 Mdot
.90772 .22659 Mdot
.90777 .02942 Mdot
.90782 .40894 Mdot
.90786 .18136 Mdot
.90791 .48459 Mdot
.90796 .41539 Mdot
.90801 .4436 Mdot
.90805 .31997 Mdot
.9081 .02549 Mdot
.90815 .18153 Mdot
.9082 .47516 Mdot
.90824 .38348 Mdot
.90829 .47914 Mdot
.90834 .21225 Mdot
.90839 .32183 Mdot
.90844 .38623 Mdot
.90848 .3321 Mdot
.90853 .53068 Mdot
.90858 .13743 Mdot
.90863 .09408 Mdot
.90867 .48618 Mdot
.90872 .06414 Mdot
.90877 .07593 Mdot
.90882 .39475 Mdot
.90886 .2743 Mdot
.90891 .04943 Mdot
.90896 .27031 Mdot
.90901 .2281 Mdot
.90905 .39304 Mdot
.9091 .23736 Mdot
.90915 .43004 Mdot
.9092 .51146 Mdot
.90924 .38226 Mdot
.90929 .07054 Mdot
.90934 .5582 Mdot
.90939 .14269 Mdot
.90944 .50645 Mdot
.90948 .46161 Mdot
.90953 .25108 Mdot
.90958 .35978 Mdot
.90963 .18906 Mdot
.90967 .53426 Mdot
.90972 .12836 Mdot
.90977 .28041 Mdot
.90982 .3062 Mdot
.90986 .48483 Mdot
.90991 .06714 Mdot
.90996 .48899 Mdot
.91001 .0466 Mdot
.91005 .45011 Mdot
.9101 .40015 Mdot
.91015 .2756 Mdot
.9102 .25689 Mdot
.91024 .22746 Mdot
.91029 .57344 Mdot
.91034 .36747 Mdot
.91039 .47796 Mdot
.91044 .17163 Mdot
.91048 .02995 Mdot
.91053 .23948 Mdot
.91058 .57484 Mdot
.91063 .31334 Mdot
.91067 .3822 Mdot
.91072 .48303 Mdot
.91077 .40049 Mdot
.91082 .38241 Mdot
.91086 .26855 Mdot
.91091 .21732 Mdot
.91096 .109 Mdot
.91101 .50091 Mdot
.91105 .21612 Mdot
.9111 .33166 Mdot
.91115 .0771 Mdot
.9112 .06551 Mdot
.91124 .41929 Mdot
.91129 .07077 Mdot
.91134 .42354 Mdot
.91139 .44137 Mdot
.91144 .44918 Mdot
.91148 .30663 Mdot
.91153 .5489 Mdot
.91158 .28445 Mdot
.91163 .43394 Mdot
.91167 .08185 Mdot
.91172 .57739 Mdot
.91177 .57443 Mdot
.91182 .06645 Mdot
.91186 .20215 Mdot
.91191 .19161 Mdot
.91196 .20673 Mdot
.91201 .40122 Mdot
.91205 .58815 Mdot
.9121 .09732 Mdot
.91215 .30914 Mdot
.9122 .19981 Mdot
.91224 .2712 Mdot
.91229 .03493 Mdot
.91234 .25835 Mdot
.91239 .38385 Mdot
.91243 .21514 Mdot
.91248 .21472 Mdot
.91253 .4203 Mdot
.91258 .53799 Mdot
.91263 .51184 Mdot
.91267 .26914 Mdot
.91272 .15056 Mdot
.91277 .11876 Mdot
.91282 .44469 Mdot
.91286 .29507 Mdot
.91291 .17945 Mdot
.91296 .06702 Mdot
.91301 .25725 Mdot
.91305 .11817 Mdot
.9131 .57604 Mdot
.91315 .26912 Mdot
.9132 .27242 Mdot
.91324 .03556 Mdot
.91329 .28161 Mdot
.91334 .08402 Mdot
.91339 .01593 Mdot
.91343 .01534 Mdot
.91348 .03797 Mdot
.91353 .3035 Mdot
.91358 .40411 Mdot
.91363 .40394 Mdot
.91367 .221 Mdot
.91372 .36883 Mdot
.91377 .4956 Mdot
.91382 .14951 Mdot
.91386 .08515 Mdot
.91391 .26478 Mdot
.91396 .06561 Mdot
.91401 .45777 Mdot
.91405 .50903 Mdot
.9141 .21246 Mdot
.91415 .41169 Mdot
.9142 .3543 Mdot
.91424 .53631 Mdot
.91429 .54666 Mdot
.91434 .15397 Mdot
.91439 .33346 Mdot
.91443 .26941 Mdot
.91448 .47735 Mdot
.91453 .15275 Mdot
.91458 .33283 Mdot
.91463 .24615 Mdot
.91467 .18856 Mdot
.91472 .35196 Mdot
.91477 .53221 Mdot
.91482 .03986 Mdot
.91486 .42305 Mdot
.91491 .45969 Mdot
.91496 .3974 Mdot
.91501 .55803 Mdot
.91505 .17299 Mdot
.9151 .40878 Mdot
.91515 .54296 Mdot
.9152 .06371 Mdot
.91524 .56385 Mdot
.91529 .60042 Mdot
.91534 .20337 Mdot
.91539 .13072 Mdot
.91543 .0319 Mdot
.91548 .46116 Mdot
.91553 .47324 Mdot
.91558 .46464 Mdot
.91563 .15787 Mdot
.91567 .32312 Mdot
.91572 .15512 Mdot
.91577 .2332 Mdot
.91582 .57264 Mdot
.91586 .57448 Mdot
.91591 .22623 Mdot
.91596 .20805 Mdot
.91601 .16429 Mdot
.91605 .1295 Mdot
.9161 .43215 Mdot
.91615 .25334 Mdot
.9162 .59463 Mdot
.91624 .32405 Mdot
.91629 .49251 Mdot
.91634 .20434 Mdot
.91639 .04549 Mdot
.91643 .32695 Mdot
.91648 .30386 Mdot
.91653 .08833 Mdot
.91658 .0283 Mdot
.91663 .46912 Mdot
.91667 .43394 Mdot
.91672 .22702 Mdot
.91677 .47375 Mdot
.91682 .16071 Mdot
.91686 .29354 Mdot
.91691 .59715 Mdot
.91696 .50444 Mdot
.91701 .18956 Mdot
.91705 .08201 Mdot
.9171 .40381 Mdot
.91715 .35486 Mdot
.9172 .07476 Mdot
.91724 .25318 Mdot
.91729 .16517 Mdot
.91734 .36355 Mdot
.91739 .35404 Mdot
.91743 .36399 Mdot
.91748 .56415 Mdot
.91753 .33277 Mdot
.91758 .04179 Mdot
.91762 .07485 Mdot
.91767 .49053 Mdot
.91772 .31918 Mdot
.91777 .176 Mdot
.91782 .24423 Mdot
.91786 .27822 Mdot
.91791 .44875 Mdot
.91796 .02999 Mdot
.91801 .55402 Mdot
.91805 .2844 Mdot
.9181 .54763 Mdot
.91815 .44376 Mdot
.9182 .48672 Mdot
.91824 .48391 Mdot
.91829 .20748 Mdot
.91834 .38371 Mdot
.91839 .24824 Mdot
.91843 .33345 Mdot
.91848 .44725 Mdot
.91853 .04438 Mdot
.91858 .48757 Mdot
.91862 .37262 Mdot
.91867 .12919 Mdot
.91872 .01729 Mdot
.91877 .42744 Mdot
.91882 .48542 Mdot
.91886 .41333 Mdot
.91891 .44462 Mdot
.91896 .19792 Mdot
.91901 .2219 Mdot
.91905 .56791 Mdot
.9191 .42934 Mdot
.91915 .24722 Mdot
.9192 .54083 Mdot
.91924 .03498 Mdot
.91929 .58891 Mdot
.91934 .36383 Mdot
.91939 .07163 Mdot
.91943 .43082 Mdot
.91948 .21991 Mdot
.91953 .1303 Mdot
.91958 .34151 Mdot
.91962 .58689 Mdot
.91967 .19024 Mdot
.91972 .24605 Mdot
.91977 .57221 Mdot
.91982 .47241 Mdot
.91986 .18765 Mdot
.91991 .42194 Mdot
.91996 .1015 Mdot
.92001 .07379 Mdot
.92005 .34636 Mdot
.9201 .23873 Mdot
.92015 .48292 Mdot
.9202 .10921 Mdot
.92024 .52034 Mdot
.92029 .59484 Mdot
.92034 .54542 Mdot
.92039 .08894 Mdot
.92043 .53476 Mdot
.92048 .24571 Mdot
.92053 .48849 Mdot
.92058 .26144 Mdot
.92062 .32956 Mdot
.92067 .13012 Mdot
.92072 .1617 Mdot
.92077 .27787 Mdot
.92082 .15403 Mdot
.92086 .4874 Mdot
.92091 .19281 Mdot
.92096 .40879 Mdot
.92101 .56971 Mdot
.92105 .08017 Mdot
.9211 .10601 Mdot
.92115 .3497 Mdot
.9212 .23806 Mdot
.92124 .44476 Mdot
.92129 .22642 Mdot
.92134 .2552 Mdot
.92139 .32104 Mdot
.92143 .45325 Mdot
.92148 .28432 Mdot
.92153 .18098 Mdot
.92158 .3896 Mdot
.92162 .22224 Mdot
.92167 .39916 Mdot
.92172 .52286 Mdot
.92177 .07475 Mdot
.92181 .10683 Mdot
.92186 .25217 Mdot
.92191 .2597 Mdot
.92196 .52404 Mdot
.92201 .22276 Mdot
.92205 .07407 Mdot
.9221 .45424 Mdot
.92215 .55766 Mdot
.9222 .1573 Mdot
.92224 .57138 Mdot
.92229 .11924 Mdot
.92234 .33431 Mdot
.92239 .31587 Mdot
.92243 .35967 Mdot
.92248 .46736 Mdot
.92253 .02798 Mdot
.92258 .46594 Mdot
.92262 .09005 Mdot
.92267 .30109 Mdot
.92272 .2417 Mdot
.92277 .25841 Mdot
.92281 .29422 Mdot
.92286 .38156 Mdot
.92291 .18166 Mdot
.92296 .16629 Mdot
.92301 .05676 Mdot
.92305 .13657 Mdot
.9231 .26095 Mdot
.92315 .54686 Mdot
.9232 .58602 Mdot
.92324 .28566 Mdot
.92329 .30662 Mdot
.92334 .40427 Mdot
.92339 .02935 Mdot
.92343 .18113 Mdot
.92348 .57563 Mdot
.92353 .10311 Mdot
.92358 .27301 Mdot
.92362 .3171 Mdot
.92367 .56236 Mdot
.92372 .24049 Mdot
.92377 .19766 Mdot
.92381 .03071 Mdot
.92386 .33537 Mdot
.92391 .58541 Mdot
.92396 .50677 Mdot
.92401 .25248 Mdot
.92405 .16842 Mdot
.9241 .43383 Mdot
.92415 .46471 Mdot
.9242 .13062 Mdot
.92424 .51079 Mdot
.92429 .4903 Mdot
.92434 .48201 Mdot
.92439 .44828 Mdot
.92443 .21888 Mdot
.92448 .10074 Mdot
.92453 .46737 Mdot
.92458 .28186 Mdot
.92462 .24657 Mdot
.92467 .60096 Mdot
.92472 .20907 Mdot
.92477 .56809 Mdot
.92481 .28753 Mdot
.92486 .37518 Mdot
.92491 .02611 Mdot
.92496 .55208 Mdot
.92501 .55549 Mdot
.92505 .39309 Mdot
.9251 .12267 Mdot
.92515 .31431 Mdot
.9252 .40178 Mdot
.92524 .56259 Mdot
.92529 .26129 Mdot
.92534 .1984 Mdot
.92539 .49432 Mdot
.92543 .087 Mdot
.92548 .3826 Mdot
.92553 .35344 Mdot
.92558 .29014 Mdot
.92562 .58958 Mdot
.92567 .51856 Mdot
.92572 .08629 Mdot
.92577 .05828 Mdot
.92581 .59195 Mdot
.92586 .3242 Mdot
.92591 .12153 Mdot
.92596 .37407 Mdot
.92601 .23148 Mdot
.92605 .31279 Mdot
.9261 .17277 Mdot
.92615 .4219 Mdot
.9262 .44171 Mdot
.92624 .20483 Mdot
.92629 .46179 Mdot
.92634 .03483 Mdot
.92639 .48245 Mdot
.92643 .54687 Mdot
.92648 .2781 Mdot
.92653 .14384 Mdot
.92658 .41016 Mdot
.92662 .17897 Mdot
.92667 .52798 Mdot
.92672 .45702 Mdot
.92677 .42391 Mdot
.92681 .26374 Mdot
.92686 .4564 Mdot
.92691 .41346 Mdot
.92696 .43528 Mdot
.927 .54287 Mdot
.92705 .34958 Mdot
.9271 .0541 Mdot
.92715 .21851 Mdot
.9272 .24478 Mdot
.92724 .19152 Mdot
.92729 .23552 Mdot
.92734 .38012 Mdot
.92739 .05466 Mdot
.92743 .33306 Mdot
.92748 .2154 Mdot
.92753 .501 Mdot
.92758 .11112 Mdot
.92762 .06967 Mdot
.92767 .08626 Mdot
.92772 .10555 Mdot
.92777 .53547 Mdot
.92781 .14501 Mdot
.92786 .23256 Mdot
.92791 .28497 Mdot
.92796 .28644 Mdot
.928 .29194 Mdot
.92805 .42243 Mdot
.9281 .45301 Mdot
.92815 .34689 Mdot
.9282 .54568 Mdot
.92824 .38304 Mdot
.92829 .2492 Mdot
.92834 .11682 Mdot
.92839 .36887 Mdot
.92843 .16223 Mdot
.92848 .47241 Mdot
.92853 .07686 Mdot
.92858 .05052 Mdot
.92862 .55016 Mdot
.92867 .57473 Mdot
.92872 .56907 Mdot
.92877 .58418 Mdot
.92881 .47861 Mdot
.92886 .4839 Mdot
.92891 .0483 Mdot
.92896 .45388 Mdot
.929 .26075 Mdot
.92905 .21364 Mdot
.9291 .36519 Mdot
.92915 .17665 Mdot
.9292 .44164 Mdot
.92924 .36396 Mdot
.92929 .033 Mdot
.92934 .2343 Mdot
.92939 .07331 Mdot
.92943 .12946 Mdot
.92948 .51951 Mdot
.92953 .46875 Mdot
.92958 .5144 Mdot
.92962 .26038 Mdot
.92967 .45735 Mdot
.92972 .43294 Mdot
.92977 .56757 Mdot
.92981 .28897 Mdot
.92986 .49161 Mdot
.92991 .45208 Mdot
.92996 .10367 Mdot
.93 .4084 Mdot
.93005 .45802 Mdot
.9301 .60153 Mdot
.93015 .44624 Mdot
.9302 .20947 Mdot
.93024 .10754 Mdot
.93029 .43959 Mdot
.93034 .0193 Mdot
.93039 .44884 Mdot
.93043 .08924 Mdot
.93048 .22 Mdot
.93053 .54932 Mdot
.93058 .33409 Mdot
.93062 .17306 Mdot
.93067 .35457 Mdot
.93072 .04963 Mdot
.93077 .08842 Mdot
.93081 .31903 Mdot
.93086 .52495 Mdot
.93091 .08539 Mdot
.93096 .40277 Mdot
.931 .43074 Mdot
.93105 .08758 Mdot
.9311 .58504 Mdot
.93115 .59769 Mdot
.93119 .57605 Mdot
.93124 .08937 Mdot
.93129 .15351 Mdot
.93134 .40293 Mdot
.93139 .48322 Mdot
.93143 .25311 Mdot
.93148 .14892 Mdot
.93153 .55742 Mdot
.93158 .40869 Mdot
.93162 .04782 Mdot
.93167 .20292 Mdot
.93172 .23804 Mdot
.93177 .25034 Mdot
.93181 .29658 Mdot
.93186 .16801 Mdot
.93191 .16433 Mdot
.93196 .53463 Mdot
.932 .37495 Mdot
.93205 .09733 Mdot
.9321 .36489 Mdot
.93215 .1186 Mdot
.93219 .30209 Mdot
.93224 .11561 Mdot
.93229 .37052 Mdot
.93234 .14588 Mdot
.93239 .22742 Mdot
.93243 .56542 Mdot
.93248 .57091 Mdot
.93253 .26598 Mdot
.93258 .57764 Mdot
.93262 .43122 Mdot
.93267 .0282 Mdot
.93272 .46062 Mdot
.93277 .54452 Mdot
.93281 .243 Mdot
.93286 .39349 Mdot
.93291 .22499 Mdot
.93296 .26265 Mdot
.933 .0897 Mdot
.93305 .24386 Mdot
.9331 .29368 Mdot
.93315 .49102 Mdot
.93319 .5957 Mdot
.93324 .4823 Mdot
.93329 .18978 Mdot
.93334 .20365 Mdot
.93339 .49479 Mdot
.93343 .12648 Mdot
.93348 .05862 Mdot
.93353 .57955 Mdot
.93358 .53269 Mdot
.93362 .15889 Mdot
.93367 .39596 Mdot
.93372 .01662 Mdot
.93377 .11618 Mdot
.93381 .1454 Mdot
.93386 .53867 Mdot
.93391 .07542 Mdot
.93396 .47651 Mdot
.934 .35524 Mdot
.93405 .32839 Mdot
.9341 .41609 Mdot
.93415 .40152 Mdot
.93419 .12608 Mdot
.93424 .04943 Mdot
.93429 .52839 Mdot
.93434 .40915 Mdot
.93439 .24711 Mdot
.93443 .46297 Mdot
.93448 .33946 Mdot
.93453 .51768 Mdot
.93458 .13534 Mdot
.93462 .41906 Mdot
.93467 .36323 Mdot
.93472 .58832 Mdot
.93477 .57977 Mdot
.93481 .03781 Mdot
.93486 .36133 Mdot
.93491 .48684 Mdot
.93496 .44908 Mdot
.935 .10246 Mdot
.93505 .30062 Mdot
.9351 .02504 Mdot
.93515 .10855 Mdot
.93519 .37739 Mdot
.93524 .48785 Mdot
.93529 .22684 Mdot
.93534 .58579 Mdot
.93539 .34267 Mdot
.93543 .56279 Mdot
.93548 .42102 Mdot
.93553 .35339 Mdot
.93558 .48303 Mdot
.93562 .23804 Mdot
.93567 .50666 Mdot
.93572 .23276 Mdot
.93577 .07868 Mdot
.93581 .47813 Mdot
.93586 .52167 Mdot
.93591 .25632 Mdot
.93596 .05558 Mdot
.936 .13151 Mdot
.93605 .04954 Mdot
.9361 .41057 Mdot
.93615 .55644 Mdot
.93619 .43422 Mdot
.93624 .03921 Mdot
.93629 .31673 Mdot
.93634 .19376 Mdot
.93638 .54969 Mdot
.93643 .41569 Mdot
.93648 .33427 Mdot
.93653 .45442 Mdot
.93658 .59023 Mdot
.93662 .598 Mdot
.93667 .58421 Mdot
.93672 .57471 Mdot
.93677 .3669 Mdot
.93681 .10604 Mdot
.93686 .36615 Mdot
.93691 .51075 Mdot
.93696 .49209 Mdot
.937 .18769 Mdot
.93705 .12454 Mdot
.9371 .46988 Mdot
.93715 .37529 Mdot
.93719 .15286 Mdot
.93724 .3173 Mdot
.93729 .51676 Mdot
.93734 .54439 Mdot
.93738 .12836 Mdot
.93743 .01527 Mdot
.93748 .33771 Mdot
.93753 .59802 Mdot
.93758 .31599 Mdot
.93762 .28433 Mdot
.93767 .48661 Mdot
.93772 .0225 Mdot
.93777 .32132 Mdot
.93781 .30345 Mdot
.93786 .51523 Mdot
.93791 .25893 Mdot
.93796 .22999 Mdot
.938 .54062 Mdot
.93805 .01919 Mdot
.9381 .37016 Mdot
.93815 .057 Mdot
.93819 .43079 Mdot
.93824 .15264 Mdot
.93829 .5982 Mdot
.93834 .50747 Mdot
.93838 .1282 Mdot
.93843 .2392 Mdot
.93848 .06851 Mdot
.93853 .39382 Mdot
.93858 .12764 Mdot
.93862 .50482 Mdot
.93867 .07381 Mdot
.93872 .09254 Mdot
.93877 .44664 Mdot
.93881 .03292 Mdot
.93886 .06602 Mdot
.93891 .37455 Mdot
.93896 .15789 Mdot
.939 .12102 Mdot
.93905 .41042 Mdot
.9391 .15927 Mdot
.93915 .2206 Mdot
.93919 .11654 Mdot
.93924 .05497 Mdot
.93929 .11698 Mdot
.93934 .39313 Mdot
.93938 .56722 Mdot
.93943 .0601 Mdot
.93948 .21284 Mdot
.93953 .27964 Mdot
.93958 .34273 Mdot
.93962 .59491 Mdot
.93967 .42234 Mdot
.93972 .16671 Mdot
.93977 .44123 Mdot
.93981 .53581 Mdot
.93986 .34451 Mdot
.93991 .3234 Mdot
.93996 .42302 Mdot
.94 .4845 Mdot
.94005 .57329 Mdot
.9401 .18021 Mdot
.94015 .31671 Mdot
.94019 .08879 Mdot
.94024 .42873 Mdot
.94029 .56294 Mdot
.94034 .21489 Mdot
.94038 .04853 Mdot
.94043 .32646 Mdot
.94048 .18451 Mdot
.94053 .25099 Mdot
.94057 .59176 Mdot
.94062 .12833 Mdot
.94067 .5082 Mdot
.94072 .51159 Mdot
.94077 .60017 Mdot
.94081 .30932 Mdot
.94086 .3562 Mdot
.94091 .08506 Mdot
.94096 .07907 Mdot
.941 .56813 Mdot
.94105 .04752 Mdot
.9411 .26537 Mdot
.94115 .1979 Mdot
.94119 .59817 Mdot
.94124 .47063 Mdot
.94129 .55198 Mdot
.94134 .12382 Mdot
.94138 .18415 Mdot
.94143 .51102 Mdot
.94148 .3518 Mdot
.94153 .09 Mdot
.94157 .46101 Mdot
.94162 .34122 Mdot
.94167 .11552 Mdot
.94172 .10157 Mdot
.94177 .34739 Mdot
.94181 .43634 Mdot
.94186 .20726 Mdot
.94191 .10472 Mdot
.94196 .05278 Mdot
.942 .09485 Mdot
.94205 .1369 Mdot
.9421 .04036 Mdot
.94215 .08798 Mdot
.94219 .06204 Mdot
.94224 .47486 Mdot
.94229 .44578 Mdot
.94234 .09313 Mdot
.94238 .19473 Mdot
.94243 .52621 Mdot
.94248 .33667 Mdot
.94253 .51231 Mdot
.94257 .28704 Mdot
.94262 .18912 Mdot
.94267 .26138 Mdot
.94272 .066 Mdot
.94277 .54914 Mdot
.94281 .08831 Mdot
.94286 .17452 Mdot
.94291 .32194 Mdot
.94296 .12751 Mdot
.943 .48437 Mdot
.94305 .0845 Mdot
.9431 .28387 Mdot
.94315 .04737 Mdot
.94319 .36218 Mdot
.94324 .05885 Mdot
.94329 .2106 Mdot
.94334 .58865 Mdot
.94338 .49064 Mdot
.94343 .2164 Mdot
.94348 .13218 Mdot
.94353 .40863 Mdot
.94357 .56776 Mdot
.94362 .48305 Mdot
.94367 .22319 Mdot
.94372 .1363 Mdot
.94377 .39334 Mdot
.94381 .23639 Mdot
.94386 .1719 Mdot
.94391 .19048 Mdot
.94396 .31974 Mdot
.944 .07658 Mdot
.94405 .45328 Mdot
.9441 .07768 Mdot
.94415 .4387 Mdot
.94419 .5954 Mdot
.94424 .18412 Mdot
.94429 .04502 Mdot
.94434 .09123 Mdot
.94438 .55126 Mdot
.94443 .57685 Mdot
.94448 .0597 Mdot
.94453 .20391 Mdot
.94457 .34957 Mdot
.94462 .45938 Mdot
.94467 .25439 Mdot
.94472 .23948 Mdot
.94477 .46984 Mdot
.94481 .2509 Mdot
.94486 .1328 Mdot
.94491 .44946 Mdot
.94496 .24817 Mdot
.945 .09371 Mdot
.94505 .54564 Mdot
.9451 .14443 Mdot
.94515 .1863 Mdot
.94519 .24375 Mdot
.94524 .48267 Mdot
.94529 .30906 Mdot
.94534 .19422 Mdot
.94538 .07434 Mdot
.94543 .45235 Mdot
.94548 .23254 Mdot
.94553 .24629 Mdot
.94557 .10082 Mdot
.94562 .40736 Mdot
.94567 .04334 Mdot
.94572 .50004 Mdot
.94576 .24476 Mdot
.94581 .16768 Mdot
.94586 .40718 Mdot
.94591 .0449 Mdot
.94596 .59719 Mdot
.946 .04959 Mdot
.94605 .56105 Mdot
.9461 .40006 Mdot
.94615 .51819 Mdot
.94619 .10727 Mdot
.94624 .43133 Mdot
.94629 .22848 Mdot
.94634 .28915 Mdot
.94638 .22793 Mdot
.94643 .13698 Mdot
.94648 .04897 Mdot
.94653 .22952 Mdot
.94657 .37891 Mdot
.94662 .50777 Mdot
.94667 .40601 Mdot
.94672 .14341 Mdot
.94676 .57487 Mdot
.94681 .47914 Mdot
.94686 .50929 Mdot
.94691 .50198 Mdot
.94696 .4219 Mdot
.947 .08666 Mdot
.94705 .47909 Mdot
.9471 .50811 Mdot
.94715 .38701 Mdot
.94719 .12894 Mdot
.94724 .09374 Mdot
.94729 .59324 Mdot
.94734 .29445 Mdot
.94738 .30094 Mdot
.94743 .46859 Mdot
.94748 .3188 Mdot
.94753 .08122 Mdot
.94757 .17867 Mdot
.94762 .43433 Mdot
.94767 .10399 Mdot
.94772 .30564 Mdot
.94776 .27422 Mdot
.94781 .04303 Mdot
.94786 .56391 Mdot
.94791 .3341 Mdot
.94796 .39841 Mdot
.948 .13707 Mdot
.94805 .07664 Mdot
.9481 .51553 Mdot
.94815 .32645 Mdot
.94819 .2613 Mdot
.94824 .17185 Mdot
.94829 .14323 Mdot
.94834 .21222 Mdot
.94838 .18227 Mdot
.94843 .18194 Mdot
.94848 .4521 Mdot
.94853 .51461 Mdot
.94857 .317 Mdot
.94862 .46646 Mdot
.94867 .38559 Mdot
.94872 .35065 Mdot
.94876 .486 Mdot
.94881 .37717 Mdot
.94886 .09465 Mdot
.94891 .09113 Mdot
.94896 .45767 Mdot
.949 .41659 Mdot
.94905 .36387 Mdot
.9491 .29605 Mdot
.94915 .33531 Mdot
.94919 .35466 Mdot
.94924 .45167 Mdot
.94929 .57292 Mdot
.94934 .08872 Mdot
.94938 .19752 Mdot
.94943 .32315 Mdot
.94948 .37541 Mdot
.94953 .50978 Mdot
.94957 .03029 Mdot
.94962 .47437 Mdot
.94967 .46413 Mdot
.94972 .20748 Mdot
.94976 .16716 Mdot
.94981 .10349 Mdot
.94986 .12819 Mdot
.94991 .32481 Mdot
.94996 .39331 Mdot
.95 .02355 Mdot
.95005 .05176 Mdot
.9501 .47046 Mdot
.95015 .58004 Mdot
.95019 .263 Mdot
.95024 .35904 Mdot
.95029 .14986 Mdot
.95034 .24008 Mdot
.95038 .41466 Mdot
.95043 .38945 Mdot
.95048 .07584 Mdot
.95053 .05727 Mdot
.95057 .10622 Mdot
.95062 .02875 Mdot
.95067 .16939 Mdot
.95072 .04169 Mdot
.95076 .23517 Mdot
.95081 .16795 Mdot
.95086 .56523 Mdot
.95091 .47786 Mdot
.95095 .14639 Mdot
.951 .05447 Mdot
.95105 .25513 Mdot
.9511 .09926 Mdot
.95115 .13755 Mdot
.95119 .01742 Mdot
.95124 .388 Mdot
.95129 .12255 Mdot
.95134 .47787 Mdot
.95138 .2617 Mdot
.95143 .25285 Mdot
.95148 .48579 Mdot
.95153 .07792 Mdot
.95157 .47557 Mdot
.95162 .19171 Mdot
.95167 .44323 Mdot
.95172 .57503 Mdot
.95176 .46153 Mdot
.95181 .03703 Mdot
.95186 .41624 Mdot
.95191 .35457 Mdot
.95195 .30829 Mdot
.952 .07512 Mdot
.95205 .5417 Mdot
.9521 .22289 Mdot
.95215 .26853 Mdot
.95219 .42331 Mdot
.95224 .45715 Mdot
.95229 .10005 Mdot
.95234 .26582 Mdot
.95238 .05002 Mdot
.95243 .3493 Mdot
.95248 .2255 Mdot
.95253 .01883 Mdot
.95257 .4005 Mdot
.95262 .46684 Mdot
.95267 .16229 Mdot
.95272 .14658 Mdot
.95276 .22349 Mdot
.95281 .03832 Mdot
.95286 .19059 Mdot
.95291 .28837 Mdot
.95295 .20117 Mdot
.953 .2254 Mdot
.95305 .43935 Mdot
.9531 .58341 Mdot
.95315 .14076 Mdot
.95319 .28703 Mdot
.95324 .23117 Mdot
.95329 .32959 Mdot
.95334 .32078 Mdot
.95338 .4332 Mdot
.95343 .14583 Mdot
.95348 .07848 Mdot
.95353 .28546 Mdot
.95357 .09861 Mdot
.95362 .52365 Mdot
.95367 .07436 Mdot
.95372 .48829 Mdot
.95376 .2351 Mdot
.95381 .37607 Mdot
.95386 .53111 Mdot
.95391 .2795 Mdot
.95395 .21148 Mdot
.954 .20019 Mdot
.95405 .25744 Mdot
.9541 .09304 Mdot
.95415 .58941 Mdot
.95419 .36417 Mdot
.95424 .27736 Mdot
.95429 .5556 Mdot
.95434 .31709 Mdot
.95438 .14771 Mdot
.95443 .55109 Mdot
.95448 .24953 Mdot
.95453 .48721 Mdot
.95457 .01659 Mdot
.95462 .48731 Mdot
.95467 .5674 Mdot
.95472 .40331 Mdot
.95476 .09627 Mdot
.95481 .42766 Mdot
.95486 .09382 Mdot
.95491 .18292 Mdot
.95495 .32352 Mdot
.955 .49988 Mdot
.95505 .41764 Mdot
.9551 .57476 Mdot
.95514 .13804 Mdot
.95519 .25715 Mdot
.95524 .33931 Mdot
.95529 .58868 Mdot
.95534 .3772 Mdot
.95538 .58312 Mdot
.95543 .38703 Mdot
.95548 .2863 Mdot
.95553 .2442 Mdot
.95557 .04674 Mdot
.95562 .15221 Mdot
.95567 .40242 Mdot
.95572 .24232 Mdot
.95576 .16275 Mdot
.95581 .18813 Mdot
.95586 .60244 Mdot
.95591 .16077 Mdot
.95595 .33841 Mdot
.956 .10903 Mdot
.95605 .43422 Mdot
.9561 .44057 Mdot
.95614 .44186 Mdot
.95619 .29471 Mdot
.95624 .46279 Mdot
.95629 .31723 Mdot
.95634 .19942 Mdot
.95638 .55873 Mdot
.95643 .47743 Mdot
.95648 .54336 Mdot
.95653 .21963 Mdot
.95657 .1864 Mdot
.95662 .20584 Mdot
.95667 .31386 Mdot
.95672 .1876 Mdot
.95676 .04891 Mdot
.95681 .40674 Mdot
.95686 .08624 Mdot
.95691 .03956 Mdot
.95695 .4641 Mdot
.957 .40763 Mdot
.95705 .5288 Mdot
.9571 .30447 Mdot
.95714 .36978 Mdot
.95719 .57673 Mdot
.95724 .10294 Mdot
.95729 .46593 Mdot
.95734 .08978 Mdot
.95738 .12866 Mdot
.95743 .38903 Mdot
.95748 .28122 Mdot
.95753 .13438 Mdot
.95757 .25455 Mdot
.95762 .449 Mdot
.95767 .0763 Mdot
.95772 .5513 Mdot
.95776 .06343 Mdot
.95781 .14985 Mdot
.95786 .49203 Mdot
.95791 .5171 Mdot
.95795 .26001 Mdot
.958 .07832 Mdot
.95805 .46718 Mdot
.9581 .06771 Mdot
.95814 .4557 Mdot
.95819 .15284 Mdot
.95824 .17742 Mdot
.95829 .30125 Mdot
.95834 .48229 Mdot
.95838 .06461 Mdot
.95843 .31481 Mdot
.95848 .22618 Mdot
.95853 .36834 Mdot
.95857 .2789 Mdot
.95862 .0483 Mdot
.95867 .10651 Mdot
.95872 .1285 Mdot
.95876 .43322 Mdot
.95881 .57533 Mdot
.95886 .15854 Mdot
.95891 .07978 Mdot
.95895 .29808 Mdot
.959 .09801 Mdot
.95905 .24477 Mdot
.9591 .4231 Mdot
.95914 .23447 Mdot
.95919 .23415 Mdot
.95924 .19177 Mdot
.95929 .57072 Mdot
.95934 .09634 Mdot
.95938 .07144 Mdot
.95943 .49384 Mdot
.95948 .10314 Mdot
.95953 .04644 Mdot
.95957 .35995 Mdot
.95962 .28237 Mdot
.95967 .33812 Mdot
.95972 .37087 Mdot
.95976 .32636 Mdot
.95981 .19056 Mdot
.95986 .22433 Mdot
.95991 .54098 Mdot
.95995 .35436 Mdot
.96 .04673 Mdot
.96005 .15925 Mdot
.9601 .25761 Mdot
.96014 .27106 Mdot
.96019 .40529 Mdot
.96024 .33948 Mdot
.96029 .03785 Mdot
.96033 .05161 Mdot
.96038 .22823 Mdot
.96043 .37208 Mdot
.96048 .54483 Mdot
.96053 .5835 Mdot
.96057 .33772 Mdot
.96062 .28365 Mdot
.96067 .5131 Mdot
.96072 .23825 Mdot
.96076 .07006 Mdot
.96081 .54885 Mdot
.96086 .15694 Mdot
.96091 .51522 Mdot
.96095 .48282 Mdot
.961 .33924 Mdot
.96105 .21929 Mdot
.9611 .17557 Mdot
.96114 .45079 Mdot
.96119 .19469 Mdot
.96124 .565 Mdot
.96129 .50784 Mdot
.96133 .06021 Mdot
.96138 .45854 Mdot
.96143 .54187 Mdot
.96148 .47093 Mdot
.96153 .43531 Mdot
.96157 .10117 Mdot
.96162 .60036 Mdot
.96167 .49076 Mdot
.96172 .1123 Mdot
.96176 .42085 Mdot
.96181 .10197 Mdot
.96186 .26721 Mdot
.96191 .05695 Mdot
.96195 .47532 Mdot
.962 .54836 Mdot
.96205 .35532 Mdot
.9621 .17746 Mdot
.96214 .15079 Mdot
.96219 .34379 Mdot
.96224 .19446 Mdot
.96229 .32999 Mdot
.96233 .55943 Mdot
.96238 .38211 Mdot
.96243 .28995 Mdot
.96248 .28449 Mdot
.96253 .11559 Mdot
.96257 .44357 Mdot
.96262 .42234 Mdot
.96267 .45251 Mdot
.96272 .02913 Mdot
.96276 .44653 Mdot
.96281 .53491 Mdot
.96286 .35492 Mdot
.96291 .21161 Mdot
.96295 .35927 Mdot
.963 .2824 Mdot
.96305 .31268 Mdot
.9631 .33962 Mdot
.96314 .41423 Mdot
.96319 .53041 Mdot
.96324 .14993 Mdot
.96329 .20353 Mdot
.96333 .08515 Mdot
.96338 .35066 Mdot
.96343 .42326 Mdot
.96348 .24743 Mdot
.96353 .30637 Mdot
.96357 .07542 Mdot
.96362 .15348 Mdot
.96367 .14655 Mdot
.96372 .46613 Mdot
.96376 .25641 Mdot
.96381 .3043 Mdot
.96386 .13212 Mdot
.96391 .03431 Mdot
.96395 .32483 Mdot
.964 .5527 Mdot
.96405 .52384 Mdot
.9641 .27837 Mdot
.96414 .05714 Mdot
.96419 .25474 Mdot
.96424 .19893 Mdot
.96429 .46746 Mdot
.96433 .13005 Mdot
.96438 .11952 Mdot
.96443 .59872 Mdot
.96448 .39702 Mdot
.96452 .38272 Mdot
.96457 .29958 Mdot
.96462 .366 Mdot
.96467 .10536 Mdot
.96472 .322 Mdot
.96476 .16081 Mdot
.96481 .23416 Mdot
.96486 .24255 Mdot
.96491 .0803 Mdot
.96495 .45984 Mdot
.965 .11675 Mdot
.96505 .22295 Mdot
.9651 .35879 Mdot
.96514 .51046 Mdot
.96519 .19624 Mdot
.96524 .54791 Mdot
.96529 .31637 Mdot
.96533 .27043 Mdot
.96538 .60063 Mdot
.96543 .09516 Mdot
.96548 .20102 Mdot
.96552 .16562 Mdot
.96557 .01662 Mdot
.96562 .30146 Mdot
.96567 .42163 Mdot
.96572 .46937 Mdot
.96576 .25394 Mdot
.96581 .21081 Mdot
.96586 .11434 Mdot
.96591 .32327 Mdot
.96595 .03449 Mdot
.966 .57158 Mdot
.96605 .04875 Mdot
.9661 .46676 Mdot
.96614 .52106 Mdot
.96619 .36334 Mdot
.96624 .29328 Mdot
.96629 .55962 Mdot
.96633 .33953 Mdot
.96638 .41875 Mdot
.96643 .58024 Mdot
.96648 .3039 Mdot
.96652 .34222 Mdot
.96657 .3383 Mdot
.96662 .39393 Mdot
.96667 .15299 Mdot
.96672 .34031 Mdot
.96676 .05155 Mdot
.96681 .57562 Mdot
.96686 .28694 Mdot
.96691 .10108 Mdot
.96695 .44406 Mdot
.967 .47599 Mdot
.96705 .567 Mdot
.9671 .0813 Mdot
.96714 .47581 Mdot
.96719 .44194 Mdot
.96724 .11496 Mdot
.96729 .16356 Mdot
.96733 .12718 Mdot
.96738 .16337 Mdot
.96743 .15866 Mdot
.96748 .42736 Mdot
.96752 .31175 Mdot
.96757 .18645 Mdot
.96762 .45808 Mdot
.96767 .09984 Mdot
.96772 .57677 Mdot
.96776 .39584 Mdot
.96781 .31981 Mdot
.96786 .36286 Mdot
.96791 .53993 Mdot
.96795 .42355 Mdot
.968 .04757 Mdot
.96805 .27649 Mdot
.9681 .11057 Mdot
.96814 .55089 Mdot
.96819 .08389 Mdot
.96824 .2099 Mdot
.96829 .23809 Mdot
.96833 .12366 Mdot
.96838 .57226 Mdot
.96843 .06104 Mdot
.96848 .12562 Mdot
.96852 .56362 Mdot
.96857 .42831 Mdot
.96862 .23701 Mdot
.96867 .4172 Mdot
.96872 .39188 Mdot
.96876 .57356 Mdot
.96881 .15188 Mdot
.96886 .44376 Mdot
.96891 .59936 Mdot
.96895 .26846 Mdot
.969 .39234 Mdot
.96905 .50716 Mdot
.9691 .19052 Mdot
.96914 .2356 Mdot
.96919 .13057 Mdot
.96924 .4113 Mdot
.96929 .24295 Mdot
.96933 .16641 Mdot
.96938 .52399 Mdot
.96943 .18791 Mdot
.96948 .134 Mdot
.96952 .19748 Mdot
.96957 .47766 Mdot
.96962 .077 Mdot
.96967 .17371 Mdot
.96971 .37249 Mdot
.96976 .25536 Mdot
.96981 .26312 Mdot
.96986 .38516 Mdot
.96991 .40226 Mdot
.96995 .11819 Mdot
.97 .42269 Mdot
.97005 .38913 Mdot
.9701 .14851 Mdot
.97014 .32917 Mdot
.97019 .51886 Mdot
.97024 .21332 Mdot
.97029 .51623 Mdot
.97033 .21332 Mdot
.97038 .12227 Mdot
.97043 .57369 Mdot
.97048 .36453 Mdot
.97052 .29265 Mdot
.97057 .53768 Mdot
.97062 .4544 Mdot
.97067 .18176 Mdot
.97071 .41831 Mdot
.97076 .47539 Mdot
.97081 .29539 Mdot
.97086 .41259 Mdot
.97091 .17766 Mdot
.97095 .22698 Mdot
.971 .51356 Mdot
.97105 .02504 Mdot
.9711 .07418 Mdot
.97114 .40761 Mdot
.97119 .13914 Mdot
.97124 .47986 Mdot
.97129 .34833 Mdot
.97133 .49208 Mdot
.97138 .52914 Mdot
.97143 .56696 Mdot
.97148 .14972 Mdot
.97152 .38451 Mdot
.97157 .55877 Mdot
.97162 .21714 Mdot
.97167 .4604 Mdot
.97171 .45015 Mdot
.97176 .11908 Mdot
.97181 .05009 Mdot
.97186 .0568 Mdot
.97191 .57809 Mdot
.97195 .42702 Mdot
.972 .24083 Mdot
.97205 .48247 Mdot
.9721 .36582 Mdot
.97214 .51678 Mdot
.97219 .23049 Mdot
.97224 .423 Mdot
.97229 .56153 Mdot
.97233 .39235 Mdot
.97238 .35395 Mdot
.97243 .08938 Mdot
.97248 .08416 Mdot
.97252 .46653 Mdot
.97257 .39032 Mdot
.97262 .54298 Mdot
.97267 .30298 Mdot
.97271 .51109 Mdot
.97276 .18788 Mdot
.97281 .09729 Mdot
.97286 .45615 Mdot
.97291 .40671 Mdot
.97295 .1525 Mdot
.973 .05519 Mdot
.97305 .48139 Mdot
.9731 .58302 Mdot
.97314 .515 Mdot
.97319 .17605 Mdot
.97324 .13028 Mdot
.97329 .08095 Mdot
.97333 .29922 Mdot
.97338 .35638 Mdot
.97343 .17207 Mdot
.97348 .29192 Mdot
.97352 .5486 Mdot
.97357 .28171 Mdot
.97362 .10262 Mdot
.97367 .42871 Mdot
.97371 .17299 Mdot
.97376 .34206 Mdot
.97381 .40297 Mdot
.97386 .52095 Mdot
.9739 .58843 Mdot
.97395 .25948 Mdot
.974 .55014 Mdot
.97405 .12895 Mdot
.9741 .45064 Mdot
.97414 .219 Mdot
.97419 .08347 Mdot
.97424 .14925 Mdot
.97429 .53896 Mdot
.97433 .05765 Mdot
.97438 .55652 Mdot
.97443 .08302 Mdot
.97448 .25445 Mdot
.97452 .30459 Mdot
.97457 .39915 Mdot
.97462 .39442 Mdot
.97467 .30918 Mdot
.97471 .03759 Mdot
.97476 .31124 Mdot
.97481 .56904 Mdot
.97486 .1509 Mdot
.9749 .29886 Mdot
.97495 .5116 Mdot
.975 .0628 Mdot
.97505 .1658 Mdot
.9751 .05408 Mdot
.97514 .56478 Mdot
.97519 .53717 Mdot
.97524 .31849 Mdot
.97529 .43841 Mdot
.97533 .49603 Mdot
.97538 .40263 Mdot
.97543 .38285 Mdot
.97548 .39547 Mdot
.97552 .54284 Mdot
.97557 .33432 Mdot
.97562 .14311 Mdot
.97567 .10559 Mdot
.97571 .15839 Mdot
.97576 .54322 Mdot
.97581 .43726 Mdot
.97586 .0827 Mdot
.9759 .45047 Mdot
.97595 .57751 Mdot
.976 .30107 Mdot
.97605 .38717 Mdot
.9761 .54219 Mdot
.97614 .52942 Mdot
.97619 .14998 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00EOoonfX4o`000?oooo]Zj?oonfX005Gooo]Z
1?l0003ooookJ^Sooo]Z001EoookJPCo0000oooonf[XoookJP00EOoonfX4o`000?oooo]Zj?oonfX0
013ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00
O`Oooo]Z0ol007l9oookJPCo0000oooonf[XoookJP003ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o1_oonfX3o`00O`Wooo]Z1?l0003ooookJ^So
oo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP?o001o2OoonfX4o`000?oooo]Z
j?oonfX000?ooo]Z2_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX4o`0001;ooo]Z0ol00013
oookJP?o00004?oonfX3o`0000;ooo]Z0ol0000<oookJP?o00005_oonfX3o`0000;ooo]Z1_l0000;
oookJP?o0000<_oonfX3o`0001gooo]Z0ol00009oookJP?o00001OoonfX4o`0002Kooo]Z0ol0000A
oookJP?o0000C_oonfX3o`0003kooo]Z0003oookJP[o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX3o`00O`Wo
oo]Z1_l00006oookJPOo00000ooonfX3o`0000[ooo]Z1Ol000000ooonf[o0000o`000003o`0000Wo
oo]Z0ol000001?oonf[o0000o`000?l00002oookJPKo00005_oonfX3o`0000?ooo]Z0ol000000ooo
nf[o0000o`000003o`0000Cooo]Z2?l0000:oookJPGo00002_oonfX3o`0000Wooo]Z2ol00002oook
JP?o00001_oonfX7o`0000Cooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00?o00003OoonfX4
o`0000Sooo]Z2?l0000KoookJPWo000000?ooo]Zo`000?l000000ol00005oookJPCo00001?oonfX3
o`0000?ooo]Z1Ol0000EoookJP[o00003?oonfX3o`0000;ooo]Z0ol00005oookJPCo00000ooonfX3
o`0001Gooo]Z0ol00002oookJP?o00003_oonfX3o`0000cooo]Z0ol00002oookJPGo00001OoonfX4
o`0000Kooo]Z0ol00002oookJP?o00008?oonfX000kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX6o`0000Kooo]Z
1ol00003oookJPSo000000Gooo]Zo`000?l0003o0000oookJP0;o`0000Cooo]Z0ol00002oookJPOo
00000_oonfX6o`000004oookJ_l0003o0000o`0000Wooo]Z1_l00003oookJP?o00000ooonfX9o`00
0003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000008o`00
00Oooo]Z0ol000000ooonf[o0000o`000003o`0000?ooo]Z4?l00006oookJPOo00000_oonfX<o`00
0005oookJ_l0003o0000o`000?oonfX00ol00009oookJPCo00000_oonfX4o`0000;ooo]Z2?l00003
oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX3o`000003oookJ_l0003o000000Co000000?o
oo]Zo`000?l000002_l000000ooonf[o0000o`000005o`0000?ooo]Z1?l00004oookJP_o00001Ooo
nfX3o`0000gooo]Z2ol00003oookJP_o00000_oonfX<o`0000?ooo]Z0ol00007oookJPCo00001?oo
nfX3o`0000;ooo]Z1?l00002oookJPCo000000Cooo]Zo`000?l0003o00002?oonfX8o`0000Gooo]Z
3Ol00003oookJPOo00000ooonfX5o`0000;ooo]Z0ol0000PoookJP003_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l9oook
JPOo00000ooonfX9o`0000Gooo]Z2_l000000ooonf[o0000o`000009o`0000Cooo]Z3Ol000000ooo
nf[o0000o`000004o`000004oookJ_l0003o0000o`0000Wooo]Z1_l000000ooonf[o0000o`00000J
o`0000;ooo]Z1_l000000ooonf[o0000o`000003o`0000;ooo]Z0ol000001?oonf[o0000o`000?l0
0003oookJP?o000000?ooo]Zo`000?l000000ol00004oookJPKo00000ooonfX7o`0000Kooo]Z1_l0
0002oookJPco000000?ooo]Zo`000?l000001Ol00009oookJPCo000000?ooo]Zo`000?l000000ol0
0002oookJPSo00000ooonfX=o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000002_l0
00000ooonf[o0000o`000005o`0000?ooo]Z1?l00004oookJP_o00000_oonfX6o`0000Wooo]Z1ol0
00000ooonf[o0000o`000005o`000003oookJ_l0003o000000co000000?ooo]Zo`000?l000002_l0
00000ooonf[o0000o`00000Eo`0000;ooo]Z3_l00008oookJPSo00000_oonfX6o`0000;ooo]Z2?l0
0003oookJPOo00000ooonfX5o`0000;ooo]Z0ol0000PoookJP003_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPgo
000000Cooo]Zo`000?l0003o00001?oonfX=o`000005oookJ_l0003o0000o`000?oonfX02?l00003
oookJPGo00000ooonfX6o`0000?ooo]Z0ol000001?oonf[o0000o`000?l00005oookJP?o000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`00000>o`000003oookJ_l0003o000001Go00000ooo
nfX4o`000004oookJ_l0003o0000o`0000?ooo]Z0ol000000ooonf[o0000o`000007o`0000;ooo]Z
0ol00004oookJPSo00001_oonfX4o`0000?ooo]Z3Ol00003oookJPCo00000_oonfX3o`0000?ooo]Z
1Ol000000ooonf[o0000o`000003o`0000;ooo]Z1ol00002oookJPoo000000?ooo]Zo`000?l00000
1?l000000ooonf[o0000o`000004o`0000Sooo]Z1_l00002oookJP?o00001_oonfX<o`000003oook
J_l0003o000000Co00002?oonfX8o`0000;ooo]Z5Ol00002oookJRCo000000?ooo]Zo`000?l00000
1?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000;o00000_oonfX9o`0000;ooo]Z
1ol000001?oonf[o0000o`000?l00008oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX4o`00
02Kooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1OoonfX3o`00O`Wooo]Z4Ol00003oookJPko000000Gooo]Zo`000?l0003o0000
oookJP0;o`0000;ooo]Z0ol00005oookJPCo00000ooonfX3o`000003oookJ_l0003o000000;o0000
1?oonfX3o`000003oookJ_l0003o000000?o00000_oonfX;o`0000;ooo]Z0ol000000ooonf[o0000
o`000003o`0000?ooo]Z1Ol00002oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPCo0000
0_oonfX3o`000003oookJ_l0003o000000go00001ooonfX:o`0000Cooo]Z1Ol00003oookJP?o0000
0_oonfX;o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l00003oookJPGo0000
00?ooo]Zo`000?l000000_l00002oookJPSo00000_oonfX@o`000003oookJ_l0003o000000;o0000
1ooonfX4o`0000Gooo]Z1Ol00002oookJPWo000000Gooo]Zo`000?l0003o0000oookJP08o`000003
oookJ_l0003o000000Go000000?ooo]Zo`000?l000003?l00002oookJQko00000_oonfXGo`000005
oookJ_l0003o0000o`000?oonfX01_l00004oookJP?o00000_oonfX4o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`000005o`0000[ooo]Z1Ol00003oook
JP?o00001ooonfX3o`0001gooo]Z000>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX6o`00O`Wooo]Z1?l000000ooonf[o0000o`00
0007o`0000Kooo]Z1?l00002oookJPSo000000?ooo]Zo`000?l000003Ol00007oookJPOo00000ooo
nfX3o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000001ol00003oookJPKo00001_oo
nfX8o`000004oookJ_l0003o0000o`0000;ooo]Z2?l000000ooonf[o0000o`000002o`0000;ooo]Z
1?l00006oookJQ7o00001?oonfX;o`0000Cooo]Z2ol00002oookJPGo000000?ooo]Zo`000?l00000
0ol00006oookJQOo00001_oonfX3o`0000?ooo]Z2_l000000ooonf[o0000o`000008o`000003oook
J_l0003o000000go000000?ooo]Zo`000?l000001ol00005oookJPSo00000ooonfX5o`000003oook
J_l0003o0000023o00000_oonfX:o`0000;ooo]Z0ol00002oookJPco00001ooonfX3o`000003oook
J_l0003o000000Go00000ooonfX3o`0000;ooo]Z2Ol000000ooonf[o0000o`00000@o`0000Gooo]Z
0ol00002oookJPGo00000ooonfX3o`0000Oooo]Z0ol0000MoookJP003ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJPKo001o2OoonfX4o`0000Cooo]Z1_l00006oookJP?o00000ooonfX7o`0000;ooo]Z1_l0
0005oookJPCo00000_oonfX3o`000003oookJ_l0003o000000Co00001OoonfX3o`000003oookJ_l0
003o000000[o000000?ooo]Zo`000?l000002ol00008oookJPKo000000Cooo]Zo`000?l0003o0000
1?oonfX3o`0000[ooo]Z1ol00003oookJPOo00000_oonfX8o`0000Cooo]Z1?l00003oookJP?o0000
00Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00004oook
JPGo000000Cooo]Zo`000?l0003o00000_oonfXGo`0000Kooo]Z0ol000000ooonf[o0000o`00000:
o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000005ol00002oookJP?o000000?ooo]Z
o`000?l000000_l00006oookJPGo000000?ooo]Zo`000?l000004_l00002oookJPco000000?ooo]Z
o`000?l000003_l00004oookJPWo00002?oonfX7o`000003oookJ_l0003o000000?o000000?ooo]Z
o`000?l000000_l00003oookJPKo00000_oonfXBo`000003oookJ_l0003o000000Go000000?ooo]Z
o`000?l000000_l00005oookJP?o00000ooonfX3o`000004oookJ_l0003o0000o`0001gooo]Z000?
oookJPOo001o2?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`Gooo]Z1?l007l9
oookJPCo00001?oonfX3o`0000Wooo]Z0ol00003oookJP[o00000_oonfX;o`0000?ooo]Z0ol00000
0ooonf[o0000o`000004o`0000Gooo]Z0ol00005oookJQCo00002_oonfX6o`000004oookJ_l0003o
0000o`0000Cooo]Z0ol00004oookJP?o00001?oonfX7o`000003oookJ_l0003o000000Go00000ooo
nfX4o`000004oookJ_l0003o0000o`0000Cooo]Z0ol00008oookJP?o000000?ooo]Zo`000?l00000
2?l00002oookJPGo00000_oonfX3o`0000?ooo]Z7?l00002oookJPOo000000Cooo]Zo`000?l0003o
00000ooonfX3o`0000Gooo]Z2Ol000000ooonf[o0000o`000008o`0000;ooo]Z1_l000001?oonf[o
0000o`000?l00002oookJPOo000000?ooo]Zo`000?l000000ol00009oookJP?o00000ooonfX3o`00
00?ooo]Z7ol00002oookJPOo00000_oonfX;o`0000Oooo]Z1ol00002oookJP[o00000ooonfXRo`00
0004oookJ_l0003o0000o`0000Gooo]Z1?l00003oookJP?o00008OoonfX0013ooo]Z1Ol007l:oook
JPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1ooonfX3o`00O`Wooo]Z1?l0000@oook
JPCo00000_oonfX3o`0000;ooo]Z1Ol00005oookJPKo00001OoonfX:o`0000Cooo]Z0ol00005oook
JQOo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000008o`0000_ooo]Z1Ol00002oook
JPoo00000ooonfX4o`0000Oooo]Z1?l00002oookJP?o000000?ooo]Zo`000?l000002Ol00004oook
JPSo00000_oonfX3o`0000?ooo]Z2?l000000ooonf[o0000o`000003o`000003oookJ_l0003o0000
00Oo000000Cooo]Zo`000?l0003o00000_oonfX4o`0000Cooo]Z0ol00003oookJP?o00000_oonfX;
o`0000;ooo]Z2?l00003oookJPOo000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`000008
o`0000?ooo]Z1_l00006oookJPOo00000_oonfXFo`0000;ooo]Z1ol00002oookJP_o000000Cooo]Z
o`000?l0003o00000_oonfX4o`000004oookJ_l0003o0000o`0000Cooo]Z2?l00002oookJPko0000
2_oonfXBo`0000;ooo]Z1?l00003oookJP?o00008OoonfX005Gooo]Z1?l00004oookJPCo00000_oo
nfX3o`0000Cooo]Z0ol00002oookJP?o00000_oonfX5o`0000Gooo]Z1_l00007oookJPGo00001ooo
nfX3o`0000Gooo]Z3?l000000ooonf[o0000o`00000?o`000003oookJ_l0003o000000So00002_oo
nfX6o`0000;ooo]Z3ol00003oookJP?o00002?oonfX4o`0000;ooo]Z1ol00002oookJPKo00001?oo
nfX3o`0000;ooo]Z0ol00002oookJP?o00001OoonfX<o`0000;ooo]Z2?l000001?oonf[o0000o`00
0?l00002oookJPOo00000_oonfX3o`0000;ooo]Z0ol00002oookJQ;o00001_oonfX5o`0000?ooo]Z
3Ol000000ooonf[o0000o`000008o`0000?ooo]Z1_l0000:oookJP?o00000_oonfXFo`0000Gooo]Z
1Ol000000ooonf[o0000o`000008o`0000;ooo]Z0ol00002oookJPCo00001_oonfXHo`0000;ooo]Z
1Ol00003oookJQ3o000000Cooo]Zo`000?l0003o00000_oonfX3o`0000Cooo]Z1?l0000PoookJP00
EOoonfX4o`0000;ooo]Z1_l00002oookJP?o00001?oonfX8o`0000;ooo]Z1?l000001?oonf[o0000
o`000?l00002oookJPKo00001ooonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000003o`0000?o
oo]Z3_l000000ooonf[o0000o`00000?o`0000Kooo]Z1_l00008oookJPOo000000Gooo]Zo`000?l0
003o0000oookJP07o`000003oookJ_l0003o000000Ko00001?oonfX3o`0000?ooo]Z0ol00003oook
JPOo00000_oonfX3o`0000Cooo]Z1_l00006oookJPCo00001_oonfX3o`000003oookJ_l0003o0000
00Co00000ooonfX7o`0000;ooo]Z1_l00002oookJPGo000000Cooo]Zo`000?l0003o00000_oonfX=
o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000Kooo]Z1Ol00006oookJP?o00000_oonfX5
o`0000Cooo]Z2?l00003oookJPGo00001?oonfX4o`0000;ooo]Z1Ol000001Ooonf[o0000o`000?l0
003ooo]Z00Co00001_oonfX3o`000003oookJ_l0003o000000_o000000?ooo]Zo`000?l000001ol0
0003oookJP?o00000_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z6_l000000ooonf[o0000
o`00000Jo`0000?ooo]Z0ol000000ooonf[o0000o`000004o`000004oookJ_l0003o0000o`0001co
oo]Z001EoookJPCo00000_oonfX7o`000004oookJ_l0003o0000o`0000Kooo]Z1ol000000ooonf[o
0000o`000002o`000004oookJ_l0003o0000o`0000Cooo]Z1?l00003oookJP?o00001?oonfX6o`00
0005oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o0000o`00000;o`0000;ooo]Z3Ol00000
1?oonf[o0000o`000?l00005oookJPOo00001OoonfX7o`0000Cooo]Z0ol000000ooonf[o0000o`00
0005o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000000_l00002oookJP?o00001?oo
nfX5o`0000[ooo]Z2Ol00004oookJPCo00001?oonfX3o`0000?ooo]Z1_l00005oookJPGo00000ooo
nfXAo`000003oookJ_l0003o000000Ko00000_oonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`00
0002o`0000Gooo]Z0ol00007oookJPco00001OoonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z
1Ol000000ooonf[o0000o`000007o`0000;ooo]Z0ol00003oookJPKo00001_oonfX3o`000003oook
J_l0003o000000co000000?ooo]Zo`000?l000001ol00002oookJP?o00001_oonfX3o`0000;ooo]Z
1?l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000
6?l000000ooonf[o0000o`000002o`0000Cooo]Z2_l000001?oonf[o0000o`000?l0000LoookJP00
EOoonfX9o`000003oookJ_l0003o000000Co000000Cooo]Zo`000?l0003o00000ooonfX7o`000004
oookJ_l0003o0000o`0000;ooo]Z3Ol000001?oonf[o0000o`000?l00004oookJPko000000?ooo]Z
o`000?l000001?l00002oookJPKo00002OoonfX9o`000003oookJ_l0003o000000Wo00000_oonfX9
o`0000Gooo]Z0ol000000ooonf[o0000o`00000Eo`0000;ooo]Z0ol00004oookJPGo000000Cooo]Z
o`000?l0003o00001_oonfX9o`000003oookJ_l0003o000000Co00001OoonfX<o`0000Gooo]Z0ol0
0003oookJQ?o000000?ooo]Zo`000?l000001Ol00003oookJPGo00000ooonfX7o`0000?ooo]Z1Ol0
0002oookJQ7o00000ooonfX3o`000003oookJ_l0003o000000Oo00000ooonfX9o`0000;ooo]Z1Ol0
00000ooonf[o0000o`000006o`0000?ooo]Z1?l00003oookJPKo00000_oonfX4o`000003oookJ_l0
003o000000So000000Cooo]Zo`000?l0003o00001_oonfX3o`0000;ooo]Z0ol00002oookJPCo0000
1OoonfX=o`000003oookJ_l0003o000000Oo00000ooonfX5o`0000Gooo]Z1ol000000ooonf[o0000
o`000005o`0000Cooo]Z0ol0000LoookJP00EOoonfX8o`0000;ooo]Z5?l000001?oonf[o0000o`00
0?l00003oookJPOo00000_oonfX7o`0000Cooo]Z3_l00003oookJPgo00001OoonfX<o`000003oook
J_l0003o000000So00000ooonfX7o`0000?ooo]Z0ol00007oookJPOo000000?ooo]Zo`000?l00000
4?l00003oookJPCo00000_oonfX4o`0000Kooo]Z2Ol000000ooonf[o0000o`000008o`000003oook
J_l0003o000000Go00001_oonfX7o`0000;ooo]Z2ol00002oookJPOo000000?ooo]Zo`000?l00000
3Ol00003oookJPSo00000_oonfX5o`0000;ooo]Z3Ol000001?oonf[o0000o`000?l00003oookJP?o
00000ooonfX=o`000003oookJ_l0003o000000Go00000_oonfX3o`000005oookJ_l0003o0000o`00
0?oonfX01_l000000ooonf[o0000o`000002o`0000;ooo]Z1?l00005oookJPCo00001?oonfX;o`00
00Gooo]Z1?l00003oookJPOo00001?oonfX3o`000003oookJ_l0003o000001?o00001?oonfX4o`00
00Kooo]Z3Ol0000ToookJP00EOoonfX8o`0000?ooo]Z4Ol00002oookJP?o00000ooonfX8o`0000;o
oo]Z1ol00004oookJPoo00000_oonfX=o`0000Gooo]Z1?l000000ooonf[o0000o`000003o`0000?o
oo]Z2_l00003oookJPgo00001_oonfX8o`0000;ooo]Z1Ol000000ooonf[o0000o`000008o`0000;o
oo]Z4_l00002oookJPKo00000_oonfX:o`0000?ooo]Z1Ol00006oookJPOo00000_oonfX=o`0000?o
oo]Z0ol00004oookJPgo00000_oonfX:o`000003oookJ_l0003o000000So00000_oonfX4o`000005
oookJ_l0003o0000o`000?oonfX00ol000001?oonf[o0000o`000?l00002oookJQCo000000?ooo]Z
o`000?l000000_l000001?oonf[o0000o`000?l00005oookJPKo000000Cooo]Zo`000?l0003o0000
0ooonfX7o`0000;ooo]Z0ol00003oookJPco000000Cooo]Zo`000?l0003o00000_oonfX4o`0000?o
oo]Z1ol00004oookJP?o000000?ooo]Zo`000?l000004ol00004oookJPCo00002OoonfX7o`0002Oo
oo]Z001EoookJPKo00002?oonfX=o`0000?ooo]Z0ol00003oookJPSo00000_oonfX7o`0000Cooo]Z
6_l000000ooonf[o0000o`000004o`0000;ooo]Z1?l000000ooonf[o0000o`000002o`0000Cooo]Z
1ol000001?oonf[o0000o`000?l00002oookJPgo00001_oonfX3o`0000;ooo]Z1Ol00002oookJP?o
00000ooonfX8o`0000;ooo]Z2ol000000ooonf[o0000o`000006o`0000;ooo]Z0ol00004oookJPco
000000?ooo]Zo`000?l000001?l00002oookJQ?o00000_oonfX3o`0000?ooo]Z0ol00004oookJP_o
00001?oonfX>o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000001_l00002oookJPko
000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`000006o`000005oookJ_l0003o0000o`00
0?oonfX01_l000000ooonf[o0000o`000003o`000003oookJ_l0003o0000013o000000?ooo]Zo`00
0?l000002_l00002oookJPCo00000ooonfX7o`0000Cooo]Z0ol000000ooonf[o0000o`000004o`00
0003oookJ_l0003o000000co000000?ooo]Zo`000?l000001Ol00002oookJPGo000000?ooo]Zo`00
0?l000001?l000000ooonf[o0000o`000003o`000004oookJ_l0003o0000o`0001oooo]Z001Eoook
JPKo00001ooonfX3o`000003oookJ_l0003o000000So00000ooonfX3o`0000;ooo]Z2Ol00002oook
JPOo00001?oonfX3o`0000Wooo]Z3_l000000ooonf[o0000o`000004o`0000?ooo]Z0ol00004oook
JP?o00000_oonfX;o`0000;ooo]Z0ol00003oookJPGo00002?oonfX6o`000004oookJ_l0003o0000
o`0000Sooo]Z2?l00002oookJP?o00000_oonfX6o`000003oookJ_l0003o000000Ko00000_oonfX3
o`000004oookJ_l0003o0000o`0000;ooo]Z2_l00002oookJQ?o000000?ooo]Zo`000?l000000_l0
0004oookJP?o00000ooonfX3o`0000Cooo]Z1ol000001?oonf[o0000o`000?l00004oookJQKo0000
00?ooo]Zo`000?l000005Ol00002oookJP_o00001?oonfX7o`000005oookJ_l0003o0000o`000?oo
nfX00ol00002oookJPOo00000ooonfX@o`000003oookJ_l0003o000000go00002?oonfX5o`000003
oookJ_l0003o000000Co000000?ooo]Zo`000?l000000_l00003oookJP?o00003?oonfX7o`0000;o
oo]Z6?l0000MoookJP00EOoonfX4o`0000Wooo]Z0ol00002oookJP_o00001_oonfX3o`000003oook
J_l0003o000000;o00001OoonfX7o`000005oookJ_l0003o0000o`000?oonfX00ol00005oookJQKo
00000ooonfX3o`0000?ooo]Z2?l00002oookJPOo00000_oonfX6o`0000;ooo]Z0ol00002oookJP?o
00001_oonfX;o`0000Cooo]Z1_l000001?oonf[o0000o`000?l00005oookJPKo00000ooonfX6o`00
00Kooo]Z0ol00002oookJRCo00001OoonfX3o`0000Wooo]Z2ol000001?oonf[o0000o`000?l00006
oookJPKo000000?ooo]Zo`000?l000007ol00002oookJP[o00001ooonfX5o`000005oookJ_l0003o
0000o`000?oonfX03?l00002oookJQ7o000000?ooo]Zo`000?l000003Ol0000=oookJPco00002_oo
nfX3o`0000Gooo]Z0ol00006oookJQSo00007OoonfX005Gooo]Z2?l00003oookJPGo00000_oonfX5
o`000003oookJ_l0003o000000Go00001?oonfX7o`0000Gooo]Z3?l000000ooonf[o0000o`000004
o`0000;ooo]Z5ol00002oookJPCo00000_oonfX8o`0000;ooo]Z1ol00002oookJP_o00000_oonfX4
o`0000Gooo]Z3_l000000ooonf[o0000o`00000Ao`0000Gooo]Z1_l00006oookJP?o00000_oonfXC
o`0000?ooo]Z1?l000000ooonf[o0000o`00000?o`0000Sooo]Z3?l000001?oonf[o0000o`000?l0
0003oookJPKo00001?oonfXRo`000003oookJ_l0003o000000[o00000_oonfX6o`0000Oooo]Z2_l0
00000ooonf[o0000o`00000Do`0000;ooo]Z3?l0000:oookJQ7o00000_oonfX3o`0000?ooo]Z0ol0
0005oookJP?o00001OoonfXKo`0001_ooo]Z001EoookJPSo00000ooonfX5o`000003oookJ_l0003o
000000;o00000ooonfX7o`0000Kooo]Z1Ol000000ooonf[o0000o`000005o`000003oookJ_l0003o
000000Ko000000?ooo]Zo`000?l000001?l00002oookJPSo00000_oonfX=o`0000;ooo]Z3_l00002
oookJPOo000000?ooo]Zo`000?l000002_l00002oookJP_o000000?ooo]Zo`000?l000007?l00000
1Ooonf[o0000o`000?l0003ooo]Z00Ko00002?oonfXEo`0000Gooo]Z9ol00002oookJPKo00000_oo
nfX:o`0000Cooo]Z0ol00002oookJPKo000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00
000Ao`0000;ooo]Z1_l000001?oonf[o0000o`000?l00006oookJPOo000000?ooo]Zo`000?l00000
5?l00002oookJPko00001_oonfX?o`000004oookJ_l0003o0000o`0000;ooo]Z2Ol0000=oookJPCo
000000?ooo]Zo`000?l000001?l000001?oonf[o0000o`000?l00002oookJP[o00006ooonfX005Go
oo]Z2?l00003oookJP[o00001?oonfX6o`000004oookJ_l0003o0000o`0000;ooo]Z1?l00002oook
JQ3o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000007o`0000;ooo]Z2?l000000ooo
nf[o0000o`00000?o`000004oookJ_l0003o0000o`0000;ooo]Z2ol000001?oonf[o0000o`000?l0
0006oookJP[o000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00000Po`0000Sooo]Z3Ol0
00000ooonf[o0000o`000005o`0000;ooo]Z0ol000000ooonf[o0000o`000008o`0000?ooo]Z6?l0
0003oookJP_o000000?ooo]Zo`000?l000001?l00003oookJPCo00000ooonfX3o`0000?ooo]Z2Ol0
00001Ooonf[o0000o`000?l0003ooo]Z01Ko000000?ooo]Zo`000?l000001?l00005oookJPSo0000
00?ooo]Zo`000?l000005?l00002oookJQ7o00000ooonfX?o`000003oookJ_l0003o000000;o0000
00?ooo]Zo`000?l000002_l00008oookJPgo000000Cooo]Zo`000?l0003o00000_oonfX4o`000003
oookJ_l0003o000000?o00006ooonfX005Gooo]Z1ol00004oookJP[o00001?oonfX6o`000004oook
J_l0003o0000o`0000;ooo]Z1?l00002oookJPKo000000?ooo]Zo`000?l000001Ol00003oookJP?o
000000Gooo]Zo`000?l0003o0000oookJP09o`0000;ooo]Z2?l00002oookJPgo00000_oonfX@o`00
00;ooo]Z0ol00002oookJPGo00000ooonfX;o`0000;ooo]Z0ol00002oookJPKo00000ooonfXGo`00
00Cooo]Z3ol00002oookJPOo00000_oonfXDo`0000Gooo]Z2?l000000ooonf[o0000o`000003o`00
00Gooo]Z2ol000000ooonf[o0000o`000004o`0000;ooo]Z1Ol00003oookJPCo00000_oonfX=o`00
0003oookJ_l0003o0000017o00001?oonfX6o`0000Gooo]Z2Ol00002oookJPCo000000Cooo]Zo`00
0?l0003o00001?oonfX6o`0000Kooo]Z0ol00003oookJP_o000000?ooo]Zo`000?l000001_l00003
oookJPWo00000_oonfX7o`000004oookJ_l0003o0000o`0000Sooo]Z4Ol00002oookJPCo000000?o
oo]Zo`000?l000000_l0000LoookJP00EOoonfX7o`0000Cooo]Z5?l000001?oonf[o0000o`000?l0
0002oookJP?o00001_oonfX3o`000004oookJ_l0003o0000o`0000Gooo]Z2Ol000000ooonf[o0000
o`000007o`0000Oooo]Z1?l000000ooonf[o0000o`000007o`000004oookJ_l0003o0000o`0000;o
oo]Z5_l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000[o00000_oonfX5o`0000?o
oo]Z1?l00006oookJPWo000000?ooo]Zo`000?l000002?l00003oookJP[o00000_oonfX3o`0000Co
oo]Z3_l00002oookJPko00001?oonfX3o`0000Cooo]Z1Ol00004oookJPco000000?ooo]Zo`000?l0
00000ol00003oookJPGo00001?oonfX3o`0000;ooo]Z8Ol00004oookJP?o00000_oonfX9o`000003
oookJ_l0003o000000?o000000?ooo]Zo`000?l000001ol00004oookJPKo00003?oonfX3o`0000?o
oo]Z1Ol00004oookJPCo00001?oonfX9o`0000;ooo]Z2ol00008oookJPGo000000?ooo]Zo`000?l0
00002Ol00002oookJP[o00006ooonfX005Gooo]Z8?l00005oookJP?o00000ooonfX6o`000004oook
J_l0003o0000o`0000;ooo]Z3?l00005oookJPGo00001?oonfX7o`000003oookJ_l0003o000000Oo
00001_oonfX3o`0000;ooo]Z4Ol000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Oo
00001OoonfX5o`0000?ooo]Z1?l00006oookJP[o00000_oonfX8o`0000?ooo]Z1ol000001?oonf[o
0000o`000?l00005oookJPOo000000Gooo]Zo`000?l0003o0000oookJP04o`0000?ooo]Z2Ol00002
oookJPKo000000Cooo]Zo`000?l0003o00000ooonfX8o`0000;ooo]Z2?l00007oookJP?o00000_oo
nfX6o`000003oookJ_l0003o000000Co00002?oonfXBo`0000Cooo]Z1Ol000001?oonf[o0000o`00
0?l00004oookJR7o00002?oonfX3o`0000Cooo]Z1?l000000ooonf[o0000o`000004o`000003oook
J_l0003o000000Go00001?oonfX:o`000003oookJ_l0003o000000So00000ooonfX6o`0000Sooo]Z
1_l00003oookJPSo000000Cooo]Zo`000?l0003o00006ooonfX005Gooo]Z4ol00002oookJP_o0000
2ooonfX3o`0000Cooo]Z0ol00002oookJPko00001OoonfX4o`0000?ooo]Z2Ol000000ooonf[o0000
o`000005o`0000cooo]Z1ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000ko0000
1_oonfX5o`0000;ooo]Z1?l00004oookJPOo00000_oonfX3o`0000Cooo]Z1ol00006oookJPOo0000
00?ooo]Zo`000?l000003Ol000001?oonf[o0000o`000?l00002oookJP?o00001?oonfX<o`0000;o
oo]Z0ol00002oookJPSo00000_oonfX;o`0000Wooo]Z1_l000000ooonf[o0000o`000004o`000004
oookJ_l0003o0000o`0000Cooo]Z0ol00002oookJPgo00000_oonfXGo`000003oookJ_l0003o0000
01Ko000000?ooo]Zo`000?l000000ol00002oookJPGo00000ooonfX3o`000005oookJ_l0003o0000
o`000?oonfX02_l00004oookJP[o00000ooonfX3o`0000;ooo]Z1?l00002oookJPKo00002?oonfX5
o`0000Cooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00?o00006ooonfX005Gooo]Z4ol00002
oookJP?o00000_oonfX6o`0000Cooo]Z0ol00003oookJPCo000000?ooo]Zo`000?l000005?l00000
1?oonf[o0000o`000?l00002oookJQ7o000000?ooo]Zo`000?l000000ol00004oookJPKo00000_oo
nfX7o`0000Cooo]Z1Ol000000ooonf[o0000o`00000?o`0000Cooo]Z5?l00005oookJP?o00000_oo
nfX9o`0000?ooo]Z0ol00003oookJQSo00000_oonfX3o`0000;ooo]Z0ol00002oookJPWo00000_oo
nfX3o`0000;ooo]Z2?l00002oookJP_o00001_oonfX@o`000004oookJ_l0003o0000o`0000Gooo]Z
0ol000001Ooonf[o0000o`000?l0003ooo]Z00Ko00001OoonfX3o`000003oookJ_l0003o000001co
00000ooonfX;o`000003oookJ_l0003o000000?o00000_oonfX5o`0000?ooo]Z4_l00003oookJP?o
00000_oonfX>o`000004oookJ_l0003o0000o`0000;ooo]Z1_l00008oookJPGo00001?oonfX4o`00
02?ooo]Z001EoookJPCo00000_oonfX=o`0000;ooo]Z1?l000001?oonf[o0000o`000?l00007oook
JP?o00000ooonfX3o`0000;ooo]Z2Ol00003oookJPKo000000?ooo]Zo`000?l000001Ol00002oook
JQ7o000000?ooo]Zo`000?l000001Ol00002oookJPKo00000ooonfX3o`0000?ooo]Z2Ol000000ooo
nf[o0000o`00000?o`0000?ooo]Z5Ol00007oookJPgo00000_oonfX5o`000003oookJ_l0003o0000
00Oo00000_oonfX:o`0000Gooo]Z2?l00002oookJPKo00001OoonfX5o`0000;ooo]Z0ol00005oook
JP_o00001?oonfXBo`000004oookJ_l0003o0000o`0000;ooo]Z1_l00005oookJP?o00001OoonfX6
o`0000Cooo]Z6_l00004oookJQ7o00001?oonfX5o`0000?ooo]Z1?l000000ooonf[o0000o`000009
o`000003oookJ_l0003o000000?o00001?oonfX<o`000004oookJ_l0003o0000o`0000;ooo]Z1Ol0
0004oookJP?o00000_oonfX5o`0000Cooo]Z1Ol0000RoookJP00EOoonfX4o`0000;ooo]Z1ol00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00001ooo
nfX5o`000004oookJ_l0003o0000o`0000;ooo]Z2Ol00003oookJPKo00001?oonfX4o`0000?ooo]Z
1_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000[o00000_oonfX6o`000005oook
J_l0003o0000o`000?oonfX00ol000000ooonf[o0000o`000005o`0000?ooo]Z1_l000000ooonf[o
0000o`00000?o`0000?ooo]Z1?l000000ooonf[o0000o`000007o`0000Oooo]Z2Ol000001?oonf[o
0000o`000?l00002oookJPGo000000?ooo]Zo`000?l000001_l000001Ooonf[o0000o`000?l0003o
oo]Z00Co000000Cooo]Zo`000?l0003o00001ooonfX9o`000003oookJ_l0003o000000;o00000_oo
nfX3o`0000;ooo]Z0ol00002oookJP?o00001_oonfX:o`0000Cooo]Z1Ol000001?oonf[o0000o`00
0?l00002oookJP[o000000?ooo]Zo`000?l000001_l00005oookJPKo00000_oonfX6o`0000Kooo]Z
1?l00002oookJPgo00000_oonfX3o`0000Oooo]Z2ol00009oookJP?o00000ooonfX;o`000004oook
J_l0003o0000o`0000;ooo]Z1ol00003oookJP_o00001_oonfX8o`000004oookJ_l0003o0000o`00
00;ooo]Z0ol00006oookJPGo00008_oonfX005Gooo]Z1Ol000000ooonf[o0000o`00000;o`000003
oookJ_l0003o000000?o00003?oonfXBo`0000Cooo]Z1_l00004oookJP?o00001OoonfX3o`0000?o
oo]Z3?l000000ooonf[o0000o`000002o`0000Cooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z
00?o000000?ooo]Zo`000?l000001_l00002oookJPGo00000_oonfXAo`0000Cooo]Z0ol000000ooo
nf[o0000o`000007o`0000Oooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00001?oonfX3
o`000003oookJ_l0003o000000Ko000000Cooo]Zo`000?l0003o00000_oonfX3o`0000_ooo]Z3_l0
0002oookJQ;o000000?ooo]Zo`000?l000002?l00004oookJP?o00000_oonfX3o`0000Kooo]Z1ol0
00000ooonf[o0000o`000006o`0000Gooo]Z3_l00006oookJP?o00000ooonfXBo`0000Gooo]Z3Ol0
0009oookJPCo000000?ooo]Zo`000?l000002?l00003oookJP?o00000_oonfX3o`000004oookJ_l0
003o0000o`0000;ooo]Z1_l00002oookJPCo000000Cooo]Zo`000?l0003o00000_oonfX=o`000003
oookJ_l0003o000000co00000_oonfX3o`0001gooo]Z001EoookJPKo00001?oonfX4o`0000;ooo]Z
0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Ko00000_oonfX?o`000003oook
J_l0003o000000;o00001?oonfX6o`0000Gooo]Z0ol00004oookJP?o000000?ooo]Zo`000?l00000
3?l000001?oonf[o0000o`000?l00003oookJPGo00000_oonfX7o`0000;ooo]Z8Ol00004oookJP?o
000000Gooo]Zo`000?l0003o0000oookJP05o`0000?ooo]Z2Ol000001Ooonf[o0000o`000?l0003o
oo]Z00Go000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000006o`000003oookJ_l0003o
000000Co000000?ooo]Zo`000?l000001?l0000:oookJP[o00000_oonfX;o`000003oookJ_l0003o
000000Co00000_oonfX7o`0000_ooo]Z0ol00004oookJQ;o000000Gooo]Zo`000?l0003o0000oook
JP0>o`0000gooo]Z1_l000000ooonf[o0000o`000008o`0000Gooo]Z0ol00004oookJPCo00001?oo
nfX4o`0000;ooo]Z1Ol000000ooonf[o0000o`000008o`0000Sooo]Z0ol000000ooonf[o0000o`00
0009o`0000?ooo]Z0ol000000ooonf[o0000o`00000To`0001gooo]Z001EoookJPWo00000_oonfX4
o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001_l00002oookJPoo00000_oonfX4
o`0000Gooo]Z1?l00002oookJPKo00001?oonfX3o`000003oookJ_l0003o000000Wo00001?oonfX<
o`0000;ooo]Z0ol000000ooonf[o0000o`00000Jo`0000;ooo]Z1ol00002oookJPWo000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000007o`0000Gooo]Z1Ol000000ooonf[o0000o`000008
o`0000Oooo]Z0ol000000ooonf[o0000o`000006o`000004oookJ_l0003o0000o`0000Cooo]Z0ol0
00000ooonf[o0000o`000004o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`00000=o`0000_ooo]Z0ol00003oookJRKo00001ooonfX3o`0000?ooo]Z4?l0
00001?oonf[o0000o`000?l00002oookJP?o00001OoonfX3o`0000Cooo]Z1?l00002oookJPGo0000
00?ooo]Zo`000?l000003Ol00007oookJPSo000000Cooo]Zo`000?l0003o00000_oonfX3o`000003
oookJ_l0003o000002Co00007OoonfX005Gooo]Z2_l00002oookJPco000000?ooo]Zo`000?l00000
1_l000000ooonf[o0000o`000002o`0000;ooo]Z2ol000000ooonf[o0000o`000002o`0000Gooo]Z
3Ol000000ooonf[o0000o`00000?o`000004oookJ_l0003o0000o`0000;ooo]Z3ol000000ooonf[o
0000o`000006o`0000;ooo]Z2_l00003oookJPGo00000ooonfX4o`0000Cooo]Z0ol00002oookJQSo
00001OoonfX7o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000000ol000001Ooonf[o
0000o`000?l0003ooo]Z00co00000ooonfX6o`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?l000001?l000000ooonf[o0000o`00000Fo`0000Cooo]Z0ol000001?oonf[o0000o`000?l00002
oookJQko00000ooonfX4o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00003oookJPOo00001?oo
nfX5o`000004oookJ_l0003o0000o`0000Sooo]Z4_l00002oookJQgo00000ooonfX3o`000004oook
J_l0003o0000o`0000Cooo]Z1ol00002oookJQco00007?oonfX005Gooo]Z1?l000000ooonf[o0000
o`00000?o`0000Cooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00go000000?ooo]Zo`000?l0
00001ol00003oookJPko000000?ooo]Zo`000?l000001ol00004oookJPSo00000_oonfX<o`0000?o
oo]Z2Ol00004oookJPoo00001?oonfX4o`0000Cooo]Z1?l000000ooonf[o0000o`00000Ho`0000?o
oo]Z5ol00002oookJQGo000000Cooo]Zo`000?l0003o00000_oonfX6o`0000?ooo]Z5_l00004oook
JP?o000000Cooo]Zo`000?l0003o00000_oonfX6o`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?l000003?l000000ooonf[o0000o`000003o`000004oookJ_l0003o0000o`0000?ooo]Z1_l0
00001?oonf[o0000o`000?l00004oookJPSo00000_oonfX9o`0000Sooo]Z0ol00002oookJPCo0000
1?oonfX6o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000005_l000000ooonf[o0000
o`000003o`000004oookJ_l0003o0000o`0000Sooo]Z2?l00004oookJQKo00006ooonfX005Gooo]Z
1?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000ko000000?ooo]Zo`000?l00000
3_l00002oookJPWo00000ooonfX8o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l00000
1ol00002oookJPco000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000008o`0000Cooo]Z
3?l00007oookJP?o00000_oonfX3o`000003oookJ_l0003o000000?o00000_oonfXGo`0000;ooo]Z
2_l000000ooonf[o0000o`00000=o`0000Gooo]Z4?l000001Ooonf[o0000o`000?l0003ooo]Z00Wo
000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l00002oookJP?o00001_oonfX4o`00
00?ooo]Z1ol000000ooonf[o0000o`000004o`0000?ooo]Z0ol000000ooonf[o0000o`00000=o`00
00;ooo]Z0ol000000ooonf[o0000o`00000=o`0000Kooo]Z4?l0000:oookJPCo000000?ooo]Zo`00
0?l000000_l000000ooonf[o0000o`00000<o`000003oookJ_l0003o000000Ko00000_oonfX9o`00
0004oookJ_l0003o0000o`0000;ooo]Z0ol00003oookJPGo00001_oonfX8o`000004oookJ_l0003o
0000o`0000;ooo]Z1_l00003oookJP_o00006ooonfX005Gooo]Z1?l000000ooonf[o0000o`000005
o`000003oookJ_l0003o000001?o00000ooonfX9o`0000Cooo]Z1ol00003oookJP?o000000?ooo]Z
o`000?l000000_l000000ooonf[o0000o`000005o`0000?ooo]Z2_l00002oookJP?o000000?ooo]Z
o`000?l000006Ol00002oookJPko000000?ooo]Zo`000?l000001?l00005oookJP?o000000?ooo]Z
o`000?l000002?l000000ooonf[o0000o`000006o`0000Cooo]Z2?l000000ooonf[o0000o`000004
o`000003oookJ_l0003o000001;o00001?oonfX=o`000003oookJ_l0003o000001;o00001ooonfX3
o`0000?ooo]Z0ol000001?oonf[o0000o`000?l00004oookJPKo000000?ooo]Zo`000?l000001?l0
0008oookJP?o00001_oonfX5o`0000;ooo]Z0ol00003oookJPWo000000Cooo]Zo`000?l0003o0000
0ooonfXCo`000003oookJ_l0003o000000Co00001?oonfX3o`000003oookJ_l0003o000000;o0000
00?ooo]Zo`000?l000002ol000000ooonf[o0000o`000005o`0000Cooo]Z1Ol00002oookJPKo0000
0_oonfX3o`0000;ooo]Z1_l00006oookJPKo000000?ooo]Zo`000?l000000ol00002oookJPKo0000
0_oonfX<o`0001_ooo]Z001EoookJPCo000000?ooo]Zo`000?l000007Ol00002oookJPSo00001?oo
nfX4o`0000Kooo]Z7Ol000001?oonf[o0000o`000?l00002oookJP_o00000_oonfX>o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000000ol00006oookJPOo00000_oonfX5o`0000?ooo]Z
2?l000000ooonf[o0000o`000005o`0000Gooo]Z0ol000000ooonf[o0000o`000002o`000003oook
J_l0003o000000Co000000?ooo]Zo`000?l000000_l00004oookJPOo000000?ooo]Zo`000?l00000
0_l00002oookJP?o00000_oonfX6o`000003oookJ_l0003o000001Oo00003?oonfX3o`000004oook
J_l0003o0000o`0000Cooo]Z1_l000000ooonf[o0000o`000004o`0000Sooo]Z1Ol00004oookJPGo
000000Cooo]Zo`000?l0003o00001?oonfX9o`000004oookJ_l0003o0000o`0000?ooo]Z3?l00005
oookJP_o00000_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z4ol00006oookJP?o00001?oo
nfX7o`000005oookJ_l0003o0000o`000?oonfX01ol00007oookJPco000000?ooo]Zo`000?l00000
1Ol000000ooonf[o0000o`000008o`0001gooo]Z001EoookJPWo000000?ooo]Zo`000?l000006?l0
0007oookJP?o00001?oonfX3o`0000Oooo]Z1_l000000ooonf[o0000o`00000Do`000004oookJ_l0
003o0000o`0000?ooo]Z5_l00005oookJPCo00002?oonfXBo`000003oookJ_l0003o0000013o0000
0ooonfX:o`0000Cooo]Z0ol000000ooonf[o0000o`000005o`0000Kooo]Z1ol00002oookJPSo0000
0ooonfX@o`0000?ooo]Z0ol000001?oonf[o0000o`000?l00004oookJP?o00001OoonfX3o`000003
oookJ_l0003o000000?o00000_oonfX3o`000004oookJ_l0003o0000o`0000Wooo]Z0ol00004oook
JPCo00000ooonfX3o`0000?ooo]Z5?l00003oookJPgo00000ooonfX<o`0000;ooo]Z0ol000000ooo
nf[o0000o`00000Jo`0000Wooo]Z1ol000001Ooonf[o0000o`000?l0003ooo]Z00So00001ooonfX;
o`000003oookJ_l0003o000000Go000000Cooo]Zo`000?l0003o00001?oonfX3o`0001gooo]Z001E
oookJPGo00001OoonfX4o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000003?l00007
oookJP?o00003_oonfX6o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002ol00000
1?oonf[o0000o`000?l00003oookJQ?o00002?oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z
4Ol00002oookJPKo00000_oonfX7o`0000Cooo]Z3Ol00002oookJPGo000000?ooo]Zo`000?l00000
1ol00004oookJPSo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000003o`000003oook
J_l0003o000000[o00000_oonfX3o`0000;ooo]Z0ol00004oookJP_o00000ooonfX3o`0000Kooo]Z
1ol00004oookJPCo00001?oonfX9o`0000Cooo]Z3Ol000000ooonf[o0000o`000006o`000003oook
J_l0003o000000Oo000000Cooo]Zo`000?l0003o00000ooonfX<o`0000;ooo]Z0ol000000ooonf[o
0000o`000004o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000003?l0000:oookJQCo
000000Cooo]Zo`000?l0003o00000_oonfX6o`000003oookJ_l0003o000000ko00001?oonfX3o`00
01gooo]Z001EoookJP[o00000ooonfX8o`000003oookJ_l0003o000000co00001_oonfX5o`0000Ko
oo]Z3Ol00004oookJQ3o00003OoonfXCo`0000Cooo]Z2_l000000ooonf[o0000o`000008o`000003
oookJ_l0003o000000Co00000ooonfX6o`0000;ooo]Z1ol00004oookJPgo000000?ooo]Zo`000?l0
00000ol00005oookJPOo00000ooonfX8o`0000;ooo]Z3Ol000000ooonf[o0000o`00000:o`0000;o
oo]Z2_l00002oookJQ7o00000ooonfX:o`0000?ooo]Z1Ol00005oookJPSo00000_oonfX?o`000003
oookJ_l0003o000000;o000000Gooo]Zo`000?l0003o0000oookJP03o`0000?ooo]Z0ol000001?oo
nf[o0000o`000?l00003oookJP[o00000_oonfX5o`000003oookJ_l0003o0000013o00000ooonfX7
o`000004oookJ_l0003o0000o`0000Kooo]Z2ol00002oookJPOo000000?ooo]Zo`000?l000000ol0
0003oookJP?o00001OoonfX;o`0000;ooo]Z0ol0000PoookJP00EOoonfX:o`0000;ooo]Z2Ol00000
0ooonf[o0000o`000006o`0000?ooo]Z1_l00003oookJPGo00001OoonfX;o`0000Kooo]Z1ol00000
1?oonf[o0000o`000?l00003oookJP?o00003ooonfX6o`000003oookJ_l0003o000000_o000000?o
oo]Zo`000?l000006_l00003oookJPGo000000?ooo]Zo`000?l000001ol00004oookJPgo000000?o
oo]Zo`000?l000000ol00002oookJP[o00000ooonfX=o`000003oookJ_l0003o000000Oo000000?o
oo]Zo`000?l000000ol00002oookJPGo00000_oonfX5o`0000;ooo]Z3Ol00002oookJPKo00001?oo
nfX3o`0000;ooo]Z1Ol00003oookJPCo00001_oonfX8o`0000;ooo]Z0ol00002oookJP_o000000Go
oo]Zo`000?l0003o0000oookJP03o`0000Gooo]Z1?l00002oookJPOo00000_oonfX5o`0000Cooo]Z
0ol00006oookJPoo00000ooonfX5o`0000?ooo]Z0ol00006oookJPoo000000?ooo]Zo`000?l00000
2Ol00007oookJQ?o000000Cooo]Zo`000?l0003o00007?oonfX005Gooo]Z2_l00002oookJQ;o0000
0ooonfX>o`0000Gooo]Z2ol00006oookJPOo00003ooonfX3o`0000;ooo]Z3ol00004oookJQGo0000
00?ooo]Zo`000?l000000_l000001Ooonf[o0000o`000?l0003ooo]Z00?o00000ooonfX6o`000003
oookJ_l0003o000000Oo00001ooonfX:o`000003oookJ_l0003o000000?o00000_oonfX3o`0000Co
oo]Z0ol00002oookJPCo00001?oonfX6o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l0
00000_l00003oookJPCo00001OoonfX4o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l0
00004?l00002oookJPKo00000_oonfX3o`0000Kooo]Z2Ol00002oookJP?o00000_oonfX;o`000003
oookJ_l0003o000000?o00001ooonfX4o`0000;ooo]Z1ol000000ooonf[o0000o`000004o`0000Co
oo]Z0ol00003oookJQ3o000000?ooo]Zo`000?l000004Ol0000;oookJQ;o00001ooonfX3o`0000;o
oo]Z4_l0000LoookJP00EOoonfXNo`000004oookJ_l0003o0000o`0000;ooo]Z3ol000001Ooonf[o
0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000000ol00004oookJPOo000000Cooo]Zo`00
0?l0003o00001_oonfX3o`0000;ooo]Z0ol00002oookJPoo00000_oonfX3o`000003oookJ_l0003o
000000So00000ooonfX6o`000004oookJ_l0003o0000o`0000;ooo]Z0ol000000ooonf[o0000o`00
000:o`000003oookJ_l0003o000000Go00002OoonfX:o`000003oookJ_l0003o000000?o00000_oo
nfX3o`0000;ooo]Z1Ol00002oookJPGo00000ooonfX4o`0000?ooo]Z5Ol000000ooonf[o0000o`00
0006o`0000;ooo]Z2?l000000ooonf[o0000o`000008o`000003oookJ_l0003o000000Ko000000?o
oo]Zo`000?l000001?l00002oookJPGo00000_oonfX;o`0000Cooo]Z0ol00003oookJP[o000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`00000Eo`0000[ooo]Z1_l00002oookJPSo000000?o
oo]Zo`000?l000000_l000000ooonf[o0000o`000005o`0000?ooo]Z1?l00009oookJQ3o000000Go
oo]Zo`000?l0003o0000oookJP05o`000004oookJ_l0003o0000o`0000;ooo]Z4_l0000LoookJP00
EOoonfXNo`000003oookJ_l0003o000001;o00002ooonfX3o`0000Oooo]Z2?l00004oookJQ_o0000
0_oonfX<o`0000;ooo]Z2?l00002oookJP?o00001_oonfX<o`0000?ooo]Z1Ol00007oookJPco0000
00Cooo]Zo`000?l0003o00001?oonfX3o`0000;ooo]Z3ol000000ooonf[o0000o`00000Io`000003
oookJ_l0003o000000Ko00000_oonfX5o`0000Cooo]Z4ol000000ooonf[o0000o`000004o`0000;o
oo]Z4_l00004oookJQco000000?ooo]Zo`000?l000001?l00002oookJP[o000000Cooo]Zo`000?l0
003o00000_oonfX9o`0000;ooo]Z2Ol000000ooonf[o0000o`000002o`000005oookJ_l0003o0000
o`000?oonfX00ol00003oookJPCo00001_oonfX8o`000003oookJ_l0003o000000Co000000Cooo]Z
o`000?l0003o00001OoonfX:o`000003oookJ_l0003o0000013o00007?oonfX005Gooo]Z1ol00000
0ooonf[o0000o`00000<o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000005?l00008
oookJPCo00000_oonfX3o`0000;ooo]Z2ol000000ooonf[o0000o`00000Io`0000;ooo]Z3?l00000
0ooonf[o0000o`00000?o`0000?ooo]Z2ol00004oookJP?o00000_oonfX3o`0000Cooo]Z1?l00000
1Ooonf[o0000o`000?l0003ooo]Z00?o000000Cooo]Zo`000?l0003o00000_oonfX5o`0000;ooo]Z
3ol000000ooonf[o0000o`000009o`0000;ooo]Z9Ol000000ooonf[o0000o`00000>o`0000;ooo]Z
0ol000000ooonf[o0000o`00000Co`0000?ooo]Z7?l000000ooonf[o0000o`000004o`0000Cooo]Z
1?l00005oookJP?o00000_oonfX4o`0000;ooo]Z0ol00002oookJPSo00001_oonfX7o`0000Gooo]Z
0ol00006oookJPoo00002OoonfXNo`0001_ooo]Z001EoookJPOo000000?ooo]Zo`000?l000000_l0
0004oookJPGo00000_oonfX7o`000003oookJ_l0003o000000Co00000_oonfX5o`000003oookJ_l0
003o000000Ko00002?oonfX9o`0000;ooo]Z2ol000000ooonf[o0000o`00000Ho`0000Gooo]Z1?l0
0002oookJP?o00000_oonfXCo`0000?ooo]Z1Ol000000ooonf[o0000o`000005o`0000?ooo]Z1ol0
0002oookJPCo000000Gooo]Zo`000?l0003o0000oookJP03o`0000Kooo]Z1Ol00003oookJPko0000
1?oonfX:o`0000;ooo]Z1?l00004oookJQ[o00000_oonfX3o`000003oookJ_l0003o000000?o0000
1?oonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`00000Co`000003oookJ_l0003o000000oo0000
00?ooo]Zo`000?l000004Ol00004oookJP?o00000ooonfX6o`0000;ooo]Z2Ol00002oookJPSo0000
0_oonfX3o`000003oookJ_l0003o000000Oo00000ooonfX5o`0000;ooo]Z4Ol0000:oookJQSo0000
00?ooo]Zo`000?l000000_l0000KoookJP00EOoonfX7o`000003oookJ_l0003o000000?o00001?oo
nfX;o`0000?ooo]Z2ol00003oookJP_o000000Gooo]Zo`000?l0003o0000oookJP09o`0000Cooo]Z
3ol000000ooonf[o0000o`00000Bo`0000Kooo]Z0ol00003oookJP?o000000?ooo]Zo`000?l00000
4Ol000000ooonf[o0000o`00000Go`0000?ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z
0ol000000ooonf[o0000o`00000@o`0000Cooo]Z1_l00005oookJPco00000_oonfXNo`0000Cooo]Z
0ol00006oookJPKo00000_oonfX>o`0000;ooo]Z1_l000000ooonf[o0000o`000007o`0000Gooo]Z
1ol00002oookJPWo00000_oonfX3o`0000Cooo]Z2Ol00008oookJP?o00001OoonfX8o`0000;ooo]Z
0ol000000ooonf[o0000o`000007o`0000?ooo]Z1_l000001?oonf[o0000o`000?l00002oookJPoo
00000_oonfX3o`000003oookJ_l0003o000001Oo00000_oonfX3o`0001_ooo]Z001EoookJPCo0000
1_oonfX3o`0000;ooo]Z3Ol00003oookJP_o00000ooonfX;o`000003oookJ_l0003o000000?o0000
0_oonfX6o`0000?ooo]Z4?l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000Co0000
00Cooo]Zo`000?l0003o00001OoonfX5o`0000;ooo]Z0ol000000ooonf[o0000o`00000Ao`000003
oookJ_l0003o000001co00000ooonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`00000:o`000003
oookJ_l0003o000000?o000000?ooo]Zo`000?l000002?l00004oookJPco00000_oonfX4o`000003
oookJ_l0003o000000;o00000_oonfX3o`000003oookJ_l0003o000000Oo00000ooonfX4o`0000?o
oo]Z0ol000001?oonf[o0000o`000?l00005oookJP?o00000_oonfX7o`0000;ooo]Z1Ol00002oook
JPKo000000?ooo]Zo`000?l000002ol00003oookJPGo00000_oonfX3o`000003oookJ_l0003o0000
00?o00000_oonfX3o`0000Oooo]Z1_l00008oookJP?o00001OoonfX9o`000004oookJ_l0003o0000
o`0000?ooo]Z1ol000001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000001?l0
0002oookJP?o000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l00002oookJP?o0000
00?ooo]Zo`000?l000002?l00003oookJP?o000000?ooo]Zo`000?l000001ol0000OoookJP00EOoo
nfX=o`0000;ooo]Z0ol00003oookJPOo00000ooonfX;o`0000Kooo]Z2?l000000ooonf[o0000o`00
000;o`0000;ooo]Z3_l000001?oonf[o0000o`000?l00003oookJPoo00000_oonfX3o`0000;ooo]Z
2_l000000ooonf[o0000o`000006o`0000?ooo]Z1Ol00004oookJP?o00000_oonfX7o`000003oook
J_l0003o000000Co00000_oonfXDo`000003oookJ_l0003o0000013o000000?ooo]Zo`000?l00000
2?l00004oookJPWo00000ooonfX6o`0000Oooo]Z0ol000000ooonf[o0000o`00000>o`0000?ooo]Z
0ol000001?oonf[o0000o`000?l00005oookJP[o00001?oonfX5o`0000;ooo]Z0ol00002oookJQKo
00001ooonfX3o`0000Kooo]Z0ol00002oookJPSo00004OoonfX3o`000003oookJ_l0003o000000?o
00002?oonfX5o`0000;ooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000001ol000001?oonf[o
0000o`000?l00004oookJP?o00000_oonfX3o`000005oookJ_l0003o0000o`000?oonfX01_l00007
oookJPWo00007ooonfX005Gooo]Z3Ol000000ooonf[o0000o`000002o`0000Gooo]Z1Ol00005oook
JP?o000000?ooo]Zo`000?l000000ol00002oookJP?o000000?ooo]Zo`000?l000005Ol000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000000Go00000ooonfX6o`0000;ooo]Z1_l00002oook
JPGo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00000?o`000004oookJ_l0003o0000
o`0000Cooo]Z0ol00006oookJPKo000000Cooo]Zo`000?l0003o00001?oonfX3o`000003oookJ_l0
003o000000_o00000ooonfX4o`0000;ooo]Z2?l000000ooonf[o0000o`000003o`000003oookJ_l0
003o000000co000000Gooo]Zo`000?l0003o0000oookJP06o`0000;ooo]Z1ol00002oookJPGo0000
0_oonfX3o`000003oookJ_l0003o000000ko00000ooonfX3o`000004oookJ_l0003o0000o`0000Ko
oo]Z1?l00004oookJP?o00000_oonfX3o`0000Cooo]Z0ol00002oookJQSo000000Cooo]Zo`000?l0
003o00002_oonfX8o`000003oookJ_l0003o000000Co00000ooonfX7o`0000Gooo]Z0ol000000ooo
nf[o0000o`000003o`0000Kooo]Z1ol000000ooonf[o0000o`000002o`0000;ooo]Z4Ol0000Aoook
JPWo00001ooonfX6o`0001oooo]Z001EoookJQGo00000_oonfX5o`0000Gooo]Z0ol000000ooonf[o
0000o`000003o`0000;ooo]Z1?l000000ooonf[o0000o`000002o`0000;ooo]Z6Ol00004oookJPWo
000000?ooo]Zo`000?l000001Ol00004oookJP?o000000?ooo]Zo`000?l000000_l000000ooonf[o
0000o`00000>o`0000;ooo]Z1Ol0000;oookJP[o00001?oonfX3o`000005oookJ_l0003o0000o`00
0?oonfX01?l00002oookJP?o00000ooonfX4o`0000;ooo]Z1?l000001?oonf[o0000o`000?l00002
oookJPCo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000004o`0000;ooo]Z0ol00000
0ooonf[o0000o`000004o`0000;ooo]Z2?l000000ooonf[o0000o`000003o`0000;ooo]Z0ol00003
oookJPKo000000?ooo]Zo`000?l000003ol00006oookJPOo000000Cooo]Zo`000?l0003o00000ooo
nfX3o`0000Sooo]Z7?l00006oookJP?o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`00
000<o`000003oookJ_l0003o000000?o00000ooonfX4o`0000Oooo]Z1ol000001?oonf[o0000o`00
0?l00003oookJQ7o00000ooonfX3o`0000Cooo]Z0ol00004oookJPWo00002?oonfX6o`0001kooo]Z
001EoookJQgo00001?oonfX8o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000003Ol0
00000ooonf[o0000o`000005o`000003oookJ_l0003o000000?o00001_oonfX9o`000003oookJ_l0
003o000000Co00002?oonfX9o`0000;ooo]Z4_l0000;oookJP[o00000ooonfX8o`000003oookJ_l0
003o000000;o00003_oonfX4o`000004oookJ_l0003o0000o`0000;ooo]Z1?l000000ooonf[o0000
o`000004o`0000Cooo]Z0ol00002oookJP?o00000ooonfXDo`0000;ooo]Z0ol00003oookJPKo0000
1OoonfX=o`0000Wooo]Z1?l000001?oonf[o0000o`000?l00003oookJP?o00002_oonfX8o`000005
oookJ_l0003o0000o`000?oonfX03Ol000001?oonf[o0000o`000?l00002oookJP?o00000ooonfX4
o`000003oookJ_l0003o0000013o000000?ooo]Zo`000?l000003Ol00003oookJPOo00000_oonfX3
o`0000?ooo]Z2ol000000ooonf[o0000o`000002o`0000Cooo]Z0ol00004oookJP?o000000?ooo]Z
o`000?l000002_l00008oookJPOo00007OoonfX005Gooo]Z2?l00005oookJPco000000Cooo]Zo`00
0?l0003o00001_oonfX5o`0000;ooo]Z1_l000000ooonf[o0000o`00000Lo`0000?ooo]Z4_l00008
oookJPWo00000ooonfX3o`0000Oooo]Z1ol00002oookJP?o00000_oonfX3o`000003oookJ_l0003o
000001;o00000_oonfX4o`0000[ooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00So00000_oo
nfX5o`0000Oooo]Z1?l000001?oonf[o0000o`000?l00002oookJQ;o00000ooonfX3o`0000?ooo]Z
2Ol00002oookJPgo00002OoonfX4o`000004oookJ_l0003o0000o`0000?ooo]Z0ol00004oookJPCo
00000_oonfX8o`000003oookJ_l0003o000000?o00000_oonfX3o`000003oookJ_l0003o000000Co
000000?ooo]Zo`000?l000001_l00004oookJQCo00000ooonfX?o`0000?ooo]Z2Ol00002oookJP?o
000000?ooo]Zo`000?l000002Ol00009oookJPCo00000ooonfX3o`000003oookJ_l0003o000000Wo
00000ooonfX3o`0000?ooo]Z1ol0000MoookJP00EOoonfX:o`0000[ooo]Z1Ol000001?oonf[o0000
o`000?l00006oookJP?o00000_oonfX5o`0000Gooo]Z2?l00003oookJQ;o00000ooonfXBo`0000So
oo]Z2Ol0000=oookJPGo00000ooonfX4o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000?o
oo]Z3Ol00002oookJPKo00002?oonfX4o`0000?ooo]Z1ol000001?oonf[o0000o`000?l00003oook
JPCo00001_oonfX4o`000004oookJ_l0003o0000o`0000;ooo]Z2ol000001?oonf[o0000o`000?l0
0002oookJP?o00001ooonfX9o`0000Cooo]Z2_l00005oookJPCo000000?ooo]Zo`000?l000002?l0
0008oookJPCo00000_oonfX8o`000003oookJ_l0003o000000Ko00001_oonfX9o`0000;ooo]Z6Ol0
0003oookJPWo00000_oonfX4o`0000?ooo]Z3_l00002oookJP[o00000ooonfX3o`0000?ooo]Z1?l0
0007oookJPGo00000_oonfX5o`0000;ooo]Z0ol00003oookJPOo00007OoonfX005Gooo]Z2_l00000
0ooonf[o0000o`000002o`0000Cooo]Z1_l00003oookJP?o000000?ooo]Zo`000?l000003Ol00005
oookJPOo000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000007o`000003oookJ_l0003o
0000017o00000ooonfX3o`0000?ooo]Z2Ol0000=oookJP?o000000Gooo]Zo`000?l0003o0000oook
JP04o`0000;ooo]Z0ol00002oookJPco000000Gooo]Zo`000?l0003o0000oookJP05o`0000;ooo]Z
0ol00008oookJPCo00000_oonfX8o`000003oookJ_l0003o000000?o00000_oonfX3o`0000?ooo]Z
4?l00004oookJP?o00000_oonfX3o`000003oookJ_l0003o000000;o00000ooonfX@o`000005oook
J_l0003o0000o`000?oonfX01Ol000001?oonf[o0000o`000?l00002oookJPoo00001ooonfX5o`00
0003oookJ_l0003o000001?o00000ooonfX9o`0000;ooo]Z4?l000000ooonf[o0000o`000006o`00
00?ooo]Z2?l00004oookJQgo00000_oonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z1Ol00007
oookJPCo000000?ooo]Zo`000?l000001?l00002oookJP?o00001OoonfX4o`0001kooo]Z001Eoook
JP[o000000?ooo]Zo`000?l000000_l00004oookJPKo00000ooonfX3o`000003oookJ_l0003o0000
00go000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0003o000000Ko00000_oonfX3
o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000_o000000?ooo]Z
o`000?l000006?l00003oookJPKo000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0
003o000000;o000000?ooo]Zo`000?l000000_l00002oookJPKo00001ooonfX3o`000003oookJ_l0
003o000000?o000000?ooo]Zo`000?l000001ol00004oookJP?o00000_oonfX?o`000004oookJ_l0
003o0000o`0000?ooo]Z7?l000000ooonf[o0000o`000002o`0000?ooo]Z1ol000000ooonf[o0000
o`000002o`000005oookJ_l0003o0000o`000?oonfX03Ol00002oookJPOo000000?ooo]Zo`000?l0
00001Ol00004oookJPOo00000_oonfX7o`000003oookJ_l0003o000000_o00001OoonfX6o`0000?o
oo]Z4?l000000ooonf[o0000o`000002o`000004oookJ_l0003o0000o`0000?ooo]Z2?l00006oook
JP[o00000ooonfX3o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000001Ol00002oook
JPWo00002OoonfX:o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001?l0000Loook
JP00EOoonfX:o`000003oookJ_l0003o000000;o00001?oonfX6o`0000?ooo]Z0ol000000ooonf[o
0000o`00000Qo`0000;ooo]Z1Ol00002oookJP?o000000?ooo]Zo`000?l000001_l00003oookJP?o
00000_oonfXHo`0000?ooo]Z3_l00002oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPKo
00002ooonfX5o`000003oookJ_l0003o000000Oo00000ooonfX4o`000003oookJ_l0003o000000ko
00001ooonfXDo`0000?ooo]Z1Ol000000ooonf[o0000o`000002o`0000?ooo]Z3?l000001Ooonf[o
0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`000007o`00
0004oookJ_l0003o0000o`0000Cooo]Z5Ol00003oookJPSo000000?ooo]Zo`000?l000000_l00000
1?oonf[o0000o`000?l00002oookJP[o00000_oonfX3o`0000Sooo]Z1Ol00003oookJPGo000000?o
oo]Zo`000?l000008?l000000ooonf[o0000o`000005o`0000;ooo]Z7?l000000ooonf[o0000o`00
0009o`0001cooo]Z001EoookJPCo00000_oonfX8o`0000Kooo]Z1Ol00005oookJP?o00000_oonfX6
o`0000?ooo]Z3?l000001Ooonf[o0000o`000?l0003ooo]Z00Ko00000_oonfX4o`0000?ooo]Z0ol0
0002oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX3o`0000?ooo]Z4?l000000ooonf[o0000
o`000005o`0000;ooo]Z2Ol000001?oonf[o0000o`000?l00003oookJP?o000000?ooo]Zo`000?l0
00000_l00002oookJPKo00001_oonfX3o`0000Cooo]Z0ol000000ooonf[o0000o`000007o`000003
oookJ_l0003o000000Co000000?ooo]Zo`000?l000003_l0000:oookJQ7o00000ooonfX5o`0000Oo
oo]Z0ol00003oookJPOo000000?ooo]Zo`000?l000001_l00003oookJQ3o000000?ooo]Zo`000?l0
00001?l00004oookJPWo000000?ooo]Zo`000?l000002?l00004oookJPgo00001_oonfX5o`0000Oo
oo]Z0ol0000:oookJP_o000000?ooo]Zo`000?l000008?l00003oookJPCo00000_oonfXMo`000003
oookJ_l0003o000000Wo00007?oonfX005Gooo]Z1Ol000000ooonf[o0000o`000006o`0000Kooo]Z
1Ol00004oookJPCo00000ooonfX3o`0000Gooo]Z3?l00005oookJPKo000000?ooo]Zo`000?l00000
0ol00003oookJPSo000000Cooo]Zo`000?l0003o00000_oonfX4o`0000Kooo]Z1Ol00003oookJPKo
00000_oonfX5o`0000;ooo]Z3_l00008oookJP?o000000?ooo]Zo`000?l000000_l00003oookJPSo
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`0000;ooo]Z0ol000000ooonf[o
0000o`00000<o`0000;ooo]Z1ol00007oookJQ3o000000Cooo]Zo`000?l0003o00000ooonfX6o`00
00Kooo]Z4?l000000ooonf[o0000o`000002o`000003oookJ_l0003o0000017o000000?ooo]Zo`00
0?l000001?l00002oookJP_o00001?oonfX9o`000003oookJ_l0003o000000co00001_oonfX6o`00
0004oookJ_l0003o0000o`0000;ooo]Z0ol0000:oookJROo00001ooonfX6o`0000?ooo]Z0ol00000
1?oonf[o0000o`000?l00003oookJQ7o00000ooonfX;o`0001cooo]Z001EoookJPCo00001_oonfX3
o`0000Oooo]Z4ol00006oookJPko00000ooonfX4o`0000;ooo]Z4?l000001?oonf[o0000o`000?l0
0002oookJPCo00000ooonfX6o`0000Gooo]Z1_l00002oookJPKo000000?ooo]Zo`000?l000003?l0
00001?oonf[o0000o`000?l00004oookJP?o00000_oonfX5o`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`0000;ooo]Z0ol000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000Go00001?oonfX5o`0000Wooo]Z5?l00003oookJQ;o0000
0_oonfX8o`000003oookJ_l0003o000000Ko00000_oonfX>o`000003oookJ_l0003o000000Co0000
0_oonfX4o`000003oookJ_l0003o000000Ko00000_oonfX9o`000003oookJ_l0003o000000Go0000
0_oonfX3o`0000Wooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00Co00000_oonfX3o`0000;o
oo]Z0ol000000ooonf[o0000o`00000<o`0000?ooo]Z1_l00003oookJPGo000000?ooo]Zo`000?l0
00001?l00005oookJPWo00000_oonfX4o`0000;ooo]Z0ol00004oookJP?o00000ooonfX:o`000003
oookJ_l0003o000000Oo00007_oonfX005Gooo]Z1?l0000?oookJPgo000000?ooo]Zo`000?l00000
1?l00005oookJPWo00000_oonfX<o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l00000
2?l00002oookJP?o00000_oonfX9o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z
3Ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000Wo00000ooonfX3o`000003oook
J_l0003o000001;o00000_oonfX3o`0000;ooo]Z5?l00005oookJP?o000000?ooo]Zo`000?l00000
4_l00003oookJPco000000?ooo]Zo`000?l000000ol00005oookJPOo000000?ooo]Zo`000?l00000
1Ol000001?oonf[o0000o`000?l00004oookJPOo000000?ooo]Zo`000?l000000ol00003oookJPCo
000000Gooo]Zo`000?l0003o0000oookJP04o`0000;ooo]Z1Ol000001Ooonf[o0000o`000?l0003o
oo]Z00?o000000Gooo]Zo`000?l0003o0000oookJP03o`0000Cooo]Z1Ol000000ooonf[o0000o`00
0003o`000005oookJ_l0003o0000o`000?oonfX01?l00002oookJP?o000000?ooo]Zo`000?l00000
0_l000001Ooonf[o0000o`000?l0003ooo]Z00Wo00001?oonfX6o`0000;ooo]Z3?l00006oookJPWo
00000_oonfX:o`0000?ooo]Z0ol00003oookJP?o000000?ooo]Zo`000?l000002?l00003oookJPCo
00007OoonfX005Gooo]Z2Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX<o`0000;o
oo]Z1Ol00003oookJPco00000_oonfX<o`0000;ooo]Z2?l000000ooonf[o0000o`00000;o`0000Co
oo]Z2Ol00002oookJP?o000000Cooo]Zo`000?l0003o00000ooonfXEo`000003oookJ_l0003o0000
00[o00000_oonfX4o`000003oookJ_l0003o0000013o00002?oonfXDo`0000Gooo]Z0ol000001?oo
nf[o0000o`000?l00002oookJPoo000000?ooo]Zo`000?l000003?l000001?oonf[o0000o`000?l0
0009oookJPGo000000?ooo]Zo`000?l000001Ol000001Ooonf[o0000o`000?l0003ooo]Z00Ko0000
1_oonfX6o`0000;ooo]Z0ol00002oookJPko00002?oonfX8o`0000Cooo]Z1Ol000000ooonf[o0000
o`000005o`0000;ooo]Z1Ol00002oookJP?o000000?ooo]Zo`000?l000000_l000001Ooonf[o0000
o`000?l0003ooo]Z00Wo00001ooonfX3o`0000;ooo]Z2?l000001?oonf[o0000o`000?l00003oook
JPko000000?ooo]Zo`000?l000001ol00003oookJP?o00000ooonfX3o`000003oookJ_l0003o0000
00Oo00001OoonfX3o`0001gooo]Z001EoookJPgo000000?ooo]Zo`000?l000003ol0000:oookJQ[o
00000_oonfXBo`000004oookJ_l0003o0000o`0000Cooo]Z4_l00003oookJPSo000000Gooo]Zo`00
0?l0003o0000oookJP08o`0000?ooo]Z2ol000000ooonf[o0000o`000002o`0000Cooo]Z3Ol00007
oookJPWo00000_oonfX<o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00002oookJPoo000000?o
oo]Zo`000?l000002_l0000AoookJPGo000000?ooo]Zo`000?l000000ol00005oookJPKo00001Ooo
nfX<o`0000;ooo]Z0ol000000ooonf[o0000o`000008o`000004oookJ_l0003o0000o`0000Cooo]Z
2?l00004oookJPgo00000_oonfX5o`0000Kooo]Z4Ol00007oookJP?o00000ooonfX<o`0000?ooo]Z
3_l00002oookJPSo00003ooonfX7o`0000Gooo]Z1Ol0000KoookJP00EOoonfX=o`000003oookJ_l0
003o000000Oo000000?ooo]Zo`000?l000003_l000001Ooonf[o0000o`000?l0003ooo]Z01Ko0000
0_oonfX@o`0000?ooo]Z1_l00003oookJQWo000000?ooo]Zo`000?l000000ol000000ooonf[o0000
o`000006o`0000?ooo]Z2ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000?o0000
0_oonfX3o`0000;ooo]Z1Ol00003oookJPOo00001OoonfX8o`0000Gooo]Z1Ol00002oookJQ3o0000
1OoonfX5o`0000;ooo]Z1_l00004oookJPKo000000?ooo]Zo`000?l000000_l00002oookJPCo0000
00?ooo]Zo`000?l000001Ol00003oookJP?o00001OoonfX>o`000003oookJ_l0003o000000?o0000
00?ooo]Zo`000?l000000ol00002oookJPOo00001?oonfX;o`0000;ooo]Z0ol000000ooonf[o0000
o`00000To`0000;ooo]Z0ol00002oookJQ;o00000_oonfX;o`000004oookJ_l0003o0000o`0000Co
oo]Z1_l00005oookJPOo00000_oonfX7o`0000Sooo]Z0ol0000KoookJP00EOoonfX4o`000003oook
J_l0003o000000Co00001?oonfX9o`000003oookJ_l0003o000000go00001OoonfX5o`000003oook
J_l0003o000000_o00001OoonfX>o`0000Gooo]Z1_l00003oookJPgo000000?ooo]Zo`000?l00000
2Ol000000ooonf[o0000o`000003o`0000Cooo]Z1Ol000000ooonf[o0000o`00000Go`0000Wooo]Z
1Ol00002oookJPSo000000?ooo]Zo`000?l000002Ol00006oookJPGo00000_oonfXDo`0000;ooo]Z
3_l00002oookJPKo000000?ooo]Zo`000?l000004?l00003oookJPGo00000ooonfX6o`000003oook
J_l0003o000000_o00000_oonfX3o`0000Gooo]Z1Ol00003oookJPco00000_oonfX3o`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000006Ol00002oookJP?o000000?ooo]Zo`000?l00000
2Ol00002oookJPKo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000003o`0000Cooo]Z
0ol00004oookJP?o00001OoonfX7o`0000;ooo]Z2?l000001?oonf[o0000o`000?l00003oookJP?o
00006ooonfX001gooo]Z00?ogMU/oookJ_oonfX01OoonfX00ooMfFcooo]ZoookJP0]oookJPWo0000
2?oonfX7o`000003oookJ_l0003o000000go00001OoonfX5o`000003oookJ_l0003o000000Co0000
0ooonfX5o`0000Kooo]Z2ol00007oookJQ3o000000Cooo]Zo`000?l0003o00000_oonfX;o`000005
oookJ_l0003o0000o`000?oonfX00ol00002oookJPCo00000_oonfXIo`0000Wooo]Z1Ol00002oook
JPSo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000004o`0000;ooo]Z0ol00002oook
JP?o000000?ooo]Zo`000?l000003?l00002oookJPGo00000_oonfX>o`0000;ooo]Z1_l000000ooo
nf[o0000o`000004o`000003oookJ_l0003o000000Wo00000_oonfX6o`000003oookJ_l0003o0000
00Co00000ooonfX=o`0000;ooo]Z0ol00005oookJPGo00000ooonfXAo`0000;ooo]Z7Ol00003oook
JPCo00000ooonfXAo`000004oookJ_l0003o0000o`0000?ooo]Z1_l000000ooonf[o0000o`000006
o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001?l00003oookJPOo00000_oonfX8
o`000003oookJ_l0003o000000Ko00007?oonfX001;ooo]Z1Ol007l5oookJP03omgIK?l007ooEE=g
00Gooo]Z00?oEE=go`00Ooo<b6h01ooonfX3o`00O`Gooo]Z1Ol007lJoookJPWo00002OoonfX6o`00
0003oookJ_l0003o000000Ko00000_oonfX4o`0000Sooo]Z2?l000000ooonf[o0000o`000009o`00
00Cooo]Z3Ol00005oookJP[o000000Gooo]Zo`000?l0003o0000oookJP05o`0000;ooo]Z3?l00004
oookJP?o00000_oonfX3o`0000?ooo]Z1Ol000000ooonf[o0000o`00000Ao`0000Cooo]Z5?l00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000Co00000_oonfX3o`0000;ooo]Z1ol00000
0ooonf[o0000o`000004o`0000Cooo]Z2Ol000000ooonf[o0000o`00000;o`0000?ooo]Z0ol00004
oookJPGo00000ooonfX4o`000004oookJ_l0003o0000o`0000?ooo]Z1_l000000ooonf[o0000o`00
0004o`0000?ooo]Z1Ol000000ooonf[o0000o`000005o`0000_ooo]Z0ol00002oookJQ?o000000?o
oo]Zo`000?l000001_l00002oookJP[o00000_oonfX9o`0000;ooo]Z1?l00004oookJQ3o000000Co
oo]Zo`000?l0003o00000ooonfX:o`0000;ooo]Z4?l00006oookJP?o00001_oonfX?o`0001_ooo]Z
000AoookJPOo001o1OoonfX00omEDgOo001ooeECM`03oookJP04oeECMol007oo8B5lonkZJ`Oooo]Z
0ol007l4oookJPOo001o6OoonfX<o`0000Kooo]Z1_l000000ooonf[o0000o`000007o`000003oook
J_l0003o000000So00000_oonfX8o`000003oookJ_l0003o000000[o00000ooonfX5o`000003oook
J_l0003o000000Wo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000003o`000005oook
J_l0003o0000o`000?oonfX01_l000000ooonf[o0000o`000005o`0000;ooo]Z0ol00004oookJP?o
00000_oonfX5o`0000;ooo]Z0ol000000ooonf[o0000o`00000@o`000003oookJ_l0003o000000;o
000000?ooo]Zo`000?l000004_l00004oookJPWo000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`000005o`0000;ooo]Z1_l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000Go
000000?ooo]Zo`000?l000001ol00003oookJPGo00000_oonfX5o`0000;ooo]Z1?l00007oookJPOo
000000?ooo]Zo`000?l000001?l00004oookJPCo000000?ooo]Zo`000?l000001Ol0000;oookJP_o
00000_oonfX;o`000003oookJ_l0003o000001;o00000_oonfX9o`0000;ooo]Z3?l00002oookJPko
00001_oonfX6o`0000?ooo]Z4?l00005oookJPOo00000ooonfX?o`0001_ooo]Z000@oookJPCo001o
00Cooo]Zo`00Ool007oo001o1_oonfX02?mEDgOo001ooeECMooonf[oEE=go`00OolQ8Gcok^Y[2?oo
nfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007lIoookJPco00001_oonfX7o`000003oook
J_l0003o000000Ko000000?ooo]Zo`000?l000002?l00004oookJP?o00001?oonfX<o`0000?ooo]Z
4Ol00002oookJPKo00000_oonfX5o`000003oookJ_l0003o000000Co00000ooonfX:o`0000_ooo]Z
0ol000000ooonf[o0000o`000007o`0000Cooo]Z3ol000000ooonf[o0000o`00000Eo`000003oook
J_l0003o000000Go000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000004o`0000?ooo]Z
8?l00003oookJPGo00001?oonfX3o`000003oookJ_l0003o000000;o00000ooonfX3o`0000;ooo]Z
0ol000000ooonf[o0000o`000004o`0000Oooo]Z2Ol000001Ooonf[o0000o`000?l0003ooo]Z00Co
00001_oonfX@o`000003oookJ_l0003o000000_o00000_oonfX4o`0000?ooo]Z1_l00002oookJPWo
00001OoonfXIo`0000Kooo]Z2?l00002oookJP_o000000?ooo]Zo`000?l000001?l00002oookJPOo
00000ooonfX?o`0001_ooo]Z0004oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP06oeEC
Mol007oo411mo`00OolQ8Gcok^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfX<o`00
00Sooo]Z1Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000So00002_oonfX8o`00
0003oookJ_l0003o000000;o00000ooonfXAo`0000Gooo]Z2?l00006oookJP?o00001OoonfX9o`00
00;ooo]Z0ol00005oookJQ3o000000Cooo]Zo`000?l0003o00000_oonfX;o`000004oookJ_l0003o
0000o`0000?ooo]Z1_l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000Go000000?o
oo]Zo`000?l000001Ol000000ooonf[o0000o`000005o`0000?ooo]Z3?l000001Ooonf[o0000o`00
0?l0003ooo]Z00ko00000ooonfX5o`0000Gooo]Z1ol00002oookJPCo000000?ooo]Zo`000?l00000
2Ol00007oookJPWo00001OoonfX9o`000003oookJ_l0003o000001?o000000?ooo]Zo`000?l00000
1_l00002oookJPCo00000ooonfX6o`0000;ooo]Z1ol00002oookJP?o00000_oonfX?o`0000;ooo]Z
2?l00003oookJPKo00000_oonfX9o`0000Sooo]Z1ol000000ooonf[o0000o`000005o`0000Gooo]Z
3?l0000LoookJP001?oonfX:o`00O`Sooo]Z0ol007l7oookJP04oa0@OOl007oo001oomgIK0[ooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z2ol000000ooonf[o0000o`000004o`0000;ooo]Z
1Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l00000
0_l00006oookJP?o00000_oonfX6o`0000?ooo]Z1ol00002oookJPoo00001OoonfX8o`0000?ooo]Z
1ol00004oookJPko00001OoonfX@o`000004oookJ_l0003o0000o`0000Gooo]Z2?l00004oookJPWo
000000Cooo]Zo`000?l0003o00000ooonfX;o`000004oookJ_l0003o0000o`0000Gooo]Z1ol00003
oookJP_o00000_oonfX6o`000005oookJ_l0003o0000o`000?oonfX01_l00002oookJPKo00001?oo
nfX8o`0000?ooo]Z1?l000000ooonf[o0000o`000009o`0000?ooo]Z0ol000000ooonf[o0000o`00
0007o`0000?ooo]Z3ol000000ooonf[o0000o`00000<o`0000Cooo]Z1ol00003oookJPCo00000ooo
nfX@o`000004oookJ_l0003o0000o`0000;ooo]Z3?l00005oookJPOo000000?ooo]Zo`000?l00000
4_l00008oookJPOo00000ooonfX5o`0000Oooo]Z1ol000001?oonf[o0000o`000?l0000KoookJP00
5_oonfX3o`00O`Kooo]Z00KoEE=go`00Ool@47go001oob4QO?o^jV/9oookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007lHoookJQ?o000000?ooo]Zo`000?l000000_l00003oookJPco00000_oonfX4o`00
00Gooo]Z0ol00002oookJQ3o00000_oonfX=o`0000;ooo]Z0ol00004oookJPKo00000_oonfX8o`00
00Cooo]Z0ol000000ooonf[o0000o`000008o`000005oookJ_l0003o0000o`000?oonfX01Ol00008
oookJP?o000000?ooo]Zo`000?l000001?l00002oookJPSo00001?oonfX4o`0000;ooo]Z0ol0000:
oookJPOo00000ooonfX5o`0000Cooo]Z1Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o
000000;o00000ooonfX5o`000005oookJ_l0003o0000o`000?oonfX03_l00004oookJPGo000000Co
oo]Zo`000?l0003o00000_oonfX3o`0000;ooo]Z2ol00003oookJP?o000000?ooo]Zo`000?l00000
1Ol00005oookJPoo000000?ooo]Zo`000?l000001?l00004oookJPCo00001OoonfX6o`0000Cooo]Z
0ol00003oookJR;o000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000@o`0000Oooo]Z
0ol000000ooonf[o0000o`00000<o`0000Gooo]Z2Ol000001?oonf[o0000o`000?l0000KoookJP00
4OoonfX2o`00O`;ooo]Z1?l007l5oookJP08oeECMol007ooEE=goookJ_mEDgOo001oob4QO?o^jV/8
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lHoookJQCo000000Cooo]Zo`000?l0003o00000ooo
nfX3o`0000;ooo]Z1ol00002oookJPco00000_oonfXAo`0000Oooo]Z1ol000000ooonf[o0000o`00
0006o`0000?ooo]Z3Ol00002oookJPGo000000?ooo]Zo`000?l000001_l00003oookJP?o00001_oo
nfX3o`0000?ooo]Z1Ol000000ooonf[o0000o`000004o`0000?ooo]Z0ol000000ooonf[o0000o`00
0004o`000003oookJ_l0003o000000;o00000_oonfX3o`0000Gooo]Z3?l00003oookJPGo00001?oo
nfX5o`000003oookJ_l0003o000000_o00000ooonfXKo`000005oookJ_l0003o0000o`000?oonfX0
2?l00002oookJP?o00000ooonfX7o`0000?ooo]Z0ol00002oookJPGo000000Cooo]Zo`000?l0003o
00000_oonfX8o`000003oookJ_l0003o000000Co00000ooonfX7o`000003oookJ_l0003o000000;o
00001OoonfX6o`0000Cooo]Z0ol00003oookJPco000000?ooo]Zo`000?l000004ol000000ooonf[o
0000o`000009o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001?l00002oookJP?o
00002?oonfX3o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001_l00004oookJP[o
000000Cooo]Zo`000?l0003o00006ooonfX0017ooo]Z1ol007l5oookJP03oeECMol007ooEE=g00?o
oo]Z00CoEE=go`00OolQ8Gcok^Y[1ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfXDo`00
00Oooo]Z0ol00002oookJRSo00001_oonfXAo`000003oookJ_l0003o000000Wo00001_oonfX3o`00
00?ooo]Z1Ol00002oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX6o`0000?ooo]Z1_l00000
0ooonf[o0000o`000004o`0000Gooo]Z1ol000001?oonf[o0000o`000?l00006oookJP?o00000_oo
nfX6o`0000Wooo]Z1Ol00004oookJPGo000000?ooo]Zo`000?l000002_l00009oookJPKo00001?oo
nfX@o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000_l00002oookJPOo00000ooo
nfX3o`0000;ooo]Z0ol00002oookJPCo00000ooonfX7o`000003oookJ_l0003o000000ko00000_oo
nfX3o`0000Cooo]Z1?l00006oookJPCo00001OoonfX8o`000003oookJ_l0003o000000oo00000ooo
nfX>o`0000?ooo]Z2?l00003oookJPSo00001OoonfX3o`000003oookJ_l0003o000000Wo00001ooo
nfX4o`0000;ooo]Z1?l000001?oonf[o0000o`000?l0000KoookJP004OoonfX6o`00O`Gooo]Z00?o
gMU/o`00OomEDgL01OoonfX00omEDgOo001oolc8KP07oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07lHoookJQCo000000Cooo]Zo`000?l0003o00001OoonfX6o`000003oookJ_l0003o000001Go0000
0_oonfX7o`000004oookJ_l0003o0000o`0000?ooo]Z6?l000001Ooonf[o0000o`000?l0003ooo]Z
00?o00001_oonfX3o`0000Cooo]Z1?l00002oookJP?o00000ooonfX3o`000003oookJ_l0003o0000
00Co00000ooonfX6o`000003oookJ_l0003o000000Co00001OoonfX<o`0000Gooo]Z0ol00002oook
JPOo00001?oonfX6o`0000Oooo]Z1Ol000000ooonf[o0000o`000004o`0000;ooo]Z1ol00002oook
JP?o000000?ooo]Zo`000?l000001?l00004oookJPGo00001?oonfX6o`0000;ooo]Z5ol00008oook
JPWo00000_oonfX3o`0000;ooo]Z5Ol000000ooonf[o0000o`000004o`000003oookJ_l0003o0000
00?o00001?oonfX9o`000005oookJ_l0003o0000o`000?oonfX02ol000000ooonf[o0000o`000008
o`0000?ooo]Z3_l00003oookJPSo000000?ooo]Zo`000?l000004?l000000ooonf[o0000o`000005
o`000005oookJ_l0003o0000o`000?oonfX02_l00002oookJPSo00006ooonfX0017ooo]Z0_l007l:
oookJP03omgIK?oonf[ooo]Z00Gooo]Z00?ogMU/oookJ_oonfX00ooonfX6o`00O`?ooo]Z0ol007l3
oookJP?o001o2ooonfX01?nHUW;o001oo`00OomVI7H9oookJP[o000000?ooo]Zo`000?l000002ol0
0005oookJPKo00000_oonfX5o`0000?ooo]Z4?l00004oookJP?o00000ooonfX3o`000003oookJ_l0
003o000001[o000000Cooo]Zo`000?l0003o00001?oonfX6o`0000Cooo]Z0ol00002oookJPCo0000
0_oonfX3o`000003oookJ_l0003o000000go000000?ooo]Zo`000?l000001?l000001Ooonf[o0000
o`000?l0003ooo]Z00co00000_oonfX7o`0000?ooo]Z1ol00002oookJPKo00001ooonfX?o`0000?o
oo]Z0ol00002oookJP?o00000ooonfX3o`0000Kooo]Z1Ol00002oookJP?o000000Cooo]Zo`000?l0
003o00000_oonfXIo`0000Kooo]Z2?l000000ooonf[o0000o`000004o`000003oookJ_l0003o0000
00_o000000Gooo]Zo`000?l0003o0000oookJP03o`0000Cooo]Z0ol000000ooonf[o0000o`000003
o`0000Cooo]Z3Ol000000ooonf[o0000o`000006o`0000;ooo]Z0ol00002oookJPOo00000ooonfXI
o`000003oookJ_l0003o0000013o00000_oonfX6o`000005oookJ_l0003o0000o`000?oonfX02?l0
0004oookJPSo00006ooonfX0017ooo]Z0_l007lHoookJPKo001o1?oonfX3o`00O`04oookJ_l007oo
001oo`00O`_ooo]Z00?ogMU/o`00Ool007l00_l007l00omgMGGooo]ZoookJP06oookJPSo000000?o
oo]Zo`000?l000003Ol00005oookJPKo00001?oonfX9o`0000?ooo]Z1?l000000ooonf[o0000o`00
0003o`0000?ooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00go00001?oonfX;o`000004oook
J_l0003o0000o`0000?ooo]Z2Ol00002oookJP?o000000?ooo]Zo`000?l000000ol00002oookJP?o
000000?ooo]Zo`000?l000002Ol00004oookJPKo00000_oonfX4o`000004oookJ_l0003o0000o`00
00;ooo]Z2ol000000ooonf[o0000o`00000;o`0000;ooo]Z2?l00002oookJPgo00000_oonfX5o`00
0004oookJ_l0003o0000o`0000;ooo]Z1Ol000001?oonf[o0000o`000?l00006oookJPGo00000_oo
nfX3o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o00001_oonfXAo`000003oook
J_l0003o000000So00000ooonfX6o`0000Cooo]Z4ol00003oookJPGo000000?ooo]Zo`000?l00000
2?l000000ooonf[o0000o`000006o`0000;ooo]Z4ol00006oookJPGo00000ooonfX:o`0000Sooo]Z
0ol00002oookJP?o000000?ooo]Zo`000?l000002?l00004oookJP?o000000Gooo]Zo`000?l0003o
0000oookJP08o`0000Kooo]Z1Ol0000LoookJP004_oonfX7o`00OaCooo]Z1?l007l4oookJPOo001o
2ooonfX01_mEDgOo001ookZhKonj^6oo001ooa0@O@Sooo]Z1_l00003oookJQCo00000ooonfX5o`00
00;ooo]Z2_l000000ooonf[o0000o`000003o`0000?ooo]Z4?l00004oookJPKo000000Cooo]Zo`00
0?l0003o00001?oonfX:o`0000;ooo]Z0ol00003oookJQCo00001_oonfX>o`000003oookJ_l0003o
000000ko00000_oonfX;o`000003oookJ_l0003o000000Co00001?oonfX3o`0000?ooo]Z1ol00002
oookJP_o00000_oonfX:o`0000?ooo]Z1Ol000000ooonf[o0000o`000004o`0000?ooo]Z1Ol00000
0ooonf[o0000o`000002o`0000;ooo]Z1ol00008oookJPGo000000?ooo]Zo`000?l000004Ol00004
oookJPOo00000ooonfX?o`000005oookJ_l0003o0000o`000?oonfX01ol000000ooonf[o0000o`00
000Vo`0000Kooo]Z1?l00003oookJP_o00002?oonfX>o`0000;ooo]Z1_l00002oookJPGo00000ooo
nfX7o`0000Kooo]Z1Ol0000LoookJP004_oonfX7o`00OaGooo]Z0ol007l5oookJPGo001o1?oonfX7
o`00O`03oookJ_l@47go001o00;ooo]Z0_l007l8oookJPKo00000ooonfX7o`000003oookJ_l0003o
000000[o00000ooonfX5o`0000Cooo]Z2?l000000ooonf[o0000o`000004o`0000;ooo]Z3ol00007
oookJP_o00000_oonfX9o`0000Cooo]Z2?l000000ooonf[o0000o`000004o`0000?ooo]Z2Ol00003
oookJQOo000000?ooo]Zo`000?l000001Ol00002oookJP[o00001OoonfX3o`0000Wooo]Z8_l00002
oookJPGo000000?ooo]Zo`000?l000001ol00004oookJPKo00000_oonfX7o`0000Sooo]Z1?l00006
oookJPko00001_oonfX6o`0000?ooo]Z3ol000000ooonf[o0000o`000005o`000003oookJ_l0003o
000001[o00000_oonfX=o`000004oookJ_l0003o0000o`0000;ooo]Z1_l000000ooonf[o0000o`00
000=o`0000;ooo]Z3ol00004oookJPOo000000?ooo]Zo`000?l000000ol00003oookJPKo00000ooo
nfX3o`000003oookJ_l0003o000000?o00007?oonfX004Oooo]Z0_l007l2okZhK`;o001o2?oonfX4
o`0000Gooo]Z0ol00007oookJP_o000000?ooo]Zo`000?l000001Ol00006oookJPGo000000?ooo]Z
o`000?l000004?l00002oookJPCo00001_oonfX7o`000004oookJ_l0003o0000o`0000;ooo]Z2?l0
0004oookJQco00000ooonfXLo`000003oookJ_l0003o000000co00001OoonfX3o`0000Sooo]Z4?l0
0005oookJQCo00000_oonfX:o`000003oookJ_l0003o000000Ko00001OoonfX4o`000003oookJ_l0
003o000000Co000000Cooo]Zo`000?l0003o00000ooonfX3o`000003oookJ_l0003o000000So0000
00?ooo]Zo`000?l000001?l00003oookJPKo00000ooonfX6o`0000?ooo]Z0ol00005oookJPKo0000
00?ooo]Zo`000?l000004Ol000000ooonf[o0000o`000006o`0000;ooo]Z2Ol00003oookJPKo0000
00?ooo]Zo`000?l000001?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000Go0000
0_oonfX?o`0000Oooo]Z1?l000000ooonf[o0000o`000003o`0000?ooo]Z1Ol00002oookJPGo0000
00?ooo]Zo`000?l000000ol0000LoookJP00AooonfX5o`00O`03oeECMooonf[ooo]Z00Kooo]Z1Ol0
0004oookJP?o00002?oonfXEo`0000?ooo]Z1Ol00002oookJP_o000000?ooo]Zo`000?l000002_l0
0005oookJPOo000000Cooo]Zo`000?l0003o00000_oonfX3o`0000;ooo]Z0ol00004oookJT7o0000
0_oonfX7o`0000Gooo]Z0ol00008oookJPCo00000_oonfX8o`0000Oooo]Z1?l00003oookJP?o0000
00?ooo]Zo`000?l000002?l00007oookJPko00002OoonfX6o`000004oookJ_l0003o0000o`0000?o
oo]Z1_l00002oookJPgo00001?oonfX3o`0000Gooo]Z1_l00003oookJP?o00001?oonfX7o`0000?o
oo]Z1?l000001?oonf[o0000o`000?l0000:oookJPKo00001?oonfXBo`000003oookJ_l0003o0000
00Co000000?ooo]Zo`000?l000002Ol000001?oonf[o0000o`000?l00002oookJP?o00001?oonfX8
o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000002
o`0000?ooo]Z1_l00002oookJPGo00000_oonfX4o`0001cooo]Z0017oookJP06oa0@OOl007ooEE=g
o`00Oolb<W[ok^Y[2?oonfX5o`0000?ooo]Z1ol00005oookJPGo00000_oonfX>o`0000?ooo]Z1Ol0
00000ooonf[o0000o`000002o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000002_l0
0007oookJPSo00002?oonfX3o`0000Cooo]Z0ol00005oookJPGo000000?ooo]Zo`000?l000002ol0
00001Ooonf[o0000o`000?l0003ooo]Z01;o00000_oonfX=o`000003oookJ_l0003o000000Ko0000
1OoonfX3o`0000Sooo]Z0ol00003oookJPGo00000ooonfX3o`0000?ooo]Z1ol00006oookJPWo0000
1ooonfX@o`0000Cooo]Z2Ol000000ooonf[o0000o`000002o`0000;ooo]Z2?l00003oookJPCo0000
0ooonfX4o`0000?ooo]Z0ol00004oookJPGo00001OoonfX3o`0000?ooo]Z1Ol00003oookJPOo0000
00?ooo]Zo`000?l000001?l00009oookJP?o00000_oonfXEo`0000;ooo]Z0ol000001?oonf[o0000
o`000?l00002oookJPSo00001OoonfX3o`0000Cooo]Z2Ol000000ooonf[o0000o`000006o`000003
oookJ_l0003o000000?o00001?oonfX=o`0000;ooo]Z0ol0000MoookJP00AooonfX01?mEDgOo001o
ohN5Loo<b6h2ogMeM@Sooo]Z1Ol00002oookJPSo00001OoonfX5o`0000?ooo]Z3Ol00009oookJPGo
00000_oonfX5o`0000Gooo]Z2?l000000ooonf[o0000o`000002o`0000?ooo]Z1ol00004oookJP?o
00001ooonfX3o`0000Oooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000002ol000000ooonf[o
0000o`000002o`000003oookJ_l0003o000000Wo00001?oonfX9o`0000Gooo]Z2?l00005oookJPKo
00001OoonfX6o`0000;ooo]Z0ol00003oookJP?o00000_oonfX8o`0000Kooo]Z2Ol00007oookJPGo
00000_oonfX<o`000003oookJ_l0003o000000Go00000ooonfX4o`0000Gooo]Z1Ol00003oookJPCo
00000ooonfX5o`0000;ooo]Z5?l00003oookJPGo00000ooonfX7o`000003oookJ_l0003o000000Co
00002OoonfX3o`0000;ooo]Z1_l000000ooonf[o0000o`00000;o`0000;ooo]Z1?l000001?oonf[o
0000o`000?l00005oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPKo000000?ooo]Zo`00
0?l000000_l00006oookJPSo000000?ooo]Zo`000?l000000ol00004oookJP[o00001OoonfX3o`00
01gooo]Z0017oookJP03olc8K_l007oo001o00;o001o00?oEE=goookJ_oonfX01_oonfX4o`000003
oookJ_l0003o000000So00001OoonfX6o`0000Cooo]Z0ol000000ooonf[o0000o`000003o`0000[o
oo]Z2ol00007oookJPOo00000_oonfX4o`0000Cooo]Z1_l00004oookJP?o00001ooonfX3o`0000Oo
oo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000So00000ooonfX4o`0000Ko
oo]Z2Ol000000ooonf[o0000o`000007o`0000Kooo]Z2?l00006oookJPKo00000ooonfX7o`0000;o
oo]Z0ol000000ooonf[o0000o`000003o`0000;ooo]Z2?l00005oookJP?o000000?ooo]Zo`000?l0
00000ol00003oookJP?o00000_oonfXCo`000003oookJ_l0003o000000So000000?ooo]Zo`000?l0
00000_l00005oookJP_o00000_oonfXKo`0000Cooo]Z2ol000001?oonf[o0000o`000?l00002oook
JPOo00001OoonfXIo`0000;ooo]Z1_l000001?oonf[o0000o`000?l00003oookJPGo000000?ooo]Z
o`000?l000000_l000000ooonf[o0000o`00000=o`0000Gooo]Z0ol00004oookJPCo00001OoonfX;
o`0000;ooo]Z1Ol0000MoookJP00B?oonfX01OnYYg7o411mo`00OomEDgOok^Y[00Sooo]Z1?l00000
0ooonf[o0000o`000006o`0000;ooo]Z0ol00002oookJPKo00001?oonfX3o`000003oookJ_l0003o
000000?o00001ooonfX=o`0000Oooo]Z3_l00004oookJP?o00000_oonfX3o`000003oookJ_l0003o
000000Ko00000_oonfX:o`0000Gooo]Z3ol00002oookJPGo00001?oonfX;o`000003oookJ_l0003o
000000Oo000000Gooo]Zo`000?l0003o0000oookJP05o`000004oookJ_l0003o0000o`0000Kooo]Z
1_l00003oookJPSo000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z2?l00007oookJP?o
000000?ooo]Zo`000?l000001Ol000001Ooonf[o0000o`000?l0003ooo]Z00_o00000ooonfX;o`00
00;ooo]Z1?l00002oookJP?o00001OoonfX[o`0000?ooo]Z5_l00004oookJQSo00001?oonfX5o`00
00Sooo]Z2_l000000ooonf[o0000o`00000?o`0000Cooo]Z2?l00005oookJPOo00000_oonfX4o`00
00;ooo]Z1_l0000LoookJP00EOoonfX4o`000003oookJ_l0003o000000?o00000ooonfX?o`000004
oookJ_l0003o0000o`0000;ooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00So000000?ooo]Z
o`000?l000001ol00004oookJPko00001ooonfX5o`000003oookJ_l0003o000000Ko00000_oonfXD
o`0000Cooo]Z0ol00005oookJPCo00001OoonfX;o`000004oookJ_l0003o0000o`0000?ooo]Z0ol0
00001Ooonf[o0000o`000?l0003ooo]Z00Go00002_oonfX6o`0000?ooo]Z4?l000000ooonf[o0000
o`000007o`0000Cooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000Gooo]Zo`000?l0
003o0000oookJP03o`0000?ooo]Z4_l00003oookJPCo00000_oonfX:o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000006o`0000;ooo]Z4_l00002oook
JPKo000000?ooo]Zo`000?l000003?l00004oookJQSo00001?oonfX5o`0000Sooo]Z2Ol00002oook
JQ7o00001?oonfX8o`0000?ooo]Z2Ol000000ooonf[o0000o`000004o`000003oookJ_l0003o0000
00Co00007?oonfX005Gooo]Z2ol00002oookJPoo000000?ooo]Zo`000?l000000ol00002oookJPOo
000000?ooo]Zo`000?l000000ol00004oookJP?o00000ooonfX3o`0000Cooo]Z1?l00003oookJP?o
00002_oonfX6o`000003oookJ_l0003o000000Ko00000_oonfXDo`0000cooo]Z1Ol000000ooonf[o
0000o`000006o`0000oooo]Z1Ol000000ooonf[o0000o`000003o`0000Cooo]Z1_l000001?oonf[o
0000o`000?l00006oookJPWo00000_oonfX4o`000003oookJ_l0003o000000Ko00001OoonfX3o`00
00;ooo]Z0ol00003oookJPOo000000?ooo]Zo`000?l000000_l00002oookJQ;o00000_oonfX4o`00
00?ooo]Z3_l00003oookJPCo00000_oonfX:o`0000Gooo]Z3ol00002oookJPKo000000Cooo]Zo`00
0?l0003o00000_oonfX5o`0000Sooo]Z1ol00002oookJP[o00000_oonfX3o`0000Gooo]Z1_l00005
oookJQ;o000000?ooo]Zo`000?l000002?l00004oookJPSo000000?ooo]Zo`000?l000004?l00002
oookJPGo00007?oonfX005Gooo]Z1?l000000ooonf[o0000o`000009o`000003oookJ_l0003o0000
00Wo000000?ooo]Zo`000?l000000ol00002oookJPko00000ooonfX3o`0000?ooo]Z0ol00005oook
JP?o00000ooonfX5o`0000?ooo]Z1?l000000ooonf[o0000o`000002o`0000Kooo]Z6ol000000ooo
nf[o0000o`000002o`0000;ooo]Z5_l00004oookJP?o00000_oonfX8o`000004oookJ_l0003o0000
o`0000Kooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000o`000003o`0000;ooo]Z0ol00002oookJPSo00001OoonfX4o`000004oookJ_l0
003o0000o`0000Kooo]Z0ol00002oookJPCo00000ooonfX?o`0000Cooo]Z1_l000000ooonf[o0000
o`00000:o`000005oookJ_l0003o0000o`000?oonfX01?l00002oookJP[o00000ooonfX7o`0000;o
oo]Z1?l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l0
00001Ol00009oookJPCo00000_oonfX<o`0000;ooo]Z0ol00005oookJPKo00000_oonfXDo`0000;o
oo]Z2Ol00006oookJPOo000000?ooo]Zo`000?l000004Ol000001?oonf[o0000o`000?l0000Noook
JP00EOoonfX4o`000003oookJ_l0003o000000Ko000000Gooo]Zo`000?l0003o0000oookJP08o`00
00?ooo]Z1Ol00002oookJPWo00000_oonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`000004o`00
00Oooo]Z0ol000000ooonf[o0000o`000004o`0000;ooo]Z1?l000001?oonf[o0000o`000?l00009
oookJQ?o00000ooonfX3o`000003oookJ_l0003o000000;o00000_oonfXIo`000003oookJ_l0003o
000000Wo00000ooonfX3o`0000;ooo]Z4_l000000ooonf[o0000o`000002o`000003oookJ_l0003o
000000;o000000Cooo]Zo`000?l0003o00001_oonfX8o`0000;ooo]Z2Ol00006oookJP?o00000_oo
nfX4o`0000?ooo]Z2?l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Oo000000?o
oo]Zo`000?l000000ol000000ooonf[o0000o`00000Io`0000?ooo]Z1_l00003oookJPCo00001?oo
nfX3o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`00
0004o`0000;ooo]Z3?l000000ooonf[o0000o`000002o`0000Kooo]Z0ol000000ooonf[o0000o`00
0005o`0000;ooo]Z1ol000000ooonf[o0000o`00000:o`000003oookJ_l0003o000000?o000000Co
oo]Zo`000?l0003o00001?oonfX6o`000005oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o
0000o`000008o`000003oookJ_l0003o000000Co00008?oonfX005Gooo]Z1?l000000ooonf[o0000
o`000006o`000005oookJ_l0003o0000o`000?oonfX04?l00007oookJPWo00000_oonfX:o`000003
oookJ_l0003o000000;o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004o`0000;o
oo]Z1?l000000ooonf[o0000o`000007o`0000?ooo]Z4ol00002oookJP?o00000_oonfX5o`000003
oookJ_l0003o000000Oo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000004o`000003
oookJ_l0003o000000Ko00000ooonfX6o`000003oookJ_l0003o0000017o000000?ooo]Zo`000?l0
00000_l00005oookJQ;o00000_oonfX;o`0000?ooo]Z0ol0000:oookJPCo00000_oonfX3o`0000;o
oo]Z2?l000000ooonf[o0000o`000005o`0000;ooo]Z1_l000000ooonf[o0000o`00000=o`0000?o
oo]Z1Ol00003oookJQ3o000000Gooo]Zo`000?l0003o0000oookJP0=o`0000?ooo]Z1_l00002oook
JPco000000?ooo]Zo`000?l000000_l00004oookJQKo000000?ooo]Zo`000?l000005?l00002oook
JPKo00000ooonfX6o`0000;ooo]Z2Ol000000ooonf[o0000o`000007o`0001kooo]Z001EoookJPCo
000000Cooo]Zo`000?l0003o00000_oonfX3o`000003oookJ_l0003o000000Go00000_oonfX>o`00
00;ooo]Z3?l000000ooonf[o0000o`000008o`000003oookJ_l0003o000000Oo00000_oonfX5o`00
00;ooo]Z1?l000000ooonf[o0000o`000007o`0000Kooo]Z5Ol00004oookJP?o00000ooonfX7o`00
00Cooo]Z1Ol000000ooonf[o0000o`000004o`0000?ooo]Z1?l00005oookJQWo00000ooonfX3o`00
00;ooo]Z5Ol00002oookJP_o000000?ooo]Zo`000?l000000ol00003oookJP?o00001?oonfX4o`00
0003oookJ_l0003o000000;o00000_oonfX9o`0000Cooo]Z0ol00002oookJPKo000000Gooo]Zo`00
0?l0003o0000oookJP0;o`0000?ooo]Z4_l000000ooonf[o0000o`000006o`0000Cooo]Z2Ol00005
oookJPko00001ooonfX4o`0000Cooo]Z4?l000000ooonf[o0000o`000003o`0000Cooo]Z1Ol00000
0ooonf[o0000o`00000;o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000001?l00004
oookJP?o000000?ooo]Zo`000?l000002ol0000NoookJP00EOoonfX5o`0000Gooo]Z2ol00005oook
JPOo000000Gooo]Zo`000?l0003o0000oookJP0=o`000003oookJ_l0003o000000So000000?ooo]Z
o`000?l000001ol00002oookJPKo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00000:
o`000003oookJ_l0003o000001Go00001?oonfX9o`000004oookJ_l0003o0000o`0000;ooo]Z3_l0
0003oookJPCo000000Gooo]Zo`000?l0003o0000oookJP0?o`000003oookJ_l0003o000000Oo0000
0ooonfXGo`0000;ooo]Z0ol00003oookJPSo000000?ooo]Zo`000?l000000ol00003oookJP?o0000
1?oonfX9o`0000;ooo]Z2Ol00004oookJP?o00000_oonfX3o`0000Sooo]Z2ol00003oookJP[o0000
00?ooo]Zo`000?l000003_l00007oookJPSo000000?ooo]Zo`000?l000004_l00004oookJP?o0000
1?oonfX9o`0000Cooo]Z0ol000000ooonf[o0000o`000003o`0000Cooo]Z1?l00002oookJPgo0000
00?ooo]Zo`000?l000004Ol000001Ooonf[o0000o`000?l0003ooo]Z00go00007_oonfX005Gooo]Z
5?l00002oookJP?o000000?ooo]Zo`000?l000001Ol000001Ooonf[o0000o`000?l0003ooo]Z00go
00001OoonfX6o`0000Gooo]Z1_l000000ooonf[o0000o`000009o`000003oookJ_l0003o000000;o
000000Gooo]Zo`000?l0003o0000oookJP0Jo`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?l000001_l000001?oonf[o0000o`000?l00002oookJQ;o00001?oonfX3o`0000Gooo]Z5Ol00003
oookJPgo000000?ooo]Zo`000?l000001Ol00004oookJP?o00000_oonfX6o`0000Cooo]Z1Ol00003
oookJPKo00000_oonfX7o`0000?ooo]Z0ol000000ooonf[o0000o`000003o`0000Cooo]Z0ol00000
0ooonf[o0000o`000003o`0000Oooo]Z2_l000000ooonf[o0000o`000004o`000003oookJ_l0003o
000000Oo00001?oonfX6o`000003oookJ_l0003o000000?o00001OoonfX8o`000004oookJ_l0003o
0000o`0000;ooo]Z3ol00007oookJP?o000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00
0002o`0000;ooo]Z2Ol00005oookJQ3o00000ooonfX;o`0000;ooo]Z1_l00003oookJP?o000000Co
oo]Zo`000?l0003o00000_oonfX4o`00023ooo]Z001EoookJQWo000000?ooo]Zo`000?l000006ol0
00000ooonf[o0000o`000005o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z4ol0
00000ooonf[o0000o`000007o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000003Ol0
00000ooonf[o0000o`00000:o`0000;ooo]Z5Ol000001?oonf[o0000o`000?l00003oookJQCo0000
1_oonfX=o`000003oookJ_l0003o000000Co00001OoonfX3o`0000;ooo]Z1Ol00002oookJPOo0000
0ooonfX7o`0000;ooo]Z1_l00004oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX6o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000ooonfX:o`000003oookJ_l0003o0000
00Go000000?ooo]Zo`000?l000001_l00004oookJQ3o000000Cooo]Zo`000?l0003o00000_oonfX3
o`000004oookJ_l0003o0000o`0000;ooo]Z2?l000000ooonf[o0000o`000007o`0000Cooo]Z3ol0
00000ooonf[o0000o`000006o`0000Gooo]Z4_l00003oookJP?o00000ooonfX6o`000003oookJ_l0
003o000000Co00000_oonfX6o`000003oookJ_l0003o000000Co00008OoonfX005Gooo]Z9_l00003
oookJPko000000?ooo]Zo`000?l000001Ol00002oookJPWo000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`000007o`0000;ooo]Z4?l00002oookJPgo00001OoonfX8o`000005oookJ_l0003o
0000o`000?oonfX04_l00002oookJP?o000000?ooo]Zo`000?l000005?l00009oookJPOo00003Ooo
nfX3o`0000?ooo]Z1Ol00002oookJPCo00001OoonfX8o`0000;ooo]Z2?l00002oookJP?o000000?o
oo]Zo`000?l000002_l000000ooonf[o0000o`000008o`0000?ooo]Z1_l00004oookJPOo000000?o
oo]Zo`000?l000001_l00004oookJQ3o000000Cooo]Zo`000?l0003o00001OoonfX6o`000003oook
J_l0003o000000?o00000ooonfX3o`0000;ooo]Z1?l00004oookJPoo000000?ooo]Zo`000?l00000
1_l00003oookJPGo000000?ooo]Zo`000?l000003_l000000ooonf[o0000o`000003o`000003oook
J_l0003o000000_o00000_oonfX6o`000004oookJ_l0003o0000o`0002Cooo]Z001EoookJPKo0000
1?oonfX7o`0000;ooo]Z5?l00006oookJP?o000000?ooo]Zo`000?l000001?l00003oookJPGo0000
0_oonfX9o`0000?ooo]Z1_l000000ooonf[o0000o`000007o`0000;ooo]Z0ol000000ooonf[o0000
o`00000:o`0000;ooo]Z1_l000000ooonf[o0000o`000002o`0000Gooo]Z3_l000000ooonf[o0000
o`00000@o`0000;ooo]Z0ol000000ooonf[o0000o`00000Ho`0000?ooo]Z3?l000001Ooonf[o0000
o`000?l0003ooo]Z00So00000ooonfX;o`0000;ooo]Z5Ol00002oookJPCo00000ooonfX6o`0000Go
oo]Z2Ol00003oookJPKo00002?oonfX9o`0000Oooo]Z2ol000000ooonf[o0000o`000002o`000004
oookJ_l0003o0000o`0000Gooo]Z1_l000000ooonf[o0000o`000006o`0000Gooo]Z1?l00004oook
JQ?o00000_oonfX3o`0000?ooo]Z1Ol00002oookJQGo000000?ooo]Zo`000?l000002_l00003oook
JPoo00007ooonfX005Gooo]Z1_l000000ooonf[o0000o`000006o`0000Cooo]Z3_l000000ooonf[o
0000o`000003o`0000;ooo]Z1ol00003oookJPGo00000_oonfX4o`000003oookJ_l0003o000000Wo
00000ooonfX4o`000005oookJ_l0003o0000o`000?oonfX01ol00002oookJQ3o00000_oonfX6o`00
0003oookJ_l0003o000000?o00001?oonfX6o`000003oookJ_l0003o000000go00000_oonfX8o`00
00?ooo]Z0ol000000ooonf[o0000o`00000Ho`000003oookJ_l0003o000000co000000Gooo]Zo`00
0?l0003o0000oookJP08o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001Ol00002
oookJQGo00000ooonfX5o`000003oookJ_l0003o000000;o00002OoonfX9o`0000;ooo]Z1Ol00000
0ooonf[o0000o`000002o`0000;ooo]Z2Ol00002oookJPGo000000?ooo]Zo`000?l000002Ol00003
oookJPKo00001OoonfX6o`000003oookJ_l0003o000000So00000ooonfX3o`0000;ooo]Z1_l00002
oookJQ?o00000_oonfX6o`0000Cooo]Z1_l000000ooonf[o0000o`00000@o`000003oookJ_l0003o
000000Co000000?ooo]Zo`000?l000002?l00002oookJPKo00007_oonfX005Gooo]Z1Ol00002oook
JPKo00001_oonfX5o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000ol00002oook
JPKo00001?oonfX6o`0000;ooo]Z4Ol000000ooonf[o0000o`000002o`000003oookJ_l0003o0000
00Oo00000ooonfX6o`0000?ooo]Z1?l0000?oookJPGo00000_oonfX8o`000005oookJ_l0003o0000
o`000?oonfX01_l00004oookJP[o000000Cooo]Zo`000?l0003o00000ooonfX5o`000003oookJ_l0
003o0000023o000000?ooo]Zo`000?l000002?l00003oookJPGo000000?ooo]Zo`000?l000001Ol0
0002oookJP?o000000?ooo]Zo`000?l000003_l000000ooonf[o0000o`00000;o`0000Wooo]Z5Ol0
0002oookJQ3o00002?oonfX5o`0000;ooo]Z1_l0000?oookJPOo00002?oonfX3o`0000Gooo]Z2?l0
00000ooonf[o0000o`000007o`0000?ooo]Z1?l00009oookJPKo000000?ooo]Zo`000?l000003?l0
0004oookJP?o00000_oonfX:o`0000;ooo]Z1_l0000NoookJP00EOoonfX4o`000003oookJ_l0003o
000000?o00001?oonfX8o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000000_l00003
oookJPOo00001OoonfX4o`0000;ooo]Z:Ol00003oookJPCo000000?ooo]Zo`000?l000000ol00002
oookJP?o00000_oonfX7o`0000Kooo]Z1Ol00004oookJPCo00001_oonfX4o`0000;ooo]Z1?l00000
1?oonf[o0000o`000?l00003oookJPGo000000?ooo]Zo`000?l000007Ol00006oookJPSo00000_oo
nfX8o`0000;ooo]Z1?l00002oookJPco00001OoonfX3o`000003oookJ_l0003o000000ko00001_oo
nfX>o`000003oookJ_l0003o000000Co00000_oonfX@o`0000Kooo]Z3ol0000>oookJP?o00000_oo
nfX6o`0000;ooo]Z1ol00004oookJQco00001ooonfX8o`0000;ooo]Z2_l00004oookJP?o00000_oo
nfX8o`0000Oooo]Z1?l0000MoookJP00EOoonfX4o`000004oookJ_l0003o0000o`0000Cooo]Z1ol0
0004oookJPKo00000_oonfX6o`0000?ooo]Z2?l00006oookJP?o00001?oonfXBo`0000;ooo]Z4?l0
00000ooonf[o0000o`000007o`000003oookJ_l0003o000000?o00000_oonfX3o`0000;ooo]Z1ol0
0006oookJPGo00001?oonfX8o`0000;ooo]Z2_l000000ooonf[o0000o`000002o`0000;ooo]Z0ol0
000;oookJP?o000000?ooo]Zo`000?l000001_l00002oookJPKo00002OoonfX8o`0000;ooo]Z0ol0
0002oookJP?o00000ooonfX3o`0000;ooo]Z2ol00002oookJPCo00001?oonfX@o`0000;ooo]Z0ol0
00000ooonf[o0000o`000004o`0000?ooo]Z1Ol000000ooonf[o0000o`000002o`0000?ooo]Z4_l0
0004oookJP_o00000_oonfX3o`0000;ooo]Z0ol00007oookJPGo000000?ooo]Zo`000?l000001Ol0
00000ooonf[o0000o`000006o`0000;ooo]Z3?l000000ooonf[o0000o`00000Do`0000;ooo]Z4ol0
00000ooonf[o0000o`000006o`0000;ooo]Z1?l00004oookJPGo00000_oonfX4o`0001cooo]Z001E
oookJP[o00000_oonfX7o`0000;ooo]Z3_l00005oookJPWo00000_oonfX5o`0000Gooo]Z2_l00002
oookJPKo00000_oonfX6o`000003oookJ_l0003o000001Oo00000_oonfX<o`0000;ooo]Z0ol00000
0ooonf[o0000o`000008o`000003oookJ_l0003o000000Wo000000Gooo]Zo`000?l0003o0000oook
JP03o`000003oookJ_l0003o000000?o00004_oonfX@o`0000;ooo]Z0ol00004oookJPSo00000_oo
nfX3o`0000;ooo]Z0ol000000ooonf[o0000o`000003o`0000;ooo]Z2ol00002oookJP_o000000?o
oo]Zo`000?l000002_l00002oookJP?o000000?ooo]Zo`000?l000001Ol00002oookJQSo000000?o
oo]Zo`000?l000001?l00004oookJP_o00000_oonfX4o`000004oookJ_l0003o0000o`0000?ooo]Z
0ol000000ooonf[o0000o`00000Do`0000;ooo]Z0ol00003oookJPKo000000?ooo]Zo`000?l00000
5?l00003oookJQ_o000000?ooo]Zo`000?l000000ol00004oookJPGo00000_oonfX4o`0001cooo]Z
001EoookJP[o00000_oonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000?ooo]Z2ol0
00001Ooonf[o0000o`000?l0003ooo]Z00Go00000_oonfX5o`0000Cooo]Z3?l000000ooonf[o0000
o`000003o`0000?ooo]Z1_l000001?oonf[o0000o`000?l00002oookJQ;o00001OoonfX6o`000003
oookJ_l0003o000000;o00000_oonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l0
00000ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l0
00000ol00007oookJPKo00001?oonfX5o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l0
00002Ol00008oookJP?o00001?oonfX3o`0000;ooo]Z0ol00004oookJP_o00000_oonfXWo`000003
oookJ_l0003o000000go00001?oonfX4o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l0
00004ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000001?o000000?ooo]Zo`000?l0
00000ol00003oookJP?o00001OoonfX>o`0000;ooo]Z1Ol000000ooonf[o0000o`00000=o`0000?o
oo]Z2ol000000ooonf[o0000o`000003o`0000;ooo]Z2Ol000001?oonf[o0000o`000?l0000Loook
JP00EOoonfX:o`0000;ooo]Z6ol000000ooonf[o0000o`00000>o`0000?ooo]Z1ol000000ooonf[o
0000o`000003o`0000;ooo]Z1?l00002oookJPCo00001_oonfX>o`000003oookJ_l0003o000000?o
00001_oonfX;o`0000;ooo]Z2?l000000ooonf[o0000o`000003o`0000;ooo]Z2_l00004oookJP[o
00001ooonfX6o`0000Cooo]Z1?l000000ooonf[o0000o`000007o`0000?ooo]Z2?l00008oookJPCo
00000ooonfX8o`0000Cooo]ZA?l00003oookJPCo00000_oonfX3o`0000?ooo]Z0ol000000ooonf[o
0000o`00000Ao`0000?ooo]Z2?l000000ooonf[o0000o`000005o`0000;ooo]Z2Ol000000ooonf[o
0000o`000003o`0000Cooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000001ol000001?oonf[o
0000o`000?l00003oookJP?o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000009o`00
0003oookJ_l0003o000000Go00000_oonfX8o`0000;ooo]Z2Ol0000PoookJP00EOoonfX:o`0000;o
oo]Z2Ol000000ooonf[o0000o`00000Ko`0000Gooo]Z2Ol00002oookJRKo000000?ooo]Zo`000?l0
00001?l000000ooonf[o0000o`00000<o`0000Cooo]Z1ol000000ooonf[o0000o`000003o`000003
oookJ_l0003o000001;o00002ooonfX6o`0000?ooo]Z1Ol000001?oonf[o0000o`000?l00002oook
JPCo00000ooonfX:o`0000Kooo]Z3Ol00004oookJPGo00000_oonfX3o`000003oookJ_l0003o0000
02_o000000?ooo]Zo`000?l000001Ol00002oookJPGo00000_oonfX4o`0000;ooo]Z0ol000000ooo
nf[o0000o`000003o`0000;ooo]Z4_l00003oookJPSo000000?ooo]Zo`000?l000001Ol00002oook
JPoo00000_oonfX5o`0000;ooo]Z0ol000000ooonf[o0000o`000005o`0000;ooo]Z3_l00003oook
JPGo00000ooonfX;o`0000;ooo]Z1?l000000ooonf[o0000o`00000?o`0001gooo]Z001EoookJP[o
00000ooonfX8o`000003oookJ_l0003o000001Co00000ooonfX7o`0000;ooo]Z2_l000001?oonf[o
0000o`000?l00002oookJQGo00000_oonfX:o`000003oookJ_l0003o000000Co000000?ooo]Zo`00
0?l000002Ol00002oookJPSo000000Gooo]Zo`000?l0003o0000oookJP07o`0000Cooo]Z4Ol00002
oookJP?o00001_oonfX4o`0000?ooo]Z2Ol00003oookJP?o00001_oonfX7o`0000Oooo]Z3?l00003
oookJPKo00001_oonfXeo`000003oookJ_l0003o000000Wo00000ooonfX7o`0000Cooo]Z0ol00002
oookJPWo00001_oonfXBo`0000;ooo]Z3?l00004oookJP[o00002_oonfX?o`0000[ooo]Z2ol00002
oookJPKo000000?ooo]Zo`000?l000002?l00002oookJP?o00007OoonfX005Gooo]Z1Ol00002oook
JP?o00000ooonfX6o`0000?ooo]Z1?l00003oookJPKo000000?ooo]Zo`000?l000001_l00003oook
JP?o000000Gooo]Zo`000?l0003o0000oookJP04o`0000?ooo]Z1?l000001?oonf[o0000o`000?l0
0002oookJP?o00000ooonfX3o`0000;ooo]Z2_l00003oookJP[o000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`000008o`0000;ooo]Z2?l00002oookJP?o000000?ooo]Zo`000?l000001Ol0
0005oookJPco000000Cooo]Zo`000?l0003o00000_oonfX4o`0000Kooo]Z0ol00002oookJPWo0000
3OoonfX7o`0000[ooo]Z1Ol000001?oonf[o0000o`000?l00003oookJPWo00000ooonfX<o`0000?o
oo]Z3Ol000000ooonf[o0000o`000007o`0000;ooo]Z1ol00002oookJP?o00000_oonfX8o`0000Co
oo]Z2ol00006oookJPKo000000?ooo]Zo`000?l000000ol00004oookJQ;o00000_oonfXGo`0000?o
oo]Z0ol000001?oonf[o0000o`000?l00003oookJQ7o00001?oonfX3o`0000;ooo]Z6Ol000001?oo
nf[o0000o`000?l00002oookJP?o00007OoonfX005Gooo]Z1ol00005oookJPOo00000ooonfX4o`00
00Cooo]Z3?l00005oookJP?o000000?ooo]Zo`000?l000001Ol00005oookJPOo000000Cooo]Zo`00
0?l0003o00002OoonfX3o`0000Cooo]Z3?l000001Ooonf[o0000o`000?l0003ooo]Z00Oo00000_oo
nfX3o`000005oookJ_l0003o0000o`000?oonfX02Ol00002oookJP?o00000_oonfX6o`0000Sooo]Z
3Ol00002oookJPWo00000_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z1?l00005oookJPKo
00001_oonfX3o`0000Gooo]Z0ol00006oookJPGo000000?ooo]Zo`000?l000001Ol000001?oonf[o
0000o`000?l00004oookJPGo00002ooonfX:o`0000;ooo]Z2Ol000001Ooonf[o0000o`000?l0003o
oo]Z00Wo00000_oonfX3o`000003oookJ_l0003o000000;o00001?oonfX;o`0000Gooo]Z1_l00002
oookJPGo00001?oonfX3o`000003oookJ_l0003o000000co000000?ooo]Zo`000?l000005_l00003
oookJP?o000000Cooo]Zo`000?l0003o00001_oonfX?o`0000?ooo]Z0ol00006oookJP?o00000_oo
nfXIo`0001gooo]Z001EoookJPWo00000ooonfX>o`0000Gooo]Z2ol000001Ooonf[o0000o`000?l0
003ooo]Z00?o00001?oonfX4o`000003oookJ_l0003o000000;o00000ooonfX4o`000003oookJ_l0
003o000000Ko00001?oonfX3o`000003oookJ_l0003o000000Oo00000ooonfX3o`000005oookJ_l0
003o0000o`000?oonfX01ol000000ooonf[o0000o`000002o`0000Gooo]Z1ol00004oookJPGo0000
00?ooo]Zo`000?l000001ol00004oookJPco00000ooonfX>o`000003oookJ_l0003o000000Oo0000
1?oonfX<o`000004oookJ_l0003o0000o`0000Gooo]Z0ol00005oookJPGo00000_oonfX7o`000003
oookJ_l0003o000000?o00000_oonfX5o`0000Kooo]Z0ol00002oookJPGo000000?ooo]Zo`000?l0
00000_l00006oookJPGo000000?ooo]Zo`000?l000002?l00009oookJPOo000000?ooo]Zo`000?l0
00000ol00003oookJPGo00000ooonfX6o`0000Cooo]Z9Ol000000ooonf[o0000o`00000;o`0000;o
oo]Z0ol000000ooonf[o0000o`000002o`0000Gooo]Z3ol00003oookJPCo00001OoonfX3o`0000;o
oo]Z2?l000000ooonf[o0000o`00000=o`0001kooo]Z001EoookJPWo00000ooonfX3o`000003oook
J_l0003o000000Go00002?oonfXCo`0000Cooo]Z0ol00002oookJP_o000000?ooo]Zo`000?l00000
1_l00004oookJPgo00000ooonfX3o`0000;ooo]Z2_l000000ooonf[o0000o`000002o`0000;ooo]Z
1ol00004oookJPWo00000ooonfX;o`000003oookJ_l0003o000000So00000ooonfXHo`0000Cooo]Z
3?l000001?oonf[o0000o`000?l00005oookJP?o00000ooonfX7o`0000;ooo]Z1ol000000ooonf[o
0000o`000006o`0000Wooo]Z4Ol00005oookJQ;o00000ooonfX3o`000003oookJ_l0003o000000Go
000000?ooo]Zo`000?l000000ol00003oookJPGo00000ooonfX7o`0000Kooo]Z:Ol00002oookJPGo
00000ooonfX:o`0000?ooo]Z3_l00003oookJPCo000000?ooo]Zo`000?l000003ol000000ooonf[o
0000o`00000=o`0001kooo]Z001EoookJPWo00000ooonfX3o`0000;ooo]Z2Ol00003oookJPKo0000
00Gooo]Zo`000?l0003o0000oookJP0<o`0000;ooo]Z4ol000000ooonf[o0000o`000005o`000003
oookJ_l0003o000000go00000_oonfX3o`0000;ooo]Z1ol00004oookJP?o00000ooonfX7o`0000;o
oo]Z2ol00003oookJPco000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000005o`000003
oookJ_l0003o000000Go000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`000004o`000003
oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000_l00009oookJPKo00002ooonfX:o`000004
oookJ_l0003o0000o`0000?ooo]Z4Ol00005oookJP?o000000?ooo]Zo`000?l000002?l000000ooo
nf[o0000o`000007o`0000Cooo]Z1?l000000ooonf[o0000o`000003o`0000?ooo]Z1Ol00006oook
JPCo000000Cooo]Zo`000?l0003o00000_oonfX@o`0000Cooo]Z0ol00008oookJP[o00001?oonfX3
o`0000?ooo]Z0ol000000ooonf[o0000o`00000=o`000003oookJ_l0003o000000Co00001?oonfX4
o`000003oookJ_l0003o000000;o00000_oonfXCo`000003oookJ_l0003o000000Ko00007OoonfX0
05Gooo]Z2?l00004oookJP?o00000_oonfX4o`0000;ooo]Z0ol00003oookJRco00000ooonfXJo`00
00;ooo]Z1Ol00007oookJPCo000000?ooo]Zo`000?l000001Ol00002oookJP_o00001?oonfX;o`00
0003oookJ_l0003o000001Ko00000_oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z1_l00000
0ooonf[o0000o`00000<o`0000Wooo]Z1ol00003oookJP?o00001?oonfX:o`000003oookJ_l0003o
000000?o000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z2?l000000ooonf[o0000o`00
0002o`0000Cooo]Z1_l00005oookJPWo00001?oonfX3o`0000Cooo]Z0ol000000ooonf[o0000o`00
0006o`0000Gooo]Z1?l000001?oonf[o0000o`000?l00003oookJP[o00001OoonfX3o`000003oook
J_l0003o000000;o00000ooonfX3o`0000?ooo]Z1_l000001?oonf[o0000o`000?l00003oookJP?o
00000_oonfX3o`000003oookJ_l0003o000000[o00001?oonfX6o`0000Cooo]Z1?l000000ooonf[o
0000o`000002o`0000;ooo]Z1Ol000000ooonf[o0000o`00000Do`0001gooo]Z001EoookJPSo0000
1?oonfX3o`0000;ooo]Z1?l00002oookJP?o00000ooonfX]o`0000;ooo]Z3ol00003oookJPSo0000
0ooonfX3o`0000Gooo]Z1ol00003oookJPGo00000_oonfX3o`000004oookJ_l0003o0000o`0000Co
oo]Z2Ol000000ooonf[o0000o`00000Ho`000003oookJ_l0003o000000?o00001_oonfX;o`000003
oookJ_l0003o000000go00000_oonfX3o`000005oookJ_l0003o0000o`000?oonfX01ol000001?oo
nf[o0000o`000?l00002oookJPco000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000003
o`0000?ooo]Z2?l00002oookJPCo00001?oonfX6o`000004oookJ_l0003o0000o`0000;ooo]Z1ol0
0005oookJQ?o00001OoonfX3o`0000;ooo]Z0ol00003oookJPKo000000Gooo]Zo`000?l0003o0000
oookJP03o`000005oookJ_l0003o0000o`000?oonfX01?l000000ooonf[o0000o`000008o`0000Go
oo]Z3_l000001?oonf[o0000o`000?l00002oookJPOo000000Cooo]Zo`000?l0003o00000_oonfX8
o`0000Kooo]Z0ol000000ooonf[o0000o`00000Ko`0001gooo]Z001EoookJPWo00000ooonfX;o`00
00Wooo]Z3_l000001?oonf[o0000o`000?l00002oookJPOo00001?oonfX;o`0000Gooo]Z1?l00008
oookJPSo000000Gooo]Zo`000?l0003o0000oookJP03o`000004oookJ_l0003o0000o`0000;ooo]Z
2Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o
00000_oonfX;o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000002Ol000000ooonf[o
0000o`00000;o`0000Gooo]Z1_l00003oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX9o`00
00;ooo]Z1ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000go000000Gooo]Zo`00
0?l0003o0000oookJP03o`0000?ooo]Z0ol000000ooonf[o0000o`00000Ao`000003oookJ_l0003o
000000Co000000Cooo]Zo`000?l0003o00000_oonfX3o`000003oookJ_l0003o000000?o00000ooo
nfXCo`0000Gooo]Z0ol000000ooonf[o0000o`000004o`0000Cooo]Z0ol000000ooonf[o0000o`00
0005o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002ol00002oookJPko00002?oo
nfX5o`000004oookJ_l0003o0000o`0000?ooo]Z2ol00004oookJPgo00000_oonfX3o`0000;ooo]Z
2_l0000NoookJP00EOoonfX4o`0000;ooo]Z3Ol000000ooonf[o0000o`000003o`0000Oooo]Z0ol0
0002oookJPCo00000_oonfX3o`0000Kooo]Z1ol00007oookJPSo00000ooonfX5o`0000Wooo]Z2?l0
00001Ooonf[o0000o`000?l0003ooo]Z00?o000000Gooo]Zo`000?l0003o0000oookJP06o`000005
oookJ_l0003o0000o`000?oonfX03?l00004oookJP_o00001?oonfX3o`000004oookJ_l0003o0000
o`0000;ooo]Z5?l00005oookJPgo00001_oonfX:o`000003oookJ_l0003o000000Go000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`00000=o`000005oookJ_l0003o0000o`000?oonfX00ol0
0003oookJP?o000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000003o`000003oookJ_l0
003o000000Co00000_oonfX3o`0000?ooo]Z0ol00006oookJPGo00001?oonfX:o`0000;ooo]Z0ol0
0002oookJPSo00000_oonfX6o`0000Cooo]Z0ol000000ooonf[o0000o`000005o`0000?ooo]Z1Ol0
0002oookJPgo00000ooonfX6o`0000;ooo]Z0ol00007oookJPSo000000?ooo]Zo`000?l000008?l0
0002oookJP?o00000_oonfX7o`00027ooo]Z001EoookJPGo000000?ooo]Zo`000?l000002ol00000
0ooonf[o0000o`000005o`0000;ooo]Z1ol000000ooonf[o0000o`000009o`0000?ooo]Z0ol00002
oookJP?o00000_oonfX4o`000003oookJ_l0003o000000Co00000ooonfX7o`0000Wooo]Z0ol00000
1?oonf[o0000o`000?l00002oookJPOo000000Gooo]Zo`000?l0003o0000oookJP06o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000002Ol00004oookJPKo00000_oonfX3o`0000?ooo]Z
0ol00002oookJQSo00001?oonfX?o`000004oookJ_l0003o0000o`0000;ooo]Z0ol00002oookJPGo
00000_oonfX5o`0000Cooo]Z3Ol000000ooonf[o0000o`00000=o`0000;ooo]Z1?l000000ooonf[o
0000o`000003o`0000;ooo]Z1Ol00003oookJPCo00000_oonfX8o`0000?ooo]Z0ol000000ooonf[o
0000o`000005o`0000Cooo]Z0ol00008oookJQOo000000Cooo]Zo`000?l0003o00001?oonfX4o`00
00?ooo]Z3_l000000ooonf[o0000o`000003o`0000;ooo]Z4_l000000ooonf[o0000o`000005o`00
00?ooo]Z2_l000000ooonf[o0000o`00000Io`0000;ooo]Z0ol000001?oonf[o0000o`000?l0000Q
oookJP00EOoonfX5o`0000?ooo]Z1?l00006oookJPWo00000_oonfX3o`000005oookJ_l0003o0000
o`000?oonfX00ol000000ooonf[o0000o`00000;o`0000;ooo]Z2Ol000000ooonf[o0000o`000003
o`000003oookJ_l0003o000000So000000Cooo]Zo`000?l0003o00001OoonfX7o`0000Gooo]Z1_l0
0003oookJP_o000000?ooo]Zo`000?l000002_l00002oookJPOo00000_oonfX9o`0000?ooo]Z4?l0
0002oookJP?o00000_oonfXCo`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002ol0
0005oookJQWo00001?oonfX4o`0000;ooo]Z0ol00004oookJP_o00000ooonfX>o`000003oookJ_l0
003o000000Oo00000_oonfX4o`0000Oooo]Z5ol00008oookJPCo00000ooonfX:o`000005oookJ_l0
003o0000o`000?oonfX01?l00002oookJQ?o000000?ooo]Zo`000?l000000ol00003oookJPco0000
0_oonfX9o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000002?l000001?oonf[o0000
o`000?l0000QoookJP00EOoonfX5o`0000?ooo]Z1_l00002oookJP_o00000_oonfX3o`000003oook
J_l0003o000001?o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`000003o`000003oook
J_l0003o000000co00000ooonfX9o`0000Gooo]Z1_l00009oookJPGo000000?ooo]Zo`000?l00000
1Ol00002oookJP?o00000_oonfX5o`0000Cooo]Z7?l00005oookJQCo00000_oonfX5o`0000Cooo]Z
3Ol00005oookJPGo00000_oonfXBo`0000Cooo]Z1?l00002oookJPSo00001?oonfXGo`000003oook
J_l0003o000000go00000ooonfX=o`0000;ooo]Z3?l00008oookJQ7o000000?ooo]Zo`000?l00000
6ol00002oookJPCo000000?ooo]Zo`000?l000003?l00002oookJQCo000000?ooo]Zo`000?l00000
4Ol0000LoookJP00EOoonfX4o`0000;ooo]Z2?l00002oookJPoo00001?oonfXCo`000003oookJ_l0
003o000000Ko00001?oonfX4o`000003oookJ_l0003o000000co00000ooonfX9o`0000Gooo]Z1ol0
0008oookJP?o00001ooonfX4o`000004oookJ_l0003o0000o`0000;ooo]Z7_l000000ooonf[o0000
o`000006o`0000?ooo]Z3Ol000000ooonf[o0000o`000004o`0000;ooo]Z1Ol00004oookJQ3o0000
0_oonfX3o`0000Cooo]Z0ol000001?oonf[o0000o`000?l00004oookJPOo00001?oonfX4o`0000Co
oo]Z1_l00004oookJQSo000000Cooo]Zo`000?l0003o00000_oonfX9o`0000?ooo]Z8?l00003oook
JR;o000000?ooo]Zo`000?l000002_l00002oookJPCo000000?ooo]Zo`000?l000002Ol00005oook
JPCo00000_oonfX:o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000003ol0000Loook
JP00EOoonfXCo`0000?ooo]Z3?l000000ooonf[o0000o`00000;o`0000;ooo]Z2_l000001?oonf[o
0000o`000?l00002oookJPGo00001?oonfX:o`0000;ooo]Z2ol00005oookJPOo00002?oonfX>o`00
00Kooo]Z3Ol00004oookJQKo00000_oonfXDo`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000001_l000001Ooonf[o0000o`000?l0003ooo]Z00So00002OoonfX3o`0000Cooo]Z0ol00000
1?oonf[o0000o`000?l00003oookJP?o000000?ooo]Zo`000?l000000ol00004oookJPOo00001?oo
nfX3o`000003oookJ_l0003o000001Wo000000Cooo]Zo`000?l0003o00001OoonfX6o`000003oook
J_l0003o000000Wo000000?ooo]Zo`000?l000003?l00003oookJQko000000Cooo]Zo`000?l0003o
00000ooonfX8o`0000;ooo]Z1_l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Co
00000_oonfX7o`0000;ooo]Z2Ol00004oookJQGo00007?oonfX005Gooo]Z4ol000000ooonf[o0000
o`00000Bo`0000?ooo]Z1Ol00002oookJPko000000?ooo]Zo`000?l000000_l00006oookJP?o0000
00?ooo]Zo`000?l000001?l00002oookJP_o00001OoonfX7o`0000Wooo]Z3Ol00007oookJPco0000
1?oonfX@o`0000;ooo]Z2Ol00002oookJPko00000_oonfX3o`0000?ooo]Z2?l000001Ooonf[o0000
o`000?l0003ooo]Z00So00004?oonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z2Ol00006oook
JPOo00000_oonfX9o`000003oookJ_l0003o000001?o000000Gooo]Zo`000?l0003o0000oookJP03
o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000D
o`0000Gooo]Z1ol00004oookJPSo000000?ooo]Zo`000?l000002ol00002oookJPOo00000ooonfX3
o`0000Sooo]Z1ol00002oookJPSo000000?ooo]Zo`000?l000006ol00002oookJP?o00007?oonfX0
05Gooo]Z4Ol00003oookJQGo00000_oonfX6o`0000;ooo]Z5?l00005oookJPWo00000_oonfX9o`00
00Sooo]Z0ol00006oookJPCo00000_oonfX<o`000004oookJ_l0003o0000o`0000?ooo]Z3ol00008
oookJP[o00001?oonfX8o`0000;ooo]Z0ol00003oookJP?o000000?ooo]Zo`000?l000004Ol00000
0ooonf[o0000o`000009o`0000Gooo]Z0ol00007oookJPGo000000?ooo]Zo`000?l000003_l00002
oookJP_o00001?oonfX6o`000003oookJ_l0003o000001Oo000000?ooo]Zo`000?l000001_l00000
1?oonf[o0000o`000?l00003oookJQ?o00002_oonfX5o`0000?ooo]Z1?l00002oookJQ7o00000ooo
nfX3o`0000Kooo]Z0ol00008oookJQ7o00000_oonfX3o`000003oookJ_l0003o000001Co00000_oo
nfX5o`0001cooo]Z001EoookJP[o00001OoonfX8o`000003oookJ_l0003o000000oo00000ooonfX5
o`0000;ooo]Z5ol00002oookJPCo00000_oonfX3o`0000Cooo]Z1ol00006oookJP?o00000_oonfX:
o`000003oookJ_l0003o0000027o00001_oonfX=o`000003oookJ_l0003o000000go00000ooonfXG
o`000003oookJ_l0003o000000Wo00001OoonfX4o`0000Kooo]Z0ol00002oookJQ7o00000_oonfX=
o`0000;ooo]Z2Ol000000ooonf[o0000o`000004o`0000;ooo]Z1_l00002oookJP?o00001?oonfX8
o`000004oookJ_l0003o0000o`0000?ooo]Z3?l00008oookJP?o000000Cooo]Zo`000?l0003o0000
0_oonfX6o`000003oookJ_l0003o000000Go00000_oonfX?o`0000?ooo]Z1_l00004oookJP?o0000
1ooonfX4o`0000?ooo]Z3?l000000ooonf[o0000o`00000:o`000003oookJ_l0003o000000Wo0000
0ooonfX3o`0001kooo]Z001EoookJP[o00001OoonfX6o`0000?ooo]Z1ol000000ooonf[o0000o`00
0007o`0000?ooo]Z1Ol00003oookJP?o00000_oonfX3o`0000?ooo]Z1?l000000ooonf[o0000o`00
0004o`0000;ooo]Z1?l00002oookJPWo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00
000@o`000005oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o0000o`00000>o`0000;ooo]Z
2Ol00002oookJP?o000000?ooo]Zo`000?l000001Ol00003oookJRoo00000_oonfX8o`0000Gooo]Z
1ol00002oookJPGo000000?ooo]Zo`000?l000001ol000001Ooonf[o0000o`000?l0003ooo]Z01?o
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000005o`0000Cooo]Z3?l00004oookJPSo
00001OoonfX<o`0000Cooo]Z0ol00003oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX>o`00
00;ooo]Z4_l000000ooonf[o0000o`000003o`0000Cooo]Z1ol00008oookJPko000000Cooo]Zo`00
0?l0003o00000ooonfX6o`000004oookJ_l0003o0000o`0000;ooo]Z1?l000001Ooonf[o0000o`00
0?l0003ooo]Z00?o00007_oonfX005Gooo]Z2_l00005oookJPKo00000ooonfX7o`0000;ooo]Z2_l0
0002oookJP?o00001?oonfX9o`0000[ooo]Z0ol00008oookJPWo000000?ooo]Zo`000?l000004ol0
00000ol007oooo]ZoookJP02oookJP?o000000?o001oo`000?l000005?l00004oookJP?o00001?oo
nfX3o`000003oookJ_l0003o000000Ko00000_oonfX<o`0000;ooo]Z8Ol00003oookJPCo001o1Ol0
00000ooonf[o001oo`000007o`000003oookJ_l007oo000000Co000000?ooo]Zo`000?l000001ol0
00001?oonf[o0000o`000?l00002oookJQ;o000000?ooo]Zo`000?l000003_l000000ooonf[o0000
o`000002o`0000;ooo]Z1?l00004oookJP_o00001?oonfX?o`000004oookJ_l0003o0000o`0000;o
001o1?l000001?oonf[o0000o`000?l00002o`00O`ko00000_oonfX5o`0000;ooo]Z0ol000000ooo
nf[o0000o`00000;o`000003oookJ_l0003o000000So00001ooonfXCo`0000?ooo]Z1_l000001?l0
07oo0000o`000?l00002oookJP05o`00Ool0003o0000o`000?l007l00ol000001?oonf[o0000o`00
0?l00003o`00O`Gooo]Z1Ol007l5oookJPGo001o1ooonfX005Gooo]Z1?l000001?oonf[o0000o`00
0?l00008oookJPGo00000ooonfX7o`0000?ooo]Z2Ol00002oookJP?o000000?ooo]Zo`000?l00000
1_l000000ooonf[o0000o`000002o`0000Wooo]Z1_l00006oookJQCo000000?o001oo`000?l00000
2Ol00003oookJP?o00000ol007l3o`000003oookJ_l007oo001o00Co000000?o001ooookJ_l00000
2?l00008oookJPGo00000_oonfX7o`0000;ooo]Z2?l00008oookJQOo00000_oonfX7o`000003oook
J_l007oo000000;o000000?o001oo`000?l000003Ol000000ol007oo0000o`00000=o`000003o`00
Oooonf[o000000;o00000_oonfX7o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l00000
2_l000001Ooonf[o0000o`000?l0003ooo]Z00[o000000?ooo]Zo`000?l000001ol00002oookJP?o
00001?oonfX:o`0000;o001o3?l00003oookJPCo001o3ol00002oookJPCo000000Cooo]Zo`000?l0
003o00001OoonfX:o`000003oookJ_l0003o000000Wo00001_oonfXCo`0000?ooo]Z0ol007l3o`00
00?o001o0_oonfX2o`00O`_o00001?l007l3oookJPOo001o0ooonfX7o`00O`Kooo]Z001EoookJPCo
000000Cooo]Zo`000?l0003o00002_oonfX3o`0000Gooo]Z3?l000000ooonf[o0000o`000002o`00
00;ooo]Z0ol000000ooonf[o0000o`00000Ao`0000Gooo]Z1Ol00005oookJPgo000000?ooo]Zo`00
Ool000001?l00002o`00O`;ooo]Z5?l000000ooonf[o001oo`00O`03o`0000;o001o00?ooo]Zo`00
0?l000000_l000000ooonf[o0000o`000002o`0000Gooo]Z1_l00003oookJP?o000000?ooo]Zo`00
0?l000000_l00002oookJPSo00001ooonfXKo`0000?o001o2?l00003o`00O`Wo000000Go001oo`00
0?l0003o0000o`00O`09o`0000?o001o0ol000000ol007oooo]ZoookJP03oookJPOo00000_oonfX>
o`0000;ooo]Z1ol000001?oonf[o0000o`000?l00004oookJPOo000000?ooo]Zo`000?l000001ol0
0002oookJQOo000000?ooo]Zo`00Ool000001Ol00003oookJP[o00000_l007l7o`0000;ooo]Z0ol0
0002oookJP?o00002OoonfX>o`000004oookJ_l0003o0000o`0000Cooo]Z3Ol00002oookJPKo0000
0_oonfX3o`0000;o001o1ooonfX2o`00O`_o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP00EOoonfX4o`00
0003oookJ_l0003o000000Go00001OoonfX6o`0000?ooo]Z3?l000000ooonf[o0000o`000002o`00
00;ooo]Z6_l00002oookJPSo00000_oonfX=o`000003oookJ_l007oo000000Oo000000?ooo]Zo`00
0?l000004Ol000001?oonf[o001oo`00Ool007l3o`0000?o001o2Ol00003oookJQ;o00000ooonfX;
o`0000?ooo]Z2?l000000ooonf[o0000o`000004o`0000Gooo]Z0ol000000ooonf[o0000o`000002
o`0000?o001o2?l000001?oonf[o001oo`00Ool007l9o`000003o`00Oooonf[o001o00co000000Co
oo]Zo`000?l0003o00000_l007l4oookJPOo00001_oonfX:o`0000?ooo]Z1_l000000ooonf[o0000
o`00000<o`000003oookJ_l0003o000000Oo00001OoonfXDo`0000;o001o6?l000001?l007oo0000
o`000?l00002oookJP_o00002?oonfX<o`000005oookJ_l0003o0000o`000?oonfX06?l00002oook
JP?o00000ol007l5oookJP?o00000ooonfX6o`000004o`00Oooonf[ooo]ZoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00EOoo
nfX4o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000003_l000000ooonf[o0000o`00
000=o`000003oookJ_l0003o000000go000000?ooo]Zo`000?l000001ol00002oookJQGo00000_oo
nfX:o`000003oookJ_l007oo000000;o00000_oonfX2o`00O`co000000?o001oo`000?l000001?l0
0002o`00O`Ko00000_oonfX9o`0000;ooo]Z2ol00002oookJPco00000ooonfX6o`0000?ooo]Z2Ol0
0002oookJP?o000000?ooo]Zo`000?l000000_l00003o`00O`03oookJ_l0003o000000So000000?o
001oo`000?l000001ol000000ol007oooo]Zo`00O`03o`000003oookJ_l0003o000000;o000000?o
oo]Zo`000?l000001Ol00002o`00O`Wo00003?oonfX3o`0000?ooo]Z6?l00002oookJPSo00001Ooo
nfXGo`0000;ooo]Z5Ol000001Ol007oo0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l00000
1ol00003oookJPgo00002?oonfXNo`0000Co001o0ooonfX3o`000004oookJ_l0003o0000o`0000;o
001o00Cooo]Zo`000?l0003o00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX005Gooo]Z3?l000000ooonf[o0000o`00000>
o`000003oookJ_l0003o000000go000000Cooo]Zo`000?l0003o00000ooonfX9o`0000;ooo]Z2?l0
0002oookJP_o00001OoonfX5o`0000;ooo]Z2_l000000ooonf[o001oo`000002o`0000;ooo]Z0ol0
07lDo`0000?ooo]Z3ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000_o00000ooo
nfX6o`0000?ooo]Z2Ol00002oookJPWo00000_l007l00ooonf[o0000o`000008o`000003o`00Oooo
nf[o000000Oo000000?o001oo`000?l000000ol00002oookJP_o00000_l007l9o`0000Sooo]Z1?l0
0006oookJPKo00000ooonfX?o`0000;ooo]Z0ol0000;oookJP?o00000_l007l6o`0000;ooo]Z1?l0
00000ol007oooo]Zo`000003o`0000;ooo]Z00?o001oo`000?l000003ol000000ooonf[o0000o`00
000Ao`0000?ooo]Z3Ol00007oookJPCo000000Cooo]Zo`000?l0003o00001?oonfX;o`000003oook
J_l0003o000000Go000000?ooo]Zo`00Ool007l00ol000000ooonf[o0000o`00000;o`0000?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Gooo]Z001EoookJQ7o00001?oonfX8o`0000;ooo]Z4ol00002oookJPKo000000Gooo]Zo`000?l0
003o0000oookJP06o`0000Cooo]Z2ol00005oookJPko00000ol007l00ooonf[o001oo`000005o`00
00;o001o5?l00005oookJPgo000000?ooo]Zo`000?l000005?l00009oookJPGo000000?ooo]Zo`00
0?l000007ol000000ol007oooo]Zo`000003o`000003oookJ_l0003o000000[o000000?o001oo`00
0?l000001ol00002o`00O`_o00001_oonfX6o`0000;ooo]Z2Ol00002oookJP[o000000?ooo]Zo`00
0?l000000_l000001?oonf[o0000o`000?l00005oookJP?o00001?oonfX3o`0000?o001o1Ol00000
0ol007oooo]Zo`000002o`0000;o001o00?ooo]Zo`000?l000000_l00002oookJP?o001o2?l00002
o`00O`03oookJ_l007oo000000;o000000?ooo]Zo`000?l000002?l00003oookJPKo00000ooonfX6
o`0000_ooo]Z1_l00002oookJPCo00001OoonfXAo`0000;ooo]Z00Go001oo`000?l0003o0000oook
JP03o`00O`go00000ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z001EoookJPGo00000ooonfX6o`0000gooo]Z5ol00004oookJP?o0000
00?ooo]Zo`000?l000000_l000000ooonf[o0000o`000004o`0000Cooo]Z2_l0000:oookJP?o0000
0_oonfX6o`000003o`00Oooonf[ooo]Z00?o001o00?ooo]Zo`000?l000000ol000000ooonf[o001o
o`00000<o`0000;ooo]Z0ol00005oookJPKo000000?ooo]Zo`000?l000001?l00004oookJQGo0000
0ooonfX3o`000003oookJ_l0003o000000?o00001OoonfXLo`0000;o001o00?ooo]Zo`00Ool00000
6?l00003o`00O`03oookJ_l0003o000000;o00000_oonfX7o`0000?ooo]Z1_l00002oookJPWo0000
0_oonfX6o`0000Gooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000Cooo]Zo`000?l0
003o00001?oonfX;o`0000;o001o1_l000000ol007oo0000o`000004o`0000;o001o1Ol00002oook
JP?o001o4Ol00002oookJPgo00003OoonfX6o`0000;ooo]Z1?l00003oookJQ;o00001?oonfX5o`00
00;o001o2?l00002o`00O`?o00000ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Gooo]Z001EoookJPOo000000?ooo]Zo`000?l000001ol0000:
oookJPGo00000_oonfX5o`000003oookJ_l0003o000000So00001?oonfX8o`0000Wooo]Z3?l00003
oookJP?o00001?oonfX3o`0000;ooo]Z1_l00003oookJP?o001o00?ooo]Zo`000?l000000ol00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000Wo00000_l007l7oookJPCo000000?ooo]Z
o`000?l000001?l00002oookJPKo00000ooonfX>o`0000;ooo]Z2_l00003oookJP?o000000?ooo]Z
o`000?l000002_l000000ooonf[o0000o`00000>o`000003o`00Ool0003o000001Oo00000_l007l?
o`000005oookJ_l0003o0000o`000?oonfX01?l00002oookJP?o000000?ooo]Zo`000?l000000ol0
0002oookJP[o000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000003o`0000?ooo]Z2_l0
0005o`00O`?o00000ol007l9o`000004o`00Oooonf[ooo]ZoookJP?o001o1ol00003o`00O`03oook
J_l0003o000001;o00000ooonfX3o`0000Gooo]Z2?l00004oookJPGo000000?ooo]Zo`000?l00000
4_l00002oookJPGo00000_l007l8o`0000;o001o0ol00003o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX005Gooo]Z1ol000000ooonf[o
0000o`00000=o`0000?ooo]Z1_l00003oookJPGo00000ooonfX6o`0000Sooo]Z1Ol00006oookJQGo
00001?oonfX3o`0000;ooo]Z2Ol00003o`00O`?ooo]Z0ol000000ooonf[o0000o`000003o`000003
oookJ_l0003o000000[o000000?o001ooookJ_oonfX00_oonfX>o`0000;ooo]Z5ol00002oookJPSo
00001OoonfX3o`000005oookJ_l0003o0000o`000?oonfX02?l000000ol007oo0000o`00000>o`00
00?o001o5ol00002o`00O`Wo00000_oonfX4o`000003oookJ_l0003o0000013o000000?ooo]Zo`00
0?l000002_l00002oookJPKo000000?ooo]Zo`000?l000000_l00003oookJP?o00000_oonfX00ol0
07oo0000o`000008o`000003o`00Oooonf[ooo]Z00;ooo]Z3ol000001?l007oooo]ZoookJ_oonfX3
o`00O`Oo00000ol007l2oookJQCo00000_oonfX6o`0000;ooo]Z0ol00002oookJP?o00000ooonfX:
o`000003oookJ_l0003o000000ko00000_oonfX5o`0000;o001o2_l00003oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00EOoo
nfX7o`000003oookJ_l0003o000000ko00000_oonfX5o`0000Kooo]Z0ol00003oookJPKo00002?oo
nfX5o`0000Kooo]Z1_l00003oookJPko00001_oonfX3o`0000?ooo]Z1?l000001Ooonf[o001oo`00
Ool007oooo]Z00?o001o0_oonfX5o`0000?o001o2ol00004oookJPoo000000?ooo]Zo`000?l00000
5?l00002oookJP[o00001?oonfX3o`000005oookJ_l0003o0000o`000?oonfX02?l000000ol007oo
0000o`00000:o`000005o`00Ool0003o0000o`000?oonfX00ol007l8o`000003o`00Ool0003o0000
01Ko00000ooonfXFo`000003oookJ_l0003o000000[o00000_oonfX:o`0000Cooo]Z1Ol000000ol0
07oo0000o`00000;o`000003oookJ_l0003o000000go00000ol007l01Ooonf[o001oo`00Ool007oo
oo]Z00Oo00000_l007l5oookJPko000000Cooo]Zo`000?l0003o00000_oonfX;o`0000;ooo]Z0ol0
0003oookJPco000000?ooo]Zo`000?l000003Ol000000ooonf[o001oo`00O`09o`000003o`00Ool0
003o000000?o000000?o001ooookJ_l007l00_l007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z001EoookJPKo00000_oonfX@o`0000;ooo]Z
1Ol00005oookJPKo000000?ooo]Zo`000?l000001?l00002oookJP?o00001?oonfX6o`0000Cooo]Z
1_l00003oookJPko000000?ooo]Zo`000?l000001_l00003o`00O`Co000000?ooo]Zo`00Ool007l0
1Ol007l2oookJPGo00000ol007l6o`000003o`00Ool0003o000000;o00000_oonfX;o`0000?ooo]Z
0ol00002oookJPWo000000Gooo]Zo`000?l0003o0000oookJP03o`000004oookJ_l0003o0000o`00
00;ooo]Z0ol000000ooonf[o0000o`00000;o`0000;ooo]Z2?l00003oookJP03o`00Ool0003o0000
017o000000?o001oo`000?l000001_l000001?l007oo0000o`000?l00002o`00O`?o000000?o001o
o`000?l000003Ol00003oookJQKo000000?ooo]Zo`000?l000001Ol00007oookJPgo00000ooonfXS
o`0000;o001o2ol00002o`00O`Gooo]Z2Ol00004oookJPGo00001OoonfX5o`0000Gooo]Z1?l00000
0ooonf[o0000o`000004o`000003oookJ_l0003o000000Co000000Cooo]Zo`000?l0003o00001_oo
nfX6o`0000?o001o2?l00002o`00O`So00000_l007l3oookJPOo001o0ooonfX7o`00O`Kooo]Z001E
oookJPco00000_oonfX:o`0000?ooo]Z1ol000000ooonf[o0000o`000005o`0000?ooo]Z0ol00003
oookJPGo00000ooonfX5o`0000Cooo]Z1_l00002oookJQSo00000ol007l3o`0000?ooo]Z00?o001o
o`000?l000000ol000000ooonf[o0000o`000004o`0000;o001o00?ooo]Zo`000?l000000ol00000
0ol007oo0000o`000003o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000004?l00004
oookJPOo000000Cooo]Zo`000?l0003o00000_oonfX3o`000003oookJ_l0003o000000co000000?o
oo]Zo`000?l000002Ol000000ooonf[o0000o`000007o`0000;o001o2?l00003o`00O`Ko000000Go
001oo`000?l0003o0000o`00O`04oookJPSo000000?ooo]Zo`000?l000001?l00006oookJP[o0000
00?ooo]Zo`000?l000000_l000000ooonf[o0000o`000002o`0000;ooo]Z1_l00009oookJQSo0000
00?ooo]Zo`000?l000002_l000000ooonf[o001oo`000009o`0000;o001o2ol000001?l007oooo]Z
oookJ_oonfX<o`0000?ooo]Z1_l00002oookJP[o00001?oonfXAo`000004oookJ_l0003o0000o`00
00?ooo]Z2_l000001?l007oooo]ZoookJ_oonfX3o`0000;o001o2ol000000ol007oooo]ZoookJP03
oookJPGo001o1OoonfX5o`00O`Oooo]Z001EoookJPGo000000?ooo]Zo`000?l000001?l00006oook
JP?o00001?oonfX9o`000003oookJ_l0003o000000Ko00000_oonfX3o`0000?ooo]Z4?l000001?oo
nf[o0000o`000?l00003oookJPko000000?ooo]Zo`000?l000001_l00002oookJP?o000000Cooo]Z
o`000?l0003o00001?oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z0ol00002oookJPWo0000
0_oonfX;o`000003oookJ_l0003o000000oo00000_oonfX6o`000003oookJ_l0003o000000;o0000
1_oonfX=o`000003oookJ_l0003o000000?o00000_oonfX4o`000003oookJ_l0003o000000?o0000
00Gooo]Zo`000?l0003o0000oookJP04o`0000;ooo]Z3?l000001?oonf[o0000o`000?l00005oook
JPSo000000Cooo]Zo`000?l0003o00000ooonfX3o`0000Cooo]Z2Ol000000ooonf[o0000o`000002
o`0000;ooo]Z1?l000000ooonf[o0000o`000002o`0000Cooo]Z0ol00003oookJPOo000000?ooo]Z
o`000?l000003ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000;o00001?oonfX8
o`0000;ooo]Z2Ol00006oookJPgo00000_oonfX4o`0000Cooo]Z3?l00002oookJQGo000000?ooo]Z
o`000?l000002_l00004oookJPCo000000Gooo]Zo`000?l0003o0000oookJP07o`0001cooo]Z001E
oookJPGo000000?ooo]Zo`000?l000001?l00007oookJPGo000000?ooo]Zo`000?l000001ol00000
0ooonf[o0000o`000006o`0000;ooo]Z1?l00004oookJPko000000Cooo]Zo`000?l0003o00000ooo
nfX6o`0000;ooo]Z1_l000000ooonf[o0000o`000006o`0000;ooo]Z0ol000000ooonf[o0000o`00
0002o`0000?ooo]Z2Ol00002oookJPko000000?ooo]Zo`000?l000002?l00003oookJPco000000?o
oo]Zo`000?l000002_l00002oookJP?o00000_oonfX3o`000003oookJ_l0003o000000co00000_oo
nfX3o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000000[o000000Cooo]Zo`000?l0003o00001OoonfX<o`0000?ooo]Z
0ol000000ooonf[o0000o`000008o`0000[ooo]Z0ol00004oookJP?o000000?ooo]Zo`000?l00000
0_l00003oookJPOo000000Gooo]Zo`000?l0003o0000oookJP06o`0000Cooo]Z1Ol00006oookJPGo
000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z0ol00002oookJPWo00001OoonfXBo`00
00Cooo]Z3Ol00003oookJPGo000000?ooo]Zo`000?l000003?l000000ooonf[o0000o`000005o`00
00;ooo]Z0ol00004oookJPCo000000?ooo]Zo`000?l000002_l0000KoookJP00EOoonfX5o`0000?o
oo]Z1?l00002oookJPko00001OoonfX;o`0000;ooo]Z0ol000000ooonf[o0000o`00000Ko`0000Go
oo]Z3Ol00002oookJPSo00001OoonfX5o`0000Cooo]Z6Ol00009oookJPKo000000?ooo]Zo`000?l0
00003ol00002oookJP?o000000?ooo]Zo`000?l000003?l00002oookJPOo00000ooonfX7o`0000?o
oo]Z5ol00005oookJPWo00001OoonfX3o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l0
00001?l00002oookJP?o00000_oonfX3o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`0000?o
oo]Z1_l00002oookJP?o00001?oonfX6o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0
003o00000_oonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000006o`0000;ooo]Z2ol00006oook
JQ7o000000?ooo]Zo`000?l000000_l00002oookJPSo00000_oonfX:o`0000Cooo]Z1ol000001?oo
nf[o0000o`000?l00006oookJPCo00001?oonfX3o`0000;ooo]Z2ol0000KoookJP00EOoonfX5o`00
00?ooo]Z1?l00002oookJPko00001OoonfX@o`000003oookJ_l0003o000000Wo000000?ooo]Zo`00
0?l000002_l00003oookJPGo000000?ooo]Zo`000?l000003?l00003oookJPOo00001OoonfX5o`00
00Oooo]Z5_l00006oookJPKo00001?oonfX>o`0000Gooo]Z0ol00009oookJPKo00000_oonfX7o`00
00?ooo]Z0ol000001?oonf[o0000o`000?l00004oookJP[o00000ooonfX;o`0000?ooo]Z2Ol00006
oookJPSo00000_oonfX6o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z2Ol00000
1?oonf[o0000o`000?l00002oookJPOo00001_oonfX<o`000004oookJ_l0003o0000o`0000;ooo]Z
0ol00003oookJQ_o00002?oonfX=o`000003oookJ_l0003o000000;o00000_oonfX8o`0000;ooo]Z
2Ol00009oookJPCo00001?oonfX3o`0000;ooo]Z1?l00003oookJP?o00000ooonfX;o`0001_ooo]Z
001EoookJPGo00000ooonfX4o`0000;ooo]Z1Ol00005oookJP?o00001_oonfX4o`000003oookJ_l0
003o000000Wo000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000:o`0000?ooo]Z1Ol0
00000ooonf[o0000o`00000<o`0000?ooo]Z1ol00005oookJP[o00000_oonfX4o`000003oookJ_l0
003o000000Go000000?ooo]Zo`000?l000000_l00002oookJP?o000000?ooo]Zo`000?l000002?l0
0005oookJP?o000000?ooo]Zo`000?l000002?l0000?oookJP?o00001ooonfX6o`0000Cooo]Z0ol0
0003oookJPoo00000ooonfX;o`0000;ooo]Z2_l00006oookJPSo00000_oonfX6o`0000;ooo]Z0ol0
00000ooonf[o0000o`000002o`0000;ooo]Z1_l00002oookJPGo000000Gooo]Zo`000?l0003o0000
oookJP04o`0000Kooo]Z2?l000000ooonf[o0000o`000005o`0000;ooo]Z0ol00005oookJQWo0000
0ooonfX3o`0000Gooo]Z2_l000000ooonf[o0000o`00000<o`0000;ooo]Z3Ol00005oookJP_o0000
0_oonfX6o`000004oookJ_l0003o0000o`0000;ooo]Z3?l0000KoookJP00EOoonfX5o`0000;ooo]Z
1_l00002oookJPOo00002ooonfX3o`0000Cooo]Z1ol00003oookJPSo00001?oonfX<o`0000?ooo]Z
1Ol000000ooonf[o0000o`000007o`0000;ooo]Z0ol00003oookJPGo00002?oonfX:o`000003oook
J_l0003o000000oo00001?oonfX<o`0000Gooo]Z0ol00006oookJPGo00002ooonfX7o`000003oook
J_l0003o000000Oo00000_oonfX3o`0000;ooo]Z0ol00002oookJPOo00000_oonfX3o`0000Gooo]Z
0ol000001?oonf[o0000o`000?l00003oookJPCo000000?ooo]Zo`000?l000002?l00002oookJPWo
000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000009o`0000Gooo]Z1?l00002oookJPko
00001_oonfX8o`000003oookJ_l0003o000000Co00000ooonfX3o`0000Cooo]Z6_l00002oookJPGo
00000ooonfX<o`0000?ooo]Z4ol00002oookJPSo00000_oonfX<o`000003oookJ_l0003o000000Co
000000Cooo]Zo`000?l0003o00000_oonfX<o`0001_ooo]Z001:oookJ_oo0000j?l0000?oookJP00
B_oonf[oo`000>So00003ooonfX004[ooo]Zool0003Xo`0000oooo]Z001:oookJ_oo0000j?l0000?
oookJP00EOoonfX7o`0000;ooo]Z0ol00004oookJPSo000000Gooo]Zo`000?l0003o0000oookJP07
o`0000kooo]Z0ol00002oookJPKo00001_oonfX3o`0000;ooo]Z2ol00003oookJPco00001?oonfX<
o`0000;ooo]Z0ol00004oookJPGo000000Cooo]Zo`000?l0003o00000_oonfX6o`0000;ooo]Z0ol0
0002oookJPko000000?ooo]Zo`000?l000001ol00002oookJPSo00000_oonfXNo`000004oookJ_l0
003o0000o`0000Kooo]Z2_l00003oookJPGo00001?oonfX9o`0000Gooo]Z3Ol00003oookJPCo0000
1OoonfXAo`000004oookJ_l0003o0000o`0000;ooo]Z1_l00002oookJPGo00001?oonfX4o`0000Oo
oo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;o00000ooonfX4o`000003
oookJ_l0003o000000;o00000_oonfX3o`0000Cooo]Z1?l00006oookJP?o000000?ooo]Zo`000?l0
00003Ol00003oookJPKo000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000;o`0000?o
oo]Z1Ol00002oookJPGo000000?ooo]Zo`000?l000002_l00002oookJP03o`000?oonf[ooo]Z01[o
oo]Z001EoookJPko00000_oonfXEo`0000Oooo]Z0ol00002oookJPGo00000ooonfX4o`0000Kooo]Z
0ol00002oookJPKo00001OoonfX3o`0000;ooo]Z0ol00003oookJPCo00001?oonfX;o`000003oook
J_l0003o000000Oo00000_oonfX3o`000003oookJ_l0003o000000Wo00000_oonfX3o`0000;ooo]Z
6?l00002oookJPgo00000_oonfX5o`0000?ooo]Z4ol00009oookJPSo00001?oonfX4o`0000Cooo]Z
1Ol0000:oookJPko000000?ooo]Zo`000?l000000ol00005oookJP?o00000_oonfX:o`0000Sooo]Z
1ol000001?oonf[o0000o`000?l00005oookJPCo00000ooonfX3o`0000_ooo]Z2ol00002oookJPSo
00001?oonfX4o`0000Kooo]Z4?l00006oookJPKo00001?oonfX7o`000003oookJ_l0003o000000Wo
00000ooonfXJo`0000;ooo]Z0ol0000KoookJP00EOoonfX@o`0000Gooo]Z4?l00007oookJP[o0000
0ooonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Co0000
1?oonfX4o`0000;ooo]Z1?l00002oookJP?o00000_oonfX3o`0000;ooo]Z5?l000000ooonf[o0000
o`00000=o`0000Oooo]Z2ol00002oookJPco000000?ooo]Zo`000?l000002ol00002oookJPGo0000
0ooonfXCo`0000Cooo]Z0ol00002oookJPSo00001OoonfX3o`000003oookJ_l0003o000000Oo0000
0_oonfX3o`0000Gooo]Z3Ol000000ooonf[o0000o`000003o`0000Cooo]Z1?l00002oookJQ;o0000
0ooonfX8o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000000ol00007oookJQoo0000
0_oonfXEo`0000Kooo]Z2?l000000ooonf[o0000o`000004o`0000;ooo]Z0ol000000ooonf[o0000
o`000006o`0000;ooo]Z5_l000000ooonf[o0000o`000002o`000004oookJ_l0003o0000o`0001_o
oo]Z001EoookJQ3o00001?oonfX:o`0000;ooo]Z1Ol00003oookJP?o000000?ooo]Zo`000?l00000
2?l00003oookJPCo00000_oonfX4o`000005oookJ_l0003o0000o`000?oonfX00ol00007oookJPCo
00000ooonfX3o`0000Oooo]Z2_l00003oookJPGo000000?ooo]Zo`000?l000001?l00003oookJP_o
00000_oonfX6o`0000;ooo]Z6_l000001?oonf[o0000o`000?l00003oookJPCo000000?ooo]Zo`00
0?l000000ol000000ooonf[o0000o`000009o`0000?ooo]Z2Ol00004oookJP?o00000_oonfX5o`00
00Cooo]Z0ol00002oookJQGo000000?ooo]Zo`000?l000006Ol00002oookJP?o000000?ooo]Zo`00
0?l000003_l00002oookJPGo00000ooonfX:o`000003oookJ_l0003o000000?o00001?oonfXHo`00
00;ooo]Z2Ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000Oo00002?oonfX6o`00
0004oookJ_l0003o0000o`0000Gooo]Z0ol000000ooonf[o0000o`000006o`000003oookJ_l0003o
000000Co000000Gooo]Zo`000?l0003o0000oookJP0;o`0000;ooo]Z1?l000001?oonf[o0000o`00
0?l0000KoookJP00EOoonfX@o`0000?ooo]Z1ol000000ooonf[o0000o`00000:o`000004oookJ_l0
003o0000o`0000Cooo]Z1Ol00005oookJPGo000000?ooo]Zo`000?l000001_l00004oookJP?o0000
1?oonfX:o`0000Kooo]Z1ol000000ooonf[o0000o`000003o`000004oookJ_l0003o0000o`0000?o
oo]Z1_l00003oookJPGo000000?ooo]Zo`000?l000000ol00002oookJR;o00001ooonfX3o`0000;o
oo]Z0ol00003oookJPGo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000007o`000003
oookJ_l0003o000000So00001_oonfXJo`000003oookJ_l0003o000000Ko00000ooonfX4o`000003
oookJ_l0003o000000go00000_oonfX@o`0000?ooo]Z1?l000000ooonf[o0000o`00000Bo`0000;o
oo]Z5ol00003oookJPWo000000?ooo]Zo`000?l000001Ol00006oookJPSo00002?oonfX6o`000003
oookJ_l0003o000000;o00001?oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z0ol000000ooo
nf[o0000o`000006o`0000?ooo]Z2ol000000ooonf[o0000o`000003o`0001oooo]Z001EoookJPko
00000ooonfX9o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000002?l00003oookJPKo
000000?ooo]Zo`000?l000001ol00002oookJPKo00001OoonfX3o`0000Cooo]Z2_l00005oookJPCo
000000?ooo]Zo`000?l000001ol000001Ooonf[o0000o`000?l0003ooo]Z00Go00001_oonfX:o`00
00;ooo]Z4?l000000ooonf[o0000o`000003o`0000Cooo]Z1?l00002oookJPOo00000_oonfX5o`00
0003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000006o`00
00Cooo]Z1_l000000ooonf[o0000o`000008o`0000Kooo]Z7Ol00003oookJP?o00000ooonfXGo`00
0004oookJ_l0003o0000o`0000;ooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00Ko000000Go
oo]Zo`000?l0003o0000oookJP0@o`0000;ooo]Z1?l00003oookJQ3o00000ooonfX4o`0000;ooo]Z
0ol000000ooonf[o0000o`000008o`0000?ooo]Z1_l00005oookJP?o00000_oonfX6o`000003oook
J_l0003o000000Co00002ooonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z0ol00004oookJPoo
00008?oonfX005Gooo]Z2?l000000ooonf[o0000o`00000=o`000005oookJ_l0003o0000o`000?oo
nfX00ol000000ooonf[o0000o`000008o`0000?ooo]Z1_l000000ooonf[o0000o`00000?o`0000Co
oo]Z1?l00005oookJPSo000000Cooo]Zo`000?l0003o00000_oonfX4o`000003oookJ_l0003o0000
00Oo000000?ooo]Zo`000?l000001Ol00002oookJP?o00001?oonfX:o`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?l000002Ol000001?oonf[o0000o`000?l0000?oookJPCo00000_oonfX;
o`0000;ooo]Z1Ol000000ooonf[o0000o`000005o`0000Gooo]Z1Ol000000ooonf[o0000o`000008
o`000004oookJ_l0003o0000o`0000?ooo]Z2?l000000ooonf[o0000o`00000Go`0000?ooo]Z5ol0
0006oookJPGo000000Gooo]Zo`000?l0003o0000oookJP05o`000003oookJ_l0003o000000;o0000
0_oonfX9o`0000;ooo]Z1?l000000ooonf[o0000o`000003o`000003oookJ_l0003o0000013o0000
00?ooo]Zo`000?l000001?l00002oookJPko00000ooonfX6o`0000;ooo]Z2?l00003oookJP?o0000
00?ooo]Zo`000?l000001?l00008oookJP?o00001?oonfX8o`000003oookJ_l0003o000000Co0000
00?ooo]Zo`000?l000002ol0000NoookJP00EOoonfX8o`000003oookJ_l0003o000000go000000?o
oo]Zo`000?l000000ol00002oookJP_o00000ooonfX5o`0000;ooo]Z1_l000000ooonf[o0000o`00
0005o`000003oookJ_l0003o000000;o00000_oonfX3o`0000Gooo]Z1_l00002oookJPKo000000Co
oo]Zo`000?l0003o00000_oonfX6o`0000Gooo]Z1_l00002oookJP?o00001?oonfX:o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000000_l00002oookJPGo00000_oonfX3o`0000;ooo]Z
0ol00009oookJPCo00000_oonfX;o`0000Cooo]Z2ol00005oookJPCo00000ooonfX6o`0000Cooo]Z
0ol00003oookJP?o000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000Ao`0000Gooo]Z
6?l00002oookJP?o00000ooonfX7o`0000?ooo]Z0ol00005oookJPCo00001OoonfX:o`000003oook
J_l0003o000000co00001OoonfX6o`0000;ooo]Z6?l000000ooonf[o0000o`000006o`0000?ooo]Z
0ol000000ooonf[o0000o`000006o`0000Kooo]Z1?l000000ooonf[o0000o`000005o`0000Cooo]Z
1_l000000ooonf[o0000o`000007o`000004oookJ_l0003o0000o`0001kooo]Z001EoookJP[o0000
1?oonfX6o`0000Gooo]Z1Ol000000ooonf[o0000o`000006o`0000Sooo]Z1Ol00002oookJPgo0000
00?ooo]Zo`000?l000000_l000000ooonf[o0000o`000002o`0000Gooo]Z1_l00002oookJPKo0000
00Cooo]Zo`000?l0003o00001OoonfX5o`0000?ooo]Z2ol00008oookJPKo000000Cooo]Zo`000?l0
003o00000_oonfX4o`0000;ooo]Z0ol00004oookJPoo00002?oonfX7o`000005oookJ_l0003o0000
o`000?oonfX03_l00005oookJPCo00000_oonfX7o`0000?ooo]Z1?l00003oookJP?o000000?ooo]Z
o`000?l000001_l00004oookJP?o00001ooonfX;o`0000?ooo]Z4_l00002oookJPCo00000_oonfX3
o`0000?ooo]Z1?l00004oookJPGo00000_oonfX6o`0000Kooo]Z0ol000000ooonf[o0000o`000004
o`000003oookJ_l0003o000000co00001OoonfX6o`0000;ooo]Z6?l000000ooonf[o0000o`00000=
o`0000Gooo]Z0ol00006oookJPco000000?ooo]Zo`000?l000001?l00006oookJP?o000000Gooo]Z
o`000?l0003o0000oookJP03o`0001kooo]Z001EoookJQGo000000Cooo]Zo`000?l0003o00000_oo
nfX>o`000004oookJ_l0003o0000o`0000;ooo]Z7_l00005oookJP?o000000?ooo]Zo`000?l00000
2?l000000ooonf[o0000o`00000;o`0000;ooo]Z2ol000000ooonf[o0000o`000005o`0000;ooo]Z
1_l00002oookJP?o000000?ooo]Zo`000?l000001_l00004oookJPoo00002?oonfX7o`000003oook
J_l0003o000000Go000000?ooo]Zo`000?l000001?l00004oookJPWo00000_oonfX3o`000004oook
J_l0003o0000o`0000?ooo]Z1_l00004oookJP_o00001_oonfX3o`000003oookJ_l0003o000000_o
00000ooonfX;o`000003oookJ_l0003o000000Co00000_oonfX4o`000003oookJ_l0003o000000Co
00000_oonfX5o`0000;ooo]Z3Ol00006oookJP?o000000?ooo]Zo`000?l000001?l00004oookJPWo
00001ooonfX5o`0000;ooo]Z1ol00003oookJQ3o00000ooonfX<o`0000Gooo]Z0ol00002oookJP?o
00000_oonfXCo`0000?ooo]Z0ol00003oookJP?o00001?oonfX3o`0001_ooo]Z001EoookJQ7o0000
00Gooo]Zo`000?l0003o0000oookJP0<o`0000Cooo]Z0ol000000ooonf[o0000o`000002o`0000?o
oo]Z6ol00006oookJP[o000000Cooo]Zo`000?l0003o00000ooonfXPo`0000;ooo]Z5ol000000ooo
nf[o0000o`00000@o`0000Cooo]Z2?l000000ooonf[o0000o`000005o`0000?ooo]Z4?l00003oook
JPOo00000ooonfX6o`0000;ooo]Z1Ol00005oookJP?o00001_oonfX3o`000003oookJ_l0003o0000
00co00000_oonfX;o`0000;ooo]Z1ol00005oookJPKo00000ooonfX4o`0000;ooo]Z3Ol00002oook
JP?o000000?ooo]Zo`000?l000002?l00003oookJPgo00000_oonfX7o`0000;ooo]Z6_l00002oook
JP?o000000?ooo]Zo`000?l000002_l00002oookJP?o000000?ooo]Zo`000?l000007Ol00002oook
JPCo00001?oonfX3o`0001_ooo]Z001EoookJPWo000000?ooo]Zo`000?l000001Ol000001Ooonf[o
0000o`000?l0003ooo]Z00oo000000Gooo]Zo`000?l0003o0000oookJP0<o`0000?ooo]Z4?l00008
oookJP_o000000?ooo]Zo`000?l000006ol000000ooonf[o0000o`000006o`0000;ooo]Z5ol00000
0ooonf[o0000o`00000Ao`0000?ooo]Z2?l00003oookJPKo00000_oonfX@o`0000Kooo]Z1Ol00004
oookJPCo00000_oonfX5o`0000;ooo]Z1ol000001Ooonf[o0000o`000?l0003ooo]Z00[o00000_oo
nfX6o`0000Cooo]Z1ol00002oookJPWo00001OoonfX6o`0000?ooo]Z1ol00002oookJPWo00000ooo
nfX3o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000003Ol00002oookJP?o00000_oo
nfX3o`000003oookJ_l0003o000001go00000_oonfX7o`000004oookJ_l0003o0000o`0000;ooo]Z
0ol000000ooonf[o0000o`000004o`000004oookJ_l0003o0000o`0000Gooo]Z6Ol000001?oonf[o
0000o`000?l0000KoookJP00EOoonfX:o`000003oookJ_l0003o000000So00001?oonfX<o`0000Ko
oo]Z2Ol00002oookJQ;o00002OoonfXGo`0000;ooo]Z1ol000000ooonf[o0000o`00000>o`000004
oookJ_l0003o0000o`0000Gooo]Z2ol000000ooonf[o0000o`000003o`0000Oooo]Z3Ol00003oook
JPSo00001_oonfX3o`0000;ooo]Z4?l00006oookJPGo00000ooonfX5o`0000;ooo]Z1?l00003oook
JPOo000000Cooo]Zo`000?l0003o00001?oonfX5o`0000;ooo]Z2?l00006oookJPGo00000_oonfX:
o`0000Gooo]Z1ol000001Ooonf[o0000o`000?l0003ooo]Z00Go000000?ooo]Zo`000?l000001Ol0
0004oookJP?o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`00000;o`0000;ooo]Z0ol0
0002oookJP?o00000_oonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000003o`0000?ooo]Z1ol0
0004oookJPKo00000_oonfX7o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002?l0
0004oookJP?o00001?oonfX7o`0000?ooo]Z3?l0000LoookJP00EOoonfX:o`000004oookJ_l0003o
0000o`0000;ooo]Z1_l00006oookJPWo00001_oonfX9o`0000;ooo]Z1_l00002oookJPWo00001?oo
nfXBo`0000;ooo]Z2?l00004oookJQOo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00
000>o`0000kooo]Z2_l00004oookJP?o00002_oonfX4o`0000;ooo]Z0ol000000ooonf[o0000o`00
000=o`0000;ooo]Z1Ol00003oookJPOo00001ooonfX7o`000003oookJ_l0003o000000oo00002?oo
nfX8o`0000;ooo]Z2_l00005oookJP?o000000Cooo]Zo`000?l0003o00001OoonfX5o`000003oook
J_l0003o000000Go00002?oonfX7o`000003oookJ_l0003o000000Ko00000_oonfX3o`0000cooo]Z
0ol00003oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPKo00001ooonfXHo`0000Oooo]Z
1?l00004oookJP?o00001?oonfX6o`0000Cooo]Z3?l0000LoookJP00EOoonfX:o`0000Kooo]Z1_l0
0006oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX3o`0000?ooo]Z0ol000001?oonf[o0000
o`000?l00004oookJPCo00001?oonfX9o`000003oookJ_l0003o000000Wo00000ooonfX7o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000_oonfX6o`000003oookJ_l0003o0000
00go00001?oonfX4o`000003oookJ_l0003o0000017o00000_oonfX3o`0000Wooo]Z1?l00007oook
JP?o00001ooonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z2ol00002oookJP[o00001OoonfX7
o`000004oookJ_l0003o0000o`0000?ooo]Z1_l000000ooonf[o0000o`00000@o`0000Sooo]Z2Ol0
0002oookJPWo00001ooonfX5o`0000Gooo]Z3Ol000001?oonf[o0000o`000?l00004oookJPCo0000
1?oonfX3o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o00000_oonfX3o`0000Oo
oo]Z1_l000000ooonf[o0000o`000006o`0000;ooo]Z1_l00006oookJP[o00000_oonfX=o`0000Oo
oo]Z1Ol00003oookJP?o00001?oonfX6o`0000Oooo]Z2Ol0000LoookJP00EOoonfX9o`0000Cooo]Z
0ol00003oookJPCo00001_oonfX6o`000003oookJ_l0003o000000;o00000_oonfX8o`0000Gooo]Z
0ol00003oookJPSo00000_oonfX<o`0000;ooo]Z1_l00003oookJPWo00000_oonfX6o`000005oook
J_l0003o0000o`000?oonfX01Ol00002oookJP?o00001_oonfX3o`000003oookJ_l0003o000000Go
00001_oonfX6o`0000;ooo]Z0ol00004oookJP?o000000?ooo]Zo`000?l000000ol00004oookJPGo
000000Cooo]Zo`000?l0003o00001?oonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z2Ol00004
oookJP[o00000ooonfX9o`000003oookJ_l0003o000000;o00001OoonfX3o`000003oookJ_l0003o
000001;o00001_oonfXBo`0000Cooo]Z0ol00002oookJPGo000000Gooo]Zo`000?l0003o0000oook
JP0Ao`0000Cooo]Z1?l00003oookJPCo000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`00
0?l00002oookJPKo00001?oonfX@o`000003oookJ_l0003o000000Oo00000ooonfX:o`000003oook
J_l0003o000000oo00001_oonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000008o`0000Kooo]Z
0ol00002oookJP?o00007OoonfX005Gooo]Z1?l00003oookJP?o00000_oonfX4o`0000Cooo]Z0ol0
0005oookJPOo000000?ooo]Zo`000?l000000_l00002oookJPco00001ooonfX3o`0000;ooo]Z2Ol0
0003oookJPCo00000ooonfX6o`0000?ooo]Z1_l00005oookJPOo000000?ooo]Zo`000?l000001_l0
0007oookJP_o000000Cooo]Zo`000?l0003o00001_oonfX7o`000004oookJ_l0003o0000o`0000Co
oo]Z2Ol00004oookJPGo000000?ooo]Zo`000?l000002?l00007oookJPSo00002_oonfX3o`0000Go
oo]Z3_l00009oookJPKo000000?ooo]Zo`000?l000002ol00006oookJP_o00000_oonfX5o`000003
oookJ_l0003o000000oo000000?ooo]Zo`000?l000005ol00003oookJPCo000000?ooo]Zo`000?l0
00000_l000001?oonf[o0000o`000?l00002oookJPKo00001?oonfX@o`000003oookJ_l0003o0000
00Oo00000_oonfX4o`0000Gooo]Z2?l00004oookJPWo00000ooonfX5o`0000?ooo]Z1ol00003oook
JPGo000000Cooo]Zo`000?l0003o00001_oonfX3o`0001gooo]Z001EoookJPCo00000ooonfX3o`00
0003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001?l00002oookJPOo000000?ooo]Zo`00
0?l000000_l00002oookJPco00001_oonfXFo`0000?ooo]Z1?l00006oookJPGo00001OoonfX7o`00
0003oookJ_l0003o000000Co00001_oonfX>o`000004oookJ_l0003o0000o`0000Kooo]Z2Ol00002
oookJP?o000000?ooo]Zo`000?l000001Ol00006oookJPGo000000?ooo]Zo`000?l000001ol00002
oookJP?o00000ooonfX5o`0000Oooo]Z1Ol00009oookJP?o00001_oonfX5o`0000Kooo]Z4ol00000
1Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX6o`0000;ooo]Z2?l00002oookJQ;o00000_oo
nfXNo`0000;ooo]Z2?l00005oookJP?o00001_oonfX>o`0000Cooo]Z1_l00002oookJP?o00001_oo
nfX8o`0000;ooo]Z0ol00002oookJPKo00000_oonfX5o`000005oookJ_l0003o0000o`000?oonfX0
1_l00003oookJPWo00000_oonfX3o`000004oookJ_l0003o0000o`0001gooo]Z001EoookJPCo0000
0ooonfX3o`000003oookJ_l0003o000000So00000_oonfX3o`0000;ooo]Z1?l00002oookJPWo0000
0_oonfX9o`0000Kooo]Z0ol000000ooonf[o0000o`00000@o`0000?ooo]Z1?l00005oookJPGo0000
00Cooo]Zo`000?l0003o00001_oonfX7o`000003oookJ_l0003o000000Co00000_oonfX=o`0000Oo
oo]Z0ol00002oookJPgo000000?ooo]Zo`000?l000001?l00003oookJP?o000000Cooo]Zo`000?l0
003o00000ooonfX9o`000003oookJ_l0003o000000?o00000_oonfX:o`0000;ooo]Z1ol00007oook
JP?o00001_oonfX3o`0000Sooo]Z3ol000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Z
o`000?l000002Ol00002oookJQ[o000000Gooo]Zo`000?l0003o0000oookJP0=o`000003oookJ_l0
003o000000co00000_oonfX9o`0000Gooo]Z1Ol00003oookJPCo00000ooonfX9o`0000Cooo]Z2_l0
0002oookJP?o000000?ooo]Zo`000?l000002ol00002oookJPKo00000_oonfX5o`000003oookJ_l0
003o000001Wo000000Cooo]Zo`000?l0003o00007OoonfX005Gooo]Z1?l00007oookJPoo000000?o
oo]Zo`000?l000006?l00002oookJP?o00000_oonfX3o`000003oookJ_l0003o000000oo00001?oo
nfX3o`0000;ooo]Z0ol000000ooonf[o0000o`000003o`000005oookJ_l0003o0000o`000?oonfX0
0ol00002oookJPKo000000?ooo]Zo`000?l000001Ol00002oookJPWo00002ooonfX3o`0000;ooo]Z
1?l000000ooonf[o0000o`00000:o`0000Kooo]Z0ol000001?oonf[o0000o`000?l00003oookJP?o
00000_oonfX4o`000003oookJ_l0003o000000oo00000_oonfX7o`00017ooo]Z0ol000001?oonf[o
0000o`000?l00003oookJQ?o000000Gooo]Zo`000?l0003o0000oookJP0;o`0000;ooo]Z1ol00000
0ooonf[o0000o`00000@o`000005oookJ_l0003o0000o`000?oonfX01ol00002oookJQ?o00000_oo
nfX9o`0000;ooo]Z3ol00003oookJP?o000000?ooo]Zo`000?l000000ol00005oookJPOo00001?oo
nfX3o`000003oookJ_l0003o000000_o00000_oonfX3o`0000Gooo]Z1Ol000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000000;o00007?oonfX005Gooo]Z1?l00008oookJQ[o00000_oonfX5
o`0000;ooo]Z3?l00003oookJPKo00000_oonfX4o`0000?ooo]Z0ol00005oookJPCo000000Gooo]Z
o`000?l0003o0000oookJP09o`000003oookJ_l0003o0000017o00000_oonfX?o`0000;ooo]Z1_l0
0002oookJP?o00001?oonfX<o`0000Cooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00Ko0000
00?ooo]Zo`000?l000005?l00002oookJP_o00000ooonfX3o`0000Kooo]Z1?l000000ooonf[o0000
o`000003o`0000Gooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00Ko00001_oonfX9o`0000Co
oo]Z6_l000001Ooonf[o0000o`000?l0003ooo]Z01co00000_oonfX4o`000003oookJ_l0003o0000
00;o00000_oonfX?o`0000?ooo]Z0ol00003oookJP?o00001_oonfX8o`0000;ooo]Z0ol000000ooo
nf[o0000o`000009o`0000?ooo]Z0ol00006oookJPCo00000_oonfX5o`000003oookJ_l0003o0000
00So000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000008o`0001cooo]Z001EoookJPCo
00001?oonfX3o`0000;ooo]Z5Ol00007oookJPCo00001OoonfX9o`0000?ooo]Z1_l00002oookJPCo
000000Cooo]Zo`000?l0003o00000_oonfX3o`0000;ooo]Z1?l000001Ooonf[o0000o`000?l0003o
oo]Z00Oo00000_oonfX8o`0000Cooo]Z2?l00004oookJPKo000000?ooo]Zo`000?l000003?l00005
oookJQ3o00002ooonfXLo`0000?ooo]Z1Ol00003oookJPCo00000ooonfX5o`0000Cooo]Z1?l00000
0ooonf[o0000o`000003o`0000Gooo]Z1ol000000ooonf[o0000o`000004o`0000[ooo]Z1Ol00004
oookJPco00000_oonfX;o`0000Kooo]Z4ol00003oookJP?o00001_oonfX8o`000003oookJ_l0003o
000000ko00000ooonfX4o`000003oookJ_l0003o000000;o00002ooonfX3o`0000;ooo]Z0ol00004
oookJQ3o00000_oonfX9o`000003oookJ_l0003o000000?o00000ooonfX6o`0000;ooo]Z0ol00000
0ooonf[o0000o`000004o`000004oookJ_l0003o0000o`0001cooo]Z001EoookJPCo000000?ooo]Z
o`000?l000002_l000000ooonf[o0000o`00000:o`0000;ooo]Z0ol00006oookJP?o00001_oonfX9
o`0000?ooo]Z1?l00009oookJP?o00000_oonfX3o`0000?ooo]Z1?l00003oookJPSo00000_oonfX8
o`0000Cooo]Z2?l00004oookJP?o000000?ooo]Zo`000?l000003_l00003oookJPgo00000ooonfX6
o`0000;ooo]Z0ol00003oookJP[o000000?ooo]Zo`000?l000002Ol00002oookJPCo00000ooonfX5
o`0000?ooo]Z1?l00003oookJPco00001?oonfX3o`0000Gooo]Z1ol00002oookJPOo00002?oonfX6
o`0000;ooo]Z0ol00004oookJPKo00000_oonfX3o`000003oookJ_l0003o000000Ko000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000005o`0000?ooo]Z0ol00005oookJPGo00001?oonfX8
o`000003oookJ_l0003o000000?o00000_oonfX3o`000003oookJ_l0003o000000?o00001?oonfX3
o`000003oookJ_l0003o000000Ko00001_oonfX4o`0000;ooo]Z0ol00004oookJQ3o00000_oonfX9
o`0000?ooo]Z0ol00003oookJP?o000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0
003o000000Go00007ooonfX005Gooo]Z1?l000000ooonf[o0000o`000006o`000005oookJ_l0003o
0000o`000?oonfX01ol000000ooonf[o0000o`000002o`0000;ooo]Z1_l00003oookJP?o000000Co
oo]Zo`000?l0003o00000_oonfX9o`0000?ooo]Z2?l00005oookJP?o000000?ooo]Zo`000?l00000
0_l00004oookJP?o000000?ooo]Zo`000?l000005?l00009oookJQKo00000ooonfX=o`000004oook
J_l0003o0000o`0000?ooo]Z1Ol00002oookJPCo00000_oonfX5o`000003oookJ_l0003o000000;o
00000ooonfX@o`0000;ooo]Z1Ol00003oookJQ?o00001?oonfX3o`000005oookJ_l0003o0000o`00
0?oonfX01Ol00007oookJPCo00001_oonfX8o`0000;ooo]Z1Ol00002oookJPKo00001?oonfX:o`00
0003oookJ_l0003o000000Co00000ooonfX4o`0000Cooo]Z1?l00004oookJPKo00001_oonfX<o`00
00;ooo]Z0ol000000ooonf[o0000o`000002o`0000Cooo]Z1?l000000ooonf[o0000o`000006o`00
00?ooo]Z1_l00003oookJP?o00000_oonfXMo`000003oookJ_l0003o000000Wo000000?ooo]Zo`00
0?l000003_l0000NoookJP00EOoonfXBo`0000?ooo]Z1?l000000ooonf[o0000o`00000<o`000005
oookJ_l0003o0000o`000?oonfX01?l000000ooonf[o0000o`000007o`000003oookJ_l0003o0000
00go00000ooonfXBo`000003oookJ_l0003o000000ko00002OoonfX?o`0000?ooo]Z1?l00003oook
JPco00000_oonfX3o`0000?ooo]Z2ol00004oookJPSo00000ooonfX6o`000003oookJ_l0003o0000
00Oo00002_oonfXCo`0000;ooo]Z2Ol000000ooonf[o0000o`000005o`0000Gooo]Z1ol000000ooo
nf[o0000o`00000?o`0000;ooo]Z1_l00002oookJPco000000?ooo]Zo`000?l000001?l00003oook
JP?o00001OoonfX4o`0000;ooo]Z6Ol00007oookJPCo00001?oonfX3o`0000;ooo]Z2?l00003oook
JQSo00000ooonfX=o`0000Cooo]Z1?l000000ooonf[o0000o`00000>o`0000;ooo]Z1_l0000Moook
JP00EOoonfX7o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000000_l00006oookJP?o
00000ooonfX5o`000005oookJ_l0003o0000o`000?oonfX01?l000000ooonf[o0000o`000002o`00
00Kooo]Z3ol00003oookJPWo00000_oonfX6o`000003oookJ_l0003o000001;o00001OoonfX6o`00
00?ooo]Z1ol00003oookJPCo00000ooonfX3o`0000;ooo]Z2?l000001Ooonf[o0000o`000?l0003o
oo]Z00Wo000000?ooo]Zo`000?l000000_l00003oookJPWo00000_oonfX6o`000003oookJ_l0003o
000000Oo00002_oonfXAo`0000;ooo]Z2ol00003oookJPKo00001?oonfX3o`000003oookJ_l0003o
000000oo000000Cooo]Zo`000?l0003o00001?oonfX4o`0000;ooo]Z2ol00005oookJP?o00000_oo
nfX4o`0000Gooo]Z3?l000000ooonf[o0000o`000008o`000003oookJ_l0003o000000Go00000ooo
nfX3o`0000Cooo]Z3Ol00007oookJPCo000000?ooo]Zo`000?l000003Ol000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000001Co000000?ooo]Zo`000?l000001Ol00003oookJPko00007Ooo
nfX005Gooo]Z1ol000000ooonf[o0000o`000004o`000005oookJ_l0003o0000o`000?oonfX01_l0
0002oookJPKo00001?oonfX3o`0000Kooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000o`000003o`000003oookJ_l0003o000001So00001?oonfX4o`0000;ooo]Z2?l0
0003oookJPGo00000ooonfX5o`0000Oooo]Z1_l000000ooonf[o0000o`000002o`0000?ooo]Z0ol0
0004oookJQCo000000?ooo]Zo`000?l000000_l00004oookJPSo00000_oonfX3o`0000;ooo]Z1?l0
0002oookJPGo00001?oonfX3o`0000;ooo]Z1_l00002oookJPWo00000ooonfX<o`0000?ooo]Z2?l0
00001Ooonf[o0000o`000?l0003ooo]Z00Wo000000?ooo]Zo`000?l000001Ol00006oookJQ?o0000
0ooonfX3o`0000Cooo]Z1_l00003oookJPco000000?ooo]Zo`000?l000004?l00003oookJP?o0000
1?oonfX<o`0000;ooo]Z0ol00003oookJPCo000000?ooo]Zo`000?l000000ol000000ooonf[o0000
o`000003o`0000Kooo]Z1?l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Go0000
0_oonfX5o`0000Cooo]Z2?l00006oookJP[o00007OoonfX005Gooo]Z1ol000000ooonf[o0000o`00
0004o`0000Gooo]Z1ol000000ooonf[o0000o`000004o`0000Cooo]Z0ol000000ooonf[o0000o`00
0002o`0000Sooo]Z3?l000000ooonf[o0000o`00000Ko`000003oookJ_l0003o000000?o000000?o
oo]Zo`000?l000001_l00003oookJPOo000000?ooo]Zo`000?l000000ol000001Ooonf[o0000o`00
0?l0003ooo]Z00go000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000Jo`000005oook
J_l0003o0000o`000?oonfX03?l000000ooonf[o0000o`00000:o`0000Cooo]Z0ol00002oookJP?o
00001_oonfX8o`0000?ooo]Z3?l00003oookJPSo00001_oonfX3o`0000;ooo]Z0ol000000ooonf[o
0000o`000003o`0000Gooo]Z1ol000000ooonf[o0000o`000002o`0000Cooo]Z1_l00003oookJPCo
00000ooonfX6o`0000Gooo]Z1_l00005oookJPCo00000_oonfXBo`0000Cooo]Z3?l00002oookJPCo
000000?ooo]Zo`000?l000000_l00006oookJP[o000000?ooo]Zo`000?l000001?l000001?oonf[o
0000o`000?l00002oookJPOo00000_oonfX7o`0000;ooo]Z2?l00006oookJPGo000000Cooo]Zo`00
0?l0003o00007_oonfX005Gooo]Z3_l000000ooonf[o0000o`000003o`000003oookJ_l0003o0000
00?o000000?ooo]Zo`000?l000001?l00004oookJP?o000000?ooo]Zo`000?l000001_l00004oook
JPSo00001?oonfX/o`000005oookJ_l0003o0000o`000?oonfX01_l00003oookJP?o000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000006o`0000;ooo]Z5Ol00004oookJPSo00000_oonfX3
o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`000006
o`0000;ooo]Z1_l00006oookJPGo00001?oonfX<o`0000Gooo]Z2_l000000ooonf[o0000o`000003
o`0000Kooo]Z1_l00002oookJPco00001?oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z1?l0
0002oookJP?o000000?ooo]Zo`000?l000000_l00004oookJPCo00002?oonfXEo`0000Oooo]Z0ol0
000:oookJPCo000000?ooo]Zo`000?l000001?l00003oookJP_o000000?ooo]Zo`000?l000002Ol0
00000ooonf[o0000o`000004o`0000Oooo]Z3Ol00002oookJP?o000000?ooo]Zo`000?l000000ol0
00001?oonf[o0000o`000?l0000NoookJP00EOoonfX8o`0000?ooo]Z2Ol000000ooonf[o0000o`00
0003o`0000gooo]Z2_l00004oookJP?o000000?ooo]Zo`000?l000000_l00004oookJQ3o000000?o
oo]Zo`000?l000001Ol000000ooonf[o0000o`00000@o`0000;ooo]Z1?l00003oookJPGo00001?oo
nfX8o`000003oookJ_l0003o000000Co00001?oonfX@o`0000Wooo]Z2?l00002oookJQ3o000000?o
oo]Zo`000?l000002?l000000ooonf[o0000o`00000:o`000004oookJ_l0003o0000o`0000;ooo]Z
0ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Co00000_oonfX9o`0000?ooo]Z
2_l000000ooonf[o0000o`000003o`0000Wooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l00000
1_l00004oookJPOo000000?ooo]Zo`000?l000003Ol00004oookJPGo00001OoonfX7o`0000;ooo]Z
1Ol00005oookJPCo00001ooonfX3o`0000;ooo]Z0ol00002oookJPko00000ooonfX4o`000003oook
J_l0003o000001?o00002ooonfX=o`0000;ooo]Z2Ol000001?oonf[o0000o`000?l0000NoookJP00
EOoonfX8o`000005oookJ_l0003o0000o`000?oonfX01ol000000ooonf[o0000o`000002o`0000ko
oo]Z0ol000000ooonf[o0000o`00000Io`0000;ooo]Z3Ol000001?oonf[o0000o`000?l00002oook
JPKo000000?ooo]Zo`000?l000000_l00007oookJPGo000000Gooo]Zo`000?l0003o0000oookJP03
o`0000Cooo]Z1Ol00002oookJPSo00001?oonfX3o`000003oookJ_l0003o000000Co00000ooonfX3
o`0000Wooo]Z2?l00002oookJPSo00001OoonfX3o`0000Gooo]Z1_l000000ooonf[o0000o`00000:
o`000004oookJ_l0003o0000o`0000;ooo]Z0ol00002oookJP?o00000_oonfX4o`0000Cooo]Z2Ol0
0002oookJP_o000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?l00002oookJPKo0000
1_oonfX8o`0000?ooo]Z2?l000000ooonf[o0000o`00000=o`0000;ooo]Z0ol000000ooonf[o0000
o`000002o`0000Cooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00So00000ooonfX4o`0000?o
oo]Z0ol000001?oonf[o0000o`000?l00002oookJQ?o000000?ooo]Zo`000?l000002Ol000000ooo
nf[o0000o`00000Ao`000004oookJ_l0003o0000o`0000Oooo]Z2_l000000ooonf[o0000o`000005
o`0002Gooo]Z001EoookJQ3o000000?ooo]Zo`000?l000001_l0000>oookJP?o000000?ooo]Zo`00
0?l000000ol000000ooonf[o0000o`00000Mo`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?l000000_l00004oookJP?o000000?ooo]Zo`000?l000001?l00003oookJPOo000000Gooo]Zo`00
0?l0003o0000oookJP03o`000003oookJ_l0003o000000Co00001?oonfX;o`000003oookJ_l0003o
000000So00003ooonfX6o`0000;ooo]Z2_l00002oookJPKo00001OoonfX6o`0000;ooo]Z2ol00000
1?oonf[o0000o`000?l00002oookJP?o00000_oonfX3o`0000;ooo]Z1?l000000ooonf[o0000o`00
0006o`000005oookJ_l0003o0000o`000?oonfX01_l000000ooonf[o0000o`000003o`0000;ooo]Z
0ol00002oookJQ3o000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000009o`0000Cooo]Z
5?l000000ooonf[o0000o`000002o`0000Cooo]Z0ol00005oookJPCo000000Cooo]Zo`000?l0003o
00001OoonfX3o`0000;ooo]Z0ol00006oookJPoo00001?oonfX:o`0000?ooo]Z1_l000000ooonf[o
0000o`000002o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00006oookJPWo00000ooonfX7o`00
02Gooo]Z001EoookJPgo00000ooonfX3o`000003oookJ_l0003o000000?o000000Gooo]Zo`000?l0
003o0000oookJP05o`0000Gooo]Z2?l000000ooonf[o0000o`000007o`0000;ooo]Z2Ol000000ooo
nf[o0000o`000008o`000005oookJ_l0003o0000o`000?oonfX01Ol000000ooonf[o0000o`000004
o`000003oookJ_l0003o000000Co00000ooonfX5o`0000?ooo]Z0ol000000ooonf[o0000o`000007
o`0000Gooo]Z2ol00002oookJP?o00000ooonfX5o`0000Kooo]Z2?l000000ooonf[o0000o`000002
o`0000;ooo]Z1_l00006oookJPOo00000_oonfX8o`0000;ooo]Z3?l0000?oookJP?o000000?ooo]Z
o`000?l000000_l000000ooonf[o0000o`000002o`0000Gooo]Z1_l000000ooonf[o0000o`000003
o`0000;ooo]Z5Ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000[o00001?oonfXE
o`000004oookJ_l0003o0000o`0000?ooo]Z0ol00002oookJPCo000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`000004o`000003oookJ_l0003o000000?o00001_oonfX>o`0000?ooo]Z1?l0
0002oookJPWo000000Gooo]Zo`000?l0003o0000oookJP04o`0000;ooo]Z1_l000000ooonf[o0000
o`00000=o`0000Kooo]Z0ol00004oookJPGo00000_oonfX3o`0001_ooo]Z001EoookJPKo000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`000003o`000004oookJ_l0003o0000o`0000?ooo]Z
0ol000000ooonf[o0000o`000003o`0000Gooo]Z3Ol000000ooonf[o0000o`000003o`0000Gooo]Z
1Ol000000ooonf[o0000o`000008o`0000;ooo]Z2?l000000ooonf[o0000o`000004o`0000?ooo]Z
1?l00003oookJPKo000000Cooo]Zo`000?l0003o00001?oonfX9o`0000Cooo]Z0ol000000ooonf[o
0000o`000004o`0000;ooo]Z0ol00003oookJQ?o000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`000002o`0000Sooo]Z0ol000001?oonf[o0000o`000?l00002oookJPgo00000_oonfX7o`00
00Cooo]Z0ol00004oookJP?o000000Gooo]Zo`000?l0003o0000oookJP0<o`0000;ooo]Z0ol00004
oookJP?o00001?oonfX=o`000003oookJ_l0003o000000go000000Cooo]Zo`000?l0003o00000_oo
nfX7o`0000Cooo]Z3_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000So00000ooo
nfX9o`000003oookJ_l0003o000000[o000000Cooo]Zo`000?l0003o00001ooonfX@o`0000;ooo]Z
3Ol000001?oonf[o0000o`000?l00003oookJP?o00001_oonfX=o`0000Oooo]Z0ol00003oookJP[o
00006ooonfX005Gooo]Z1ol00002oookJP?o00000_oonfX5o`0000Oooo]Z0ol000000ooonf[o0000
o`000003o`0000Gooo]Z0ol00002oookJQ3o00000_oonfX?o`0000Cooo]Z3?l00006oookJP?o0000
00?ooo]Zo`000?l000001ol000001?oonf[o0000o`000?l00004oookJPWo000000?ooo]Zo`000?l0
00001?l000000ooonf[o0000o`000007o`0000;ooo]Z8ol0000:oookJQ?o000000?ooo]Zo`000?l0
00002?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000001?o00002?oonfX5o`0000Ko
oo]Z2_l00008oookJP?o00000_oonfX@o`0000Oooo]Z2?l00004oookJPGo000000?ooo]Zo`000?l0
00002?l00003oookJPWo000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000004o`0000;o
oo]Z1_l000000ooonf[o0000o`000009o`0000;ooo]Z3Ol000000ooonf[o0000o`000003o`000004
oookJ_l0003o0000o`0000Kooo]Z2?l000000ooonf[o0000o`000002o`0000Kooo]Z4Ol0000Koook
JP00EOoonfX7o`000003oookJ_l0003o000000Oo00002_oonfX3o`0000_ooo]Z0ol000000ooonf[o
0000o`00000>o`0000;ooo]Z3ol00004oookJP?o00000_oonfX4o`000004oookJ_l0003o0000o`00
00Gooo]Z0ol000000ooonf[o0000o`000007o`000004oookJ_l0003o0000o`0000Gooo]Z3ol00003
oookJPOo00000_oonfX7o`000003oookJ_l0003o000001go00001OoonfX9o`0000?ooo]Z2?l00000
0ooonf[o0000o`000008o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol00000
0ooonf[o0000o`00000=o`0000Sooo]Z2_l00002oookJPSo000000Cooo]Zo`000?l0003o00001Ooo
nfXEo`0000Kooo]Z2Ol00006oookJP?o000000?ooo]Zo`000?l000002?l00003oookJPOo00001Ooo
nfX8o`0000?ooo]Z1_l00002oookJP?o00001?oonfX;o`0000;ooo]Z0ol000000ooonf[o0000o`00
0007o`000003oookJ_l0003o000000Oo00000_oonfX3o`000003oookJ_l0003o000000?o00000_oo
nfX3o`0000Wooo]Z2?l00003oookJPKo00006ooonfX005Gooo]Z1ol000000ooonf[o0000o`00000:
o`0000Oooo]Z0ol0000;oookJP?o000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000D
o`000004oookJ_l0003o0000o`0000?ooo]Z3_l000000ooonf[o0000o`00000:o`0000Wooo]Z3ol0
0003oookJPSo000000?ooo]Zo`000?l000001Ol00002oookJP?o00001?oonfXGo`0000Cooo]Z3?l0
00000ooonf[o0000o`000006o`000003oookJ_l0003o000000Wo00000_oonfX3o`000003oookJ_l0
003o000000?o000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000004o`0000Gooo]Z3Ol0
00000ooonf[o0000o`000004o`0000Cooo]Z0ol00006oookJPoo000000?ooo]Zo`000?l000000_l0
0006oookJP?o00000ooonfX3o`0000[ooo]Z3?l00004oookJPKo00000ooonfXAo`0000;ooo]Z0ol0
00001Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX4o`0000Oooo]Z2?l00002oookJPko0000
00Cooo]Zo`000?l0003o00001?oonfX3o`0000Wooo]Z2?l00003oookJPKo00006ooonfX005Gooo]Z
1ol000000ooonf[o0000o`00000:o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000Sooo]Z
1_l000000ooonf[o0000o`000008o`0000;ooo]Z1ol000000ooonf[o0000o`00000<o`000004oook
J_l0003o0000o`0000?ooo]Z3_l000000ooonf[o0000o`00000:o`0000;ooo]Z5?l00005oookJPWo
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`0000Kooo]Z5Ol00004oookJQGo
00000_oonfX:o`0000;ooo]Z2?l00005oookJP?o00000ooonfX7o`0000?ooo]Z1?l00002oookJPSo
000000?ooo]Zo`000?l000001ol000001?oonf[o0000o`000?l00004oookJQ7o000000?ooo]Zo`00
0?l000000ol00002oookJPKo00000_oonfX3o`0000_ooo]Z1?l00003oookJQ7o00000_oonfX:o`00
00?ooo]Z0ol00006oookJP?o00001?oonfX6o`0000Oooo]Z4Ol000000ooonf[o0000o`000004o`00
00;ooo]Z0ol00003oookJPCo000000?ooo]Zo`000?l000003Ol00002oookJPGo00007OoonfX005Go
oo]Z1ol00002oookJQCo00002OoonfX?o`0000Cooo]Z2ol00002oookJPWo000000?ooo]Zo`000?l0
00002ol000000ooonf[o0000o`000004o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l0
00003ol000001?oonf[o0000o`000?l00002oookJP?o000000?ooo]Zo`000?l000003Ol000000ooo
nf[o0000o`000003o`0000Gooo]Z2Ol000000ooonf[o0000o`000003o`0000;ooo]Z1_l00002oook
JPGo00000_oonfX>o`0000;ooo]Z0ol000000ooonf[o0000o`00000=o`0000Cooo]Z1Ol00004oook
JPKo00000ooonfX4o`0000;ooo]Z0ol00002oookJQ3o00001OoonfX6o`0000?ooo]Z2Ol00002oook
JP?o00000_oonfX3o`000003oookJ_l0003o000000Go00002ooonfX4o`0000;ooo]Z3?l000000ooo
nf[o0000o`000003o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00002oookJPCo00001_oonfX3
o`0000Cooo]Z2?l00006oookJPWo000000Cooo]Zo`000?l0003o00001?oonfX6o`0000;ooo]Z0ol0
0004oookJP?o000000?ooo]Zo`000?l000002Ol00006oookJPOo00006ooonfX005Gooo]Z1ol00003
oookJPGo00001?oonfX=o`0000Gooo]Z2_l00002oookJPOo000000?ooo]Zo`000?l000000_l00003
oookJPCo000000?ooo]Zo`000?l000001_l00005oookJPSo00001?oonfXZo`000005oookJ_l0003o
0000o`000?oonfX01?l000000ooonf[o0000o`000005o`0000Cooo]Z1Ol00003oookJPKo000000Co
oo]Zo`000?l0003o00000_oonfX?o`000003oookJ_l0003o000000Co00000_oonfX<o`0000;ooo]Z
0ol00002oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPKo00000_oonfX5o`0000?ooo]Z
1ol00003oookJPCo00001?oonfXCo`0000?ooo]Z2?l000000ooonf[o0000o`00000:o`000004oook
J_l0003o0000o`0000;ooo]Z2ol00003oookJPKo00000_oonfX3o`0000?ooo]Z6_l00004oookJP_o
00002?oonfX4o`000003oookJ_l0003o000000?o00001?oonfX;o`0000Kooo]Z1_l00002oookJPKo
000000Gooo]Zo`000?l0003o0000oookJP0;o`0000Gooo]Z2?l0000KoookJP00EOoonfX5o`0000Go
oo]Z0ol00006oookJPWo000000Cooo]Zo`000?l0003o00001OoonfX3o`0000;ooo]Z1Ol00002oook
JP?o000000?ooo]Zo`000?l000001_l00003oookJPCo000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`000005o`000003oookJ_l0003o000000Oo00000ooonfX3o`0000;ooo]Z1_l00007oook
JPWo00001_oonfX9o`000003oookJ_l0003o000000Ko00000_oonfX5o`0000Kooo]Z1Ol00002oook
JP?o00001?oonfXQo`0000;ooo]Z1_l00002oookJP?o000000?ooo]Zo`000?l000001ol00003oook
JPGo00000_oonfX?o`0000?ooo]Z1?l00004oookJQCo000000?ooo]Zo`000?l000000ol000000ooo
nf[o0000o`000008o`0000;ooo]Z2Ol00004oookJQ;o000000?ooo]Zo`000?l000002ol00002oook
JPco000000?ooo]Zo`000?l000001?l00002oookJP_o00001ooonfX;o`0000Cooo]Z1_l00002oook
JPgo00001?oonfX9o`0000?ooo]Z0ol00003oookJPCo00001OoonfX8o`0001_ooo]Z001EoookJPGo
00000_oonfX3o`0000[ooo]Z2?l000001?oonf[o0000o`000?l00002oookJPOo000000?ooo]Zo`00
0?l000000ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Oo00000_oonfX9o`00
00;ooo]Z4?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Co00001OoonfX6o`00
0003oookJ_l0003o000000?o00001_oonfXIo`0000Kooo]Z3Ol000000ooonf[o0000o`00000>o`00
0003oookJ_l0003o000000ko00000_oonfX7o`0000Gooo]Z2Ol00003oookJPGo000000?ooo]Zo`00
0?l000003_l00003oookJP_o00000_oonfX6o`000003oookJ_l0003o000001Oo000000?ooo]Zo`00
0?l000002_l00002oookJQ;o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000004o`00
0003oookJ_l0003o000000Co00000ooonfX;o`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?l000001?l00004oookJP[o000000Cooo]Zo`000?l0003o00001?oonfX7o`000003oookJ_l0003o
000000go00000_oonfX;o`000004oookJ_l0003o0000o`0000?ooo]Z1_l00003oookJPOo00007?oo
nfX005Gooo]Z1Ol00002oookJPOo00001?oonfX4o`000003oookJ_l0003o000000?o00001_oonfX7
o`0000;ooo]Z2Ol00002oookJPSo00000_oonfX9o`0000;ooo]Z4?l000001?oonf[o0000o`000?l0
0002oookJPOo00001OoonfX5o`0000;ooo]Z1Ol00004oookJPWo00000_oonfX7o`000003oookJ_l0
003o000000So00001?oonfX7o`0000;ooo]Z1?l00002oookJPoo00000_oonfXHo`0000;ooo]Z2_l0
0002oookJPSo000000?ooo]Zo`000?l000009?l000000ooonf[o0000o`00000ho`000003oookJ_l0
003o000000co00000ooonfX3o`0000Oooo]Z2?l000000ooonf[o0000o`000002o`0000Cooo]Z0ol0
0002oookJPco00002?oonfXXo`0000?ooo]Z1ol00004oookJPKo00006ooonfX005Gooo]Z1?l00003
oookJP[o000000?ooo]Zo`000?l000000_l0000<oookJQ;o00000_oonfX8o`0000;ooo]Z2Ol00004
oookJP_o00000_oonfX6o`000003oookJ_l0003o000000Go00001OoonfX<o`0000;ooo]Z2ol00002
oookJP?o000000?ooo]Zo`000?l000003?l00003oookJPSo000000?ooo]Zo`000?l000000ol00003
oookJPko00000_oonfX4o`000003oookJ_l0003o0000017o00000_oonfX4o`0000;ooo]Z0ol00000
0ooonf[o0000o`00000<o`0000;ooo]Z:?l000000ooonf[o0000o`000009o`000003oookJ_l0003o
000000_o00000_oonfXEo`0000Cooo]Z1?l00003oookJPOo000000?ooo]Zo`000?l000001?l00006
oookJPSo000000?ooo]Zo`000?l000000_l00004oookJQ;o00001ooonfX@o`0000Cooo]Z1Ol00000
0ooonf[o0000o`00000<o`0000?ooo]Z2Ol00002oookJPKo00006ooonfX005Gooo]Z1?l00006oook
JPco00001?oonfX5o`0000Cooo]Z2?l00002oookJPOo000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`000002o`0000;ooo]Z2Ol00004oookJPco000000?ooo]Zo`000?l000001?l000001?oo
nf[o0000o`000?l0000<oookJP[o000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002
o`0000Kooo]Z1Ol000000ooonf[o0000o`000008o`000003oookJ_l0003o000000Co00000ooonfX5
o`0000;ooo]Z7_l00002oookJPKo00000_oonfX7o`0000Kooo]Z1_l000000ooonf[o0000o`000002
o`0000Gooo]Z2?l00002oookJQko000000Gooo]Zo`000?l0003o0000oookJP07o`000004oookJ_l0
003o0000o`0000;ooo]Z0ol00002oookJPko000000?ooo]Zo`000?l000004Ol00003oookJPOo0000
00?ooo]Zo`000?l000001?l00003oookJPco000000Cooo]Zo`000?l0003o00000_oonfXDo`0000Oo
oo]Z3?l000000ooonf[o0000o`000005o`0000;ooo]Z1?l000000ooonf[o0000o`00000:o`0000?o
oo]Z1?l000000ooonf[o0000o`000003o`0000?ooo]Z1Ol0000KoookJP00EOoonfX4o`0000?ooo]Z
4?l00003oookJPGo00000_oonfX<o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l00000
0_l00002oookJPKo000000?ooo]Zo`000?l000001Ol00004oookJP?o000000Gooo]Zo`000?l0003o
0000oookJP04o`000003oookJ_l0003o000000Co00001?oonfX7o`000003oookJ_l0003o000000co
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`0000?ooo]Z2?l000000ooonf[o
0000o`000003o`000003oookJ_l0003o000000[o00000_oonfX6o`000003oookJ_l0003o000000Oo
00000_oonfX;o`0000;ooo]Z1_l00003oookJPgo000000?ooo]Zo`000?l000002ol000001?oonf[o
0000o`000?l00007oookJPKo00001_oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000001ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Go00000_oonfX3o`00
00Kooo]Z1Ol000000ooonf[o0000o`000006o`0000;ooo]Z9Ol000000ooonf[o0000o`00000>o`00
00;ooo]Z3_l00003oookJP?o00001ooonfX<o`000003oookJ_l0003o000000co000000?ooo]Zo`00
0?l000004?l00002oookJPCo00000ooonfX4o`0001cooo]Z001EoookJPCo000000?ooo]Zo`000?l0
00007Ol00003oookJPKo000000Cooo]Zo`000?l0003o00001?oonfX4o`0000;ooo]Z1_l000000ooo
nf[o0000o`000003o`0000Kooo]Z1?l00004oookJPCo000000?ooo]Zo`000?l000003ol000000ooo
nf[o0000o`000002o`0000;ooo]Z2?l000000ooonf[o0000o`000003o`000003oookJ_l0003o0000
00?o00000ooonfX8o`000003oookJ_l0003o0000013o00000_oonfX6o`000004oookJ_l0003o0000
o`0000;ooo]Z1?l00002oookJP_o00001?oonfX3o`0000Cooo]Z0ol000000ooonf[o0000o`000004
o`0000Cooo]Z1_l00002oookJPGo000000?ooo]Zo`000?l000001Ol00003oookJPKo00001_oonfX5
o`000004oookJ_l0003o0000o`0000?ooo]Z1_l00003oookJPWo000000?ooo]Zo`000?l000000_l0
0005oookJP?o000000Cooo]Zo`000?l0003o00001?oonfX3o`0000;ooo]Z1Ol00004oookJQko0000
0_oonfX5o`000003oookJ_l0003o000001ko00000ooonfX3o`0000Cooo]Z0ol00002oookJPCo0000
1?oonfX3o`0000;ooo]Z7ol00002oookJP?o00000ooonfX5o`0001cooo]Z001EoookJPgo000000?o
oo]Zo`000?l000002ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000_o000000?o
oo]Zo`000?l000001?l00002oookJPKo00000_oonfX5o`0000;ooo]Z1ol000000ooonf[o0000o`00
0004o`0000;ooo]Z4Ol000000ooonf[o0000o`000002o`0000;ooo]Z1_l00002oookJPCo00000ooo
nfX3o`0000?ooo]Z2_l00002oookJPGo00001?oonfXDo`0000;ooo]Z2Ol00002oookJPKo00001?oo
nfX:o`000003oookJ_l0003o000000ko00000_oonfX5o`000003oookJ_l0003o000000Ko00000_oo
nfX6o`0000Oooo]Z2?l00005oookJP?o00000ooonfXBo`0000;ooo]Z0ol000001?oonf[o0000o`00
0?l00009oookJPSo000000?ooo]Zo`000?l000002_l00003oookJP_o000000?ooo]Zo`000?l00000
1?l000001?oonf[o0000o`000?l00003oookJPWo000000?ooo]Zo`000?l000001Ol00002oookJPSo
00001_oonfX5o`0000;ooo]Z2_l000000ooonf[o0000o`000003o`0000;ooo]Z0ol000000ooonf[o
0000o`00000Go`000004oookJ_l0003o0000o`0000?ooo]Z1ol0000MoookJP00EOoonfX:o`0000;o
oo]Z5_l00003oookJPgo000000?ooo]Zo`000?l000000_l0000<oookJPGo00000_oonfX3o`000005
oookJ_l0003o0000o`000?oonfX00ol00003oookJPGo00000_oonfX:o`0000Cooo]Z1?l000000ooo
nf[o0000o`000005o`000004oookJ_l0003o0000o`0000Cooo]Z0ol000000ooonf[o0000o`000005
o`0000?ooo]Z0ol000000ooonf[o0000o`000003o`0000Cooo]Z0ol00003oookJPOo000000?ooo]Z
o`000?l000001?l00002oookJPWo00000_oonfX6o`0000Cooo]Z2_l00004oookJPgo00000_oonfX4
o`0000;ooo]Z2?l00004oookJPCo00000_oonfX>o`000003oookJ_l0003o000000Co00000ooonfX4
o`0000;ooo]Z3?l00002oookJPSo00001OoonfX5o`0000?ooo]Z0ol000001?oonf[o0000o`000?l0
0003oookJPGo000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z1_l000000ooonf[o0000
o`000003o`0000Oooo]Z0ol00003oookJQGo00000_oonfX3o`0000;ooo]Z4?l000000ooonf[o0000
o`000003o`0000Oooo]Z0ol000000ooonf[o0000o`000006o`000005oookJ_l0003o0000o`000?oo
nfX01?l00003oookJPCo00000ooonfX7o`0001gooo]Z001EoookJP[o00000_oonfX9o`000003oook
J_l0003o000000co000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`000002o`0000[ooo]Z
0ol000000ooonf[o0000o`00000>o`0000?ooo]Z2ol00002oookJPCo00001?oonfX@o`0000Cooo]Z
2Ol00005oookJP?o00001OoonfX8o`0000?ooo]Z1ol000000ooonf[o0000o`000004o`0000;ooo]Z
4?l00003oookJPCo000000?ooo]Zo`000?l000007Ol000001Ooonf[o0000o`000?l0003ooo]Z00Co
000000?ooo]Zo`000?l000001Ol00002oookJQGo00000ooonfX3o`0000?ooo]Z3?l00004oookJPSo
00000ooonfX5o`0000?ooo]Z0ol00004oookJPKo00000ooonfX7o`0000;ooo]Z1_l000000ooonf[o
0000o`000006o`0000Kooo]Z0ol000000ooonf[o0000o`00000Co`0000;ooo]Z0ol00002oookJQ3o
000000Gooo]Zo`000?l0003o0000oookJP08o`0000;ooo]Z1Ol00002oookJP?o000000Gooo]Zo`00
0?l0003o0000oookJP04o`0000?ooo]Z1_l000000ooonf[o0000o`000005o`0001gooo]Z001Eoook
JPKo000000Cooo]Zo`000?l0003o00000_oonfX8o`0000?ooo]Z6?l000000ooonf[o0000o`000005
o`0000?ooo]Z1Ol00002oookJP?o00000_oonfX?o`0000;ooo]Z1?l000000ooonf[o0000o`000007
o`0000Kooo]Z3ol00007oookJP[o00001?oonfX3o`0000Gooo]Z1ol000000ooonf[o0000o`000004
o`000003oookJ_l0003o000000Oo00000ooonfXHo`000003oookJ_l0003o000000_o000000?ooo]Z
o`000?l000003_l00005oookJQSo000000?ooo]Zo`000?l000002?l000001?oonf[o0000o`000?l0
0005oookJPWo000000Gooo]Zo`000?l0003o0000oookJP0:o`0000?ooo]Z2ol000000ooonf[o0000
o`00000@o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001_l00002oookJPOo0000
00?ooo]Zo`000?l000003?l00003oookJPWo00000ooonfX?o`0000Gooo]Z2?l00002oookJPOo0000
2?oonfX4o`0000?ooo]Z3_l0000MoookJP00EOoonfX6o`000004oookJ_l0003o0000o`0000?ooo]Z
2Ol00003oookJP?o00001OoonfXGo`0000;ooo]Z1_l000000ooonf[o0000o`000002o`000003oook
J_l0003o000000ko000000?ooo]Zo`000?l000003?l00006oookJP[o00000_oonfX3o`0000Kooo]Z
2ol00004oookJP?o00001OoonfX=o`0000Cooo]Z1ol000000ooonf[o0000o`000002o`000003oook
J_l0003o000001?o00001_oonfX>o`0000?ooo]Z2?l00004oookJQ3o00000_oonfX3o`000004oook
J_l0003o0000o`0000;ooo]Z3Ol00006oookJPSo000000Gooo]Zo`000?l0003o0000oookJP0:o`00
00?ooo]Z2ol000000ooonf[o0000o`00000Fo`0000Cooo]Z2?l00002oookJQOo00001?oonfX6o`00
00Cooo]Z3_l00006oookJR;o000000?ooo]Zo`000?l000002Ol0000MoookJP00EOoonfX4o`000004
oookJ_l0003o0000o`0000;ooo]Z0ol00006oookJP?o00000ooonfX8o`000003oookJ_l0003o0000
01co00000_oonfX3o`0000Gooo]Z0ol00004oookJPGo000000?ooo]Zo`000?l000001?l000000ooo
nf[o0000o`000005o`0000Cooo]Z3Ol00003oookJP?o00001?oonfX3o`000005oookJ_l0003o0000
o`000?oonfX00ol00003oookJPOo000000?ooo]Zo`000?l000000_l00002oookJP_o000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`00000Ho`0000Cooo]Z0ol00002oookJP_o00001ooonfX7
o`000005oookJ_l0003o0000o`000?oonfX03?l00002oookJPOo00000_oonfX=o`000004oookJ_l0
003o0000o`0000;ooo]Z0ol00005oookJPCo000000?ooo]Zo`000?l000002?l00003oookJR;o0000
00Cooo]Zo`000?l0003o00000_oonfX6o`0000?ooo]Z1_l00002oookJQ3o00001?oonfX9o`0000?o
oo]Z1_l000000ooonf[o0000o`000003o`0000Kooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z
02?o00007OoonfX005Gooo]Z2?l00002oookJPoo00000_oonfX6o`0000;ooo]Z5ol00003oookJP?o
00000_oonfX3o`000003oookJ_l0003o000000Wo00000_oonfX>o`000003oookJ_l0003o000000Co
000000?ooo]Zo`000?l000002ol00003oookJPCo00000ooonfX9o`0000;ooo]Z3_l00003oookJPco
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000So
00000_oonfX4o`0000Kooo]Z1?l00002oookJPoo000000?ooo]Zo`000?l000001_l000001?oonf[o
0000o`000?l00002oookJP?o000000?ooo]Zo`000?l000003_l00002oookJP_o000000?ooo]Zo`00
0?l000000ol00002oookJP?o00001OoonfX3o`0000?ooo]Z2Ol000000ooonf[o0000o`000005o`00
0003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000ol00003oookJP[o000000Gooo]Zo`00
0?l0003o0000oookJP08o`0000;ooo]Z1Ol00003oookJPCo00000_oonfX5o`000003oookJ_l0003o
000000;o00001?oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001?l00000
0ooonf[o0000o`000003o`0000;ooo]Z0ol000000ooonf[o0000o`000008o`000003oookJ_l0003o
000000co000000?ooo]Zo`000?l000004_l0000MoookJP00EOoonfXCo`0000?ooo]Z2ol00005oook
JPCo00001?oonfX3o`0000;ooo]Z1ol00002oookJP?o00001ooonfX4o`000003oookJ_l0003o0000
00Ko00000ooonfX;o`0000?ooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00[o000000?ooo]Z
o`000?l000000ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000go00001ooonfX=
o`0000Cooo]Z1_l000000ooonf[o0000o`000004o`000004oookJ_l0003o0000o`0000Wooo]Z2?l0
00000ooonf[o0000o`000004o`0000Cooo]Z4Ol00003oookJP?o000000Cooo]Zo`000?l0003o0000
0_oonfX8o`0000Gooo]Z1_l00002oookJPWo00000_oonfX4o`000003oookJ_l0003o000000Co0000
0ooonfX4o`0000;ooo]Z2Ol000000ooonf[o0000o`000009o`000003oookJ_l0003o000000?o0000
0ooonfX:o`000005oookJ_l0003o0000o`000?oonfX04?l00003oookJP?o00000_oonfX5o`000003
oookJ_l0003o000000?o00000_oonfX3o`0000Cooo]Z4_l00002oookJP?o000000?ooo]Zo`000?l0
00001ol00005oookJPKo000000Cooo]Zo`000?l0003o00001?oonfX3o`0000?ooo]Z3Ol0000Loook
JP00EOoonfXEo`000003oookJ_l0003o000000Co00001?oonfX3o`0000Kooo]Z4Ol00002oookJP?o
00001ooonfX4o`000003oookJ_l0003o000000Ko00000ooonfX:o`0000;ooo]Z1_l00005oookJP[o
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000Bo`0000;ooo]Z0ol00008oookJPko
00000_oonfX3o`0000;ooo]Z2_l00003oookJP?o000000Cooo]Zo`000?l0003o00000ooonfX3o`00
0003oookJ_l0003o000000Wo00001?oonfXJo`0000?ooo]Z1_l00007oookJP?o00001ooonfX5o`00
00Cooo]Z2?l00007oookJQSo00000ooonfX5o`0000?ooo]Z2_l00003oookJPco00000_oonfX7o`00
00Oooo]Z2Ol00002oookJP?o00001_oonfX@o`0000;ooo]Z0ol000000ooonf[o0000o`000007o`00
00Cooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z2ol000001?oonf[o0000o`000?l00003
oookJPKo00007?oonfX005Gooo]Z5Ol00002oookJPOo00000_oonfX4o`0000Gooo]Z1ol000000ooo
nf[o0000o`000005o`0000Cooo]Z0ol00002oookJP?o00000ooonfX3o`0000;ooo]Z0ol000000ooo
nf[o0000o`000002o`0000?ooo]Z2Ol00002oookJP_o00000_oonfX8o`000004oookJ_l0003o0000
o`0000;ooo]Z1?l00002oookJP[o000000Cooo]Zo`000?l0003o00000ooonfX3o`0000;ooo]Z0ol0
00000ooonf[o0000o`00000>o`0000;ooo]Z3?l000000ooonf[o0000o`000002o`000005oookJ_l0
003o0000o`000?oonfX01?l00002oookJP?o00000_oonfX=o`000003oookJ_l0003o000001So0000
0ooonfX6o`0000oooo]Z2?l00004oookJPOo00001ooonfXHo`0000?ooo]Z1?l00004oookJP[o0000
0ooonfX3o`000005oookJ_l0003o0000o`000?oonfX01Ol000000ooonf[o0000o`000008o`0000?o
oo]Z2ol000001?oonf[o0000o`000?l00002oookJQCo00001_oonfX7o`0000Kooo]Z2?l00002oook
JQ7o000000?ooo]Zo`000?l000001?l0000LoookJP00EOoonfX4o`000003oookJ_l0003o000000[o
000000Gooo]Zo`000?l0003o0000oookJP08o`0000;ooo]Z1?l00005oookJPOo000000?ooo]Zo`00
0?l000001?l00005oookJP?o00000_oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z2?l00003
oookJPSo000000?ooo]Zo`000?l000004_l00003oookJR7o000000Gooo]Zo`000?l0003o0000oook
JP0>o`0000Cooo]Z1Ol000001?oonf[o0000o`000?l00004oookJPgo00000_oonfX3o`0000?ooo]Z
2?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000001Co00001?oonfX3o`0000Cooo]Z
0ol00008oookJP[o00001ooonfX4o`0000Cooo]Z3_l000000ooonf[o0000o`00000<o`000003oook
J_l0003o000000;o000000?ooo]Zo`000?l000003?l00002oookJP?o00000ooonfXPo`000003oook
J_l0003o000001Go00001?oonfX3o`000004oookJ_l0003o0000o`0000[ooo]Z4Ol000000ooonf[o
0000o`000008o`0002;ooo]Z001EoookJPKo00001?oonfX7o`000005oookJ_l0003o0000o`000?oo
nfX02?l00002oookJPCo00001OoonfX>o`0000Gooo]Z0ol00002oookJPGo000000?ooo]Zo`000?l0
00002ol000001?oonf[o0000o`000?l00002oookJPGo000000?ooo]Zo`000?l000003Ol000000ooo
nf[o0000o`000004o`000003oookJ_l0003o000000[o00000_oonfX3o`000003oookJ_l0003o0000
00Co00000_oonfX7o`000003oookJ_l0003o0000013o00001OoonfX4o`000003oookJ_l0003o0000
00Co000000?ooo]Zo`000?l000003?l00003oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX3
o`000003oookJ_l0003o000000;o00000_oonfX;o`000003oookJ_l0003o000000[o00001?oonfX6
o`000004oookJ_l0003o0000o`0000?ooo]Z0ol00002oookJPGo00000_oonfX3o`000003oookJ_l0
003o000000Co000000Cooo]Zo`000?l0003o00000_oonfX5o`0000Gooo]Z1_l000000ooonf[o0000
o`00000<o`000005oookJ_l0003o0000o`000?oonfX01?l00002oookJPWo00000_oonfX3o`0000?o
oo]Z0ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000;o00000_oonfX:o`0000Co
oo]Z0ol00002oookJPgo000000?ooo]Zo`000?l000001ol00003oookJPCo000000?ooo]Zo`000?l0
00001_l00005oookJPGo000000?ooo]Zo`000?l000004ol00004oookJP?o00006ooonfX005Gooo]Z
1_l000000ooonf[o0000o`000008o`000003oookJ_l0003o000000[o00000_oonfX4o`0000Cooo]Z
1_l00002oookJPSo00001?oonfX4o`000003oookJ_l0003o0000017o000000Cooo]Zo`000?l0003o
00000ooonfXDo`000003oookJ_l0003o0000017o00000_oonfX3o`000003oookJ_l0003o000000Co
00000_oonfX=o`000003oookJ_l0003o000000_o00000_oonfX5o`0000;ooo]Z5Ol000000ooonf[o
0000o`000003o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000_l00002oookJQSo
000000?ooo]Zo`000?l000001ol000001?oonf[o0000o`000?l00003oookJPSo00001_oonfXCo`00
00Gooo]Z0ol00002oookJPWo000000?ooo]Zo`000?l000001?l000001Ooonf[o0000o`000?l0003o
oo]Z00Co00000_oonfX9o`000003oookJ_l0003o000000Co000000Cooo]Zo`000?l0003o00000_oo
nfX@o`000003oookJ_l0003o000000?o00001ooonfX8o`000003oookJ_l0003o000001?o000000?o
oo]Zo`000?l000002?l00003oookJPGo000000?ooo]Zo`000?l000004ol00004oookJP?o00006ooo
nfX005Gooo]Z1_l000000ooonf[o0000o`000008o`000003oookJ_l0003o000000[o00000_oonfX4
o`0000Cooo]Z1ol000001?oonf[o0000o`000?l00002oookJPCo000000?ooo]Zo`000?l000001?l0
00000ooonf[o0000o`00000Ao`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000002?l0
00001Ooonf[o0000o`000?l0003ooo]Z00?o00000ooonfX8o`0000?ooo]Z2?l000000ooonf[o0000
o`000007o`000003oookJ_l0003o000000Go00000ooonfX7o`0000?ooo]Z2_l00002oookJQ;o0000
1?oonfX6o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000004Ol00002oookJQ;o0000
00Cooo]Zo`000?l0003o00000ooonfX3o`0000Gooo]Z2?l00008oookJQ?o00001OoonfX4o`000003
oookJ_l0003o000001;o000000?ooo]Zo`000?l000000_l00002oookJP?o00000_oonfX4o`000003
oookJ_l0003o000000Co000000Gooo]Zo`000?l0003o0000oookJP0Ao`0000;ooo]Z2?l00006oook
JPGo00000ooonfX?o`000005oookJ_l0003o0000o`000?oonfX02_l00003oookJP?o00001OoonfX4
o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`0000Oooo]Z0ol0000KoookJP007_oonfX00ooM
fFcooo]ZoookJP05oookJP03omgIK?oonf[ooo]Z02cooo]Z1?l00003oookJQOo00000_oonfX3o`00
0005oookJ_l0003o0000o`000?oonfX01ol00006oookJP_o00000_oonfXCo`0000;ooo]Z0ol00000
0ooonf[o0000o`000005o`0000Sooo]Z0ol00003oookJPCo000000?ooo]Zo`000?l000000ol00000
0ooonf[o0000o`00000@o`000003oookJ_l0003o000000Go00000ooonfXDo`000003oookJ_l0003o
000001;o00001?oonfX4o`0000;ooo]Z1?l00002oookJPWo00000_oonfX5o`0000?ooo]Z0ol00002
oookJPoo000000Gooo]Zo`000?l0003o0000oookJP05o`0000;ooo]Z1_l000000ooonf[o0000o`00
0009o`000003oookJ_l0003o000000;o00000ooonfX8o`000004oookJ_l0003o0000o`0000Gooo]Z
5_l00005oookJPSo00000ooonfXQo`000003oookJ_l0003o000000Ko00001_oonfXKo`000003oook
J_l0003o000000So000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000003o`0000;ooo]Z
2_l000000ooonf[o0000o`000007o`0001_ooo]Z000BoookJPGo001o1_oonfX00ooMfFco001ooeEC
M`05oookJP03oeECMol007ooc<Q^00Oooo]Z0ol007l5oookJPGo001o6OoonfX5o`000003oookJ_l0
003o000000Oo000000?ooo]Zo`000?l000003?l00002oookJP?o000000Gooo]Zo`000?l0003o0000
oookJP07o`0000Gooo]Z3?l00002oookJPSo000000?ooo]Zo`000?l000002?l000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00003?oonfX6o`000005
oookJ_l0003o0000o`000?oonfX06ol00003oookJQ7o00000ooonfX3o`000003oookJ_l0003o0000
00?o000000?ooo]Zo`000?l000002?l00005oookJP?o00002?oonfX3o`0000;ooo]Z2ol00002oook
JPCo00001?oonfX=o`0000Gooo]Z3Ol00003oookJPoo00001?oonfX5o`0000;ooo]Z0ol00003oook
JQSo000000Cooo]Zo`000?l0003o00000ooonfX6o`000003oookJ_l0003o000000Co00000_oonfXK
o`000003oookJ_l0003o000000Ko00000_oonfX=o`0000?ooo]Z3ol00002oookJPOo00000ooonfX=
o`0000?ooo]Z1?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Co00007_oonfX0
017ooo]Z1ol007l6oookJP03oeECMol007ooEE=g00?ooo]Z00CoEE=go`00OolQ8Gcok^Y[1ooonfX3
o`00O`Cooo]Z1ol007lHoookJPWo00000ooonfX3o`000003oookJ_l0003o000000Wo000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000003o`0000;ooo]Z4?l00002oookJP[o000000Cooo]Z
o`000?l0003o00000_oonfX<o`0000?ooo]Z2ol000000ooonf[o0000o`000002o`0000Gooo]Z1Ol0
00000ooonf[o0000o`00000Ao`000003oookJ_l0003o000000_o00000_oonfX4o`000003oookJ_l0
003o000000Co00000_oonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000002o`0000;ooo]Z2_l0
0002oookJP?o00000_oonfX3o`0000Gooo]Z1?l00002oookJP[o00000ooonfX4o`0000Cooo]Z3Ol0
0003oookJR7o00000_oonfX7o`0000;ooo]Z1Ol000000ooonf[o0000o`00000Do`0000?ooo]Z0ol0
0003oookJPKo000000?ooo]Zo`000?l000001?l00004oookJP?o00000_oonfX3o`0000Cooo]Z1_l0
00000ooonf[o0000o`00000>o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001?l0
0005oookJP[o00000_oonfXIo`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000ol0
00000ooonf[o0000o`000004o`0001kooo]Z000@oookJPCo001o00Cooo]Zo`00Ool007oo001o1ooo
nfX02?mEDgOo001ooeECMooonf[oEE=go`00OolQ8Gcok^Y[2?oonfX3o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007lHoookJP_o00001OoonfX3o`0000;ooo]Z1_l000000ooonf[o0000o`00000;
o`0000;ooo]Z4Ol000000ooonf[o0000o`00000<o`0000;ooo]Z0ol00004oookJPOo000000?ooo]Z
o`000?l000002Ol000000ooonf[o0000o`000002o`0000Gooo]Z1Ol00004oookJPSo000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000003o`0000?ooo]Z1Ol00002oookJP_o00001OoonfX3
o`0000Cooo]Z1?l00005oookJPOo00000_oonfX3o`0000;ooo]Z1_l00002oookJP?o00000ooonfX:
o`0000?ooo]Z0ol00002oookJPCo00000_oonfX4o`000004oookJ_l0003o0000o`0000Gooo]Z4ol0
0002oookJPGo000000?ooo]Zo`000?l000003Ol00004oookJQ[o00000ooonfX5o`000003oookJ_l0
003o000000Co000000?ooo]Zo`000?l000002ol00002oookJP?o00001?oonfX3o`0000;ooo]Z6ol0
0004oookJP?o00000_oonfX8o`000004oookJ_l0003o0000o`0000?ooo]Z0ol000000ooonf[o0000
o`00000Jo`0000?ooo]Z2?l0000OoookJP004?oonfX3o`00O`?ooo]Z0ol007l7oookJP06oeECMol0
07oo411mo`00OolQ8Gcok^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o5ooonfX;o`0000Co
oo]Z0ol00005oookJPCo000000?ooo]Zo`000?l000002ol00002oookJP_o000000?ooo]Zo`000?l0
00000ol00004oookJP_o00000_oonfX3o`0000Cooo]Z0ol000001?oonf[o0000o`000?l00004oook
JP?o00000_oonfX3o`000003oookJ_l0003o000000;o00001_oonfX5o`0000?ooo]Z1ol00004oook
JPGo000000?ooo]Zo`000?l000000ol00002oookJQ_o00000_oonfX6o`0000;ooo]Z0ol00004oook
JPSo00000_oonfX6o`0000;ooo]Z0ol00002oookJPGo00000ooonfX5o`0000Kooo]Z1?l00002oook
JPWo00000ooonfXDo`000004oookJ_l0003o0000o`0000Wooo]Z2_l000000ooonf[o0000o`00000G
o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000001Ol00003oookJPko00000_oonfX3
o`0000Gooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00So000000?ooo]Zo`000?l000003ol0
00000ooonf[o0000o`000006o`000003oookJ_l0003o000000;o000000Gooo]Zo`000?l0003o0000
oookJP05o`000003oookJ_l0003o000001co000000?ooo]Zo`000?l000001?l000000ooonf[o0000
o`000003o`0001_ooo]Z000FoookJP?o001o2?oonfX01?l@47go001oo`00OooMfF`:oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007lGoookJP_o00000ooonfX=o`0000Oooo]Z1ol00003oookJP?o0000
0ooonfX3o`0000?ooo]Z1?l000000ooonf[o0000o`000003o`0000?ooo]Z1ol0000;oookJPCo0000
1?oonfX3o`0000Gooo]Z0ol00008oookJPGo000000?ooo]Zo`000?l000001_l00007oookJP?o0000
0_oonfX4o`0000;ooo]Z1?l000000ooonf[o0000o`00000Do`0000;ooo]Z1Ol00003oookJPGo0000
1OoonfX3o`0000Kooo]Z2?l00003oookJPgo00001_oonfX7o`000003oookJ_l0003o000002Go0000
00?ooo]Zo`000?l000001?l000001?oonf[o0000o`000?l00002oookJPGo00000ooonfX=o`0000;o
oo]Z3?l000000ooonf[o0000o`000005o`0000?ooo]Z3_l00006oookJP_o000000?ooo]Zo`000?l0
00001_l000001?oonf[o0000o`000?l00002oookJPgo00000_oonfX6o`0000Cooo]Z2ol00002oook
JQKo00000_oonfX5o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000000ol0000Koook
JP005_oonfX3o`00O`Oooo]Z00KoEE=go`00Ool@47go001oob4QO?o^jV/9oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007lGoookJP_o00000ooonfXBo`0000?ooo]Z2Ol0000:oookJPGo00000_oonfX?
o`0000_ooo]Z1ol000001?oonf[o0000o`000?l00005oookJPSo000000?ooo]Zo`000?l000002Ol0
0002oookJPCo00000_oonfX3o`0000Kooo]Z0ol00003oookJQ7o00000_oonfX8o`0000;ooo]Z1ol0
00000ooonf[o0000o`000006o`0000;ooo]Z0ol00006oookJQSo00000ooonfXHo`000003oookJ_l0
003o000001_o000000?ooo]Zo`000?l000003Ol00002oookJPco00000_oonfX<o`0000Cooo]Z4_l0
0002oookJPKo000000?ooo]Zo`000?l000001ol00007oookJPCo000000?ooo]Zo`000?l000000_l0
0004oookJQ7o00001OoonfX:o`000003oookJ_l0003o000000Ko000000Cooo]Zo`000?l0003o0000
0ooonfX:o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000002_l0000KoookJP004Ooo
nfX2o`00O`;ooo]Z1?l007l6oookJP08oeECMol007ooEE=goookJ_mEDgOo001oob4QO?o^jV/8oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007lGoookJR3o00001OoonfX3o`000004oookJ_l0003o0000
o`0000[ooo]Z5_l00003oookJP?o00001OoonfX7o`000003oookJ_l0003o000000Co00000_oonfX8
o`000003oookJ_l0003o000000;o00000_oonfXBo`0000Cooo]Z0ol00003oookJPKo000000Cooo]Z
o`000?l0003o00000_oonfX5o`0000;ooo]Z4Ol000000ooonf[o0000o`000006o`0000?ooo]Z1_l0
0002oookJP_o00000_oonfX8o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002Ol0
0002oookJPKo00000_oonfX=o`000003oookJ_l0003o000001Wo000000Cooo]Zo`000?l0003o0000
1ooonfX7o`0000;ooo]Z2_l00002oookJP?o00000ooonfX5o`0000;ooo]Z1_l00005oookJPKo0000
00?ooo]Zo`000?l000001ol00007oookJPWo000000Gooo]Zo`000?l0003o0000oookJP0>o`0000Oo
oo]Z1_l000000ooonf[o0000o`00000:o`0000?ooo]Z0ol000000ooonf[o0000o`000008o`000003
oookJ_l0003o000000oo00007?oonfX0017ooo]Z1ol007l6oookJP03oeECMol007ooEE=g00?ooo]Z
00CoEE=go`00OolQ8Gcok^Y[1ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o5ooonfX8o`000003
oookJ_l0003o000001Oo000000?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?l0000:oook
JQKo000000?ooo]Zo`000?l000001?l00006oookJPGo000000?ooo]Zo`000?l000003_l000000ooo
nf[o0000o`000002o`000003oookJ_l0003o0000017o00000ooonfX3o`0000Cooo]Z1_l00005oook
JPKo00000ooonfX@o`000003oookJ_l0003o000000Ko00000ooonfX7o`000003oookJ_l0003o0000
00Co00000_oonfX;o`0000;ooo]Z2Ol000001Ooonf[o0000o`000?l0003ooo]Z00ko00000ooonfX=
o`0000Cooo]Z0ol00002oookJP_o00000_oonfX5o`0000;ooo]Z2?l00002oookJPSo000000Cooo]Z
o`000?l0003o00000_oonfX5o`0000;ooo]Z0ol00003oookJPGo00000_oonfX6o`0000Gooo]Z1_l0
0003oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX3o`000003oookJ_l0003o000000So0000
00?ooo]Zo`000?l000000_l000000ooonf[o0000o`000008o`0000Oooo]Z1ol000000ooonf[o0000
o`000008o`000004oookJ_l0003o0000o`0000?ooo]Z3_l000000ooonf[o0000o`00000?o`0001co
oo]Z000AoookJPKo001o1_oonfX00ooMfFco001ooeECM`05oookJP03oeECMol007ooc<Q^00Oooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00OaOooo]Z2?l000000ooonf[o0000o`000009o`000003oook
J_l0003o000000Co00001?oonfX3o`000004oookJ_l0003o0000o`0000?ooo]Z1_l00007oookJP?o
000000Cooo]Zo`000?l0003o00000_oonfX=o`000003oookJ_l0003o000000Co00000ooonfX8o`00
0003oookJ_l0003o000000ko000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000007o`00
00;ooo]Z2?l00003oookJP?o00001?oonfX6o`0000Gooo]Z0ol00002oookJQ7o00001_oonfX3o`00
00Kooo]Z1ol00002oookJPGo00001OoonfX6o`0000?ooo]Z1ol00008oookJPko00000_oonfX6o`00
0003oookJ_l0003o000000Go00002OoonfX:o`0000Gooo]Z0ol00002oookJPSo00000_oonfX8o`00
0004oookJ_l0003o0000o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`0000?ooo]Z2_l00000
1?oonf[o0000o`000?l00009oookJP?o000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z
0ol000000ooonf[o0000o`000005o`0000Cooo]Z1?l000000ooonf[o0000o`000004o`0000;ooo]Z
0ol00003oookJQ?o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000004o`0000;ooo]Z
1_l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000Ko00007OoonfX0017ooo]Z0_l0
07l;oookJP03omgIK?oonf[ooo]Z00Gooo]Z00?ogMU/oookJ_oonfX00ooonfX6o`00O`?ooo]Z0ol0
07l3oookJP?o001o2_oonfX01?nHUW;o001oo`00OomVI7H9oookJPSo000000?ooo]Zo`000?l00000
2Ol000000ooonf[o0000o`000004o`0000Cooo]Z1ol00003oookJPco000000Gooo]Zo`000?l0003o
0000oookJP03o`0000Gooo]Z1Ol000000ooonf[o0000o`000009o`0000?ooo]Z1?l000001Ooonf[o
0000o`000?l0003ooo]Z00go00000ooonfX:o`000004oookJ_l0003o0000o`0000;ooo]Z4_l00000
0ooonf[o0000o`000008o`000003oookJ_l0003o000000_o00001?oonfX3o`0000Wooo]Z0ol00009
oookJP[o00001OoonfX6o`0000?ooo]Z1Ol00009oookJPko00000ooonfX6o`000003oookJ_l0003o
000000?o00001OoonfX?o`0000?ooo]Z7_l00002oookJQCo00001?oonfX3o`000003oookJ_l0003o
000000Co00000_oonfX3o`000005oookJ_l0003o0000o`000?oonfX00ol00002oookJPOo00002Ooo
nfX3o`0000?ooo]Z1?l00002oookJPGo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00
0005o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000001?l00002oookJQWo00007Ooo
nfX0017ooo]Z0_l007lIoookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z00?o
gMU/o`00Ool007l00_l007l00omgMGGooo]ZoookJP06oookJPSo000000?ooo]Zo`000?l000002?l0
0002oookJPKo00000_oonfX3o`0000;ooo]Z0ol000000ooonf[o0000o`00000=o`0000cooo]Z0ol0
0002oookJPOo00000ooonfX3o`000003oookJ_l0003o000000oo000000Cooo]Zo`000?l0003o0000
1_oonfX;o`0000Gooo]Z1?l000000ooonf[o0000o`000006o`0000;ooo]Z6?l000000ooonf[o0000
o`00000Go`0000Gooo]Z0ol000000ooonf[o0000o`000006o`0000?ooo]Z1ol00002oookJPKo0000
2OoonfX3o`000003oookJ_l0003o000000Oo00001?oonfX6o`0000;ooo]Z0ol00006oookJPoo0000
0ooonfX=o`0000?ooo]Z3_l000000ooonf[o0000o`00000Co`0000Cooo]Z2_l000000ooonf[o0000
o`000002o`000003oookJ_l0003o000000?o00000ooonfX5o`0000Gooo]Z1_l00007oookJP?o0000
0_oonfX=o`0000;ooo]Z9?l000000ooonf[o0000o`000008o`000004oookJ_l0003o0000o`0001go
oo]Z000BoookJPOo001o5OoonfX4o`00O`Cooo]Z1ol007l:oookJP06oeECMol007oo^[Q_okZhKol0
07oo411m2?oonfX9o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000000_l00002oook
JPSo000000?ooo]Zo`000?l000004?l00003oookJPWo00000_oonfX9o`000005oookJ_l0003o0000
o`000?oonfX05?l00004oookJPKo000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`000002
o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000005?l00002oookJQ_o000000Gooo]Z
o`000?l0003o0000oookJP03o`000003oookJ_l0003o000000Oo00000_oonfXAo`0000?ooo]Z5Ol0
0003oookJP?o00000_oonfX3o`0000?ooo]Z4?l00005oookJPgo00000ooonfX;o`000003oookJ_l0
003o000001Oo00000ooonfX:o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol0
0003oookJPSo00000_oonfX6o`0000Kooo]Z0ol00003oookJR?o000000?ooo]Zo`000?l000001Ol0
0002oookJP?o00000ooonfX?o`0001gooo]Z000BoookJPOo001o5_oonfX3o`00O`Gooo]Z1Ol007l4
oookJPOo001o00Co411mo`00Oooonf[ooo]Z0_l007l8oookJPWo000000Gooo]Zo`000?l0003o0000
oookJP08o`000003oookJ_l0003o000001Oo000000?ooo]Zo`000?l000001Ol00003oookJPWo0000
0_oonfX5o`000005oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o0000o`00000>o`000003
oookJ_l0003o000000?o00000_oonfX6o`0000;ooo]Z6?l000000ooonf[o0000o`000007o`0000Co
oo]Z0ol00002oookJPoo00000ooonfX?o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l0
00002?l000000ooonf[o0000o`000002o`0000;ooo]Z5_l000000ooonf[o0000o`00000=o`0000Go
oo]Z1?l00002oookJPGo000000?ooo]Zo`000?l000001_l00004oookJP?o000000?ooo]Zo`000?l0
00001Ol00002oookJP?o00001?oonfX:o`000003oookJ_l0003o000000Co00000_oonfXIo`000003
oookJ_l0003o000000;o000000?ooo]Zo`000?l000000ol00002oookJP?o00000ooonfX8o`0000;o
oo]Z2Ol000000ooonf[o0000o`000003o`0000?ooo]Z3ol000000ooonf[o0000o`000005o`0000;o
oo]Z2_l000000ooonf[o0000o`00000Lo`0001gooo]Z0017oookJP;o001o0_nj^6l2o`00O`Sooo]Z
5_l00005oookJP?o000000Cooo]Zo`000?l0003o00000ooonfXCo`0000?ooo]Z2Ol00002oookJP?o
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000005o`0000;ooo]Z1ol000001Ooonf[o
0000o`000?l0003ooo]Z02Oo000000?ooo]Zo`000?l000001ol00004oookJP?o00001?oonfX@o`00
00Cooo]Z1Ol000000ooonf[o0000o`000002o`0000;ooo]Z1_l00002oookJP[o000000?ooo]Zo`00
0?l000000_l00002oookJQKo000000?ooo]Zo`000?l000003Ol00005oookJP_o00000ooonfX=o`00
0003oookJ_l0003o000000Go00001OoonfXEo`000003oookJ_l0003o000001?o000000?ooo]Zo`00
0?l000001ol00003oookJP?o00001OoonfX3o`0000?ooo]Z2_l00003oookJP?o000000?ooo]Zo`00
0?l000000ol00005oookJQ7o000000Cooo]Zo`000?l0003o00000ooonfX8o`0000;ooo]Z6ol0000P
oookJP00AooonfX5o`00O`03oeECMooonf[ooo]Z00Kooo]Z5ol000000ooonf[o0000o`000007o`00
00Cooo]Z2?l00003oookJPOo00001?oonfX5o`000003oookJ_l0003o000000Ko000000?ooo]Zo`00
0?l000002ol00004oookJPKo00001_oonfX=o`0000?ooo]Z5?l00003oookJPGo00001ooonfX3o`00
00Cooo]Z1_l00002oookJP_o000000?ooo]Zo`000?l000002Ol00002oookJPGo00000_oonfX6o`00
0003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000009o`00
00;ooo]Z1_l000000ooonf[o0000o`000007o`0000;ooo]Z3Ol00004oookJP?o000000?ooo]Zo`00
0?l000001ol000000ooonf[o0000o`000006o`000003oookJ_l0003o0000017o00000_oonfX:o`00
00;ooo]Z0ol00002oookJP?o00000_oonfX<o`0000Cooo]Z0ol00005oookJP?o00001OoonfX8o`00
00?ooo]Z1ol00004oookJQCo000000Cooo]Zo`000?l0003o00000ooonfX9o`000003oookJ_l0003o
000000?o000000?ooo]Zo`000?l000003?l00002oookJPGo00008?oonfX004Oooo]Z00Ko411mo`00
OomEDgOo001ooc8bN_o^jV/8oookJQOo000000Gooo]Zo`000?l0003o0000oookJP05o`0000Gooo]Z
1ol00002oookJP[o00000_oonfX3o`0000?ooo]Z2?l000000ooonf[o0000o`000008o`0000;ooo]Z
4?l000000ooonf[o0000o`000007o`000004oookJ_l0003o0000o`0000?ooo]Z3?l000000ooonf[o
0000o`000004o`0000;ooo]Z1ol00004oookJP?o00001ooonfX6o`0000Gooo]Z3?l00002oookJPgo
00000_oonfX6o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000_l00005oookJP?o
000000?ooo]Zo`000?l000001?l00002oookJPCo00001?oonfX7o`0000Cooo]Z4ol00002oookJQ;o
000000?ooo]Zo`000?l000007Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000000ko
00001OoonfX6o`0000;ooo]Z0ol00002oookJP_o00000ooonfX7o`0000Cooo]Z4ol00003oookJPko
000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Go
00000_oonfX8o`0001gooo]Z0017oookJP04oeECMol007ooQhEcolc8KP;oMgEe2?oonfX7o`0000;o
oo]Z4_l000000ooonf[o0000o`00000<o`0000?ooo]Z4Ol00005oookJPGo000000?ooo]Zo`000?l0
00009Ol000001?oonf[o0000o`000?l00006oookJPKo00000ooonfX7o`000003oookJ_l0003o0000
00Oo00000_oonfX4o`0000Gooo]Z2_l000000ooonf[o0000o`00000<o`0000;ooo]Z2Ol00003oook
JQ?o00000_oonfX3o`0000Wooo]Z1Ol00003oookJPCo00000ooonfX3o`000003oookJ_l0003o0000
00;o00001?oonfX8o`000003oookJ_l0003o000000So00001OoonfXEo`0000Kooo]Z:_l00006oook
JPKo00001OoonfXGo`0000Cooo]Z4ol00003oookJPOo000000?ooo]Zo`000?l000002?l00003oook
JQSo00007OoonfX004Oooo]Z00?oc<Q^o`00Ool007l00_l007l00omEDgOooo]ZoookJP06oookJPCo
000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`00000;o`000003oookJ_l0003o000000Oo
00000ooonfXFo`0000Kooo]Z9?l00004oookJP?o00001?oonfX8o`0000?ooo]Z0ol000001Ooonf[o
0000o`000?l0003ooo]Z00Wo00000_oonfX5o`0000Cooo]Z4?l000000ooonf[o0000o`000006o`00
00Oooo]Z2_l00003oookJPgo00000_oonfX6o`0000Gooo]Z0ol00006oookJP?o00001?oonfX3o`00
0004oookJ_l0003o0000o`0000Oooo]Z1_l00002oookJPko000000?ooo]Zo`000?l000001ol00000
0ooonf[o0000o`000003o`0000;ooo]Z1?l00004oookJPSo000000Cooo]Zo`000?l0003o00000_oo
nfXMo`0000Cooo]Z2?l00005oookJPGo00000_oonfX3o`0000;ooo]Z2Ol00009oookJP[o000000?o
oo]Zo`000?l000000ol00003oookJQ7o00001?oonfXHo`0001gooo]Z0018oookJP05ojVWLOl@47go
001ooeECMoo^jV/02?oonfX4o`000003oookJ_l0003o000000Ko00001_oonfX=o`000003oookJ_l0
003o000000Ko00001?oonfX@o`000003oookJ_l0003o000000?o00000_oonfX;o`0000;ooo]Z3_l0
00000ooonf[o0000o`000005o`000004oookJ_l0003o0000o`0000Gooo]Z0ol00004oookJPSo0000
0ooonfX3o`0000Gooo]Z2Ol00002oookJPOo00000_oonfXHo`0000Sooo]Z2_l00004oookJPGo0000
0_oonfX3o`0000Oooo]Z0ol00005oookJPKo00001OoonfX8o`0000?ooo]Z1_l000000ooonf[o0000
o`000005o`0000;ooo]Z3_l000000ooonf[o0000o`00000=o`0000;ooo]Z1?l00004oookJPOo0000
2?oonfX@o`0000;ooo]Z5_l00005oookJPCo00000ooonfX3o`0000;ooo]Z2?l00005oookJP?o0000
0_oonfX:o`000003oookJ_l0003o000000?o00001?oonfXWo`000003oookJ_l0003o000000?o0000
7?oonfX005Gooo]Z1?l000000ooonf[o0000o`000007o`0000Gooo]Z1?l000000ooonf[o0000o`00
0006o`000003oookJ_l0003o000000So00000_oonfX;o`0000?ooo]Z5?l000000ooonf[o0000o`00
000>o`000003oookJ_l0003o000000Co00000_oonfX4o`0000Sooo]Z2ol00002oookJPGo00001_oo
nfX4o`0000Gooo]Z9_l00003oookJPOo00001OoonfX3o`0000?ooo]Z0ol00005oookJPSo00001?oo
nfX8o`0000Cooo]Z1ol00002oookJPSo000000Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z
3ol00002oookJPCo00000ooonfX6o`000003oookJ_l0003o000000?o00001?oonfX<o`0000;ooo]Z
1?l00004oookJPSo00000ooonfX9o`000003oookJ_l0003o000000[o00001?oonfX5o`000003oook
J_l0003o000000?o00000_oonfX4o`000003oookJ_l0003o000000?o00000ooonfX3o`000003oook
J_l0003o000000Ko00001?oonfX6o`0000;ooo]Z8Ol00003oookJPCo00000_oonfX4o`0001cooo]Z
001EoookJPKo000000?ooo]Zo`000?l000001Ol00002oookJP?o000000?ooo]Zo`000?l000000_l0
00000ooonf[o0000o`000009o`0000Cooo]Z0ol00005oookJQ3o00000_oonfX=o`000003oookJ_l0
003o000000_o00000_oonfX>o`0000Sooo]Z2Ol00004oookJPGo00000_oonfX3o`0000;ooo]Z4ol0
00000ooonf[o0000o`00000Ko`0000;ooo]Z1Ol00005oookJPWo00001OoonfX5o`0000Gooo]Z2_l0
0004oookJPOo00000_oonfX8o`000005oookJ_l0003o0000o`000?oonfX00ol00003oookJQCo0000
0ooonfX5o`000003oookJ_l0003o000000Go00001?oonfX4o`0000;ooo]Z1Ol00002oookJPCo0000
00?ooo]Zo`000?l000002ol00005oookJQ;o000000?ooo]Zo`000?l000003Ol000000ooonf[o0000
o`000002o`000003oookJ_l0003o0000013o00000_oonfX:o`0000;ooo]Z:?l00002oookJPCo0000
7?oonfX005Gooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00So000000?ooo]Zo`000?l00000
0_l000001?oonf[o0000o`000?l00003oookJPGo000000?ooo]Zo`000?l000002?l00002oookJR;o
000000Cooo]Zo`000?l0003o00000_oonfX4o`0000;ooo]Z3_l000000ooonf[o0000o`00000>o`00
00Cooo]Z1_l000001?oonf[o0000o`000?l00002oookJPgo00000_oonfX4o`000003oookJ_l0003o
000000Co00000ooonfX:o`0000;ooo]Z2?l00003oookJP?o000000Cooo]Zo`000?l0003o00000_oo
nfX<o`0000;ooo]Z1Ol00005oookJP[o00002?oonfX@o`0000;ooo]Z3Ol00002oookJP[o00001_oo
nfX3o`000003oookJ_l0003o000000Go00001?oonfX3o`0000?ooo]Z1Ol00002oookJP?o00000_oo
nfX3o`0000?ooo]Z1ol00005oookJROo00000ooonfX@o`0000;ooo]Z6ol000000ooonf[o0000o`00
0002o`000003oookJ_l0003o000000ko00009OoonfX005Gooo]Z1_l00005oookJPSo000000?ooo]Z
o`000?l000000_l00006oookJPCo00000ooonfX:o`0000;ooo]Z0ol000000ooonf[o0000o`000007
o`000003oookJ_l0003o0000017o00000_oonfX9o`0000;ooo]Z2_l000000ooonf[o0000o`00000:
o`0000Gooo]Z0ol00005oookJPGo000000Cooo]Zo`000?l0003o00000_oonfXCo`000003oookJ_l0
003o000000Co00000ooonfX3o`000003oookJ_l0003o000000?o00000ooonfX:o`0000Gooo]Z1?l0
0002oookJPOo000000Cooo]Zo`000?l0003o00002?oonfX3o`000003oookJ_l0003o000000Co0000
00?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?l00002oookJPGo000000?ooo]Zo`000?l0
00000_l000000ooonf[o0000o`00000;o`0000?ooo]Z3_l00004oookJP?o00001OoonfX;o`000005
oookJ_l0003o0000o`000?oonfX01ol00005oookJPCo00001ooonfX5o`0000?ooo]Z5ol000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000000Wo00000_oonfXAo`000003oookJ_l0003o0000
00Ko00000_oonfX3o`000003oookJ_l0003o000000_o000000?ooo]Zo`000?l000001?l000000ooo
nf[o0000o`00000?o`0002;ooo]Z001EoookJPCo00001ooonfX7o`0000;ooo]Z0ol00003oookJP[o
000000?ooo]Zo`000?l000002?l00002oookJP?o000000?ooo]Zo`000?l000001ol000000ooonf[o
0000o`000003o`000003oookJ_l0003o000000Oo000000Cooo]Zo`000?l0003o00000_oonfX9o`00
00Kooo]Z1?l00003oookJPco00002OoonfX3o`000003oookJ_l0003o000000Co00001OoonfX3o`00
0003oookJ_l0003o000000[o00003OoonfX3o`0000;ooo]Z1Ol00002oookJPCo00000ooonfX<o`00
00;ooo]Z2ol00008oookJPGo00000_oonfX3o`000003oookJ_l0003o000000Oo00000_oonfX5o`00
0003oookJ_l0003o0000013o00000ooonfX3o`000003oookJ_l0003o000000Co00001?oonfX3o`00
0005oookJ_l0003o0000o`000?oonfX04ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00001Ooo
nfX4o`0000Wooo]Z8_l000000ooonf[o0000o`000009o`0000;ooo]Z0ol000000ooonf[o0000o`00
0002o`0000;ooo]Z1ol000000ooonf[o0000o`000005o`0000;ooo]Z1?l000001?oonf[o0000o`00
0?l00004oookJQKo00000_oonfX7o`0000;ooo]Z0ol0000MoookJP00EOoonfX7o`0000Cooo]Z1ol0
0002oookJP?o00000ooonfX:o`0000?ooo]Z2?l00002oookJP?o000000?ooo]Zo`000?l000001ol0
00001?oonf[o0000o`000?l00007oookJPGo00001_oonfX6o`0000?ooo]Z0ol00003oookJP?o0000
0ooonfX8o`000004oookJ_l0003o0000o`0000Cooo]Z0ol00003oookJP?o00001?oonfX5o`0000;o
oo]Z1?l00003oookJPCo00000ooonfX3o`0000Cooo]Z0ol00006oookJP[o00000ooonfX3o`0000?o
oo]Z3?l00002oookJP?o000000?ooo]Zo`000?l000001Ol00002oookJP?o00000ooonfX5o`0000;o
oo]Z3Ol00004oookJP?o000000?ooo]Zo`000?l000004?l00002oookJP?o00000_oonfX4o`0000;o
oo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000005Ol000000ooo
nf[o0000o`000004o`0000;ooo]Z1?l00004oookJP?o00000_oonfX;o`000003oookJ_l0003o0000
00Oo000000?ooo]Zo`000?l000001ol00004oookJP?o000000Gooo]Zo`000?l0003o0000oookJP05
o`0000Cooo]Z0ol00002oookJPSo000000?ooo]Zo`000?l000001Ol00002oookJP?o00002_oonfX3
o`0000;ooo]Z4?l00004oookJPGo00000_oonfX3o`0001gooo]Z001EoookJPOo00001?oonfX7o`00
00;ooo]Z0ol00003oookJP_o00000_oonfX8o`0000;ooo]Z4Ol00006oookJPKo00001OoonfX5o`00
00Gooo]Z0ol00009oookJPSo000000?ooo]Zo`000?l000001?l000001?oonf[o0000o`000?l00002
oookJPCo00001?oonfXAo`0000;ooo]Z1Ol00004oookJP?o00000ooonfX9o`000005oookJ_l0003o
0000o`000?oonfX05ol00005oookJPgo00000_oonfX3o`0000?ooo]Z3?l00008oookJQ;o000000?o
oo]Zo`000?l000000_l00002oookJPCo00000_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z
6Ol000000ooonf[o0000o`000005o`0000;ooo]Z0ol00005oookJPGo000000?ooo]Zo`000?l00000
0ol00002oookJP?o000000?ooo]Zo`000?l000003?l00002oookJPKo00001OoonfX3o`0000?ooo]Z
0ol00004oookJP?o00000_oonfX9o`0000;ooo]Z1Ol00002oookJP?o00002_oonfX3o`000003oook
J_l0003o000000;o00000_oonfX8o`0000Oooo]Z1?l00003oookJPGo00006ooonfX005Gooo]Z2?l0
0004oookJPSo000000Cooo]Zo`000?l0003o00001OoonfX=o`0000;ooo]Z1?l000000ooonf[o0000
o`00000Bo`0000?ooo]Z2Ol00002oookJP?o00000_oonfX3o`0000;ooo]Z0ol000001?oonf[o0000
o`000?l00005oookJPoo000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l00007oook
JPoo00000_oonfX5o`0000Cooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00Go00001OoonfX;
o`0000;ooo]Z0ol00004oookJP?o00001ooonfX>o`0000Gooo]Z3Ol00003oookJP?o000000?ooo]Z
o`000?l000004?l000000ooonf[o0000o`00000Io`000003oookJ_l0003o000000Co000000?ooo]Z
o`000?l000002Ol000000ooonf[o0000o`000005o`0000[ooo]Z1Ol000000ooonf[o0000o`000004
o`0000Gooo]Z0ol00003oookJPSo00000ooonfX5o`0000Wooo]Z1Ol00002oookJQGo00001ooonfX3
o`0000Oooo]Z0ol000001?oonf[o0000o`000?l00003oookJPKo00002_oonfX3o`0000Gooo]Z0ol0
000KoookJP00EOoonfX;o`0000Gooo]Z1?l000001?oonf[o0000o`000?l00005oookJP[o00001?oo
nfX5o`0000?ooo]Z1_l000000ooonf[o0000o`000009o`0000;ooo]Z3ol00002oookJP?o00000_oo
nfX9o`0000Cooo]Z2_l000000ooonf[o0000o`00000:o`0000;ooo]Z1?l00004oookJP?o000000?o
oo]Zo`000?l000000ol00005oookJP?o00000ooonfX3o`0000;ooo]Z0ol000001Ooonf[o0000o`00
0?l0003ooo]Z00Go000000?ooo]Zo`000?l000003_l00008oookJP?o00001_oonfX7o`0000;ooo]Z
2_l00004oookJP?o000000?ooo]Zo`000?l000005_l00002oookJPGo000000?ooo]Zo`000?l00000
1ol000000ooonf[o0000o`00000Fo`0000Kooo]Z0ol000000ooonf[o0000o`000007o`0000;ooo]Z
0ol00003oookJPSo00000_oonfX8o`0000?ooo]Z1_l00002oookJP?o00001OoonfX5o`0000Wooo]Z
0ol00004oookJP?o000000Cooo]Zo`000?l0003o00000_oonfX<o`000004oookJ_l0003o0000o`00
00?ooo]Z0ol00007oookJPOo00001?oonfX3o`0000Gooo]Z0ol00002oookJP?o00001ooonfX3o`00
01_ooo]Z001EoookJPko00000_oonfX4o`000005oookJ_l0003o0000o`000?oonfX00ol00002oook
JPco000000?ooo]Zo`000?l000001Ol00008oookJP?o00000_oonfX6o`0000;ooo]Z4?l000001?oo
nf[o0000o`000?l00002oookJPWo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000004
o`000003oookJ_l0003o000000[o00000_oonfX4o`0000Cooo]Z0ol00003oookJP?o00002_oonfX4
o`0000;ooo]Z0ol00005oookJPGo000000?ooo]Zo`000?l000001?l00004oookJPKo000000?ooo]Z
o`000?l000002?l00006oookJPCo00000_oonfX3o`0000;ooo]Z2?l00004oookJP?o000000?ooo]Z
o`000?l000004Ol00006oookJPOo00000_oonfXCo`000003oookJ_l0003o000000Co000000Cooo]Z
o`000?l0003o00002?oonfX3o`000003oookJ_l0003o000000Oo00000_oonfX3o`0000?ooo]Z1Ol0
0002oookJP_o00000ooonfX6o`0000Sooo]Z2Ol00007oookJP?o00000_oonfX5o`000004oookJ_l0
003o0000o`0000;ooo]Z2_l00003oookJPGo000000?ooo]Zo`000?l000000_l00006oookJPKo0000
1OoonfX3o`0000Gooo]Z1?l000001?oonf[o0000o`000?l0000UoookJP00EOoonfX>o`0000;ooo]Z
1?l000000ooonf[o0000o`00000Co`000003oookJ_l0003o000000Go00000ooonfX?o`0000?ooo]Z
4?l00005oookJP[o000000?ooo]Zo`000?l000002ol00002oookJP?o00000ooonfX5o`0000;ooo]Z
1?l0000?oookJP?o00001OoonfX4o`0000[ooo]Z1?l00002oookJPSo00000ooonfXBo`0000Cooo]Z
1?l00002oookJPCo000000?ooo]Zo`000?l000001_l00004oookJP?o00000_oonfX3o`0000;ooo]Z
2?l000000ooonf[o0000o`000005o`000003oookJ_l0003o000000Oo00000_oonfXCo`000003oook
J_l0003o000000Ko00001?oonfX3o`0000?ooo]Z0ol000000ooonf[o0000o`000008o`000004oook
J_l0003o0000o`0000?ooo]Z1_l000000ooonf[o0000o`000004o`0000;ooo]Z3Ol00004oookJPco
00001ooonfX3o`0000;ooo]Z0ol00002oookJP?o000000?ooo]Zo`000?l000004_l00002oookJPWo
00000ooonfX6o`0000;ooo]Z0ol00002oookJPOo000000Cooo]Zo`000?l0003o00009OoonfX005Go
oo]Z2Ol00002oookJQoo00001OoonfXEo`0000;ooo]Z3Ol000001Ooonf[o0000o`000?l0003ooo]Z
00Wo000000Cooo]Zo`000?l0003o00000_oonfX<o`0000Sooo]Z0ol00006oookJPGo00000_oonfX3
o`0000Sooo]Z1_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Go00000_oonfX3
o`0000?ooo]Z2?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000co00000_oonfX6
o`0000;ooo]Z1?l000000ooonf[o0000o`000009o`000004oookJ_l0003o0000o`0000Oooo]Z1ol0
00000ooonf[o0000o`00000Eo`0000;ooo]Z1Ol000000ooonf[o0000o`000006o`0000;ooo]Z0ol0
00001?oonf[o0000o`000?l00004oookJPWo000000?ooo]Zo`000?l000003?l000001?oonf[o0000
o`000?l00002oookJP_o00000ooonfX<o`0000?ooo]Z3?l00007oookJP?o00000_oonfX3o`0000;o
oo]Z6?l00002oookJP[o000000Gooo]Zo`000?l0003o0000oookJP06o`0000?ooo]Z1?l000001?oo
nf[o0000o`000?l00004oookJP?o000000Cooo]Zo`000?l0003o00007_oonfX005Gooo]Z6Ol00000
0ooonf[o0000o`00000Ao`0000;ooo]Z5?l00003oookJPgo000000?ooo]Zo`000?l000002ol00000
0ooonf[o0000o`000004o`000003oookJ_l0003o000000Oo000000Cooo]Zo`000?l0003o00000_oo
nfX9o`0000?ooo]Z2_l00008oookJPKo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00
0005o`0000;ooo]Z0ol00003oookJPSo000000?ooo]Zo`000?l000000_l00002oookJPOo000000?o
oo]Zo`000?l000001?l00002oookJQco00000_oonfX<o`000005oookJ_l0003o0000o`000?oonfX0
2?l00002oookJPWo000000Cooo]Zo`000?l0003o00001?oonfX5o`0000Gooo]Z0ol000000ooonf[o
0000o`000003o`0000;ooo]Z1ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000Ko
000000Cooo]Zo`000?l0003o00000_oonfX;o`0000?ooo]Z6ol00007oookJP?o00000_oonfX3o`00
0003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000003Ol00003oookJPWo000000?ooo]Zo`00
0?l000002?l00003oookJPWo00000ooonfX3o`000004oookJ_l0003o0000o`0001kooo]Z001Eoook
JPKo000000?ooo]Zo`000?l000003_l00005oookJPOo000000?ooo]Zo`000?l000004ol000000ooo
nf[o0000o`000002o`0000;ooo]Z1Ol000000ooonf[o0000o`00000:o`0000Cooo]Z1ol000001?oo
nf[o0000o`000?l00002oookJPGo00000_oonfX<o`0000;ooo]Z2_l00002oookJPco00001ooonfX5
o`000003oookJ_l0003o000000_o00000_oonfX4o`0000;ooo]Z1ol00002oookJPKo000000?ooo]Z
o`000?l000004Ol00002oookJQKo000000?ooo]Zo`000?l000002_l00002oookJP?o000000Gooo]Z
o`000?l0003o0000oookJP03o`0000?ooo]Z3Ol00003oookJPKo00002ooonfX6o`000003oookJ_l0
003o000000_o00001OoonfX8o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000004_l0
0003oookJPKo00002ooonfX3o`0000;ooo]Z2Ol00003oookJP?o000000?ooo]Zo`000?l000001?l0
0004oookJP_o000000?ooo]Zo`000?l000000ol00002oookJP?o00000ooonfX9o`0000?ooo]Z2_l0
000KoookJP00EOoonfX5o`0000;ooo]Z2?l000000ooonf[o0000o`000005o`0000Cooo]Z2?l00002
oookJQCo00001OoonfX;o`000003oookJ_l0003o000000Ko00000_oonfX8o`0000;ooo]Z0ol00002
oookJQ?o00000_oonfX4o`000003oookJ_l0003o000001?o000000Gooo]Zo`000?l0003o0000oook
JP03o`0000Oooo]Z2?l00003oookJPCo00000_oonfX7o`000003oookJ_l0003o000001ko000000?o
oo]Zo`000?l000007Ol00006oookJPSo00000_oonfXDo`0000_ooo]Z5ol00005oookJPKo00000_oo
nfX;o`0000;ooo]Z5?l00004oookJPGo00000ooonfX3o`0000Gooo]Z0ol00002oookJP[o000000Co
oo]Zo`000?l0003o00000_oonfX5o`0000Gooo]Z2?l00004oookJPGo00000_oonfX3o`0000?ooo]Z
2Ol00003oookJP[o00006ooonfX005Gooo]Z1Ol00002oookJPSo00000_oonfX5o`0000Gooo]Z1Ol0
0006oookJQ?o000000?ooo]Zo`000?l000003?l00003oookJPGo00000ooonfX4o`0000;ooo]Z0ol0
0003oookJR_o00000_oonfX:o`000004oookJ_l0003o0000o`0000Kooo]Z3?l000001?oonf[o0000
o`000?l00002oookJPOo000000?ooo]Zo`000?l000002_l00002oookJQ7o00000_oonfX9o`0000;o
oo]Z3?l00005oookJPKo00000ooonfX>o`000003oookJ_l0003o0000013o00001_oonfX5o`0000;o
oo]Z2_l00003oookJPGo00001OoonfX6o`0000;ooo]Z1Ol000000ooonf[o0000o`000003o`0000;o
oo]Z2Ol000000ooonf[o0000o`000007o`0000Gooo]Z2ol00002oookJPKo00001ooonfX5o`000003
oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o00001ooonfX;o`000003oookJ_l0003o0000
00;o00000ooonfX?o`0000?ooo]Z2_l0000KoookJP00EOoonfX5o`0000cooo]Z3ol00006oookJQ?o
000000?ooo]Zo`000?l000003?l00003oookJPGo00000ooonfX5o`000004oookJ_l0003o0000o`00
00?ooo]Z4_l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000[o000000Cooo]Zo`00
0?l0003o00000ooonfX:o`000004oookJ_l0003o0000o`0000Cooo]Z1Ol000000ooonf[o0000o`00
0008o`0000Kooo]Z2Ol000000ooonf[o0000o`000006o`0000;ooo]Z0ol00002oookJPko000000?o
oo]Zo`000?l000000_l000001?oonf[o0000o`000?l00002oookJPco00001OoonfX8o`000003oook
J_l0003o000000co000000?ooo]Zo`000?l000000_l00004oookJPco00001?oonfX5o`0000;ooo]Z
2?l00005oookJPGo00001OoonfX6o`0000Cooo]Z0ol000000ooonf[o0000o`000003o`0000;ooo]Z
2Ol000000ooonf[o0000o`000007o`000003oookJ_l0003o000000ko000000?ooo]Zo`000?l00000
1?l00003oookJP?o000000?ooo]Zo`000?l000002Ol00002oookJP?o00001_oonfX6o`000004oook
J_l0003o0000o`0000_ooo]Z3?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000?o
00007?oonfX005Gooo]Z1?l00004oookJPOo00001?oonfX8o`000003oookJ_l0003o000000Co0000
1_oonfX<o`0000;ooo]Z4_l00003oookJPGo00000ooonfX5o`0000Oooo]Z2ol000000ooonf[o0000
o`000004o`000003oookJ_l0003o000000Co00000_oonfX;o`0000;ooo]Z3_l00006oookJQSo0000
1_oonfX3o`0000;ooo]Z2?l00002oookJP_o00000_oonfX6o`000004oookJ_l0003o0000o`0000;o
oo]Z0ol00004oookJP[o00001OoonfX<o`0000;ooo]Z4Ol00003oookJP[o000000?ooo]Zo`000?l0
00001?l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000000ol00003oook
JP?o00002OoonfX3o`0000Gooo]Z0ol00003oookJP?o00001_oonfX5o`000004oookJ_l0003o0000
o`0000;ooo]Z1?l000000ooonf[o0000o`00000>o`000003oookJ_l0003o000000Ko000000Cooo]Z
o`000?l0003o00000_oonfX:o`0000;ooo]Z0ol00006oookJP[o00001_oonfX<o`000003oookJ_l0
003o000000;o000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000003o`0001cooo]Z001E
oookJPCo00001?oonfX7o`0000Kooo]Z1_l00004oookJPCo000000?ooo]Zo`000?l000001Ol00002
oookJPOo00000_oonfX5o`000005oookJ_l0003o0000o`000?oonfX01ol00004oookJPGo00001?oo
nfX5o`0000Sooo]Z4?l00003oookJPSo00000_oonfX7o`000003oookJ_l0003o000000_o00000ooo
nfX3o`0000;ooo]Z2Ol00004oookJP_o00001OoonfX4o`0000;ooo]Z1_l00007oookJPGo00000ooo
nfX;o`000003oookJ_l0003o000000Go00000ooonfX6o`0000Cooo]Z0ol000001?oonf[o0000o`00
0?l00002oookJP[o00000_oonfXRo`000005oookJ_l0003o0000o`000?oonfX00ol000000ooonf[o
0000o`000007o`0000Wooo]Z1?l00006oookJP?o00000ooonfX<o`0000?ooo]Z0ol00002oookJP?o
00000_oonfX8o`0000Gooo]Z0ol00002oookJPOo000000Gooo]Zo`000?l0003o0000oookJP0;o`00
00;ooo]Z0ol000001?oonf[o0000o`000?l00002oookJP?o00000_oonfX5o`0000Kooo]Z2ol00002
oookJP?o00000_oonfX3o`000003oookJ_l0003o000000Go00007?oonfX005Gooo]Z1?l00002oook
JP[o00001ooonfX4o`0000?ooo]Z3_l000001Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Z
o`000?l000001?l000001Ooonf[o0000o`000?l0003ooo]Z00Oo000000?ooo]Zo`000?l000001?l0
0002oookJP?o000000?ooo]Zo`000?l000000ol00008oookJPCo000000?ooo]Zo`000?l000002Ol0
0005oookJPKo00000ooonfX6o`000003oookJ_l0003o000000_o00000ooonfXBo`0000;ooo]Z2Ol0
00001Ooonf[o0000o`000?l0003ooo]Z00Co00001OoonfX3o`0000Oooo]Z1Ol00003oookJP_o0000
00Gooo]Zo`000?l0003o0000oookJP03o`0000;ooo]Z2Ol00002oookJP?o000000?ooo]Zo`000?l0
00002Ol000001?oonf[o0000o`000?l00002oookJQOo00000_oonfX9o`000003oookJ_l0003o0000
00;o00000_oonfX3o`000003oookJ_l0003o000000Ko00001OoonfX9o`0000Cooo]Z0ol00003oook
JPgo00000_oonfX7o`0000Gooo]Z2?l00003oookJPco00001OoonfX>o`0000;ooo]Z1?l00002oook
JP?o00000_oonfX5o`0000Kooo]Z2ol00005oookJP?o00000_oonfX8o`0001cooo]Z001EoookJPCo
00000_oonfX6o`000005oookJ_l0003o0000o`000?oonfX00ol00003oookJPGo00000_oonfXFo`00
0003oookJ_l0003o000000Co00000_oonfX6o`000005oookJ_l0003o0000o`000?oonfX02ol00000
0ooonf[o0000o`000003o`000003oookJ_l0003o000000Co00000_oonfXJo`0000?ooo]Z1_l00000
0ooonf[o0000o`00000;o`0000?ooo]Z7?l00002oookJPOo00001ooonfX3o`0000Oooo]Z0ol00000
0ooonf[o0000o`000004o`0000Cooo]Z2?l000001?oonf[o0000o`000?l00002oookJPWo00000_oo
nfX3o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000_l00002oookJP?o00000_oo
nfXRo`0000;ooo]Z0ol00002oookJPGo00000_oonfX5o`0000Gooo]Z2Ol00002oookJPGo00000ooo
nfXFo`000005oookJ_l0003o0000o`000?oonfX02?l000000ooonf[o0000o`000005o`000003oook
J_l0003o000000Co00001OoonfX>o`000003oookJ_l0003o000000Ko00001_oonfX3o`0000Oooo]Z
0ol000000ooonf[o0000o`000007o`0000;ooo]Z0ol00002oookJPSo00007?oonfX005Gooo]Z1?l0
0002oookJPKo000000Gooo]Zo`000?l0003o0000oookJP06o`000003oookJ_l0003o000000;o0000
0_oonfXMo`0000;ooo]Z2Ol00002oookJP?o00000_oonfXMo`0000;ooo]Z3ol00007oookJP?o0000
0_oonfX<o`000003oookJ_l0003o000001Oo00001ooonfX8o`0000Kooo]Z0ol000001?oonf[o0000
o`000?l00003oookJPSo00000ooonfX9o`0000Gooo]Z4Ol000000ooonf[o0000o`000003o`000003
oookJ_l0003o000000Co00000_oonfX3o`0000?ooo]Z2ol000000ooonf[o0000o`00000;o`0000So
oo]Z2_l00004oookJP?o00001OoonfX:o`000004oookJ_l0003o0000o`0000Gooo]Z1?l00002oook
JPWo00000ooonfX4o`000005oookJ_l0003o0000o`000?oonfX02?l000000ooonf[o0000o`000005
o`000003oookJ_l0003o000000Co00002OoonfX:o`000003oookJ_l0003o000000Ko00002?oonfX3
o`0000Gooo]Z2Ol000001?oonf[o0000o`000?l00002oookJP?o00000_oonfX6o`0001kooo]Z001E
oookJPCo00000_oonfX:o`000003oookJ_l0003o000000Wo00001?oonfX3o`000003oookJ_l0003o
0000013o00000_oonfX3o`0000;ooo]Z1?l00002oookJPOo00000ooonfXMo`0000;ooo]Z3ol00007
oookJP?o00000_oonfX;o`0000;ooo]Z1Ol000000ooonf[o0000o`000002o`0000?ooo]Z3?l00000
0ooonf[o0000o`000002o`0000;ooo]Z3?l00002oookJP?o000000?ooo]Zo`000?l000003?l00003
oookJP_o00000_oonfX5o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000001?l00007
oookJP_o00001?oonfX6o`000003oookJ_l0003o000000Go00000ooonfX7o`000003oookJ_l0003o
000000Go00000_oonfX:o`0000Gooo]Z0ol00005oookJP?o000000?ooo]Zo`000?l000001Ol00000
0ooonf[o0000o`000006o`0000;ooo]Z2ol00006oookJP?o000000?ooo]Zo`000?l000000ol00002
oookJPGo00001_oonfX5o`0000;ooo]Z0ol00006oookJPOo00000_oonfX8o`0000Sooo]Z1?l00006
oookJPOo000000Cooo]Zo`000?l0003o00001?oonfX6o`000003oookJ_l0003o000000?o00006ooo
nfX005Gooo]Z1Ol000000ooonf[o0000o`000008o`0000Cooo]Z1ol000001Ooonf[o0000o`000?l0
003ooo]Z00?o000000?ooo]Zo`000?l000004?l00002oookJPCo000000?ooo]Zo`000?l000000_l0
0002oookJPOo00001?oonfX=o`000003oookJ_l0003o000000co000000Cooo]Zo`000?l0003o0000
0ooonfX5o`0000oooo]Z2_l00005oookJPCo00000_oonfX4o`0000?ooo]Z2ol00002oookJPCo0000
0_oonfX?o`0000?ooo]Z3_l00002oookJQWo000000?ooo]Zo`000?l000001?l00006oookJPco0000
0_oonfX8o`000003oookJ_l0003o000000;o00002?oonfX5o`000003oookJ_l0003o0000017o0000
1OoonfX;o`000003oookJ_l0003o000000?o00000ooonfX7o`0000?ooo]Z5?l000000ooonf[o0000
o`000008o`0000;ooo]Z0ol00003oookJPGo00000_oonfX5o`0000Cooo]Z1ol00004oookJPKo0000
1?oonfX3o`000003oookJ_l0003o000000Go00000ooonfX3o`000004oookJ_l0003o0000o`0000Ko
oo]Z2?l000000ooonf[o0000o`000003o`0001_ooo]Z001EoookJQ3o00000ooonfX<o`000004oook
J_l0003o0000o`0000Cooo]Z2ol00003oookJPOo00000_oonfX4o`000003oookJ_l0003o000000Go
00001?oonfX?o`000003oookJ_l0003o000000[o000000Cooo]Zo`000?l0003o00000ooonfX5o`00
00Wooo]Z0ol00003oookJPgo00000ooonfX3o`0000;ooo]Z1?l00005oookJPOo00001?oonfXHo`00
00?ooo]Z1ol000001?oonf[o0000o`000?l00002oookJQ7o000000?ooo]Zo`000?l000001Ol00002
oookJPCo00000ooonfX=o`0000?ooo]Z2_l000000ooonf[o0000o`000005o`0000Gooo]Z0ol00003
oookJQ?o00001OoonfX;o`0000?ooo]Z1Ol000000ooonf[o0000o`000005o`0000?ooo]Z5?l00000
0ooonf[o0000o`00000Fo`000003oookJ_l0003o000000?o00000_oonfX5o`000004oookJ_l0003o
0000o`0000Gooo]Z1Ol00004oookJP?o00000_oonfX9o`0000?ooo]Z1?l00006oookJPSo000000?o
oo]Zo`000?l000000ol0000KoookJP00EOoonfX;o`0000Oooo]Z4ol000000ooonf[o0000o`00000J
o`000004oookJ_l0003o0000o`0000Kooo]Z1Ol00003oookJPWo00000ooonfXFo`0000Gooo]Z0ol0
00000ooonf[o0000o`000007o`0000?ooo]Z3Ol000000ooonf[o0000o`000003o`0000;ooo]Z3?l0
0005oookJQGo00000ooonfX5o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000001_l0
0003oookJPgo00000_oonfX5o`0000?ooo]Z3?l00004oookJPko000000Cooo]Zo`000?l0003o0000
1OoonfXCo`0000Oooo]Z0ol00004oookJPSo00001?oonfX5o`000003oookJ_l0003o000000go0000
1OoonfX9o`0000?ooo]Z1_l000000ooonf[o0000o`00000Co`0000;ooo]Z0ol0000;oookJPGo0000
1?oonfX5o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001ol00003oookJP?o0000
0_oonfX3o`00027ooo]Z001EoookJPCo000000?ooo]Zo`000?l000001_l00005oookJQ?o000000?o
oo]Zo`000?l000008?l00004oookJP?o000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`00
0005o`000003oookJ_l0003o000000ko00001?oonfX4o`000003oookJ_l0003o000000Co00002?oo
nfXAo`0000;ooo]Z3?l00002oookJQSo00000ooonfX5o`000003oookJ_l0003o000000So00000_oo
nfX3o`0000;ooo]Z3Ol00003oookJPgo00000ooonfX5o`0000?ooo]Z0ol00002oookJPKo00000_oo
nfX5o`000004oookJ_l0003o0000o`0000Cooo]Z3?l000001?oonf[o0000o`000?l00007oookJPKo
000000Cooo]Zo`000?l0003o00000_oonfX3o`0000Cooo]Z1Ol000000ooonf[o0000o`000008o`00
00;ooo]Z0ol00004oookJPSo000000Cooo]Zo`000?l0003o00000ooonfX9o`000003oookJ_l0003o
000000co00001?oonfX3o`0000;ooo]Z0ol00002oookJQ;o000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`000007o`0000Sooo]Z2Ol0000KoookJP00EOoonfX?o`0000?ooo]Z4ol000000ooo
nf[o0000o`000004o`000003oookJ_l0003o000001co000000?ooo]Zo`000?l000003Ol00003oook
JPCo00002?oonfX=o`0000?ooo]Z1?l00002oookJPGo00001OoonfX6o`000003oookJ_l0003o0000
00Wo00000_oonfX9o`000003oookJ_l0003o000000;o00000_oonfXFo`0000Cooo]Z1Ol00002oook
JPoo000000?ooo]Zo`000?l000003?l00003oookJPWo000000Cooo]Zo`000?l0003o00000ooonfX5
o`0000Cooo]Z0ol00002oookJPGo00000_oonfX3o`0000?ooo]Z0ol00004oookJPco00001_oonfX3
o`0000;ooo]Z1_l000001?oonf[o0000o`000?l00002oookJPGo00000_oonfXEo`0000Cooo]Z1?l0
00000ooonf[o0000o`000005o`0000?ooo]Z2?l00006oookJP[o00001?oonfX3o`0000;ooo]Z0ol0
0002oookJQ_o000000?ooo]Zo`000?l000001ol00006oookJP_o00006ooonfX005Gooo]Z3ol00005
oookJPgo00001OoonfX=o`0000;ooo]Z2?l000000ooonf[o0000o`00000;o`0000;ooo]Z2Ol00002
oookJPGo000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l00004oookJP?o00000ooo
nfX7o`0000?ooo]Z0ol00004oookJPKo000000?ooo]Zo`000?l000000ol00003oookJR;o000000?o
oo]Zo`000?l000003ol00002oookJP[o000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`00
0007o`000003oookJ_l0003o000000;o00000ooonfX9o`000004oookJ_l0003o0000o`0000?ooo]Z
1Ol00004oookJP?o00000_oonfX4o`0000?ooo]Z0ol00003oookJPKo00001ooonfX7o`0000;ooo]Z
1_l00005oookJP?o00001ooonfX4o`0000;ooo]Z1_l00003oookJPWo000000Cooo]Zo`000?l0003o
00000ooonfX4o`0000;ooo]Z1_l00003oookJPWo00000_oonfX8o`0000;ooo]Z0ol00004oookJP?o
00000_oonfX3o`0000;ooo]Z7_l000000ooonf[o0000o`000003o`0000Cooo]Z3_l0000KoookJP00
EOoonfX?o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000002ol000000ooonf[o0000
o`00000;o`0000;ooo]Z2?l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Go0000
00?ooo]Zo`000?l000001_l00003oookJP[o000000?ooo]Zo`000?l000002Ol000001?oonf[o0000
o`000?l00002oookJP?o00000ooonfX5o`0000;ooo]Z1_l000000ooonf[o0000o`000003o`0000?o
oo]Z1?l00002oookJPco00000_oonfX6o`0000;ooo]Z1?l0000:oookJQKo000000?ooo]Zo`000?l0
00005?l000000ooonf[o0000o`000003o`0000?ooo]Z2?l00002oookJP?o00000_oonfX3o`0000;o
oo]Z0ol00002oookJP?o00000_oonfX7o`0000;ooo]Z3?l00005oookJPOo00000_oonfX6o`0000Go
oo]Z1Ol00005oookJPGo000000?ooo]Zo`000?l000004?l000000ooonf[o0000o`00000=o`0000Ko
oo]Z1Ol000001?oonf[o0000o`000?l00002oookJPCo000000Cooo]Zo`000?l0003o00002OoonfX3
o`0000;ooo]Z1Ol00004oookJPGo00002?oonfX4o`000003oookJ_l0003o000000co00001?oonfX>
o`0001_ooo]Z001EoookJPgo00000ooonfXEo`000003oookJ_l0003o000000_o00000_oonfX?o`00
00;ooo]Z2_l00008oookJP[o000000?ooo]Zo`000?l000003Ol00002oookJPGo00000ooonfX3o`00
00;ooo]Z1_l000001?oonf[o0000o`000?l00005oookJR;o00002?oonfX?o`000003oookJ_l0003o
000000Co000000?ooo]Zo`000?l000002?l00003oookJPCo00000_oonfX3o`000003oookJ_l0003o
000001?o000000?ooo]Zo`000?l000000_l00002oookJP?o00000_oonfX3o`0000?ooo]Z1_l00002
oookJPoo00000_oonfX7o`0000;ooo]Z1Ol00006oookJPGo00001OoonfX5o`0000?ooo]Z7_l00006
oookJPGo00000_oonfX4o`0000;ooo]Z1?l000000ooonf[o0000o`000005o`0000;ooo]Z3_l00003
oookJPKo00001_oonfX4o`000003oookJ_l0003o000000co000000Gooo]Zo`000?l0003o0000oook
JP07o`0000;ooo]Z1Ol0000KoookJP00EOoonfX=o`0000?ooo]Z5Ol000000ooonf[o0000o`00000:
o`0000?ooo]Z3?l00005oookJPWo00001?oonfX8o`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?l000007?l00002oookJPGo00000_oonfX3o`0000Cooo]Z2_l00002oookJP?o00000ooonfX;
o`000003oookJ_l0003o000000Wo00000ooonfX<o`0000Gooo]Z0ol00003oookJPWo00000ooonfX9
o`000003oookJ_l0003o000000Oo00000_oonfX7o`0000Cooo]Z1?l00002oookJPSo00001_oonfX3
o`0000;ooo]Z1_l00002oookJPOo00000_oonfX6o`0000?ooo]Z1ol00004oookJPKo000000?ooo]Z
o`000?l000008ol000001?oonf[o0000o`000?l00002oookJP?o000000Cooo]Zo`000?l0003o0000
1?oonfX4o`0000;ooo]Z0ol00004oookJQGo00000ooonfX8o`0000Cooo]Z5ol00003oookJPOo0000
00?ooo]Zo`000?l000000_l0000KoookJP00EOoonfX=o`0000;ooo]Z5ol000001Ooonf[o0000o`00
0?l0003ooo]Z00Oo00000ooonfX3o`000003oookJ_l0003o000000Go00000ooonfX5o`000003oook
J_l0003o000000Co00001?oonfX8o`000003oookJ_l0003o000000co00000ooonfX?o`000005oook
J_l0003o0000o`000?oonfX02ol00002oookJPSo00001OoonfX3o`0000?ooo]Z0ol000001Ooonf[o
0000o`000?l0003ooo]Z00?o00000ooonfXDo`000004oookJ_l0003o0000o`0000;ooo]Z4_l00006
oookJPKo000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000009o`000004oookJ_l0003o
0000o`0000Kooo]Z2?l00003oookJPSo00001?oonfXAo`0000;ooo]Z6?l00002oookJQ3o00000_oo
nfX3o`000003oookJ_l0003o000000;o00001ooonfX5o`000003oookJ_l0003o000000So000000?o
oo]Zo`000?l000005_l00003oookJP?o000000?ooo]Zo`000?l000002_l00002oookJP?o000000?o
oo]Zo`000?l000004Ol00002oookJPco00007?oonfX005Gooo]Z6Ol00002oookJQ?o000000?ooo]Z
o`000?l000001ol000000ooonf[o0000o`000003o`0000;ooo]Z2?l00002oookJP?o00001_oonfX7
o`0000;ooo]Z8?l000001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000001?l0
0002oookJPOo00001_oonfX5o`000005oookJ_l0003o0000o`000?oonfX01ol00003oookJPoo0000
00Cooo]Zo`000?l0003o00000ooonfX3o`000005oookJ_l0003o0000o`000?oonfX01_l000000ooo
nf[o0000o`000005o`0000Gooo]Z1?l00004oookJPWo000000?ooo]Zo`000?l000000ol000000ooo
nf[o0000o`000007o`0000Kooo]Z0ol00002oookJPCo00000_oonfX:o`0000;ooo]Z1_l000000ooo
nf[o0000o`000008o`0000;ooo]Z5_l00004oookJP?o000000Gooo]Zo`000?l0003o0000oookJP08
o`0000;ooo]Z0ol000000ooonf[o0000o`000002o`0000Oooo]Z1Ol00002oookJPWo000000?ooo]Z
o`000?l000003ol00002oookJP?o00002OoonfX4o`0000?ooo]Z1Ol00002oookJP?o000000?ooo]Z
o`000?l000004Ol00002oookJPco00007?oonfX005Gooo]Z1Ol00006oookJPgo00001?oonfX5o`00
00;ooo]Z2ol00003oookJPOo000000?ooo]Zo`000?l000000ol00002oookJP_o00002?oonfX3o`00
00Wooo]Z2Ol000000ooonf[o0000o`000003o`000003oookJ_l0003o000000Co000000?ooo]Zo`00
0?l000001?l000001Ooonf[o0000o`000?l0003ooo]Z00_o00000_oonfX3o`000004oookJ_l0003o
0000o`0000Kooo]Z2Ol000000ooonf[o0000o`000004o`0000Cooo]Z1?l00002oookJPOo00002?oo
nfX?o`000003oookJ_l0003o000000go00001OoonfX4o`000003oookJ_l0003o000000;o000000Go
oo]Zo`000?l0003o0000oookJP0;o`0000Kooo]Z2Ol00003oookJPWo00000_oonfX5o`0000;ooo]Z
2_l00002oookJQ[o00001?oonfX7o`000005oookJ_l0003o0000o`000?oonfX01Ol000000ooonf[o
0000o`000005o`0000Cooo]Z0ol00004oookJQ_o00000_oonfX5o`0000Oooo]Z1?l00003oookJPGo
00002OoonfX8o`000003oookJ_l0003o000000Go00000_oonfX<o`0001cooo]Z001EoookJPGo0000
1_oonfX=o`0000Cooo]Z1?l00003oookJPWo00001OoonfX7o`000003oookJ_l0003o000000?o0000
0_oonfX;o`0000Sooo]Z0ol0000?oookJPco00001OoonfX6o`0000Gooo]Z2Ol000000ooonf[o0000
o`000004o`000005oookJ_l0003o0000o`000?oonfX00ol00002oookJPKo00001_oonfX4o`0000Go
oo]Z0ol00003oookJP?o00002ooonfXOo`000005oookJ_l0003o0000o`000?oonfX02?l00003oook
JPko00000ooonfX<o`0000?ooo]Z0ol00002oookJPCo000000?ooo]Zo`000?l000001?l00004oook
JPSo00001OoonfX?o`000003oookJ_l0003o000000Go00001?oonfX;o`000003oookJ_l0003o0000
00?o00001OoonfX3o`000003oookJ_l0003o000000;o00001_oonfX=o`0000Cooo]Z2ol000000ooo
nf[o0000o`000003o`0000Oooo]Z0ol00002oookJP_o00001OoonfX6o`000003oookJ_l0003o0000
00Go00001?oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z0ol0000LoookJP00EOoonfX7o`00
00Cooo]Z3Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o00000ooonfXEo`0000?ooo]Z0ol00002
oookJPOo000000?ooo]Zo`000?l000000_l00007oookJP?o00002_oonfX9o`0000?ooo]Z1Ol00003
oookJPSo00001?oonfX8o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000001Ol00002
oookJPSo00001?oonfX3o`0000Cooo]Z0ol00005oookJP?o00002ooonfX>o`000003oookJ_l0003o
000000ko000000?ooo]Zo`000?l000001ol00006oookJP_o000000Cooo]Zo`000?l0003o00000_oo
nfX9o`0000;ooo]Z0ol000000ooonf[o0000o`000006o`0000;ooo]Z1_l00004oookJPSo00001Ooo
nfX5o`0000;ooo]Z2?l000000ooonf[o0000o`000005o`0000;ooo]Z0ol000000ooonf[o0000o`00
0007o`000003oookJ_l0003o000000Co00001?oonfX8o`0000Kooo]Z1_l000000ooonf[o0000o`00
0004o`0000Cooo]Z2ol000000ooonf[o0000o`000003o`0000[ooo]Z1Ol00002oookJQ7o000000?o
oo]Zo`000?l000000ol00006oookJPco00007?oonfX005Gooo]Z1ol00004oookJPCo000000?ooo]Z
o`000?l000007ol00006oookJPOo00000_oonfX7o`0000;ooo]Z1_l00004oookJP_o000000?ooo]Z
o`000?l000001?l000001?oonf[o0000o`000?l00003oookJP_o00000_oonfX3o`000003oookJ_l0
003o000000Co00000_oonfX3o`000003oookJ_l0003o000000Go00000_oonfX8o`0000?ooo]Z1_l0
00000ooonf[o0000o`000005o`0000?ooo]Z0ol00003oookJP?o00000_oonfX5o`0000Oooo]Z1?l0
00001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000006?l00006oookJPSo0000
1?oonfX3o`000003oookJ_l0003o000000Ko00000ooonfX5o`0000?ooo]Z1Ol00002oookJPKo0000
00?ooo]Zo`000?l000002_l00006oookJP?o00000_oonfX8o`000005oookJ_l0003o0000o`000?oo
nfX04Ol00003oookJPGo000000?ooo]Zo`000?l000002Ol0000?oookJPCo00000ooonfX<o`000003
oookJ_l0003o000000;o00001OoonfX3o`0000?ooo]Z1Ol00002oookJQ3o00000_oonfX5o`0000;o
oo]Z0ol000000ooonf[o0000o`00000:o`0001cooo]Z001EoookJPOo000000?ooo]Zo`000?l00000
1Ol00004oookJP?o00000_oonfXJo`0000Gooo]Z1_l00003oookJP?o000000Cooo]Zo`000?l0003o
00000_oonfX6o`0000;ooo]Z3Ol000000ooonf[o0000o`000004o`0000Oooo]Z2ol000001?oonf[o
0000o`000?l00002oookJPSo00000ooonfX9o`000003oookJ_l0003o000000So00000_oonfX5o`00
0003oookJ_l0003o000000Go00000ooonfX3o`0000?ooo]Z2_l00007oookJP?o00000_oonfX8o`00
00;ooo]Z2ol00003oookJP?o00000_oonfX5o`0000Sooo]Z1ol00003oookJPgo000000?ooo]Zo`00
0?l000001Ol00003oookJPKo00002?oonfX3o`0000?ooo]Z1_l00003oookJPSo000000?ooo]Zo`00
0?l000001Ol00007oookJP_o000000Cooo]Zo`000?l0003o00000_oonfX6o`000003oookJ_l0003o
000000Go000000Cooo]Zo`000?l0003o00002?oonfX3o`0000_ooo]Z3?l000001?oonf[o0000o`00
0?l00006oookJP?o00000ooonfX7o`0000?ooo]Z3ol000000ooonf[o0000o`000007o`0000;ooo]Z
2_l0000MoookJP00EOoonfX6o`0000;ooo]Z1ol00002oookJPGo000000?ooo]Zo`000?l000006Ol0
0004oookJPOo00001ooonfX3o`000003oookJ_l0003o000001_o000000Cooo]Zo`000?l0003o0000
1_oonfXFo`0000?ooo]Z2Ol000001?oonf[o0000o`000?l00002oookJPSo00001OoonfX7o`0000?o
oo]Z0ol00003oookJP_o00002_oonfX;o`0000;ooo]Z2_l00002oookJP?o00000ooonfX3o`0000Go
oo]Z0ol000000ooonf[o0000o`00000Bo`000003oookJ_l0003o000000So00000_oonfX3o`000004
oookJ_l0003o0000o`0000Sooo]Z1?l00002oookJPKo000000?ooo]Zo`000?l000002ol000000ooo
nf[o0000o`000002o`0000Kooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00Oo00000_oonfX6
o`000003oookJ_l0003o000000Co00001?oonfX8o`000004oookJ_l0003o0000o`0000Cooo]Z0ol0
00000ooonf[o0000o`000005o`000003oookJ_l0003o000000;o00001?oonfX3o`0000Kooo]Z0ol0
0003oookJP?o000000Cooo]Zo`000?l0003o00002_oonfXDo`0000;ooo]Z2_l0000KoookJP00EOoo
nfX7o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000001Ol000001?oonf[o0000o`00
0?l00002oookJPCo00000ooonfX@o`0000?ooo]Z1_l00008oookJP[o000000?ooo]Zo`000?l00000
5?l000001?oonf[o0000o`000?l00004oookJP?o00001?oonfX<o`000003oookJ_l0003o000000;o
00000ooonfX9o`000004oookJ_l0003o0000o`0000Cooo]Z1_l00006oookJP?o00001OoonfX4o`00
0004oookJ_l0003o0000o`0000;ooo]Z0ol00002oookJPGo00002?oonfX=o`0000;ooo]Z1?l00000
0ooonf[o0000o`000002o`0000Gooo]Z0ol00007oookJQCo000000Gooo]Zo`000?l0003o0000oook
JP08o`0000Cooo]Z0ol000001?oonf[o0000o`000?l00004oookJP?o00000_oonfX3o`0000;ooo]Z
3?l000000ooonf[o0000o`000005o`0000;ooo]Z1Ol00004oookJPGo00001?oonfX5o`0000Cooo]Z
2?l00002oookJPGo00000_oonfX<o`0000Cooo]Z0ol000000ooonf[o0000o`000005o`000003oook
J_l0003o000000;o00000ooonfX3o`0000Kooo]Z0ol00004oookJP?o000000?ooo]Zo`000?l00000
1Ol00006oookJR3o00006ooonfX005Gooo]Z1ol00003oookJPCo000000?ooo]Zo`000?l000002Ol0
0002oookJP?o00000ooonfX6o`000003oookJ_l0003o000000So00000ooonfX6o`0000Sooo]Z2_l0
00001Ooonf[o0000o`000?l0003ooo]Z01Ko000000?ooo]Zo`000?l000001ol000000ooonf[o0000
o`00000;o`0000?ooo]Z1Ol000001Ooonf[o0000o`000?l0003ooo]Z00?o000000Cooo]Zo`000?l0
003o00000_oonfX3o`0000;ooo]Z0ol00002oookJP?o00002OoonfX8o`0000Oooo]Z1Ol00007oook
JPCo00000ooonfX8o`000003oookJ_l0003o000000Wo00000ooonfX3o`0000?ooo]Z0ol000000ooo
nf[o0000o`000006o`000003oookJ_l0003o000000?o00000_oonfX4o`000005oookJ_l0003o0000
o`000?oonfX01_l00005oookJPCo00000_oonfX3o`0000;ooo]Z2ol00005oookJPOo000000?ooo]Z
o`000?l000001Ol00002oookJPGo00000_oonfX9o`0000?ooo]Z1?l00004oookJPSo00000_oonfX5
o`0000;ooo]Z2_l00006oookJP?o000000?ooo]Zo`000?l000000ol00003oookJP?o00001?oonfX4
o`0000Gooo]Z2_l00002oookJPKo00000_oonfX3o`000003oookJ_l0003o000001ko00006ooonfX0
05Gooo]Z2?l000001?oonf[o0000o`000?l00003oookJPSo000000?ooo]Zo`000?l000001Ol00003
oookJPco000000?ooo]Zo`000?l000001Ol00003oookJP?o000000Cooo]Zo`000?l0003o00001Ooo
nfX3o`000003oookJ_l0003o000000?o00001OoonfX6o`0000;ooo]Z2ol00002oookJP_o000000Go
oo]Zo`000?l0003o0000oookJP09o`0000;ooo]Z1_l00005oookJP?o00001_oonfX3o`0000Oooo]Z
1?l00008oookJPSo00000ooonfX4o`000003oookJ_l0003o000000Co00001OoonfX3o`0000Cooo]Z
2?l00005oookJPOo00000ooonfX9o`0000?ooo]Z0ol00004oookJPCo00000ooonfX6o`0000Kooo]Z
0ol000001Ooonf[o0000o`000?l0003ooo]Z00[o000000?ooo]Zo`000?l000002Ol00005oookJPOo
000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000So
00001?oonfX3o`0000;ooo]Z4Ol000000ooonf[o0000o`000009o`0000Gooo]Z2Ol000000ooonf[o
0000o`000004o`0000Cooo]Z2?l000000ooonf[o0000o`000007o`0000?ooo]Z2ol00003oookJPko
00000ooonfX=o`0001_ooo]Z001EoookJPco00001?oonfX7o`000003oookJ_l0003o000000Go0000
0ooonfX<o`000003oookJ_l0003o000000_o000000Cooo]Zo`000?l0003o00000_oonfX6o`0000;o
oo]Z1?l00005oookJPOo000000?ooo]Zo`000?l000000ol00002oookJPCo00000_oonfX?o`000003
oookJ_l0003o000000Oo00000_oonfX6o`0000Kooo]Z0ol00005oookJP?o00000ooonfX3o`000003
oookJ_l0003o000000?o000000Cooo]Zo`000?l0003o00000_oonfX8o`0000Cooo]Z1Ol000000ooo
nf[o0000o`000003o`0000Cooo]Z1?l00004oookJPco000000Gooo]Zo`000?l0003o0000oookJP05
o`0000?ooo]Z3ol00002oookJP?o000000?ooo]Zo`000?l000001ol00006oookJP?o000000?ooo]Z
o`000?l000003?l000000ooonf[o0000o`000009o`0000Cooo]Z1ol00002oookJPSo00000ooonfX>
o`0000;ooo]Z1Ol00002oookJPKo00001?oonfX6o`0000;ooo]Z3Ol00002oookJPOo00001?oonfXL
o`0000Cooo]Z5_l000001Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX;o`0001_ooo]Z001E
oookJPgo00000ooonfX4o`0000Cooo]Z2Ol00002oookJPOo00001_oonfX9o`0000Cooo]Z2?l00005
oookJPCo00001?oonfX>o`0000;ooo]Z3?l000000ooonf[o0000o`000004o`0000;ooo]Z1_l00000
1?oonf[o0000o`000?l00002oookJPGo00001OoonfXCo`0000;ooo]Z2?l000000ooonf[o0000o`00
0007o`0000Cooo]Z2ol00004oookJP?o00002OoonfX8o`000003oookJ_l0003o000000Wo000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`000006o`0000?ooo]Z1_l00003oookJPKo00001ooo
nfX>o`0000?ooo]Z0ol00002oookJP?o00001OoonfX3o`0000;ooo]Z3?l00002oookJPoo00000_oo
nfX5o`0000;ooo]Z1_l00004oookJPKo00000_oonfX=o`0000;ooo]Z2?l00003oookJP_o000000?o
oo]Zo`000?l000003_l000000ooonf[o0000o`00000Yo`0001kooo]Z001EoookJPKo000000?ooo]Z
o`000?l000001?l00003oookJP?o00000ooonfX;o`0000;ooo]Z2_l00003oookJPCo000000?ooo]Z
o`000?l000000_l00005oookJPOo00001OoonfXGo`0000Cooo]Z3?l000001?oonf[o0000o`000?l0
0002oookJPOo00000ooonfX5o`0000Oooo]Z4ol00003oookJPOo000000?ooo]Zo`000?l000001Ol0
0007oookJP[o00001?oonfXVo`0000;ooo]Z2_l000000ooonf[o0000o`000004o`0000;ooo]Z2Ol0
0005oookJPco00000_oonfX<o`0000Cooo]Z0ol00002oookJP[o00000ooonfX7o`000003oookJ_l0
003o0000013o00000_oonfX3o`0000Cooo]Z5Ol00002oookJP_o00000_oonfX9o`0000Gooo]Z3?l0
00000ooonf[o0000o`00000To`000003oookJ_l0003o000000Go00006ooonfX005Gooo]Z3Ol00009
oookJP?o000000?ooo]Zo`000?l000001Ol00002oookJP?o00001?oonfX?o`0000Gooo]Z1Ol00007
oookJP_o000000?ooo]Zo`000?l000002Ol00004oookJPco00001?oonfX9o`000003oookJ_l0003o
000000Go00001ooonfX3o`000003oookJ_l0003o000000go00000ooonfX7o`000003oookJ_l0003o
000000;o00001OoonfX3o`0000?ooo]Z6Ol00003oookJQOo00000_oonfX:o`000003oookJ_l0003o
000000oo00001OoonfX5o`000003oookJ_l0003o000000Co00000_oonfX3o`0000;ooo]Z1ol00002
oookJPKo000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`000004o`000003oookJ_l0003o
000000;o000000?ooo]Zo`000?l000002Ol00004oookJP?o00000ooonfX9o`0000?ooo]Z1Ol00000
0ooonf[o0000o`000008o`0000Cooo]Z1Ol00002oookJQ7o000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`000006o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000004?l0000K
oookJP00EOoonfX>o`000004oookJ_l0003o0000o`0000Cooo]Z0ol000000ooonf[o0000o`000008
o`0000Kooo]Z3Ol00004oookJPOo00002?oonfX8o`0000Kooo]Z6Ol00004oookJP?o000000?ooo]Z
o`000?l000003Ol00005oookJPGo000000?ooo]Zo`000?l000006Ol00006oookJP?o00001OoonfXG
o`0000?ooo]Z2?l00003oookJP?o000000?ooo]Zo`000?l000000ol00005oookJP[o00001?oonfX8
o`0000?ooo]Z1?l00004oookJPGo000000?ooo]Zo`000?l000001Ol000001Ooonf[o0000o`000?l0
003ooo]Z013o000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`000004o`000003oookJ_l0
003o000000ko000000?ooo]Zo`000?l000004?l00005oookJP?o000000?ooo]Zo`000?l000002ol0
0002oookJQKo00000_oonfX?o`0000Oooo]Z1?l00002oookJPWo000000?ooo]Zo`000?l000001_l0
000KoookJP00EOoonfX>o`000003oookJ_l0003o000000Co000000Gooo]Zo`000?l0003o0000oook
JP03o`0000Cooo]Z1?l00007oookJPko000000?ooo]Zo`000?l000000ol00004oookJPOo000000Co
oo]Zo`000?l0003o00000ooonfX3o`000003oookJ_l0003o000001Co000000?ooo]Zo`000?l00000
1?l00002oookJP?o000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000006o`0000;ooo]Z
4_l000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Co00000_oonfX4o`000004oook
J_l0003o0000o`0000?ooo]Z2?l000000ooonf[o0000o`000008o`0000;ooo]Z1?l00003oookJPWo
00000_oonfX3o`000003oookJ_l0003o000000;o00001_oonfX9o`0000Cooo]Z2_l00003oookJP?o
00001OoonfX4o`000003oookJ_l0003o000000Go00001OoonfX5o`0000?ooo]Z2?l000000ooonf[o
0000o`00000=o`0000;ooo]Z1Ol00002oookJP?o00000_oonfX4o`000003oookJ_l0003o000000Ko
00000ooonfX?o`0000Sooo]Z0ol00003oookJPKo00000_oonfX3o`000003oookJ_l0003o000001Go
00000_oonfX<o`0000Sooo]Z1ol00004oookJP[o000000Cooo]Zo`000?l0003o00007?oonfX005Go
oo]Z1?l00005oookJPGo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000002o`0000Oo
oo]Z1?l00007oookJPSo00000ooonfX3o`000003oookJ_l0003o000000Go00000_oonfX;o`0000?o
oo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z01;o000000?ooo]Zo`000?l000001?l00004oook
JPWo00000ooonfXSo`0000?ooo]Z1?l00002oookJPCo000000?ooo]Zo`000?l000003?l00003oook
JPgo00001?oonfX3o`0000?ooo]Z0ol00002oookJP[o00001?oonfX3o`0000?ooo]Z0ol000000ooo
nf[o0000o`000007o`000004oookJ_l0003o0000o`0000?ooo]Z1Ol00002oookJPgo00000_oonfX8
o`0000?ooo]Z1ol00002oookJP_o000000Cooo]Zo`000?l0003o00000_oonfX5o`0000;ooo]Z4Ol0
0002oookJPoo00002?oonfX5o`0000?ooo]Z0ol00005oookJP?o000000?ooo]Zo`000?l000001ol0
00000ooonf[o0000o`000004o`000003oookJ_l0003o000000Co00000_oonfX;o`0000Oooo]Z2Ol0
0005oookJPOo00000ooonfX3o`0001cooo]Z001EoookJPgo000000Gooo]Zo`000?l0003o0000oook
JP03o`0000;ooo]Z0ol00002oookJPWo00001ooonfX5o`000005oookJ_l0003o0000o`000?oonfX0
1?l000000ooonf[o0000o`00000Co`000003oookJ_l0003o000000;o000000Gooo]Zo`000?l0003o
0000oookJP0;o`000003oookJ_l0003o000000Co00000_oonfX5o`0000Cooo]Z1_l00002oookJP?o
000000?ooo]Zo`000?l000003ol000000ooonf[o0000o`000003o`0000;ooo]Z1Ol00002oookJP?o
00000ooonfX3o`0000?ooo]Z1?l000000ooonf[o0000o`00000:o`000005oookJ_l0003o0000o`00
0?oonfX02ol0000<oookJP?o00000_oonfX:o`0000Cooo]Z1?l00005oookJQ3o000000?ooo]Zo`00
0?l000000ol00002oookJP_o00001?oonfX8o`0000Cooo]Z1Ol00003oookJP_o000000?ooo]Zo`00
0?l000000_l00003oookJP?o00000_oonfX?o`0000;ooo]Z1Ol00002oookJPKo00002OoonfX8o`00
0003oookJ_l0003o000000Co00002?oonfX@o`0000Wooo]Z0ol000000ooonf[o0000o`000004o`00
00;ooo]Z0ol000000ooonf[o0000o`00000<o`0000;ooo]Z1ol00003oookJP?o00007?oonfX005Go
oo]Z2Ol000000ooonf[o0000o`000005o`0000Kooo]Z1?l000000ooonf[o0000o`000009o`0000;o
oo]Z2?l000001Ooonf[o0000o`000?l0003ooo]Z00?o00000_oonfX9o`0000Cooo]Z2?l000001?oo
nf[o0000o`000?l00006oookJPGo00000_oonfX7o`0000?ooo]Z1_l000000ooonf[o0000o`000008
o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000003ol000000ooonf[o0000o`000003
o`000003oookJ_l0003o000000Wo00000ooonfX6o`000004oookJ_l0003o0000o`0000?ooo]Z1_l0
00001Ooonf[o0000o`000?l0003ooo]Z00Co00000ooonfX;o`0000?ooo]Z2Ol00003oookJP_o0000
0_oonfX4o`0000;ooo]Z1ol00003oookJPWo000000?ooo]Zo`000?l000000ol00002oookJP_o0000
1?oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z1Ol00004oookJP[o00000_oonfX:o`0000?o
oo]Z3_l00002oookJPGo000000?ooo]Zo`000?l000001?l00007oookJP_o000000?ooo]Zo`000?l0
00001?l00008oookJPgo00001OoonfX3o`0000Sooo]Z2ol000000ooonf[o0000o`00000<o`0000?o
oo]Z0ol00006oookJP?o00007?oonfX005Gooo]Z2Ol000000ooonf[o0000o`000008o`0000;ooo]Z
1Ol000000ooonf[o0000o`000009o`0000;ooo]Z4?l00002oookJPWo00001?oonfX4o`000003oook
J_l0003o000000Go00001?oonfX7o`0000;ooo]Z1ol00003oookJPKo000000?ooo]Zo`000?l00000
5ol00003oookJQSo00000_oonfX7o`000003oookJ_l0003o000000So00000_oonfX3o`0000;ooo]Z
1?l00005oookJPWo00000_oonfXHo`0000?ooo]Z2ol00003oookJPko00001?oonfX8o`0000Kooo]Z
1Ol00002oookJPCo000000?ooo]Zo`000?l000000ol00004oookJP[o000000?ooo]Zo`000?l00000
2Ol00003oookJPco00001?oonfX4o`0000;ooo]Z1_l00007oookJPKo000000?ooo]Zo`000?l00000
2Ol00008oookJPgo00001OoonfX5o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000
1Ol000000ooonf[o0000o`000004o`000003oookJ_l0003o000000Go00000ooonfX3o`0000Kooo]Z
0ol0000LoookJP00EOoonfX7o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000001Ol0
00000ooonf[o0000o`000008o`0000;ooo]Z3Ol000001?oonf[o0000o`000?l00002oookJPWo0000
00?ooo]Zo`000?l000001?l00004oookJP?o00001OoonfX7o`0000?ooo]Z2?l000000ooonf[o0000
o`000003o`0000;ooo]Z6Ol00009oookJQ;o00000_oonfXBo`0000;ooo]Z0ol000000ooonf[o0000
o`000003o`0000Gooo]Z2Ol00002oookJQCo000000Cooo]Zo`000?l0003o00000_oonfX<o`0000?o
oo]Z1Ol000000ooonf[o0000o`000006o`0000Cooo]Z2?l00006oookJPGo00000_oonfX8o`0000So
oo]Z4Ol00006oookJP?o000000?ooo]Zo`000?l000002_l000001?oonf[o0000o`000?l00002oook
JP?o00001_oonfX3o`000004oookJ_l0003o0000o`0000Oooo]Z2Ol00006oookJPgo000000Gooo]Z
o`000?l0003o0000oookJP06o`000003oookJ_l0003o000000?o00001?oonfX4o`0000;ooo]Z2?l0
0002oookJPSo000000Cooo]Zo`000?l0003o00009OoonfX0017ooo]Z1Ol007l4oookJP?o001o0ooo
nfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`Oooo]Z0ol007l8oookJPOo000000?o
oo]Zo`000?l000001_l000000ooonf[o0000o`000009o`000003oookJ_l0003o000000So00000_oo
nfX3o`0000Gooo]Z1Ol000000ooonf[o0000o`00000@o`0000Gooo]Z1Ol00002oookJPWo00001?oo
nfX8o`0000?ooo]Z1Ol000000ooonf[o0000o`00000Ho`0000Gooo]Z1Ol00003oookJP?o00001_oo
nfX3o`0000;ooo]Z0ol00002oookJPCo00000_oonfX7o`0000;ooo]Z0ol000001Ooonf[o0000o`00
0?l0003ooo]Z00?o00000ooonfX9o`0000;ooo]Z3ol00002oookJPGo000000?ooo]Zo`000?l00000
2Ol000000ooonf[o0000o`000007o`0000Cooo]Z2?l00003oookJPSo00001_oonfX3o`0000Cooo]Z
2ol00002oookJPWo000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`000007o`000003oook
J_l0003o000000_o00001_oonfX6o`0000;ooo]Z0ol00006oookJPCo000000?ooo]Zo`000?l00000
1ol00006oookJQ7o000000?ooo]Zo`000?l000002_l00004oookJPCo00000_oonfX;o`000003oook
J_l0003o000000Co0000:OoonfX0013ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol0
07l3oookJPOo001o0ooonfX7o`00O`Kooo]Z0ol007l8oookJPOo000000?ooo]Zo`000?l000001_l0
00000ooonf[o0000o`000009o`000003oookJ_l0003o000000Wo000000Gooo]Zo`000?l0003o0000
oookJP03o`0000Gooo]Z5?l00005oookJP?o00001?oonfX9o`0000Cooo]Z2?l00003oookJPGo0000
00?ooo]Zo`000?l000001?l000000ooonf[o0000o`00000Do`0000;ooo]Z1?l00005oookJP[o0000
1?oonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001Ol00007oookJP?o0000
00Cooo]Zo`000?l0003o00000_oonfX:o`0000;ooo]Z1_l00002oookJP?o00001?oonfXDo`000003
oookJ_l0003o000000Go00000ooonfX3o`0000Cooo]Z3_l00004oookJP?o00002?oonfX9o`0000;o
oo]Z1Ol000000ooonf[o0000o`000005o`000004oookJ_l0003o0000o`0000?ooo]Z2Ol000000ooo
nf[o0000o`00000;o`0000Kooo]Z2ol00005oookJPGo00000ooonfX7o`0000Kooo]Z2Ol00002oook
JP_o00000_oonfX3o`0000gooo]Z1Ol00002oookJP_o00001OoonfX3o`00027ooo]Z000@oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l6oookJP?o001o2?oonfX7o`0000;ooo]Z1ol000000ooonf[o
0000o`000007o`0000;ooo]Z3ol00002oookJP?o000000?ooo]Zo`000?l000001Ol000000ooonf[o
0000o`00000@o`000003oookJ_l0003o000000Go00000_oonfX:o`0000Kooo]Z1Ol00003oookJPGo
00001?oonfX>o`0000Gooo]Z1ol00002oookJPOo00000_oonfX:o`0000Cooo]Z1Ol00003oookJPSo
00001_oonfX3o`0000;ooo]Z0ol00002oookJP_o00000ooonfX4o`0000Wooo]Z3_l000000ooonf[o
0000o`000003o`000003oookJ_l0003o000000Go00000ooonfX5o`0000;ooo]Z3ol00003oookJP?o
00000ooonfX>o`0000;ooo]Z3?l000000ooonf[o0000o`000002o`0000?ooo]Z3Ol000001Ooonf[o
0000o`000?l0003ooo]Z00So00000ooonfXEo`0000?ooo]Z1ol00004oookJPco000000?ooo]Zo`00
0?l000004_l00004oookJPCo000000?ooo]Zo`000?l000004?l00004oookJPOo00007_oonfX000oo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP?o001o2?oonfX7o`0000Oooo]Z0ol000000ooonf[o0000o`000006o`0000;ooo]Z1Ol0
00000ooonf[o0000o`000007o`0000;ooo]Z0ol000000ooonf[o0000o`00000>o`0000Oooo]Z3?l0
00000ooonf[o0000o`000008o`000005oookJ_l0003o0000o`000?oonfX01Ol00004oookJPSo0000
1?oonfX3o`000003oookJ_l0003o000000Ko00001?oonfX3o`000003oookJ_l0003o000000[o0000
0_oonfXCo`0000?ooo]Z2?l00006oookJPCo000000Cooo]Zo`000?l0003o00000_oonfX=o`000003
oookJ_l0003o000000Ko00000ooonfXBo`000005oookJ_l0003o0000o`000?oonfX00ol000000ooo
nf[o0000o`000009o`0000Cooo]Z3Ol000000ooonf[o0000o`00000Bo`0000;ooo]Z3_l000000ooo
nf[o0000o`000005o`000004oookJ_l0003o0000o`0000Cooo]Z1Ol000000ooonf[o0000o`00000:
o`0000Cooo]Z1ol00002oookJQGo00001?oonfX4o`0000;ooo]Z1_l000000ooonf[o0000o`00000D
o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000004?l000000ooonf[o0000o`000008
o`0001kooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1OoonfX3o`00O`Sooo]Z1_l00008oookJP?o00000_oonfX5o`0000Cooo]Z
1Ol000000ooonf[o0000o`000007o`0000Kooo]Z1_l000000ooonf[o0000o`00000:o`0000Cooo]Z
3?l000000ooonf[o0000o`000008o`000005oookJ_l0003o0000o`000?oonfX01?l00005oookJPSo
00001?oonfX3o`000003oookJ_l0003o000000Ko00001?oonfX3o`0000;ooo]Z1ol000001?oonf[o
0000o`000?l0000<oookJPCo00000_oonfX3o`0000?ooo]Z1_l00008oookJPCo00003OoonfX6o`00
0003oookJ_l0003o000000Ko00000ooonfX5o`0000;ooo]Z0ol000000ooonf[o0000o`000005o`00
00[ooo]Z2_l00005oookJPco000000?ooo]Zo`000?l000004_l00002oookJPco00000ooonfX7o`00
0004oookJ_l0003o0000o`0000Cooo]Z1Ol00004oookJP?o00000_oonfX4o`0000Gooo]Z1_l00002
oookJQGo00001?oonfX4o`0000;ooo]Z1_l000000ooonf[o0000o`000004o`0000?ooo]Z4ol00000
1Ooonf[o0000o`000?l0003ooo]Z00Ko00000_oonfX3o`0000Cooo]Z2_l0000NoookJP003ooonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Go
oo]Z0ol007l8oookJPCo00002_oonfX3o`0000Cooo]Z0ol0000PoookJP?o00001_oonfX3o`0000Ko
oo]Z0ol00002oookJPGo00001?oonfX7o`000005oookJ_l0003o0000o`000?oonfX00ol00006oook
JPSo00002?oonfX8o`0000Cooo]Z0ol00002oookJPGo00004_oonfX4o`0000[ooo]Z1?l00009oook
JP?o00003OoonfX6o`0000?ooo]Z1_l00003oookJP?o00001?oonfX3o`000005oookJ_l0003o0000
o`000?oonfX00ol0000:oookJPKo000000Cooo]Zo`000?l0003o00001OoonfX7o`0000;ooo]Z0ol0
00000ooonf[o0000o`000009o`0000;ooo]Z1?l00005oookJPWo00002_oonfX3o`00017ooo]Z0ol0
000;oookJPGo00002OoonfX?o`0000[ooo]Z0ol0000=oookJP?o00001ooonfX7o`0000[ooo]Z0ol0
0009oookJP?o00009OoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o2?oonfX4o`0003gooo]Z0ol0003ooookJRCo
oo]Z0ol0000ooookJP?o0000?ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o2?oonfX4o`000?oooo]Zj?oonfX0
00oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l5oookJP?o001o2?oonfX4o`000?oooo]Zj?oonfX000oooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJPKo001o2?oonfX4o`00
0?oooo]Zj?oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX6o`00O`Sooo]Z1?l0003ooookJ^So
oo]Z000@oookJPOo001o2?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`Gooo]Z
1?l007l8oookJPCo0000oooonf[XoookJP004OoonfX5o`00O`[ooo]Z1Ol007l5oookJPGo001o1Ooo
nfX5o`00O`Gooo]Z1Ol007l7oookJP?o001o2?oonfX4o`000?oooo]Zj?oonfX005Gooo]Z1?l0003o
oookJ^Sooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-3824.98, -1.24827*^-5, \
43.4766, 7.03381*^-8}},
  CellTags->"mmtag:23:noise__random"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:23:noise__random"]
}, Open  ]],

Cell[TextData[{
  "Now suppose there is a",
  StyleBox[" periodic bias ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " that tends to kick the displacement one direction more than the other:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(GrowListBiasedNoise[
        ValuesList_List, \ \[CapitalDelta]_\ , \ \[Alpha]_\ , \ \[Beta]_, 
        randomamp_, \ lambda_]\), " ", ":=", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(Minus1 = ValuesList[\([1, \(-1\)]\)]\), ",", 
              " ", \(Minus2\  = \ ValuesList[\([1, \(-2\)]\)]\), ",", " ", 
              RowBox[{"biasednoise", " ", "=", " ", 
                
                StyleBox[\(0.5*
                    randomamp*\((\ 
                      Cos[2\ \[Pi]\ Length[ValuesList[\([1]\)]]/lambda] + \ 
                        Random[Real, {\(-1\), 1}])\)\),
                  FontColor->RGBColor[1, 0, 0]]}]}], " ", "}"}], ",", 
          "\[IndentingNewLine]", \({\[IndentingNewLine]Append[
              ValuesList[\([1]\)], \[IndentingNewLine]2*Minus1\  - \ 
                Minus2\  + \ \[CapitalDelta]\ *\((\[Beta]*\((Minus2\  - \ 
                            Minus1)\)\  - \[Alpha]*\[CapitalDelta]*
                        Minus2)\)\  + biasednoise], \[IndentingNewLine]Append[
              ValuesList[\([2]\)], biasednoise]}\)}], "]"}]}]], "Input"],

Cell[BoxData[
    \(GrowListSpecificBiasedNoise[InitialList_List]\ \  := \ 
      GrowListBiasedNoise[InitialList,  .001, 2, 0, 10^\((\(-6\))\), 
        4500]\)], "Input"],

Cell["Generate the data set---this takes quite a while", "Text"],

Cell[BoxData[
    \(\(TheBiasedData\  = \ 
        Nest[GrowListSpecificBiasedNoise, {{1, 1}, {0, 0}}, 
          20000];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ListPlot[TheBiasedData[\([1]\)]]\), "\[IndentingNewLine]", 
    \(ListPlot[TheBiasedData[\([2]\)]]\)}], "Input",
  CellTags->"mmtag:23:noise__periodic_bias"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.291699 0.092161 [
[.26188 .2792 -22 -20 ]
[.26188 .2792 22 0 ]
[.49995 .2792 -27 -20 ]
[.49995 .2792 27 0 ]
[.73802 .2792 -27 -20 ]
[.73802 .2792 27 0 ]
[.9761 .2792 -27 -20 ]
[.9761 .2792 27 0 ]
[.01131 .01522 -26.9375 -10 ]
[.01131 .01522 0 10 ]
[.01131 .10738 -26.9375 -10 ]
[.01131 .10738 0 10 ]
[.01131 .19954 -26.9375 -10 ]
[.01131 .19954 0 10 ]
[.01131 .38386 -14 -10 ]
[.01131 .38386 0 10 ]
[.01131 .47602 -14 -10 ]
[.01131 .47602 0 10 ]
[.01131 .56818 -14 -10 ]
[.01131 .56818 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .2917 m
.26188 .29795 L
s
gsave
.26188 .2792 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .2917 m
.49995 .29795 L
s
gsave
.49995 .2792 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .2917 m
.73802 .29795 L
s
gsave
.73802 .2792 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .2917 m
.9761 .29795 L
s
gsave
.9761 .2792 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .2917 m
.07142 .29545 L
s
.11904 .2917 m
.11904 .29545 L
s
.16665 .2917 m
.16665 .29545 L
s
.21427 .2917 m
.21427 .29545 L
s
.3095 .2917 m
.3095 .29545 L
s
.35711 .2917 m
.35711 .29545 L
s
.40472 .2917 m
.40472 .29545 L
s
.45234 .2917 m
.45234 .29545 L
s
.54757 .2917 m
.54757 .29545 L
s
.59518 .2917 m
.59518 .29545 L
s
.6428 .2917 m
.6428 .29545 L
s
.69041 .2917 m
.69041 .29545 L
s
.78564 .2917 m
.78564 .29545 L
s
.83325 .2917 m
.83325 .29545 L
s
.88087 .2917 m
.88087 .29545 L
s
.92848 .2917 m
.92848 .29545 L
s
.01 w
0 .2917 m
1 .2917 L
s
.25 Mabswid
.02381 .01522 m
.03006 .01522 L
s
gsave
.01131 .01522 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.02381 .10738 m
.03006 .10738 L
s
gsave
.01131 .10738 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .19954 m
.03006 .19954 L
s
gsave
.01131 .19954 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .38386 m
.03006 .38386 L
s
gsave
.01131 .38386 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .47602 m
.03006 .47602 L
s
gsave
.01131 .47602 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .56818 m
.03006 .56818 L
s
gsave
.01131 .56818 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03365 m
.02756 .03365 L
s
.02381 .05208 m
.02756 .05208 L
s
.02381 .07051 m
.02756 .07051 L
s
.02381 .08895 m
.02756 .08895 L
s
.02381 .12581 m
.02756 .12581 L
s
.02381 .14424 m
.02756 .14424 L
s
.02381 .16267 m
.02756 .16267 L
s
.02381 .18111 m
.02756 .18111 L
s
.02381 .21797 m
.02756 .21797 L
s
.02381 .2364 m
.02756 .2364 L
s
.02381 .25483 m
.02756 .25483 L
s
.02381 .27327 m
.02756 .27327 L
s
.02381 .31013 m
.02756 .31013 L
s
.02381 .32856 m
.02756 .32856 L
s
.02381 .347 m
.02756 .347 L
s
.02381 .36543 m
.02756 .36543 L
s
.02381 .40229 m
.02756 .40229 L
s
.02381 .42072 m
.02756 .42072 L
s
.02381 .43916 m
.02756 .43916 L
s
.02381 .45759 m
.02756 .45759 L
s
.02381 .49445 m
.02756 .49445 L
s
.02381 .51289 m
.02756 .51289 L
s
.02381 .53132 m
.02756 .53132 L
s
.02381 .54975 m
.02756 .54975 L
s
.02381 .58661 m
.02756 .58661 L
s
.02381 .60505 m
.02756 .60505 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .38386 Mdot
.0239 .38386 Mdot
.02395 .38386 Mdot
.024 .38386 Mdot
.02405 .38386 Mdot
.0241 .38386 Mdot
.02414 .38386 Mdot
.02419 .38386 Mdot
.02424 .38386 Mdot
.02429 .38386 Mdot
.02433 .38385 Mdot
.02438 .38385 Mdot
.02443 .38385 Mdot
.02448 .38385 Mdot
.02452 .38385 Mdot
.02457 .38385 Mdot
.02462 .38384 Mdot
.02467 .38384 Mdot
.02471 .38384 Mdot
.02476 .38384 Mdot
.02481 .38383 Mdot
.02486 .38383 Mdot
.0249 .38383 Mdot
.02495 .38383 Mdot
.025 .38382 Mdot
.02505 .38382 Mdot
.0251 .38382 Mdot
.02514 .38381 Mdot
.02519 .38381 Mdot
.02524 .38381 Mdot
.02529 .3838 Mdot
.02533 .3838 Mdot
.02538 .38379 Mdot
.02543 .38379 Mdot
.02548 .38378 Mdot
.02552 .38378 Mdot
.02557 .38377 Mdot
.02562 .38377 Mdot
.02567 .38376 Mdot
.02571 .38376 Mdot
.02576 .38375 Mdot
.02581 .38375 Mdot
.02586 .38374 Mdot
.0259 .38374 Mdot
.02595 .38373 Mdot
.026 .38372 Mdot
.02605 .38372 Mdot
.0261 .38371 Mdot
.02614 .38371 Mdot
.02619 .3837 Mdot
.02624 .38369 Mdot
.02629 .38369 Mdot
.02633 .38368 Mdot
.02638 .38367 Mdot
.02643 .38366 Mdot
.02648 .38366 Mdot
.02652 .38365 Mdot
.02657 .38364 Mdot
.02662 .38363 Mdot
.02667 .38363 Mdot
.02671 .38362 Mdot
.02676 .38361 Mdot
.02681 .3836 Mdot
.02686 .38359 Mdot
.0269 .38358 Mdot
.02695 .38357 Mdot
.027 .38357 Mdot
.02705 .38356 Mdot
.02709 .38355 Mdot
.02714 .38354 Mdot
.02719 .38353 Mdot
.02724 .38352 Mdot
.02729 .38351 Mdot
.02733 .3835 Mdot
.02738 .38349 Mdot
.02743 .38348 Mdot
.02748 .38347 Mdot
.02752 .38346 Mdot
.02757 .38345 Mdot
.02762 .38344 Mdot
.02767 .38343 Mdot
.02771 .38341 Mdot
.02776 .3834 Mdot
.02781 .38339 Mdot
.02786 .38338 Mdot
.0279 .38337 Mdot
.02795 .38336 Mdot
.028 .38335 Mdot
.02805 .38333 Mdot
.02809 .38332 Mdot
.02814 .38331 Mdot
.02819 .3833 Mdot
.02824 .38328 Mdot
.02829 .38327 Mdot
.02833 .38326 Mdot
.02838 .38325 Mdot
.02843 .38323 Mdot
.02848 .38322 Mdot
.02852 .38321 Mdot
.02857 .38319 Mdot
.02862 .38318 Mdot
.02867 .38316 Mdot
.02871 .38315 Mdot
.02876 .38314 Mdot
.02881 .38312 Mdot
.02886 .38311 Mdot
.0289 .38309 Mdot
.02895 .38308 Mdot
.029 .38306 Mdot
.02905 .38305 Mdot
.02909 .38303 Mdot
.02914 .38302 Mdot
.02919 .383 Mdot
.02924 .38299 Mdot
.02929 .38297 Mdot
.02933 .38295 Mdot
.02938 .38294 Mdot
.02943 .38292 Mdot
.02948 .38291 Mdot
.02952 .38289 Mdot
.02957 .38287 Mdot
.02962 .38286 Mdot
.02967 .38284 Mdot
.02971 .38282 Mdot
.02976 .38281 Mdot
.02981 .38279 Mdot
.02986 .38277 Mdot
.0299 .38275 Mdot
.02995 .38274 Mdot
.03 .38272 Mdot
.03005 .3827 Mdot
.03009 .38268 Mdot
.03014 .38267 Mdot
.03019 .38265 Mdot
.03024 .38263 Mdot
.03029 .38261 Mdot
.03033 .38259 Mdot
.03038 .38257 Mdot
.03043 .38255 Mdot
.03048 .38253 Mdot
.03052 .38252 Mdot
.03057 .3825 Mdot
.03062 .38248 Mdot
.03067 .38246 Mdot
.03071 .38244 Mdot
.03076 .38242 Mdot
.03081 .3824 Mdot
.03086 .38238 Mdot
.0309 .38236 Mdot
.03095 .38234 Mdot
.031 .38232 Mdot
.03105 .3823 Mdot
.03109 .38227 Mdot
.03114 .38225 Mdot
.03119 .38223 Mdot
.03124 .38221 Mdot
.03128 .38219 Mdot
.03133 .38217 Mdot
.03138 .38215 Mdot
.03143 .38213 Mdot
.03148 .3821 Mdot
.03152 .38208 Mdot
.03157 .38206 Mdot
.03162 .38204 Mdot
.03167 .38201 Mdot
.03171 .38199 Mdot
.03176 .38197 Mdot
.03181 .38195 Mdot
.03186 .38192 Mdot
.0319 .3819 Mdot
.03195 .38188 Mdot
.032 .38185 Mdot
.03205 .38183 Mdot
.03209 .38181 Mdot
.03214 .38178 Mdot
.03219 .38176 Mdot
.03224 .38174 Mdot
.03228 .38171 Mdot
.03233 .38169 Mdot
.03238 .38166 Mdot
.03243 .38164 Mdot
.03248 .38161 Mdot
.03252 .38159 Mdot
.03257 .38156 Mdot
.03262 .38154 Mdot
.03267 .38151 Mdot
.03271 .38149 Mdot
.03276 .38146 Mdot
.03281 .38144 Mdot
.03286 .38141 Mdot
.0329 .38139 Mdot
.03295 .38136 Mdot
.033 .38133 Mdot
.03305 .38131 Mdot
.03309 .38128 Mdot
.03314 .38126 Mdot
.03319 .38123 Mdot
.03324 .3812 Mdot
.03328 .38118 Mdot
.03333 .38115 Mdot
.03338 .38112 Mdot
.03343 .38109 Mdot
.03348 .38107 Mdot
.03352 .38104 Mdot
.03357 .38101 Mdot
.03362 .38098 Mdot
.03367 .38096 Mdot
.03371 .38093 Mdot
.03376 .3809 Mdot
.03381 .38087 Mdot
.03386 .38084 Mdot
.0339 .38082 Mdot
.03395 .38079 Mdot
.034 .38076 Mdot
.03405 .38073 Mdot
.03409 .3807 Mdot
.03414 .38067 Mdot
.03419 .38064 Mdot
.03424 .38061 Mdot
.03428 .38058 Mdot
.03433 .38055 Mdot
.03438 .38052 Mdot
.03443 .38049 Mdot
.03448 .38046 Mdot
.03452 .38043 Mdot
.03457 .3804 Mdot
.03462 .38037 Mdot
.03467 .38034 Mdot
.03471 .38031 Mdot
.03476 .38028 Mdot
.03481 .38025 Mdot
.03486 .38022 Mdot
.0349 .38019 Mdot
.03495 .38016 Mdot
.035 .38013 Mdot
.03505 .38009 Mdot
.03509 .38006 Mdot
.03514 .38003 Mdot
.03519 .38 Mdot
.03524 .37997 Mdot
.03528 .37993 Mdot
.03533 .3799 Mdot
.03538 .37987 Mdot
.03543 .37984 Mdot
.03548 .3798 Mdot
.03552 .37977 Mdot
.03557 .37974 Mdot
.03562 .3797 Mdot
.03567 .37967 Mdot
.03571 .37964 Mdot
.03576 .3796 Mdot
.03581 .37957 Mdot
.03586 .37954 Mdot
.0359 .3795 Mdot
.03595 .37947 Mdot
.036 .37943 Mdot
.03605 .3794 Mdot
.03609 .37936 Mdot
.03614 .37933 Mdot
.03619 .37929 Mdot
.03624 .37926 Mdot
.03628 .37922 Mdot
.03633 .37919 Mdot
.03638 .37915 Mdot
.03643 .37912 Mdot
.03647 .37908 Mdot
.03652 .37905 Mdot
.03657 .37901 Mdot
.03662 .37897 Mdot
.03667 .37894 Mdot
.03671 .3789 Mdot
.03676 .37886 Mdot
.03681 .37883 Mdot
.03686 .37879 Mdot
.0369 .37875 Mdot
.03695 .37872 Mdot
.037 .37868 Mdot
.03705 .37864 Mdot
.03709 .3786 Mdot
.03714 .37857 Mdot
.03719 .37853 Mdot
.03724 .37849 Mdot
.03728 .37845 Mdot
.03733 .37841 Mdot
.03738 .37838 Mdot
.03743 .37834 Mdot
.03747 .3783 Mdot
.03752 .37826 Mdot
.03757 .37822 Mdot
.03762 .37818 Mdot
.03767 .37814 Mdot
.03771 .3781 Mdot
.03776 .37806 Mdot
.03781 .37802 Mdot
.03786 .37799 Mdot
.0379 .37795 Mdot
.03795 .37791 Mdot
.038 .37787 Mdot
.03805 .37783 Mdot
.03809 .37779 Mdot
.03814 .37775 Mdot
.03819 .3777 Mdot
.03824 .37766 Mdot
.03828 .37762 Mdot
.03833 .37758 Mdot
.03838 .37754 Mdot
.03843 .3775 Mdot
.03847 .37746 Mdot
.03852 .37742 Mdot
.03857 .37738 Mdot
.03862 .37733 Mdot
.03867 .37729 Mdot
.03871 .37725 Mdot
.03876 .37721 Mdot
.03881 .37717 Mdot
.03886 .37712 Mdot
.0389 .37708 Mdot
.03895 .37704 Mdot
.039 .377 Mdot
.03905 .37695 Mdot
.03909 .37691 Mdot
.03914 .37687 Mdot
.03919 .37682 Mdot
.03924 .37678 Mdot
.03928 .37674 Mdot
.03933 .37669 Mdot
.03938 .37665 Mdot
.03943 .37661 Mdot
.03947 .37656 Mdot
.03952 .37652 Mdot
.03957 .37647 Mdot
.03962 .37643 Mdot
.03967 .37638 Mdot
.03971 .37634 Mdot
.03976 .37629 Mdot
.03981 .37625 Mdot
.03986 .3762 Mdot
.0399 .37616 Mdot
.03995 .37611 Mdot
.04 .37607 Mdot
.04005 .37602 Mdot
.04009 .37598 Mdot
.04014 .37593 Mdot
.04019 .37588 Mdot
.04024 .37584 Mdot
.04028 .37579 Mdot
.04033 .37574 Mdot
.04038 .3757 Mdot
.04043 .37565 Mdot
.04047 .3756 Mdot
.04052 .37556 Mdot
.04057 .37551 Mdot
.04062 .37546 Mdot
.04066 .37542 Mdot
.04071 .37537 Mdot
.04076 .37532 Mdot
.04081 .37527 Mdot
.04086 .37523 Mdot
.0409 .37518 Mdot
.04095 .37513 Mdot
.041 .37508 Mdot
.04105 .37503 Mdot
.04109 .37499 Mdot
.04114 .37494 Mdot
.04119 .37489 Mdot
.04124 .37484 Mdot
.04128 .37479 Mdot
.04133 .37474 Mdot
.04138 .37469 Mdot
.04143 .37464 Mdot
.04147 .3746 Mdot
.04152 .37455 Mdot
.04157 .3745 Mdot
.04162 .37445 Mdot
.04166 .3744 Mdot
.04171 .37435 Mdot
.04176 .3743 Mdot
.04181 .37425 Mdot
.04186 .3742 Mdot
.0419 .37415 Mdot
.04195 .3741 Mdot
.042 .37405 Mdot
.04205 .374 Mdot
.04209 .37394 Mdot
.04214 .37389 Mdot
.04219 .37384 Mdot
.04224 .37379 Mdot
.04228 .37374 Mdot
.04233 .37369 Mdot
.04238 .37364 Mdot
.04243 .37358 Mdot
.04247 .37353 Mdot
.04252 .37348 Mdot
.04257 .37343 Mdot
.04262 .37338 Mdot
.04266 .37332 Mdot
.04271 .37327 Mdot
.04276 .37322 Mdot
.04281 .37317 Mdot
.04286 .37311 Mdot
.0429 .37306 Mdot
.04295 .37301 Mdot
.043 .37295 Mdot
.04305 .3729 Mdot
.04309 .37285 Mdot
.04314 .37279 Mdot
.04319 .37274 Mdot
.04324 .37269 Mdot
.04328 .37263 Mdot
.04333 .37258 Mdot
.04338 .37252 Mdot
.04343 .37247 Mdot
.04347 .37242 Mdot
.04352 .37236 Mdot
.04357 .37231 Mdot
.04362 .37225 Mdot
.04366 .3722 Mdot
.04371 .37214 Mdot
.04376 .37209 Mdot
.04381 .37203 Mdot
.04386 .37197 Mdot
.0439 .37192 Mdot
.04395 .37186 Mdot
.044 .37181 Mdot
.04405 .37175 Mdot
.04409 .3717 Mdot
.04414 .37164 Mdot
.04419 .37158 Mdot
.04424 .37153 Mdot
.04428 .37147 Mdot
.04433 .37141 Mdot
.04438 .37136 Mdot
.04443 .3713 Mdot
.04447 .37124 Mdot
.04452 .37119 Mdot
.04457 .37113 Mdot
.04462 .37107 Mdot
.04466 .37101 Mdot
.04471 .37096 Mdot
.04476 .3709 Mdot
.04481 .37084 Mdot
.04486 .37078 Mdot
.0449 .37073 Mdot
.04495 .37067 Mdot
.045 .37061 Mdot
.04505 .37055 Mdot
.04509 .37049 Mdot
.04514 .37043 Mdot
.04519 .37037 Mdot
.04524 .37032 Mdot
.04528 .37026 Mdot
.04533 .3702 Mdot
.04538 .37014 Mdot
.04543 .37008 Mdot
.04547 .37002 Mdot
.04552 .36996 Mdot
.04557 .3699 Mdot
.04562 .36984 Mdot
.04566 .36978 Mdot
.04571 .36972 Mdot
.04576 .36966 Mdot
.04581 .3696 Mdot
.04585 .36954 Mdot
.0459 .36948 Mdot
.04595 .36942 Mdot
.046 .36936 Mdot
.04605 .3693 Mdot
.04609 .36924 Mdot
.04614 .36918 Mdot
.04619 .36912 Mdot
.04624 .36905 Mdot
.04628 .36899 Mdot
.04633 .36893 Mdot
.04638 .36887 Mdot
.04643 .36881 Mdot
.04647 .36875 Mdot
.04652 .36868 Mdot
.04657 .36862 Mdot
.04662 .36856 Mdot
.04666 .3685 Mdot
.04671 .36844 Mdot
.04676 .36837 Mdot
.04681 .36831 Mdot
.04685 .36825 Mdot
.0469 .36818 Mdot
.04695 .36812 Mdot
.047 .36806 Mdot
.04705 .368 Mdot
.04709 .36793 Mdot
.04714 .36787 Mdot
.04719 .3678 Mdot
.04724 .36774 Mdot
.04728 .36768 Mdot
.04733 .36761 Mdot
.04738 .36755 Mdot
.04743 .36748 Mdot
.04747 .36742 Mdot
.04752 .36736 Mdot
.04757 .36729 Mdot
.04762 .36723 Mdot
.04766 .36716 Mdot
.04771 .3671 Mdot
.04776 .36703 Mdot
.04781 .36697 Mdot
.04785 .3669 Mdot
.0479 .36683 Mdot
.04795 .36677 Mdot
.048 .3667 Mdot
.04805 .36664 Mdot
.04809 .36657 Mdot
.04814 .36651 Mdot
.04819 .36644 Mdot
.04824 .36637 Mdot
.04828 .36631 Mdot
.04833 .36624 Mdot
.04838 .36617 Mdot
.04843 .36611 Mdot
.04847 .36604 Mdot
.04852 .36597 Mdot
.04857 .36591 Mdot
.04862 .36584 Mdot
.04866 .36577 Mdot
.04871 .3657 Mdot
.04876 .36564 Mdot
.04881 .36557 Mdot
.04885 .3655 Mdot
.0489 .36543 Mdot
.04895 .36536 Mdot
.049 .3653 Mdot
.04905 .36523 Mdot
.04909 .36516 Mdot
.04914 .36509 Mdot
.04919 .36502 Mdot
.04924 .36495 Mdot
.04928 .36489 Mdot
.04933 .36482 Mdot
.04938 .36475 Mdot
.04943 .36468 Mdot
.04947 .36461 Mdot
.04952 .36454 Mdot
.04957 .36447 Mdot
.04962 .3644 Mdot
.04966 .36433 Mdot
.04971 .36426 Mdot
.04976 .36419 Mdot
.04981 .36412 Mdot
.04985 .36405 Mdot
.0499 .36398 Mdot
.04995 .36391 Mdot
.05 .36384 Mdot
.05004 .36377 Mdot
.05009 .3637 Mdot
.05014 .36363 Mdot
.05019 .36356 Mdot
.05024 .36349 Mdot
.05028 .36342 Mdot
.05033 .36335 Mdot
.05038 .36327 Mdot
.05043 .3632 Mdot
.05047 .36313 Mdot
.05052 .36306 Mdot
.05057 .36299 Mdot
.05062 .36292 Mdot
.05066 .36285 Mdot
.05071 .36277 Mdot
.05076 .3627 Mdot
.05081 .36263 Mdot
.05085 .36256 Mdot
.0509 .36249 Mdot
.05095 .36241 Mdot
.051 .36234 Mdot
.05104 .36227 Mdot
.05109 .3622 Mdot
.05114 .36212 Mdot
.05119 .36205 Mdot
.05124 .36198 Mdot
.05128 .3619 Mdot
.05133 .36183 Mdot
.05138 .36176 Mdot
.05143 .36168 Mdot
.05147 .36161 Mdot
.05152 .36154 Mdot
.05157 .36146 Mdot
.05162 .36139 Mdot
.05166 .36132 Mdot
.05171 .36124 Mdot
.05176 .36117 Mdot
.05181 .36109 Mdot
.05185 .36102 Mdot
.0519 .36095 Mdot
.05195 .36087 Mdot
.052 .3608 Mdot
.05204 .36072 Mdot
.05209 .36065 Mdot
.05214 .36057 Mdot
.05219 .3605 Mdot
.05224 .36042 Mdot
.05228 .36035 Mdot
.05233 .36027 Mdot
.05238 .36019 Mdot
.05243 .36012 Mdot
.05247 .36004 Mdot
.05252 .35997 Mdot
.05257 .35989 Mdot
.05262 .35982 Mdot
.05266 .35974 Mdot
.05271 .35966 Mdot
.05276 .35959 Mdot
.05281 .35951 Mdot
.05285 .35943 Mdot
.0529 .35936 Mdot
.05295 .35928 Mdot
.053 .3592 Mdot
.05304 .35913 Mdot
.05309 .35905 Mdot
.05314 .35897 Mdot
.05319 .35889 Mdot
.05324 .35882 Mdot
.05328 .35874 Mdot
.05333 .35866 Mdot
.05338 .35858 Mdot
.05343 .35851 Mdot
.05347 .35843 Mdot
.05352 .35835 Mdot
.05357 .35827 Mdot
.05362 .35819 Mdot
.05366 .35812 Mdot
.05371 .35804 Mdot
.05376 .35796 Mdot
.05381 .35788 Mdot
.05385 .3578 Mdot
.0539 .35772 Mdot
.05395 .35764 Mdot
.054 .35756 Mdot
.05404 .35748 Mdot
.05409 .3574 Mdot
.05414 .35732 Mdot
.05419 .35724 Mdot
.05424 .35717 Mdot
.05428 .35709 Mdot
.05433 .35701 Mdot
.05438 .35693 Mdot
.05443 .35684 Mdot
.05447 .35676 Mdot
.05452 .35668 Mdot
.05457 .3566 Mdot
.05462 .35652 Mdot
.05466 .35644 Mdot
.05471 .35636 Mdot
.05476 .35628 Mdot
.05481 .3562 Mdot
.05485 .35612 Mdot
.0549 .35604 Mdot
.05495 .35596 Mdot
.055 .35587 Mdot
.05504 .35579 Mdot
.05509 .35571 Mdot
.05514 .35563 Mdot
.05519 .35555 Mdot
.05523 .35547 Mdot
.05528 .35538 Mdot
.05533 .3553 Mdot
.05538 .35522 Mdot
.05543 .35514 Mdot
.05547 .35505 Mdot
.05552 .35497 Mdot
.05557 .35489 Mdot
.05562 .35481 Mdot
.05566 .35472 Mdot
.05571 .35464 Mdot
.05576 .35456 Mdot
.05581 .35447 Mdot
.05585 .35439 Mdot
.0559 .35431 Mdot
.05595 .35422 Mdot
.056 .35414 Mdot
.05604 .35405 Mdot
.05609 .35397 Mdot
.05614 .35389 Mdot
.05619 .3538 Mdot
.05623 .35372 Mdot
.05628 .35363 Mdot
.05633 .35355 Mdot
.05638 .35346 Mdot
.05643 .35338 Mdot
.05647 .35329 Mdot
.05652 .35321 Mdot
.05657 .35312 Mdot
.05662 .35304 Mdot
.05666 .35295 Mdot
.05671 .35287 Mdot
.05676 .35278 Mdot
.05681 .3527 Mdot
.05685 .35261 Mdot
.0569 .35253 Mdot
.05695 .35244 Mdot
.057 .35235 Mdot
.05704 .35227 Mdot
.05709 .35218 Mdot
.05714 .3521 Mdot
.05719 .35201 Mdot
.05723 .35192 Mdot
.05728 .35184 Mdot
.05733 .35175 Mdot
.05738 .35166 Mdot
.05743 .35158 Mdot
.05747 .35149 Mdot
.05752 .3514 Mdot
.05757 .35132 Mdot
.05762 .35123 Mdot
.05766 .35114 Mdot
.05771 .35105 Mdot
.05776 .35097 Mdot
.05781 .35088 Mdot
.05785 .35079 Mdot
.0579 .3507 Mdot
.05795 .35061 Mdot
.058 .35053 Mdot
.05804 .35044 Mdot
.05809 .35035 Mdot
.05814 .35026 Mdot
.05819 .35017 Mdot
.05823 .35008 Mdot
.05828 .35 Mdot
.05833 .34991 Mdot
.05838 .34982 Mdot
.05843 .34973 Mdot
.05847 .34964 Mdot
.05852 .34955 Mdot
.05857 .34946 Mdot
.05862 .34937 Mdot
.05866 .34928 Mdot
.05871 .34919 Mdot
.05876 .3491 Mdot
.05881 .34901 Mdot
.05885 .34892 Mdot
.0589 .34883 Mdot
.05895 .34874 Mdot
.059 .34865 Mdot
.05904 .34856 Mdot
.05909 .34847 Mdot
.05914 .34838 Mdot
.05919 .34829 Mdot
.05923 .3482 Mdot
.05928 .34811 Mdot
.05933 .34802 Mdot
.05938 .34793 Mdot
.05943 .34784 Mdot
.05947 .34775 Mdot
.05952 .34766 Mdot
.05957 .34757 Mdot
.05962 .34747 Mdot
.05966 .34738 Mdot
.05971 .34729 Mdot
.05976 .3472 Mdot
.05981 .34711 Mdot
.05985 .34702 Mdot
.0599 .34693 Mdot
.05995 .34683 Mdot
.06 .34674 Mdot
.06004 .34665 Mdot
.06009 .34656 Mdot
.06014 .34646 Mdot
.06019 .34637 Mdot
.06023 .34628 Mdot
.06028 .34619 Mdot
.06033 .34609 Mdot
.06038 .346 Mdot
.06042 .34591 Mdot
.06047 .34582 Mdot
.06052 .34572 Mdot
.06057 .34563 Mdot
.06062 .34554 Mdot
.06066 .34544 Mdot
.06071 .34535 Mdot
.06076 .34526 Mdot
.06081 .34516 Mdot
.06085 .34507 Mdot
.0609 .34498 Mdot
.06095 .34488 Mdot
.061 .34479 Mdot
.06104 .3447 Mdot
.06109 .3446 Mdot
.06114 .34451 Mdot
.06119 .34441 Mdot
.06123 .34432 Mdot
.06128 .34423 Mdot
.06133 .34413 Mdot
.06138 .34404 Mdot
.06142 .34394 Mdot
.06147 .34385 Mdot
.06152 .34375 Mdot
.06157 .34366 Mdot
.06162 .34356 Mdot
.06166 .34347 Mdot
.06171 .34337 Mdot
.06176 .34328 Mdot
.06181 .34318 Mdot
.06185 .34309 Mdot
.0619 .34299 Mdot
.06195 .3429 Mdot
.062 .3428 Mdot
.06204 .34271 Mdot
.06209 .34261 Mdot
.06214 .34252 Mdot
.06219 .34242 Mdot
.06223 .34233 Mdot
.06228 .34223 Mdot
.06233 .34213 Mdot
.06238 .34204 Mdot
.06242 .34194 Mdot
.06247 .34185 Mdot
.06252 .34175 Mdot
.06257 .34165 Mdot
.06262 .34156 Mdot
.06266 .34146 Mdot
.06271 .34137 Mdot
.06276 .34127 Mdot
.06281 .34117 Mdot
.06285 .34108 Mdot
.0629 .34098 Mdot
.06295 .34088 Mdot
.063 .34079 Mdot
.06304 .34069 Mdot
.06309 .34059 Mdot
.06314 .3405 Mdot
.06319 .3404 Mdot
.06323 .3403 Mdot
.06328 .3402 Mdot
.06333 .34011 Mdot
.06338 .34001 Mdot
.06342 .33991 Mdot
.06347 .33981 Mdot
.06352 .33972 Mdot
.06357 .33962 Mdot
.06362 .33952 Mdot
.06366 .33942 Mdot
.06371 .33932 Mdot
.06376 .33923 Mdot
.06381 .33913 Mdot
.06385 .33903 Mdot
.0639 .33893 Mdot
.06395 .33883 Mdot
.064 .33873 Mdot
.06404 .33864 Mdot
.06409 .33854 Mdot
.06414 .33844 Mdot
.06419 .33834 Mdot
.06423 .33824 Mdot
.06428 .33814 Mdot
.06433 .33804 Mdot
.06438 .33794 Mdot
.06442 .33784 Mdot
.06447 .33774 Mdot
.06452 .33764 Mdot
.06457 .33755 Mdot
.06461 .33745 Mdot
.06466 .33735 Mdot
.06471 .33725 Mdot
.06476 .33715 Mdot
.06481 .33705 Mdot
.06485 .33695 Mdot
.0649 .33685 Mdot
.06495 .33675 Mdot
.065 .33665 Mdot
.06504 .33654 Mdot
.06509 .33644 Mdot
.06514 .33634 Mdot
.06519 .33624 Mdot
.06523 .33614 Mdot
.06528 .33604 Mdot
.06533 .33594 Mdot
.06538 .33584 Mdot
.06542 .33574 Mdot
.06547 .33564 Mdot
.06552 .33554 Mdot
.06557 .33543 Mdot
.06561 .33533 Mdot
.06566 .33523 Mdot
.06571 .33513 Mdot
.06576 .33503 Mdot
.06581 .33493 Mdot
.06585 .33483 Mdot
.0659 .33472 Mdot
.06595 .33462 Mdot
.066 .33452 Mdot
.06604 .33442 Mdot
.06609 .33432 Mdot
.06614 .33422 Mdot
.06619 .33411 Mdot
.06623 .33401 Mdot
.06628 .33391 Mdot
.06633 .33381 Mdot
.06638 .3337 Mdot
.06642 .3336 Mdot
.06647 .3335 Mdot
.06652 .3334 Mdot
.06657 .33329 Mdot
.06661 .33319 Mdot
.06666 .33309 Mdot
.06671 .33299 Mdot
.06676 .33288 Mdot
.06681 .33278 Mdot
.06685 .33268 Mdot
.0669 .33257 Mdot
.06695 .33247 Mdot
.067 .33237 Mdot
.06704 .33226 Mdot
.06709 .33216 Mdot
.06714 .33206 Mdot
.06719 .33196 Mdot
.06723 .33185 Mdot
.06728 .33175 Mdot
.06733 .33164 Mdot
.06738 .33154 Mdot
.06742 .33144 Mdot
.06747 .33133 Mdot
.06752 .33123 Mdot
.06757 .33113 Mdot
.06761 .33102 Mdot
.06766 .33092 Mdot
.06771 .33081 Mdot
.06776 .33071 Mdot
.06781 .33061 Mdot
.06785 .3305 Mdot
.0679 .3304 Mdot
.06795 .33029 Mdot
.068 .33019 Mdot
.06804 .33008 Mdot
.06809 .32998 Mdot
.06814 .32987 Mdot
.06819 .32977 Mdot
.06823 .32966 Mdot
.06828 .32956 Mdot
.06833 .32946 Mdot
.06838 .32935 Mdot
.06842 .32925 Mdot
.06847 .32914 Mdot
.06852 .32903 Mdot
.06857 .32893 Mdot
.06861 .32882 Mdot
.06866 .32872 Mdot
.06871 .32861 Mdot
.06876 .32851 Mdot
.06881 .3284 Mdot
.06885 .3283 Mdot
.0689 .32819 Mdot
.06895 .32808 Mdot
.069 .32798 Mdot
.06904 .32787 Mdot
.06909 .32777 Mdot
.06914 .32766 Mdot
.06919 .32755 Mdot
.06923 .32745 Mdot
.06928 .32734 Mdot
.06933 .32724 Mdot
.06938 .32713 Mdot
.06942 .32702 Mdot
.06947 .32692 Mdot
.06952 .32681 Mdot
.06957 .3267 Mdot
.06961 .3266 Mdot
.06966 .32649 Mdot
.06971 .32638 Mdot
.06976 .32628 Mdot
.0698 .32617 Mdot
.06985 .32606 Mdot
.0699 .32596 Mdot
.06995 .32585 Mdot
.07 .32574 Mdot
.07004 .32563 Mdot
.07009 .32553 Mdot
.07014 .32542 Mdot
.07019 .32531 Mdot
.07023 .32521 Mdot
.07028 .3251 Mdot
.07033 .32499 Mdot
.07038 .32488 Mdot
.07042 .32478 Mdot
.07047 .32467 Mdot
.07052 .32456 Mdot
.07057 .32445 Mdot
.07061 .32434 Mdot
.07066 .32424 Mdot
.07071 .32413 Mdot
.07076 .32402 Mdot
.0708 .32391 Mdot
.07085 .3238 Mdot
.0709 .3237 Mdot
.07095 .32359 Mdot
.071 .32348 Mdot
.07104 .32337 Mdot
.07109 .32326 Mdot
.07114 .32315 Mdot
.07119 .32305 Mdot
.07123 .32294 Mdot
.07128 .32283 Mdot
.07133 .32272 Mdot
.07138 .32261 Mdot
.07142 .3225 Mdot
.07147 .32239 Mdot
.07152 .32228 Mdot
.07157 .32218 Mdot
.07161 .32207 Mdot
.07166 .32196 Mdot
.07171 .32185 Mdot
.07176 .32174 Mdot
.0718 .32163 Mdot
.07185 .32152 Mdot
.0719 .32141 Mdot
.07195 .3213 Mdot
.072 .32119 Mdot
.07204 .32108 Mdot
.07209 .32097 Mdot
.07214 .32086 Mdot
.07219 .32075 Mdot
.07223 .32064 Mdot
.07228 .32053 Mdot
.07233 .32042 Mdot
.07238 .32031 Mdot
.07242 .3202 Mdot
.07247 .32009 Mdot
.07252 .31998 Mdot
.07257 .31987 Mdot
.07261 .31976 Mdot
.07266 .31965 Mdot
.07271 .31954 Mdot
.07276 .31943 Mdot
.0728 .31932 Mdot
.07285 .31921 Mdot
.0729 .3191 Mdot
.07295 .31899 Mdot
.073 .31888 Mdot
.07304 .31877 Mdot
.07309 .31866 Mdot
.07314 .31855 Mdot
.07319 .31844 Mdot
.07323 .31833 Mdot
.07328 .31822 Mdot
.07333 .31811 Mdot
.07338 .318 Mdot
.07342 .31788 Mdot
.07347 .31777 Mdot
.07352 .31766 Mdot
.07357 .31755 Mdot
.07361 .31744 Mdot
.07366 .31733 Mdot
.07371 .31722 Mdot
.07376 .31711 Mdot
.0738 .317 Mdot
.07385 .31688 Mdot
.0739 .31677 Mdot
.07395 .31666 Mdot
.07399 .31655 Mdot
.07404 .31644 Mdot
.07409 .31633 Mdot
.07414 .31622 Mdot
.07419 .31611 Mdot
.07423 .31599 Mdot
.07428 .31588 Mdot
.07433 .31577 Mdot
.07438 .31566 Mdot
.07442 .31555 Mdot
.07447 .31544 Mdot
.07452 .31532 Mdot
.07457 .31521 Mdot
.07461 .3151 Mdot
.07466 .31499 Mdot
.07471 .31488 Mdot
.07476 .31476 Mdot
.0748 .31465 Mdot
.07485 .31454 Mdot
.0749 .31443 Mdot
.07495 .31431 Mdot
.07499 .3142 Mdot
.07504 .31409 Mdot
.07509 .31398 Mdot
.07514 .31387 Mdot
.07519 .31375 Mdot
.07523 .31364 Mdot
.07528 .31353 Mdot
.07533 .31342 Mdot
.07538 .3133 Mdot
.07542 .31319 Mdot
.07547 .31308 Mdot
.07552 .31296 Mdot
.07557 .31285 Mdot
.07561 .31274 Mdot
.07566 .31263 Mdot
.07571 .31251 Mdot
.07576 .3124 Mdot
.0758 .31229 Mdot
.07585 .31217 Mdot
.0759 .31206 Mdot
.07595 .31195 Mdot
.07599 .31183 Mdot
.07604 .31172 Mdot
.07609 .31161 Mdot
.07614 .3115 Mdot
.07619 .31138 Mdot
.07623 .31127 Mdot
.07628 .31116 Mdot
.07633 .31104 Mdot
.07638 .31093 Mdot
.07642 .31082 Mdot
.07647 .3107 Mdot
.07652 .31059 Mdot
.07657 .31047 Mdot
.07661 .31036 Mdot
.07666 .31025 Mdot
.07671 .31013 Mdot
.07676 .31002 Mdot
.0768 .30991 Mdot
.07685 .30979 Mdot
.0769 .30968 Mdot
.07695 .30957 Mdot
.07699 .30945 Mdot
.07704 .30934 Mdot
.07709 .30922 Mdot
.07714 .30911 Mdot
.07719 .309 Mdot
.07723 .30888 Mdot
.07728 .30877 Mdot
.07733 .30865 Mdot
.07738 .30854 Mdot
.07742 .30843 Mdot
.07747 .30831 Mdot
.07752 .3082 Mdot
.07757 .30808 Mdot
.07761 .30797 Mdot
.07766 .30785 Mdot
.07771 .30774 Mdot
.07776 .30763 Mdot
.0778 .30751 Mdot
.07785 .3074 Mdot
.0779 .30728 Mdot
.07795 .30717 Mdot
.07799 .30705 Mdot
.07804 .30694 Mdot
.07809 .30682 Mdot
.07814 .30671 Mdot
.07819 .3066 Mdot
.07823 .30648 Mdot
.07828 .30637 Mdot
.07833 .30625 Mdot
.07838 .30614 Mdot
.07842 .30602 Mdot
.07847 .30591 Mdot
.07852 .30579 Mdot
.07857 .30568 Mdot
.07861 .30556 Mdot
.07866 .30545 Mdot
.07871 .30533 Mdot
.07876 .30522 Mdot
.0788 .3051 Mdot
.07885 .30499 Mdot
.0789 .30487 Mdot
.07895 .30476 Mdot
.07899 .30464 Mdot
.07904 .30453 Mdot
.07909 .30441 Mdot
.07914 .3043 Mdot
.07918 .30418 Mdot
.07923 .30407 Mdot
.07928 .30395 Mdot
.07933 .30384 Mdot
.07938 .30372 Mdot
.07942 .30361 Mdot
.07947 .30349 Mdot
.07952 .30338 Mdot
.07957 .30326 Mdot
.07961 .30315 Mdot
.07966 .30303 Mdot
.07971 .30292 Mdot
.07976 .3028 Mdot
.0798 .30269 Mdot
.07985 .30257 Mdot
.0799 .30246 Mdot
.07995 .30234 Mdot
.07999 .30223 Mdot
.08004 .30211 Mdot
.08009 .30199 Mdot
.08014 .30188 Mdot
.08018 .30176 Mdot
.08023 .30165 Mdot
.08028 .30153 Mdot
.08033 .30142 Mdot
.08038 .3013 Mdot
.08042 .30118 Mdot
.08047 .30107 Mdot
.08052 .30095 Mdot
.08057 .30084 Mdot
.08061 .30072 Mdot
.08066 .30061 Mdot
.08071 .30049 Mdot
.08076 .30037 Mdot
.0808 .30026 Mdot
.08085 .30014 Mdot
.0809 .30003 Mdot
.08095 .29991 Mdot
.08099 .2998 Mdot
.08104 .29968 Mdot
.08109 .29956 Mdot
.08114 .29945 Mdot
.08118 .29933 Mdot
.08123 .29922 Mdot
.08128 .2991 Mdot
.08133 .29898 Mdot
.08138 .29887 Mdot
.08142 .29875 Mdot
.08147 .29864 Mdot
.08152 .29852 Mdot
.08157 .2984 Mdot
.08161 .29829 Mdot
.08166 .29817 Mdot
.08171 .29805 Mdot
.08176 .29794 Mdot
.0818 .29782 Mdot
.08185 .29771 Mdot
.0819 .29759 Mdot
.08195 .29747 Mdot
.08199 .29736 Mdot
.08204 .29724 Mdot
.08209 .29712 Mdot
.08214 .29701 Mdot
.08218 .29689 Mdot
.08223 .29677 Mdot
.08228 .29666 Mdot
.08233 .29654 Mdot
.08238 .29642 Mdot
.08242 .29631 Mdot
.08247 .29619 Mdot
.08252 .29607 Mdot
.08257 .29596 Mdot
.08261 .29584 Mdot
.08266 .29572 Mdot
.08271 .29561 Mdot
.08276 .29549 Mdot
.0828 .29537 Mdot
.08285 .29526 Mdot
.0829 .29514 Mdot
.08295 .29502 Mdot
.08299 .29491 Mdot
.08304 .29479 Mdot
.08309 .29467 Mdot
.08314 .29456 Mdot
.08318 .29444 Mdot
.08323 .29432 Mdot
.08328 .29421 Mdot
.08333 .29409 Mdot
.08337 .29397 Mdot
.08342 .29386 Mdot
.08347 .29374 Mdot
.08352 .29362 Mdot
.08357 .2935 Mdot
.08361 .29339 Mdot
.08366 .29327 Mdot
.08371 .29315 Mdot
.08376 .29304 Mdot
.0838 .29292 Mdot
.08385 .2928 Mdot
.0839 .29268 Mdot
.08395 .29257 Mdot
.08399 .29245 Mdot
.08404 .29233 Mdot
.08409 .29222 Mdot
.08414 .2921 Mdot
.08418 .29198 Mdot
.08423 .29186 Mdot
.08428 .29175 Mdot
.08433 .29163 Mdot
.08437 .29151 Mdot
.08442 .2914 Mdot
.08447 .29128 Mdot
.08452 .29116 Mdot
.08457 .29104 Mdot
.08461 .29093 Mdot
.08466 .29081 Mdot
.08471 .29069 Mdot
.08476 .29057 Mdot
.0848 .29046 Mdot
.08485 .29034 Mdot
.0849 .29022 Mdot
.08495 .2901 Mdot
.08499 .28999 Mdot
.08504 .28987 Mdot
.08509 .28975 Mdot
.08514 .28964 Mdot
.08518 .28952 Mdot
.08523 .2894 Mdot
.08528 .28928 Mdot
.08533 .28917 Mdot
.08537 .28905 Mdot
.08542 .28893 Mdot
.08547 .28881 Mdot
.08552 .2887 Mdot
.08557 .28858 Mdot
.08561 .28846 Mdot
.08566 .28834 Mdot
.08571 .28823 Mdot
.08576 .28811 Mdot
.0858 .28799 Mdot
.08585 .28787 Mdot
.0859 .28776 Mdot
.08595 .28764 Mdot
.08599 .28752 Mdot
.08604 .2874 Mdot
.08609 .28729 Mdot
.08614 .28717 Mdot
.08618 .28705 Mdot
.08623 .28693 Mdot
.08628 .28682 Mdot
.08633 .2867 Mdot
.08637 .28658 Mdot
.08642 .28646 Mdot
.08647 .28635 Mdot
.08652 .28623 Mdot
.08657 .28611 Mdot
.08661 .28599 Mdot
.08666 .28588 Mdot
.08671 .28576 Mdot
.08676 .28564 Mdot
.0868 .28552 Mdot
.08685 .28541 Mdot
.0869 .28529 Mdot
.08695 .28517 Mdot
.08699 .28505 Mdot
.08704 .28494 Mdot
.08709 .28482 Mdot
.08714 .2847 Mdot
.08718 .28458 Mdot
.08723 .28447 Mdot
.08728 .28435 Mdot
.08733 .28423 Mdot
.08737 .28411 Mdot
.08742 .284 Mdot
.08747 .28388 Mdot
.08752 .28376 Mdot
.08757 .28364 Mdot
.08761 .28352 Mdot
.08766 .28341 Mdot
.08771 .28329 Mdot
.08776 .28317 Mdot
.0878 .28305 Mdot
.08785 .28294 Mdot
.0879 .28282 Mdot
.08795 .2827 Mdot
.08799 .28258 Mdot
.08804 .28247 Mdot
.08809 .28235 Mdot
.08814 .28223 Mdot
.08818 .28211 Mdot
.08823 .282 Mdot
.08828 .28188 Mdot
.08833 .28176 Mdot
.08837 .28164 Mdot
.08842 .28152 Mdot
.08847 .28141 Mdot
.08852 .28129 Mdot
.08856 .28117 Mdot
.08861 .28105 Mdot
.08866 .28094 Mdot
.08871 .28082 Mdot
.08876 .2807 Mdot
.0888 .28058 Mdot
.08885 .28047 Mdot
.0889 .28035 Mdot
.08895 .28023 Mdot
.08899 .28011 Mdot
.08904 .28 Mdot
.08909 .27988 Mdot
.08914 .27976 Mdot
.08918 .27964 Mdot
.08923 .27953 Mdot
.08928 .27941 Mdot
.08933 .27929 Mdot
.08937 .27917 Mdot
.08942 .27906 Mdot
.08947 .27894 Mdot
.08952 .27882 Mdot
.08956 .2787 Mdot
.08961 .27859 Mdot
.08966 .27847 Mdot
.08971 .27835 Mdot
.08976 .27824 Mdot
.0898 .27812 Mdot
.08985 .278 Mdot
.0899 .27788 Mdot
.08995 .27777 Mdot
.08999 .27765 Mdot
.09004 .27753 Mdot
.09009 .27741 Mdot
.09014 .2773 Mdot
.09018 .27718 Mdot
.09023 .27706 Mdot
.09028 .27695 Mdot
.09033 .27683 Mdot
.09037 .27671 Mdot
.09042 .27659 Mdot
.09047 .27648 Mdot
.09052 .27636 Mdot
.09056 .27624 Mdot
.09061 .27613 Mdot
.09066 .27601 Mdot
.09071 .27589 Mdot
.09076 .27577 Mdot
.0908 .27566 Mdot
.09085 .27554 Mdot
.0909 .27542 Mdot
.09095 .27531 Mdot
.09099 .27519 Mdot
.09104 .27507 Mdot
.09109 .27495 Mdot
.09114 .27484 Mdot
.09118 .27472 Mdot
.09123 .2746 Mdot
.09128 .27449 Mdot
.09133 .27437 Mdot
.09137 .27425 Mdot
.09142 .27414 Mdot
.09147 .27402 Mdot
.09152 .2739 Mdot
.09156 .27379 Mdot
.09161 .27367 Mdot
.09166 .27355 Mdot
.09171 .27344 Mdot
.09176 .27332 Mdot
.0918 .2732 Mdot
.09185 .27309 Mdot
.0919 .27297 Mdot
.09195 .27285 Mdot
.09199 .27274 Mdot
.09204 .27262 Mdot
.09209 .2725 Mdot
.09214 .27239 Mdot
.09218 .27227 Mdot
.09223 .27215 Mdot
.09228 .27204 Mdot
.09233 .27192 Mdot
.09237 .2718 Mdot
.09242 .27169 Mdot
.09247 .27157 Mdot
.09252 .27145 Mdot
.09256 .27134 Mdot
.09261 .27122 Mdot
.09266 .27111 Mdot
.09271 .27099 Mdot
.09276 .27087 Mdot
.0928 .27076 Mdot
.09285 .27064 Mdot
.0929 .27052 Mdot
.09295 .27041 Mdot
.09299 .27029 Mdot
.09304 .27018 Mdot
.09309 .27006 Mdot
.09314 .26994 Mdot
.09318 .26983 Mdot
.09323 .26971 Mdot
.09328 .26959 Mdot
.09333 .26948 Mdot
.09337 .26936 Mdot
.09342 .26925 Mdot
.09347 .26913 Mdot
.09352 .26902 Mdot
.09356 .2689 Mdot
.09361 .26878 Mdot
.09366 .26867 Mdot
.09371 .26855 Mdot
.09375 .26844 Mdot
.0938 .26832 Mdot
.09385 .2682 Mdot
.0939 .26809 Mdot
.09395 .26797 Mdot
.09399 .26786 Mdot
.09404 .26774 Mdot
.09409 .26763 Mdot
.09414 .26751 Mdot
.09418 .26739 Mdot
.09423 .26728 Mdot
.09428 .26716 Mdot
.09433 .26705 Mdot
.09437 .26693 Mdot
.09442 .26682 Mdot
.09447 .2667 Mdot
.09452 .26659 Mdot
.09456 .26647 Mdot
.09461 .26636 Mdot
.09466 .26624 Mdot
.09471 .26613 Mdot
.09475 .26601 Mdot
.0948 .2659 Mdot
.09485 .26578 Mdot
.0949 .26567 Mdot
.09495 .26555 Mdot
.09499 .26543 Mdot
.09504 .26532 Mdot
.09509 .2652 Mdot
.09514 .26509 Mdot
.09518 .26497 Mdot
.09523 .26486 Mdot
.09528 .26474 Mdot
.09533 .26463 Mdot
.09537 .26451 Mdot
.09542 .2644 Mdot
.09547 .26428 Mdot
.09552 .26417 Mdot
.09556 .26405 Mdot
.09561 .26394 Mdot
.09566 .26382 Mdot
.09571 .26371 Mdot
.09575 .2636 Mdot
.0958 .26348 Mdot
.09585 .26337 Mdot
.0959 .26325 Mdot
.09595 .26314 Mdot
.09599 .26302 Mdot
.09604 .26291 Mdot
.09609 .26279 Mdot
.09614 .26268 Mdot
.09618 .26256 Mdot
.09623 .26245 Mdot
.09628 .26233 Mdot
.09633 .26222 Mdot
.09637 .26211 Mdot
.09642 .26199 Mdot
.09647 .26188 Mdot
.09652 .26176 Mdot
.09656 .26165 Mdot
.09661 .26153 Mdot
.09666 .26142 Mdot
.09671 .26131 Mdot
.09675 .26119 Mdot
.0968 .26108 Mdot
.09685 .26096 Mdot
.0969 .26085 Mdot
.09695 .26074 Mdot
.09699 .26062 Mdot
.09704 .26051 Mdot
.09709 .2604 Mdot
.09714 .26028 Mdot
.09718 .26017 Mdot
.09723 .26006 Mdot
.09728 .25994 Mdot
.09733 .25983 Mdot
.09737 .25971 Mdot
.09742 .2596 Mdot
.09747 .25949 Mdot
.09752 .25937 Mdot
.09756 .25926 Mdot
.09761 .25915 Mdot
.09766 .25903 Mdot
.09771 .25892 Mdot
.09775 .25881 Mdot
.0978 .25869 Mdot
.09785 .25858 Mdot
.0979 .25847 Mdot
.09794 .25836 Mdot
.09799 .25824 Mdot
.09804 .25813 Mdot
.09809 .25802 Mdot
.09814 .2579 Mdot
.09818 .25779 Mdot
.09823 .25768 Mdot
.09828 .25756 Mdot
.09833 .25745 Mdot
.09837 .25734 Mdot
.09842 .25723 Mdot
.09847 .25711 Mdot
.09852 .257 Mdot
.09856 .25689 Mdot
.09861 .25678 Mdot
.09866 .25666 Mdot
.09871 .25655 Mdot
.09875 .25644 Mdot
.0988 .25633 Mdot
.09885 .25621 Mdot
.0989 .2561 Mdot
.09894 .25599 Mdot
.09899 .25588 Mdot
.09904 .25576 Mdot
.09909 .25565 Mdot
.09914 .25554 Mdot
.09918 .25543 Mdot
.09923 .25531 Mdot
.09928 .2552 Mdot
.09933 .25509 Mdot
.09937 .25498 Mdot
.09942 .25487 Mdot
.09947 .25475 Mdot
.09952 .25464 Mdot
.09956 .25453 Mdot
.09961 .25442 Mdot
.09966 .25431 Mdot
.09971 .25419 Mdot
.09975 .25408 Mdot
.0998 .25397 Mdot
.09985 .25386 Mdot
.0999 .25375 Mdot
.09994 .25364 Mdot
.09999 .25352 Mdot
.10004 .25341 Mdot
.10009 .2533 Mdot
.10014 .25319 Mdot
.10018 .25308 Mdot
.10023 .25297 Mdot
.10028 .25285 Mdot
.10033 .25274 Mdot
.10037 .25263 Mdot
.10042 .25252 Mdot
.10047 .25241 Mdot
.10052 .2523 Mdot
.10056 .25219 Mdot
.10061 .25208 Mdot
.10066 .25196 Mdot
.10071 .25185 Mdot
.10075 .25174 Mdot
.1008 .25163 Mdot
.10085 .25152 Mdot
.1009 .25141 Mdot
.10094 .2513 Mdot
.10099 .25119 Mdot
.10104 .25108 Mdot
.10109 .25097 Mdot
.10114 .25086 Mdot
.10118 .25075 Mdot
.10123 .25064 Mdot
.10128 .25053 Mdot
.10133 .25042 Mdot
.10137 .25031 Mdot
.10142 .2502 Mdot
.10147 .25009 Mdot
.10152 .24998 Mdot
.10156 .24987 Mdot
.10161 .24976 Mdot
.10166 .24965 Mdot
.10171 .24954 Mdot
.10175 .24943 Mdot
.1018 .24932 Mdot
.10185 .24921 Mdot
.1019 .2491 Mdot
.10194 .24899 Mdot
.10199 .24888 Mdot
.10204 .24877 Mdot
.10209 .24866 Mdot
.10214 .24855 Mdot
.10218 .24844 Mdot
.10223 .24833 Mdot
.10228 .24822 Mdot
.10233 .24811 Mdot
.10237 .24801 Mdot
.10242 .2479 Mdot
.10247 .24779 Mdot
.10252 .24768 Mdot
.10256 .24757 Mdot
.10261 .24746 Mdot
.10266 .24735 Mdot
.10271 .24724 Mdot
.10275 .24713 Mdot
.1028 .24703 Mdot
.10285 .24692 Mdot
.1029 .24681 Mdot
.10294 .2467 Mdot
.10299 .24659 Mdot
.10304 .24648 Mdot
.10309 .24637 Mdot
.10313 .24627 Mdot
.10318 .24616 Mdot
.10323 .24605 Mdot
.10328 .24594 Mdot
.10333 .24583 Mdot
.10337 .24573 Mdot
.10342 .24562 Mdot
.10347 .24551 Mdot
.10352 .2454 Mdot
.10356 .24529 Mdot
.10361 .24519 Mdot
.10366 .24508 Mdot
.10371 .24497 Mdot
.10375 .24486 Mdot
.1038 .24476 Mdot
.10385 .24465 Mdot
.1039 .24454 Mdot
.10394 .24443 Mdot
.10399 .24433 Mdot
.10404 .24422 Mdot
.10409 .24411 Mdot
.10413 .24401 Mdot
.10418 .2439 Mdot
.10423 .24379 Mdot
.10428 .24369 Mdot
.10433 .24358 Mdot
.10437 .24347 Mdot
.10442 .24336 Mdot
.10447 .24326 Mdot
.10452 .24315 Mdot
.10456 .24305 Mdot
.10461 .24294 Mdot
.10466 .24283 Mdot
.10471 .24273 Mdot
.10475 .24262 Mdot
.1048 .24251 Mdot
.10485 .24241 Mdot
.1049 .2423 Mdot
.10494 .24219 Mdot
.10499 .24209 Mdot
.10504 .24198 Mdot
.10509 .24188 Mdot
.10513 .24177 Mdot
.10518 .24166 Mdot
.10523 .24156 Mdot
.10528 .24145 Mdot
.10533 .24135 Mdot
.10537 .24124 Mdot
.10542 .24114 Mdot
.10547 .24103 Mdot
.10552 .24093 Mdot
.10556 .24082 Mdot
.10561 .24072 Mdot
.10566 .24061 Mdot
.10571 .24051 Mdot
.10575 .2404 Mdot
.1058 .2403 Mdot
.10585 .24019 Mdot
.1059 .24009 Mdot
.10594 .23998 Mdot
.10599 .23988 Mdot
.10604 .23977 Mdot
.10609 .23967 Mdot
.10613 .23956 Mdot
.10618 .23946 Mdot
.10623 .23936 Mdot
.10628 .23925 Mdot
.10633 .23915 Mdot
.10637 .23904 Mdot
.10642 .23894 Mdot
.10647 .23884 Mdot
.10652 .23873 Mdot
.10656 .23863 Mdot
.10661 .23852 Mdot
.10666 .23842 Mdot
.10671 .23832 Mdot
.10675 .23821 Mdot
.1068 .23811 Mdot
.10685 .23801 Mdot
.1069 .2379 Mdot
.10694 .2378 Mdot
.10699 .2377 Mdot
.10704 .2376 Mdot
.10709 .23749 Mdot
.10713 .23739 Mdot
.10718 .23729 Mdot
.10723 .23719 Mdot
.10728 .23708 Mdot
.10732 .23698 Mdot
.10737 .23688 Mdot
.10742 .23678 Mdot
.10747 .23667 Mdot
.10752 .23657 Mdot
.10756 .23647 Mdot
.10761 .23637 Mdot
.10766 .23627 Mdot
.10771 .23616 Mdot
.10775 .23606 Mdot
.1078 .23596 Mdot
.10785 .23586 Mdot
.1079 .23576 Mdot
.10794 .23566 Mdot
.10799 .23556 Mdot
.10804 .23545 Mdot
.10809 .23535 Mdot
.10813 .23525 Mdot
.10818 .23515 Mdot
.10823 .23505 Mdot
.10828 .23495 Mdot
.10832 .23485 Mdot
.10837 .23475 Mdot
.10842 .23465 Mdot
.10847 .23455 Mdot
.10852 .23445 Mdot
.10856 .23435 Mdot
.10861 .23425 Mdot
.10866 .23415 Mdot
.10871 .23405 Mdot
.10875 .23395 Mdot
.1088 .23385 Mdot
.10885 .23375 Mdot
.1089 .23365 Mdot
.10894 .23355 Mdot
.10899 .23345 Mdot
.10904 .23335 Mdot
.10909 .23325 Mdot
.10913 .23315 Mdot
.10918 .23305 Mdot
.10923 .23295 Mdot
.10928 .23285 Mdot
.10932 .23275 Mdot
.10937 .23265 Mdot
.10942 .23255 Mdot
.10947 .23246 Mdot
.10952 .23236 Mdot
.10956 .23226 Mdot
.10961 .23216 Mdot
.10966 .23206 Mdot
.10971 .23196 Mdot
.10975 .23186 Mdot
.1098 .23177 Mdot
.10985 .23167 Mdot
.1099 .23157 Mdot
.10994 .23147 Mdot
.10999 .23137 Mdot
.11004 .23128 Mdot
.11009 .23118 Mdot
.11013 .23108 Mdot
.11018 .23098 Mdot
.11023 .23089 Mdot
.11028 .23079 Mdot
.11032 .23069 Mdot
.11037 .23059 Mdot
.11042 .2305 Mdot
.11047 .2304 Mdot
.11052 .2303 Mdot
.11056 .23021 Mdot
.11061 .23011 Mdot
.11066 .23001 Mdot
.11071 .22991 Mdot
.11075 .22982 Mdot
.1108 .22972 Mdot
.11085 .22963 Mdot
.1109 .22953 Mdot
.11094 .22943 Mdot
.11099 .22934 Mdot
.11104 .22924 Mdot
.11109 .22915 Mdot
.11113 .22905 Mdot
.11118 .22895 Mdot
.11123 .22886 Mdot
.11128 .22876 Mdot
.11132 .22867 Mdot
.11137 .22857 Mdot
.11142 .22848 Mdot
.11147 .22838 Mdot
.11152 .22829 Mdot
.11156 .22819 Mdot
.11161 .2281 Mdot
.11166 .228 Mdot
.11171 .22791 Mdot
.11175 .22781 Mdot
.1118 .22772 Mdot
.11185 .22762 Mdot
.1119 .22753 Mdot
.11194 .22743 Mdot
.11199 .22734 Mdot
.11204 .22724 Mdot
.11209 .22715 Mdot
.11213 .22706 Mdot
.11218 .22696 Mdot
.11223 .22687 Mdot
.11228 .22677 Mdot
.11232 .22668 Mdot
.11237 .22659 Mdot
.11242 .22649 Mdot
.11247 .2264 Mdot
.11251 .22631 Mdot
.11256 .22621 Mdot
.11261 .22612 Mdot
.11266 .22603 Mdot
.11271 .22593 Mdot
.11275 .22584 Mdot
.1128 .22575 Mdot
.11285 .22565 Mdot
.1129 .22556 Mdot
.11294 .22547 Mdot
.11299 .22538 Mdot
.11304 .22528 Mdot
.11309 .22519 Mdot
.11313 .2251 Mdot
.11318 .22501 Mdot
.11323 .22492 Mdot
.11328 .22482 Mdot
.11332 .22473 Mdot
.11337 .22464 Mdot
.11342 .22455 Mdot
.11347 .22446 Mdot
.11351 .22437 Mdot
.11356 .22427 Mdot
.11361 .22418 Mdot
.11366 .22409 Mdot
.11371 .224 Mdot
.11375 .22391 Mdot
.1138 .22382 Mdot
.11385 .22373 Mdot
.1139 .22364 Mdot
.11394 .22355 Mdot
.11399 .22346 Mdot
.11404 .22336 Mdot
.11409 .22327 Mdot
.11413 .22318 Mdot
.11418 .22309 Mdot
.11423 .223 Mdot
.11428 .22291 Mdot
.11432 .22282 Mdot
.11437 .22273 Mdot
.11442 .22264 Mdot
.11447 .22255 Mdot
.11451 .22246 Mdot
.11456 .22238 Mdot
.11461 .22229 Mdot
.11466 .2222 Mdot
.11471 .22211 Mdot
.11475 .22202 Mdot
.1148 .22193 Mdot
.11485 .22184 Mdot
.1149 .22175 Mdot
.11494 .22166 Mdot
.11499 .22157 Mdot
.11504 .22149 Mdot
.11509 .2214 Mdot
.11513 .22131 Mdot
.11518 .22122 Mdot
.11523 .22113 Mdot
.11528 .22104 Mdot
.11532 .22096 Mdot
.11537 .22087 Mdot
.11542 .22078 Mdot
.11547 .22069 Mdot
.11551 .22061 Mdot
.11556 .22052 Mdot
.11561 .22043 Mdot
.11566 .22034 Mdot
.11571 .22026 Mdot
.11575 .22017 Mdot
.1158 .22008 Mdot
.11585 .22 Mdot
.1159 .21991 Mdot
.11594 .21982 Mdot
.11599 .21974 Mdot
.11604 .21965 Mdot
.11609 .21956 Mdot
.11613 .21948 Mdot
.11618 .21939 Mdot
.11623 .2193 Mdot
.11628 .21922 Mdot
.11632 .21913 Mdot
.11637 .21905 Mdot
.11642 .21896 Mdot
.11647 .21888 Mdot
.11651 .21879 Mdot
.11656 .2187 Mdot
.11661 .21862 Mdot
.11666 .21853 Mdot
.1167 .21845 Mdot
.11675 .21836 Mdot
.1168 .21828 Mdot
.11685 .21819 Mdot
.1169 .21811 Mdot
.11694 .21803 Mdot
.11699 .21794 Mdot
.11704 .21786 Mdot
.11709 .21777 Mdot
.11713 .21769 Mdot
.11718 .2176 Mdot
.11723 .21752 Mdot
.11728 .21744 Mdot
.11732 .21735 Mdot
.11737 .21727 Mdot
.11742 .21719 Mdot
.11747 .2171 Mdot
.11751 .21702 Mdot
.11756 .21693 Mdot
.11761 .21685 Mdot
.11766 .21677 Mdot
.1177 .21669 Mdot
.11775 .2166 Mdot
.1178 .21652 Mdot
.11785 .21644 Mdot
.1179 .21635 Mdot
.11794 .21627 Mdot
.11799 .21619 Mdot
.11804 .21611 Mdot
.11809 .21602 Mdot
.11813 .21594 Mdot
.11818 .21586 Mdot
.11823 .21578 Mdot
.11828 .2157 Mdot
.11832 .21562 Mdot
.11837 .21553 Mdot
.11842 .21545 Mdot
.11847 .21537 Mdot
.11851 .21529 Mdot
.11856 .21521 Mdot
.11861 .21513 Mdot
.11866 .21505 Mdot
.1187 .21497 Mdot
.11875 .21488 Mdot
.1188 .2148 Mdot
.11885 .21472 Mdot
.1189 .21464 Mdot
.11894 .21456 Mdot
.11899 .21448 Mdot
.11904 .2144 Mdot
.11909 .21432 Mdot
.11913 .21424 Mdot
.11918 .21416 Mdot
.11923 .21408 Mdot
.11928 .214 Mdot
.11932 .21392 Mdot
.11937 .21385 Mdot
.11942 .21377 Mdot
.11947 .21369 Mdot
.11951 .21361 Mdot
.11956 .21353 Mdot
.11961 .21345 Mdot
.11966 .21337 Mdot
.1197 .21329 Mdot
.11975 .21322 Mdot
.1198 .21314 Mdot
.11985 .21306 Mdot
.1199 .21298 Mdot
.11994 .21291 Mdot
.11999 .21283 Mdot
.12004 .21275 Mdot
.12009 .21267 Mdot
.12013 .2126 Mdot
.12018 .21252 Mdot
.12023 .21244 Mdot
.12028 .21236 Mdot
.12032 .21229 Mdot
.12037 .21221 Mdot
.12042 .21213 Mdot
.12047 .21206 Mdot
.12051 .21198 Mdot
.12056 .21191 Mdot
.12061 .21183 Mdot
.12066 .21175 Mdot
.1207 .21168 Mdot
.12075 .2116 Mdot
.1208 .21153 Mdot
.12085 .21145 Mdot
.1209 .21138 Mdot
.12094 .2113 Mdot
.12099 .21123 Mdot
.12104 .21115 Mdot
.12109 .21108 Mdot
.12113 .211 Mdot
.12118 .21093 Mdot
.12123 .21085 Mdot
.12128 .21078 Mdot
.12132 .2107 Mdot
.12137 .21063 Mdot
.12142 .21055 Mdot
.12147 .21048 Mdot
.12151 .21041 Mdot
.12156 .21033 Mdot
.12161 .21026 Mdot
.12166 .21019 Mdot
.1217 .21011 Mdot
.12175 .21004 Mdot
.1218 .20997 Mdot
.12185 .20989 Mdot
.12189 .20982 Mdot
.12194 .20975 Mdot
.12199 .20967 Mdot
.12204 .2096 Mdot
.12209 .20953 Mdot
.12213 .20946 Mdot
.12218 .20938 Mdot
.12223 .20931 Mdot
.12228 .20924 Mdot
.12232 .20917 Mdot
.12237 .2091 Mdot
.12242 .20903 Mdot
.12247 .20895 Mdot
.12251 .20888 Mdot
.12256 .20881 Mdot
.12261 .20874 Mdot
.12266 .20867 Mdot
.1227 .2086 Mdot
.12275 .20853 Mdot
.1228 .20846 Mdot
.12285 .20839 Mdot
.12289 .20831 Mdot
.12294 .20824 Mdot
.12299 .20817 Mdot
.12304 .2081 Mdot
.12309 .20803 Mdot
.12313 .20796 Mdot
.12318 .20789 Mdot
.12323 .20782 Mdot
.12328 .20775 Mdot
.12332 .20768 Mdot
.12337 .20762 Mdot
.12342 .20755 Mdot
.12347 .20748 Mdot
.12351 .20741 Mdot
.12356 .20734 Mdot
.12361 .20727 Mdot
.12366 .2072 Mdot
.1237 .20713 Mdot
.12375 .20706 Mdot
.1238 .207 Mdot
.12385 .20693 Mdot
.12389 .20686 Mdot
.12394 .20679 Mdot
.12399 .20672 Mdot
.12404 .20666 Mdot
.12409 .20659 Mdot
.12413 .20652 Mdot
.12418 .20645 Mdot
.12423 .20639 Mdot
.12428 .20632 Mdot
.12432 .20625 Mdot
.12437 .20618 Mdot
.12442 .20612 Mdot
.12447 .20605 Mdot
.12451 .20598 Mdot
.12456 .20592 Mdot
.12461 .20585 Mdot
.12466 .20579 Mdot
.1247 .20572 Mdot
.12475 .20565 Mdot
.1248 .20559 Mdot
.12485 .20552 Mdot
.12489 .20546 Mdot
.12494 .20539 Mdot
.12499 .20533 Mdot
.12504 .20526 Mdot
.12509 .2052 Mdot
.12513 .20513 Mdot
.12518 .20507 Mdot
.12523 .205 Mdot
.12528 .20494 Mdot
.12532 .20487 Mdot
.12537 .20481 Mdot
.12542 .20475 Mdot
.12547 .20468 Mdot
.12551 .20462 Mdot
.12556 .20455 Mdot
.12561 .20449 Mdot
.12566 .20443 Mdot
.1257 .20436 Mdot
.12575 .2043 Mdot
.1258 .20424 Mdot
.12585 .20417 Mdot
.12589 .20411 Mdot
.12594 .20405 Mdot
.12599 .20399 Mdot
.12604 .20392 Mdot
.12609 .20386 Mdot
.12613 .2038 Mdot
.12618 .20374 Mdot
.12623 .20368 Mdot
.12628 .20361 Mdot
.12632 .20355 Mdot
.12637 .20349 Mdot
.12642 .20343 Mdot
.12647 .20337 Mdot
.12651 .20331 Mdot
.12656 .20324 Mdot
.12661 .20318 Mdot
.12666 .20312 Mdot
.1267 .20306 Mdot
.12675 .203 Mdot
.1268 .20294 Mdot
.12685 .20288 Mdot
.12689 .20282 Mdot
.12694 .20276 Mdot
.12699 .2027 Mdot
.12704 .20264 Mdot
.12708 .20258 Mdot
.12713 .20252 Mdot
.12718 .20246 Mdot
.12723 .2024 Mdot
.12728 .20234 Mdot
.12732 .20228 Mdot
.12737 .20222 Mdot
.12742 .20217 Mdot
.12747 .20211 Mdot
.12751 .20205 Mdot
.12756 .20199 Mdot
.12761 .20193 Mdot
.12766 .20187 Mdot
.1277 .20182 Mdot
.12775 .20176 Mdot
.1278 .2017 Mdot
.12785 .20164 Mdot
.12789 .20158 Mdot
.12794 .20153 Mdot
.12799 .20147 Mdot
.12804 .20141 Mdot
.12808 .20136 Mdot
.12813 .2013 Mdot
.12818 .20124 Mdot
.12823 .20119 Mdot
.12828 .20113 Mdot
.12832 .20107 Mdot
.12837 .20102 Mdot
.12842 .20096 Mdot
.12847 .2009 Mdot
.12851 .20085 Mdot
.12856 .20079 Mdot
.12861 .20074 Mdot
.12866 .20068 Mdot
.1287 .20063 Mdot
.12875 .20057 Mdot
.1288 .20052 Mdot
.12885 .20046 Mdot
.12889 .20041 Mdot
.12894 .20035 Mdot
.12899 .2003 Mdot
.12904 .20024 Mdot
.12908 .20019 Mdot
.12913 .20014 Mdot
.12918 .20008 Mdot
.12923 .20003 Mdot
.12928 .19998 Mdot
.12932 .19992 Mdot
.12937 .19987 Mdot
.12942 .19982 Mdot
.12947 .19976 Mdot
.12951 .19971 Mdot
.12956 .19966 Mdot
.12961 .1996 Mdot
.12966 .19955 Mdot
.1297 .1995 Mdot
.12975 .19945 Mdot
.1298 .1994 Mdot
.12985 .19934 Mdot
.12989 .19929 Mdot
.12994 .19924 Mdot
.12999 .19919 Mdot
.13004 .19914 Mdot
.13008 .19909 Mdot
.13013 .19904 Mdot
.13018 .19899 Mdot
.13023 .19894 Mdot
.13028 .19888 Mdot
.13032 .19883 Mdot
.13037 .19878 Mdot
.13042 .19873 Mdot
.13047 .19868 Mdot
.13051 .19863 Mdot
.13056 .19858 Mdot
.13061 .19854 Mdot
.13066 .19849 Mdot
.1307 .19844 Mdot
.13075 .19839 Mdot
.1308 .19834 Mdot
.13085 .19829 Mdot
.13089 .19824 Mdot
.13094 .19819 Mdot
.13099 .19814 Mdot
.13104 .1981 Mdot
.13108 .19805 Mdot
.13113 .198 Mdot
.13118 .19795 Mdot
.13123 .1979 Mdot
.13127 .19786 Mdot
.13132 .19781 Mdot
.13137 .19776 Mdot
.13142 .19772 Mdot
.13147 .19767 Mdot
.13151 .19762 Mdot
.13156 .19758 Mdot
.13161 .19753 Mdot
.13166 .19748 Mdot
.1317 .19744 Mdot
.13175 .19739 Mdot
.1318 .19734 Mdot
.13185 .1973 Mdot
.13189 .19725 Mdot
.13194 .19721 Mdot
.13199 .19716 Mdot
.13204 .19712 Mdot
.13208 .19707 Mdot
.13213 .19703 Mdot
.13218 .19698 Mdot
.13223 .19694 Mdot
.13227 .19689 Mdot
.13232 .19685 Mdot
.13237 .1968 Mdot
.13242 .19676 Mdot
.13247 .19672 Mdot
.13251 .19667 Mdot
.13256 .19663 Mdot
.13261 .19659 Mdot
.13266 .19654 Mdot
.1327 .1965 Mdot
.13275 .19646 Mdot
.1328 .19641 Mdot
.13285 .19637 Mdot
.13289 .19633 Mdot
.13294 .19629 Mdot
.13299 .19624 Mdot
.13304 .1962 Mdot
.13308 .19616 Mdot
.13313 .19612 Mdot
.13318 .19608 Mdot
.13323 .19603 Mdot
.13327 .19599 Mdot
.13332 .19595 Mdot
.13337 .19591 Mdot
.13342 .19587 Mdot
.13347 .19583 Mdot
.13351 .19579 Mdot
.13356 .19575 Mdot
.13361 .19571 Mdot
.13366 .19567 Mdot
.1337 .19563 Mdot
.13375 .19559 Mdot
.1338 .19555 Mdot
.13385 .19551 Mdot
.13389 .19547 Mdot
.13394 .19543 Mdot
.13399 .19539 Mdot
.13404 .19535 Mdot
.13408 .19531 Mdot
.13413 .19527 Mdot
.13418 .19523 Mdot
.13423 .19519 Mdot
.13427 .19516 Mdot
.13432 .19512 Mdot
.13437 .19508 Mdot
.13442 .19504 Mdot
.13447 .195 Mdot
.13451 .19497 Mdot
.13456 .19493 Mdot
.13461 .19489 Mdot
.13466 .19485 Mdot
.1347 .19482 Mdot
.13475 .19478 Mdot
.1348 .19474 Mdot
.13485 .19471 Mdot
.13489 .19467 Mdot
.13494 .19463 Mdot
.13499 .1946 Mdot
.13504 .19456 Mdot
.13508 .19453 Mdot
.13513 .19449 Mdot
.13518 .19445 Mdot
.13523 .19442 Mdot
.13527 .19438 Mdot
.13532 .19435 Mdot
.13537 .19431 Mdot
.13542 .19428 Mdot
.13547 .19424 Mdot
.13551 .19421 Mdot
.13556 .19417 Mdot
.13561 .19414 Mdot
.13566 .1941 Mdot
.1357 .19407 Mdot
.13575 .19404 Mdot
.1358 .194 Mdot
.13585 .19397 Mdot
.13589 .19394 Mdot
.13594 .1939 Mdot
.13599 .19387 Mdot
.13604 .19383 Mdot
.13608 .1938 Mdot
.13613 .19377 Mdot
.13618 .19374 Mdot
.13623 .1937 Mdot
.13627 .19367 Mdot
.13632 .19364 Mdot
.13637 .19361 Mdot
.13642 .19357 Mdot
.13646 .19354 Mdot
.13651 .19351 Mdot
.13656 .19348 Mdot
.13661 .19345 Mdot
.13666 .19342 Mdot
.1367 .19338 Mdot
.13675 .19335 Mdot
.1368 .19332 Mdot
.13685 .19329 Mdot
.13689 .19326 Mdot
.13694 .19323 Mdot
.13699 .1932 Mdot
.13704 .19317 Mdot
.13708 .19314 Mdot
.13713 .19311 Mdot
.13718 .19308 Mdot
.13723 .19305 Mdot
.13727 .19302 Mdot
.13732 .19299 Mdot
.13737 .19296 Mdot
.13742 .19294 Mdot
.13746 .19291 Mdot
.13751 .19288 Mdot
.13756 .19285 Mdot
.13761 .19282 Mdot
.13766 .19279 Mdot
.1377 .19277 Mdot
.13775 .19274 Mdot
.1378 .19271 Mdot
.13785 .19268 Mdot
.13789 .19266 Mdot
.13794 .19263 Mdot
.13799 .1926 Mdot
.13804 .19257 Mdot
.13808 .19255 Mdot
.13813 .19252 Mdot
.13818 .19249 Mdot
.13823 .19247 Mdot
.13827 .19244 Mdot
.13832 .19242 Mdot
.13837 .19239 Mdot
.13842 .19236 Mdot
.13846 .19234 Mdot
.13851 .19231 Mdot
.13856 .19229 Mdot
.13861 .19226 Mdot
.13866 .19224 Mdot
.1387 .19221 Mdot
.13875 .19219 Mdot
.1388 .19217 Mdot
.13885 .19214 Mdot
.13889 .19212 Mdot
.13894 .19209 Mdot
.13899 .19207 Mdot
.13904 .19205 Mdot
.13908 .19202 Mdot
.13913 .192 Mdot
.13918 .19198 Mdot
.13923 .19195 Mdot
.13927 .19193 Mdot
.13932 .19191 Mdot
.13937 .19188 Mdot
.13942 .19186 Mdot
.13946 .19184 Mdot
.13951 .19182 Mdot
.13956 .1918 Mdot
.13961 .19177 Mdot
.13966 .19175 Mdot
.1397 .19173 Mdot
.13975 .19171 Mdot
.1398 .19169 Mdot
.13985 .19167 Mdot
.13989 .19165 Mdot
.13994 .19163 Mdot
.13999 .19161 Mdot
.14004 .19158 Mdot
.14008 .19156 Mdot
.14013 .19154 Mdot
.14018 .19152 Mdot
.14023 .1915 Mdot
.14027 .19148 Mdot
.14032 .19147 Mdot
.14037 .19145 Mdot
.14042 .19143 Mdot
.14046 .19141 Mdot
.14051 .19139 Mdot
.14056 .19137 Mdot
.14061 .19135 Mdot
.14065 .19133 Mdot
.1407 .19132 Mdot
.14075 .1913 Mdot
.1408 .19128 Mdot
.14085 .19126 Mdot
.14089 .19124 Mdot
.14094 .19123 Mdot
.14099 .19121 Mdot
.14104 .19119 Mdot
.14108 .19117 Mdot
.14113 .19116 Mdot
.14118 .19114 Mdot
.14123 .19112 Mdot
.14127 .19111 Mdot
.14132 .19109 Mdot
.14137 .19107 Mdot
.14142 .19106 Mdot
.14146 .19104 Mdot
.14151 .19103 Mdot
.14156 .19101 Mdot
.14161 .191 Mdot
.14165 .19098 Mdot
.1417 .19097 Mdot
.14175 .19095 Mdot
.1418 .19094 Mdot
.14185 .19092 Mdot
.14189 .19091 Mdot
.14194 .19089 Mdot
.14199 .19088 Mdot
.14204 .19087 Mdot
.14208 .19085 Mdot
.14213 .19084 Mdot
.14218 .19082 Mdot
.14223 .19081 Mdot
.14227 .1908 Mdot
.14232 .19078 Mdot
.14237 .19077 Mdot
.14242 .19076 Mdot
.14246 .19075 Mdot
.14251 .19073 Mdot
.14256 .19072 Mdot
.14261 .19071 Mdot
.14265 .1907 Mdot
.1427 .19069 Mdot
.14275 .19067 Mdot
.1428 .19066 Mdot
.14285 .19065 Mdot
.14289 .19064 Mdot
.14294 .19063 Mdot
.14299 .19062 Mdot
.14304 .19061 Mdot
.14308 .1906 Mdot
.14313 .19059 Mdot
.14318 .19058 Mdot
.14323 .19057 Mdot
.14327 .19056 Mdot
.14332 .19055 Mdot
.14337 .19054 Mdot
.14342 .19053 Mdot
.14346 .19052 Mdot
.14351 .19051 Mdot
.14356 .1905 Mdot
.14361 .19049 Mdot
.14365 .19049 Mdot
.1437 .19048 Mdot
.14375 .19047 Mdot
.1438 .19046 Mdot
.14385 .19045 Mdot
.14389 .19045 Mdot
.14394 .19044 Mdot
.14399 .19043 Mdot
.14404 .19042 Mdot
.14408 .19042 Mdot
.14413 .19041 Mdot
.14418 .1904 Mdot
.14423 .1904 Mdot
.14427 .19039 Mdot
.14432 .19039 Mdot
.14437 .19038 Mdot
.14442 .19037 Mdot
.14446 .19037 Mdot
.14451 .19036 Mdot
.14456 .19036 Mdot
.14461 .19035 Mdot
.14465 .19035 Mdot
.1447 .19034 Mdot
.14475 .19034 Mdot
.1448 .19033 Mdot
.14485 .19033 Mdot
.14489 .19032 Mdot
.14494 .19032 Mdot
.14499 .19031 Mdot
.14504 .19031 Mdot
.14508 .19031 Mdot
.14513 .1903 Mdot
.14518 .1903 Mdot
.14523 .1903 Mdot
.14527 .19029 Mdot
.14532 .19029 Mdot
.14537 .19029 Mdot
.14542 .19029 Mdot
.14546 .19028 Mdot
.14551 .19028 Mdot
.14556 .19028 Mdot
.14561 .19028 Mdot
.14565 .19028 Mdot
.1457 .19027 Mdot
.14575 .19027 Mdot
.1458 .19027 Mdot
.14584 .19027 Mdot
.14589 .19027 Mdot
.14594 .19027 Mdot
.14599 .19027 Mdot
.14604 .19027 Mdot
.14608 .19026 Mdot
.14613 .19026 Mdot
.14618 .19026 Mdot
.14623 .19026 Mdot
.14627 .19026 Mdot
.14632 .19026 Mdot
.14637 .19026 Mdot
.14642 .19027 Mdot
.14646 .19027 Mdot
.14651 .19027 Mdot
.14656 .19027 Mdot
.14661 .19027 Mdot
.14665 .19027 Mdot
.1467 .19027 Mdot
.14675 .19027 Mdot
.1468 .19028 Mdot
.14684 .19028 Mdot
.14689 .19028 Mdot
.14694 .19028 Mdot
.14699 .19028 Mdot
.14704 .19029 Mdot
.14708 .19029 Mdot
.14713 .19029 Mdot
.14718 .1903 Mdot
.14723 .1903 Mdot
.14727 .1903 Mdot
.14732 .19031 Mdot
.14737 .19031 Mdot
.14742 .19031 Mdot
.14746 .19032 Mdot
.14751 .19032 Mdot
.14756 .19033 Mdot
.14761 .19033 Mdot
.14765 .19034 Mdot
.1477 .19034 Mdot
.14775 .19035 Mdot
.1478 .19035 Mdot
.14784 .19036 Mdot
.14789 .19036 Mdot
.14794 .19037 Mdot
.14799 .19038 Mdot
.14804 .19038 Mdot
.14808 .19039 Mdot
.14813 .19039 Mdot
.14818 .1904 Mdot
.14823 .19041 Mdot
.14827 .19041 Mdot
.14832 .19042 Mdot
.14837 .19043 Mdot
.14842 .19044 Mdot
.14846 .19044 Mdot
.14851 .19045 Mdot
.14856 .19046 Mdot
.14861 .19047 Mdot
.14865 .19048 Mdot
.1487 .19049 Mdot
.14875 .19049 Mdot
.1488 .1905 Mdot
.14884 .19051 Mdot
.14889 .19052 Mdot
.14894 .19053 Mdot
.14899 .19054 Mdot
.14904 .19055 Mdot
.14908 .19056 Mdot
.14913 .19057 Mdot
.14918 .19058 Mdot
.14923 .19059 Mdot
.14927 .1906 Mdot
.14932 .19061 Mdot
.14937 .19062 Mdot
.14942 .19063 Mdot
.14946 .19064 Mdot
.14951 .19066 Mdot
.14956 .19067 Mdot
.14961 .19068 Mdot
.14965 .19069 Mdot
.1497 .1907 Mdot
.14975 .19072 Mdot
.1498 .19073 Mdot
.14984 .19074 Mdot
.14989 .19075 Mdot
.14994 .19077 Mdot
.14999 .19078 Mdot
.15003 .19079 Mdot
.15008 .1908 Mdot
.15013 .19082 Mdot
.15018 .19083 Mdot
.15023 .19085 Mdot
.15027 .19086 Mdot
.15032 .19087 Mdot
.15037 .19089 Mdot
.15042 .1909 Mdot
.15046 .19092 Mdot
.15051 .19093 Mdot
.15056 .19095 Mdot
.15061 .19096 Mdot
.15065 .19098 Mdot
.1507 .19099 Mdot
.15075 .19101 Mdot
.1508 .19102 Mdot
.15084 .19104 Mdot
.15089 .19105 Mdot
.15094 .19107 Mdot
.15099 .19109 Mdot
.15103 .1911 Mdot
.15108 .19112 Mdot
.15113 .19113 Mdot
.15118 .19115 Mdot
.15123 .19117 Mdot
.15127 .19119 Mdot
.15132 .1912 Mdot
.15137 .19122 Mdot
.15142 .19124 Mdot
.15146 .19126 Mdot
.15151 .19127 Mdot
.15156 .19129 Mdot
.15161 .19131 Mdot
.15165 .19133 Mdot
.1517 .19135 Mdot
.15175 .19137 Mdot
.1518 .19138 Mdot
.15184 .1914 Mdot
.15189 .19142 Mdot
.15194 .19144 Mdot
.15199 .19146 Mdot
.15203 .19148 Mdot
.15208 .1915 Mdot
.15213 .19152 Mdot
.15218 .19154 Mdot
.15223 .19156 Mdot
.15227 .19158 Mdot
.15232 .1916 Mdot
.15237 .19162 Mdot
.15242 .19165 Mdot
.15246 .19167 Mdot
.15251 .19169 Mdot
.15256 .19171 Mdot
.15261 .19173 Mdot
.15265 .19175 Mdot
.1527 .19177 Mdot
.15275 .1918 Mdot
.1528 .19182 Mdot
.15284 .19184 Mdot
.15289 .19186 Mdot
.15294 .19189 Mdot
.15299 .19191 Mdot
.15303 .19193 Mdot
.15308 .19196 Mdot
.15313 .19198 Mdot
.15318 .192 Mdot
.15323 .19203 Mdot
.15327 .19205 Mdot
.15332 .19208 Mdot
.15337 .1921 Mdot
.15342 .19213 Mdot
.15346 .19215 Mdot
.15351 .19217 Mdot
.15356 .1922 Mdot
.15361 .19222 Mdot
.15365 .19225 Mdot
.1537 .19228 Mdot
.15375 .1923 Mdot
.1538 .19233 Mdot
.15384 .19235 Mdot
.15389 .19238 Mdot
.15394 .1924 Mdot
.15399 .19243 Mdot
.15403 .19246 Mdot
.15408 .19248 Mdot
.15413 .19251 Mdot
.15418 .19254 Mdot
.15423 .19257 Mdot
.15427 .19259 Mdot
.15432 .19262 Mdot
.15437 .19265 Mdot
.15442 .19268 Mdot
.15446 .1927 Mdot
.15451 .19273 Mdot
.15456 .19276 Mdot
.15461 .19279 Mdot
.15465 .19282 Mdot
.1547 .19285 Mdot
.15475 .19287 Mdot
.1548 .1929 Mdot
.15484 .19293 Mdot
.15489 .19296 Mdot
.15494 .19299 Mdot
.15499 .19302 Mdot
.15503 .19305 Mdot
.15508 .19308 Mdot
.15513 .19311 Mdot
.15518 .19314 Mdot
.15522 .19317 Mdot
.15527 .1932 Mdot
.15532 .19323 Mdot
.15537 .19326 Mdot
.15542 .1933 Mdot
.15546 .19333 Mdot
.15551 .19336 Mdot
.15556 .19339 Mdot
.15561 .19342 Mdot
.15565 .19345 Mdot
.1557 .19349 Mdot
.15575 .19352 Mdot
.1558 .19355 Mdot
.15584 .19358 Mdot
.15589 .19362 Mdot
.15594 .19365 Mdot
.15599 .19368 Mdot
.15603 .19372 Mdot
.15608 .19375 Mdot
.15613 .19378 Mdot
.15618 .19382 Mdot
.15622 .19385 Mdot
.15627 .19388 Mdot
.15632 .19392 Mdot
.15637 .19395 Mdot
.15642 .19399 Mdot
.15646 .19402 Mdot
.15651 .19406 Mdot
.15656 .19409 Mdot
.15661 .19413 Mdot
.15665 .19416 Mdot
.1567 .1942 Mdot
.15675 .19423 Mdot
.1568 .19427 Mdot
.15684 .19431 Mdot
.15689 .19434 Mdot
.15694 .19438 Mdot
.15699 .19441 Mdot
.15703 .19445 Mdot
.15708 .19449 Mdot
.15713 .19453 Mdot
.15718 .19456 Mdot
.15722 .1946 Mdot
.15727 .19464 Mdot
.15732 .19467 Mdot
.15737 .19471 Mdot
.15742 .19475 Mdot
.15746 .19479 Mdot
.15751 .19483 Mdot
.15756 .19487 Mdot
.15761 .1949 Mdot
.15765 .19494 Mdot
.1577 .19498 Mdot
.15775 .19502 Mdot
.1578 .19506 Mdot
.15784 .1951 Mdot
.15789 .19514 Mdot
.15794 .19518 Mdot
.15799 .19522 Mdot
.15803 .19526 Mdot
.15808 .1953 Mdot
.15813 .19534 Mdot
.15818 .19538 Mdot
.15822 .19542 Mdot
.15827 .19546 Mdot
.15832 .19551 Mdot
.15837 .19555 Mdot
.15842 .19559 Mdot
.15846 .19563 Mdot
.15851 .19567 Mdot
.15856 .19571 Mdot
.15861 .19576 Mdot
.15865 .1958 Mdot
.1587 .19584 Mdot
.15875 .19588 Mdot
.1588 .19593 Mdot
.15884 .19597 Mdot
.15889 .19601 Mdot
.15894 .19606 Mdot
.15899 .1961 Mdot
.15903 .19615 Mdot
.15908 .19619 Mdot
.15913 .19623 Mdot
.15918 .19628 Mdot
.15922 .19632 Mdot
.15927 .19637 Mdot
.15932 .19641 Mdot
.15937 .19646 Mdot
.15942 .1965 Mdot
.15946 .19655 Mdot
.15951 .19659 Mdot
.15956 .19664 Mdot
.15961 .19668 Mdot
.15965 .19673 Mdot
.1597 .19677 Mdot
.15975 .19682 Mdot
.1598 .19687 Mdot
.15984 .19691 Mdot
.15989 .19696 Mdot
.15994 .19701 Mdot
.15999 .19705 Mdot
.16003 .1971 Mdot
.16008 .19715 Mdot
.16013 .1972 Mdot
.16018 .19724 Mdot
.16022 .19729 Mdot
.16027 .19734 Mdot
.16032 .19739 Mdot
.16037 .19743 Mdot
.16041 .19748 Mdot
.16046 .19753 Mdot
.16051 .19758 Mdot
.16056 .19763 Mdot
.16061 .19768 Mdot
.16065 .19773 Mdot
.1607 .19778 Mdot
.16075 .19783 Mdot
.1608 .19788 Mdot
.16084 .19793 Mdot
.16089 .19798 Mdot
.16094 .19803 Mdot
.16099 .19808 Mdot
.16103 .19813 Mdot
.16108 .19818 Mdot
.16113 .19823 Mdot
.16118 .19828 Mdot
.16122 .19833 Mdot
.16127 .19838 Mdot
.16132 .19843 Mdot
.16137 .19848 Mdot
.16141 .19853 Mdot
.16146 .19859 Mdot
.16151 .19864 Mdot
.16156 .19869 Mdot
.16161 .19874 Mdot
.16165 .19879 Mdot
.1617 .19885 Mdot
.16175 .1989 Mdot
.1618 .19895 Mdot
.16184 .19901 Mdot
.16189 .19906 Mdot
.16194 .19911 Mdot
.16199 .19917 Mdot
.16203 .19922 Mdot
.16208 .19927 Mdot
.16213 .19933 Mdot
.16218 .19938 Mdot
.16222 .19943 Mdot
.16227 .19949 Mdot
.16232 .19954 Mdot
.16237 .1996 Mdot
.16241 .19965 Mdot
.16246 .19971 Mdot
.16251 .19976 Mdot
.16256 .19982 Mdot
.16261 .19987 Mdot
.16265 .19993 Mdot
.1627 .19998 Mdot
.16275 .20004 Mdot
.1628 .2001 Mdot
.16284 .20015 Mdot
.16289 .20021 Mdot
.16294 .20027 Mdot
.16299 .20032 Mdot
.16303 .20038 Mdot
.16308 .20044 Mdot
.16313 .20049 Mdot
.16318 .20055 Mdot
.16322 .20061 Mdot
.16327 .20066 Mdot
.16332 .20072 Mdot
.16337 .20078 Mdot
.16341 .20084 Mdot
.16346 .20089 Mdot
.16351 .20095 Mdot
.16356 .20101 Mdot
.16361 .20107 Mdot
.16365 .20113 Mdot
.1637 .20119 Mdot
.16375 .20125 Mdot
.1638 .2013 Mdot
.16384 .20136 Mdot
.16389 .20142 Mdot
.16394 .20148 Mdot
.16399 .20154 Mdot
.16403 .2016 Mdot
.16408 .20166 Mdot
.16413 .20172 Mdot
.16418 .20178 Mdot
.16422 .20184 Mdot
.16427 .2019 Mdot
.16432 .20196 Mdot
.16437 .20202 Mdot
.16441 .20209 Mdot
.16446 .20215 Mdot
.16451 .20221 Mdot
.16456 .20227 Mdot
.1646 .20233 Mdot
.16465 .20239 Mdot
.1647 .20245 Mdot
.16475 .20252 Mdot
.1648 .20258 Mdot
.16484 .20264 Mdot
.16489 .2027 Mdot
.16494 .20277 Mdot
.16499 .20283 Mdot
.16503 .20289 Mdot
.16508 .20296 Mdot
.16513 .20302 Mdot
.16518 .20308 Mdot
.16522 .20315 Mdot
.16527 .20321 Mdot
.16532 .20327 Mdot
.16537 .20334 Mdot
.16541 .2034 Mdot
.16546 .20347 Mdot
.16551 .20353 Mdot
.16556 .2036 Mdot
.1656 .20366 Mdot
.16565 .20372 Mdot
.1657 .20379 Mdot
.16575 .20386 Mdot
.1658 .20392 Mdot
.16584 .20399 Mdot
.16589 .20405 Mdot
.16594 .20412 Mdot
.16599 .20418 Mdot
.16603 .20425 Mdot
.16608 .20432 Mdot
.16613 .20438 Mdot
.16618 .20445 Mdot
.16622 .20452 Mdot
.16627 .20458 Mdot
.16632 .20465 Mdot
.16637 .20472 Mdot
.16641 .20478 Mdot
.16646 .20485 Mdot
.16651 .20492 Mdot
.16656 .20499 Mdot
.1666 .20505 Mdot
.16665 .20512 Mdot
.1667 .20519 Mdot
.16675 .20526 Mdot
.1668 .20533 Mdot
.16684 .2054 Mdot
.16689 .20546 Mdot
.16694 .20553 Mdot
.16699 .2056 Mdot
.16703 .20567 Mdot
.16708 .20574 Mdot
.16713 .20581 Mdot
.16718 .20588 Mdot
.16722 .20595 Mdot
.16727 .20602 Mdot
.16732 .20609 Mdot
.16737 .20616 Mdot
.16741 .20623 Mdot
.16746 .2063 Mdot
.16751 .20637 Mdot
.16756 .20644 Mdot
.1676 .20651 Mdot
.16765 .20659 Mdot
.1677 .20666 Mdot
.16775 .20673 Mdot
.1678 .2068 Mdot
.16784 .20687 Mdot
.16789 .20694 Mdot
.16794 .20702 Mdot
.16799 .20709 Mdot
.16803 .20716 Mdot
.16808 .20723 Mdot
.16813 .20731 Mdot
.16818 .20738 Mdot
.16822 .20745 Mdot
.16827 .20752 Mdot
.16832 .2076 Mdot
.16837 .20767 Mdot
.16841 .20774 Mdot
.16846 .20782 Mdot
.16851 .20789 Mdot
.16856 .20797 Mdot
.1686 .20804 Mdot
.16865 .20811 Mdot
.1687 .20819 Mdot
.16875 .20826 Mdot
.1688 .20834 Mdot
.16884 .20841 Mdot
.16889 .20849 Mdot
.16894 .20856 Mdot
.16899 .20864 Mdot
.16903 .20871 Mdot
.16908 .20879 Mdot
.16913 .20886 Mdot
.16918 .20894 Mdot
.16922 .20902 Mdot
.16927 .20909 Mdot
.16932 .20917 Mdot
.16937 .20925 Mdot
.16941 .20932 Mdot
.16946 .2094 Mdot
.16951 .20948 Mdot
.16956 .20955 Mdot
.1696 .20963 Mdot
.16965 .20971 Mdot
.1697 .20978 Mdot
.16975 .20986 Mdot
.16979 .20994 Mdot
.16984 .21002 Mdot
.16989 .2101 Mdot
.16994 .21017 Mdot
.16999 .21025 Mdot
.17003 .21033 Mdot
.17008 .21041 Mdot
.17013 .21049 Mdot
.17018 .21057 Mdot
.17022 .21065 Mdot
.17027 .21073 Mdot
.17032 .21081 Mdot
.17037 .21089 Mdot
.17041 .21096 Mdot
.17046 .21104 Mdot
.17051 .21112 Mdot
.17056 .2112 Mdot
.1706 .21128 Mdot
.17065 .21136 Mdot
.1707 .21145 Mdot
.17075 .21153 Mdot
.17079 .21161 Mdot
.17084 .21169 Mdot
.17089 .21177 Mdot
.17094 .21185 Mdot
.17099 .21193 Mdot
.17103 .21201 Mdot
.17108 .21209 Mdot
.17113 .21218 Mdot
.17118 .21226 Mdot
.17122 .21234 Mdot
.17127 .21242 Mdot
.17132 .2125 Mdot
.17137 .21259 Mdot
.17141 .21267 Mdot
.17146 .21275 Mdot
.17151 .21283 Mdot
.17156 .21292 Mdot
.1716 .213 Mdot
.17165 .21308 Mdot
.1717 .21317 Mdot
.17175 .21325 Mdot
.17179 .21333 Mdot
.17184 .21342 Mdot
.17189 .2135 Mdot
.17194 .21359 Mdot
.17199 .21367 Mdot
.17203 .21376 Mdot
.17208 .21384 Mdot
.17213 .21393 Mdot
.17218 .21401 Mdot
.17222 .21409 Mdot
.17227 .21418 Mdot
.17232 .21427 Mdot
.17237 .21435 Mdot
.17241 .21444 Mdot
.17246 .21452 Mdot
.17251 .21461 Mdot
.17256 .21469 Mdot
.1726 .21478 Mdot
.17265 .21487 Mdot
.1727 .21495 Mdot
.17275 .21504 Mdot
.17279 .21513 Mdot
.17284 .21521 Mdot
.17289 .2153 Mdot
.17294 .21539 Mdot
.17299 .21547 Mdot
.17303 .21556 Mdot
.17308 .21565 Mdot
.17313 .21574 Mdot
.17318 .21582 Mdot
.17322 .21591 Mdot
.17327 .216 Mdot
.17332 .21609 Mdot
.17337 .21618 Mdot
.17341 .21627 Mdot
.17346 .21635 Mdot
.17351 .21644 Mdot
.17356 .21653 Mdot
.1736 .21662 Mdot
.17365 .21671 Mdot
.1737 .2168 Mdot
.17375 .21689 Mdot
.17379 .21698 Mdot
.17384 .21707 Mdot
.17389 .21716 Mdot
.17394 .21725 Mdot
.17398 .21734 Mdot
.17403 .21743 Mdot
.17408 .21752 Mdot
.17413 .21761 Mdot
.17418 .2177 Mdot
.17422 .21779 Mdot
.17427 .21788 Mdot
.17432 .21797 Mdot
.17437 .21806 Mdot
.17441 .21816 Mdot
.17446 .21825 Mdot
.17451 .21834 Mdot
.17456 .21843 Mdot
.1746 .21852 Mdot
.17465 .21861 Mdot
.1747 .21871 Mdot
.17475 .2188 Mdot
.17479 .21889 Mdot
.17484 .21898 Mdot
.17489 .21908 Mdot
.17494 .21917 Mdot
.17498 .21926 Mdot
.17503 .21936 Mdot
.17508 .21945 Mdot
.17513 .21954 Mdot
.17518 .21964 Mdot
.17522 .21973 Mdot
.17527 .21982 Mdot
.17532 .21992 Mdot
.17537 .22001 Mdot
.17541 .22011 Mdot
.17546 .2202 Mdot
.17551 .2203 Mdot
.17556 .22039 Mdot
.1756 .22048 Mdot
.17565 .22058 Mdot
.1757 .22068 Mdot
.17575 .22077 Mdot
.17579 .22087 Mdot
.17584 .22096 Mdot
.17589 .22106 Mdot
.17594 .22115 Mdot
.17598 .22125 Mdot
.17603 .22134 Mdot
.17608 .22144 Mdot
.17613 .22154 Mdot
.17618 .22163 Mdot
.17622 .22173 Mdot
.17627 .22183 Mdot
.17632 .22192 Mdot
.17637 .22202 Mdot
.17641 .22212 Mdot
.17646 .22221 Mdot
.17651 .22231 Mdot
.17656 .22241 Mdot
.1766 .22251 Mdot
.17665 .2226 Mdot
.1767 .2227 Mdot
.17675 .2228 Mdot
.17679 .2229 Mdot
.17684 .223 Mdot
.17689 .22309 Mdot
.17694 .22319 Mdot
.17698 .22329 Mdot
.17703 .22339 Mdot
.17708 .22349 Mdot
.17713 .22359 Mdot
.17718 .22369 Mdot
.17722 .22379 Mdot
.17727 .22388 Mdot
.17732 .22398 Mdot
.17737 .22408 Mdot
.17741 .22418 Mdot
.17746 .22428 Mdot
.17751 .22438 Mdot
.17756 .22448 Mdot
.1776 .22458 Mdot
.17765 .22468 Mdot
.1777 .22478 Mdot
.17775 .22488 Mdot
.17779 .22498 Mdot
.17784 .22508 Mdot
.17789 .22518 Mdot
.17794 .22529 Mdot
.17798 .22539 Mdot
.17803 .22549 Mdot
.17808 .22559 Mdot
.17813 .22569 Mdot
.17818 .22579 Mdot
.17822 .22589 Mdot
.17827 .22599 Mdot
.17832 .2261 Mdot
.17837 .2262 Mdot
.17841 .2263 Mdot
.17846 .2264 Mdot
.17851 .2265 Mdot
.17856 .22661 Mdot
.1786 .22671 Mdot
.17865 .22681 Mdot
.1787 .22692 Mdot
.17875 .22702 Mdot
.17879 .22712 Mdot
.17884 .22722 Mdot
.17889 .22733 Mdot
.17894 .22743 Mdot
.17898 .22754 Mdot
.17903 .22764 Mdot
.17908 .22774 Mdot
.17913 .22785 Mdot
.17917 .22795 Mdot
.17922 .22805 Mdot
.17927 .22816 Mdot
.17932 .22826 Mdot
.17937 .22837 Mdot
.17941 .22847 Mdot
.17946 .22858 Mdot
.17951 .22868 Mdot
.17956 .22879 Mdot
.1796 .22889 Mdot
.17965 .229 Mdot
.1797 .2291 Mdot
.17975 .22921 Mdot
.17979 .22931 Mdot
.17984 .22942 Mdot
.17989 .22953 Mdot
.17994 .22963 Mdot
.17998 .22974 Mdot
.18003 .22984 Mdot
.18008 .22995 Mdot
.18013 .23006 Mdot
.18017 .23016 Mdot
.18022 .23027 Mdot
.18027 .23038 Mdot
.18032 .23048 Mdot
.18037 .23059 Mdot
.18041 .2307 Mdot
.18046 .2308 Mdot
.18051 .23091 Mdot
.18056 .23102 Mdot
.1806 .23113 Mdot
.18065 .23123 Mdot
.1807 .23134 Mdot
.18075 .23145 Mdot
.18079 .23156 Mdot
.18084 .23167 Mdot
.18089 .23178 Mdot
.18094 .23188 Mdot
.18098 .23199 Mdot
.18103 .2321 Mdot
.18108 .23221 Mdot
.18113 .23232 Mdot
.18117 .23243 Mdot
.18122 .23254 Mdot
.18127 .23265 Mdot
.18132 .23276 Mdot
.18137 .23287 Mdot
.18141 .23298 Mdot
.18146 .23309 Mdot
.18151 .2332 Mdot
.18156 .23331 Mdot
.1816 .23342 Mdot
.18165 .23353 Mdot
.1817 .23364 Mdot
.18175 .23375 Mdot
.18179 .23386 Mdot
.18184 .23397 Mdot
.18189 .23408 Mdot
.18194 .23419 Mdot
.18198 .2343 Mdot
.18203 .23441 Mdot
.18208 .23452 Mdot
.18213 .23463 Mdot
.18217 .23475 Mdot
.18222 .23486 Mdot
.18227 .23497 Mdot
.18232 .23508 Mdot
.18237 .23519 Mdot
.18241 .23531 Mdot
.18246 .23542 Mdot
.18251 .23553 Mdot
.18256 .23564 Mdot
.1826 .23575 Mdot
.18265 .23587 Mdot
.1827 .23598 Mdot
.18275 .23609 Mdot
.18279 .23621 Mdot
.18284 .23632 Mdot
.18289 .23643 Mdot
.18294 .23654 Mdot
.18298 .23666 Mdot
.18303 .23677 Mdot
.18308 .23689 Mdot
.18313 .237 Mdot
.18317 .23711 Mdot
.18322 .23723 Mdot
.18327 .23734 Mdot
.18332 .23745 Mdot
.18336 .23757 Mdot
.18341 .23768 Mdot
.18346 .2378 Mdot
.18351 .23791 Mdot
.18356 .23803 Mdot
.1836 .23814 Mdot
.18365 .23826 Mdot
.1837 .23837 Mdot
.18375 .23849 Mdot
.18379 .2386 Mdot
.18384 .23872 Mdot
.18389 .23883 Mdot
.18394 .23895 Mdot
.18398 .23906 Mdot
.18403 .23918 Mdot
.18408 .23929 Mdot
.18413 .23941 Mdot
.18417 .23953 Mdot
.18422 .23964 Mdot
.18427 .23976 Mdot
.18432 .23987 Mdot
.18436 .23999 Mdot
.18441 .24011 Mdot
.18446 .24022 Mdot
.18451 .24034 Mdot
.18456 .24046 Mdot
.1846 .24057 Mdot
.18465 .24069 Mdot
.1847 .24081 Mdot
.18475 .24092 Mdot
.18479 .24104 Mdot
.18484 .24116 Mdot
.18489 .24128 Mdot
.18494 .24139 Mdot
.18498 .24151 Mdot
.18503 .24163 Mdot
.18508 .24175 Mdot
.18513 .24187 Mdot
.18517 .24198 Mdot
.18522 .2421 Mdot
.18527 .24222 Mdot
.18532 .24234 Mdot
.18536 .24246 Mdot
.18541 .24258 Mdot
.18546 .24269 Mdot
.18551 .24281 Mdot
.18556 .24293 Mdot
.1856 .24305 Mdot
.18565 .24317 Mdot
.1857 .24329 Mdot
.18575 .24341 Mdot
.18579 .24353 Mdot
.18584 .24365 Mdot
.18589 .24377 Mdot
.18594 .24389 Mdot
.18598 .24401 Mdot
.18603 .24413 Mdot
.18608 .24425 Mdot
.18613 .24437 Mdot
.18617 .24449 Mdot
.18622 .24461 Mdot
.18627 .24473 Mdot
.18632 .24485 Mdot
.18636 .24497 Mdot
.18641 .24509 Mdot
.18646 .24521 Mdot
.18651 .24534 Mdot
.18656 .24546 Mdot
.1866 .24558 Mdot
.18665 .2457 Mdot
.1867 .24582 Mdot
.18675 .24594 Mdot
.18679 .24606 Mdot
.18684 .24619 Mdot
.18689 .24631 Mdot
.18694 .24643 Mdot
.18698 .24655 Mdot
.18703 .24667 Mdot
.18708 .2468 Mdot
.18713 .24692 Mdot
.18717 .24704 Mdot
.18722 .24716 Mdot
.18727 .24729 Mdot
.18732 .24741 Mdot
.18736 .24753 Mdot
.18741 .24766 Mdot
.18746 .24778 Mdot
.18751 .2479 Mdot
.18756 .24802 Mdot
.1876 .24815 Mdot
.18765 .24827 Mdot
.1877 .24839 Mdot
.18775 .24852 Mdot
.18779 .24864 Mdot
.18784 .24877 Mdot
.18789 .24889 Mdot
.18794 .24901 Mdot
.18798 .24914 Mdot
.18803 .24926 Mdot
.18808 .24938 Mdot
.18813 .24951 Mdot
.18817 .24963 Mdot
.18822 .24976 Mdot
.18827 .24988 Mdot
.18832 .25001 Mdot
.18836 .25013 Mdot
.18841 .25026 Mdot
.18846 .25038 Mdot
.18851 .25051 Mdot
.18855 .25063 Mdot
.1886 .25076 Mdot
.18865 .25088 Mdot
.1887 .25101 Mdot
.18875 .25113 Mdot
.18879 .25126 Mdot
.18884 .25138 Mdot
.18889 .25151 Mdot
.18894 .25164 Mdot
.18898 .25176 Mdot
.18903 .25189 Mdot
.18908 .25201 Mdot
.18913 .25214 Mdot
.18917 .25227 Mdot
.18922 .25239 Mdot
.18927 .25252 Mdot
.18932 .25265 Mdot
.18936 .25277 Mdot
.18941 .2529 Mdot
.18946 .25303 Mdot
.18951 .25315 Mdot
.18955 .25328 Mdot
.1896 .25341 Mdot
.18965 .25354 Mdot
.1897 .25366 Mdot
.18975 .25379 Mdot
.18979 .25392 Mdot
.18984 .25404 Mdot
.18989 .25417 Mdot
.18994 .2543 Mdot
.18998 .25443 Mdot
.19003 .25455 Mdot
.19008 .25468 Mdot
.19013 .25481 Mdot
.19017 .25494 Mdot
.19022 .25507 Mdot
.19027 .25519 Mdot
.19032 .25532 Mdot
.19036 .25545 Mdot
.19041 .25558 Mdot
.19046 .25571 Mdot
.19051 .25584 Mdot
.19055 .25597 Mdot
.1906 .25609 Mdot
.19065 .25622 Mdot
.1907 .25635 Mdot
.19075 .25648 Mdot
.19079 .25661 Mdot
.19084 .25674 Mdot
.19089 .25687 Mdot
.19094 .257 Mdot
.19098 .25713 Mdot
.19103 .25726 Mdot
.19108 .25738 Mdot
.19113 .25751 Mdot
.19117 .25764 Mdot
.19122 .25777 Mdot
.19127 .2579 Mdot
.19132 .25803 Mdot
.19136 .25816 Mdot
.19141 .25829 Mdot
.19146 .25842 Mdot
.19151 .25855 Mdot
.19155 .25868 Mdot
.1916 .25881 Mdot
.19165 .25894 Mdot
.1917 .25907 Mdot
.19175 .2592 Mdot
.19179 .25933 Mdot
.19184 .25946 Mdot
.19189 .2596 Mdot
.19194 .25973 Mdot
.19198 .25986 Mdot
.19203 .25999 Mdot
.19208 .26012 Mdot
.19213 .26025 Mdot
.19217 .26038 Mdot
.19222 .26051 Mdot
.19227 .26064 Mdot
.19232 .26077 Mdot
.19236 .26091 Mdot
.19241 .26104 Mdot
.19246 .26117 Mdot
.19251 .2613 Mdot
.19255 .26143 Mdot
.1926 .26156 Mdot
.19265 .26169 Mdot
.1927 .26183 Mdot
.19275 .26196 Mdot
.19279 .26209 Mdot
.19284 .26222 Mdot
.19289 .26235 Mdot
.19294 .26249 Mdot
.19298 .26262 Mdot
.19303 .26275 Mdot
.19308 .26288 Mdot
.19313 .26301 Mdot
.19317 .26315 Mdot
.19322 .26328 Mdot
.19327 .26341 Mdot
.19332 .26354 Mdot
.19336 .26368 Mdot
.19341 .26381 Mdot
.19346 .26394 Mdot
.19351 .26408 Mdot
.19355 .26421 Mdot
.1936 .26434 Mdot
.19365 .26447 Mdot
.1937 .26461 Mdot
.19374 .26474 Mdot
.19379 .26487 Mdot
.19384 .26501 Mdot
.19389 .26514 Mdot
.19394 .26527 Mdot
.19398 .26541 Mdot
.19403 .26554 Mdot
.19408 .26567 Mdot
.19413 .26581 Mdot
.19417 .26594 Mdot
.19422 .26608 Mdot
.19427 .26621 Mdot
.19432 .26634 Mdot
.19436 .26648 Mdot
.19441 .26661 Mdot
.19446 .26675 Mdot
.19451 .26688 Mdot
.19455 .26702 Mdot
.1946 .26715 Mdot
.19465 .26729 Mdot
.1947 .26742 Mdot
.19474 .26755 Mdot
.19479 .26769 Mdot
.19484 .26782 Mdot
.19489 .26796 Mdot
.19494 .26809 Mdot
.19498 .26823 Mdot
.19503 .26836 Mdot
.19508 .2685 Mdot
.19513 .26863 Mdot
.19517 .26877 Mdot
.19522 .2689 Mdot
.19527 .26904 Mdot
.19532 .26918 Mdot
.19536 .26931 Mdot
.19541 .26945 Mdot
.19546 .26958 Mdot
.19551 .26972 Mdot
.19555 .26985 Mdot
.1956 .26999 Mdot
.19565 .27013 Mdot
.1957 .27026 Mdot
.19574 .2704 Mdot
.19579 .27053 Mdot
.19584 .27067 Mdot
.19589 .27081 Mdot
.19594 .27094 Mdot
.19598 .27108 Mdot
.19603 .27122 Mdot
.19608 .27135 Mdot
.19613 .27149 Mdot
.19617 .27163 Mdot
.19622 .27176 Mdot
.19627 .2719 Mdot
.19632 .27204 Mdot
.19636 .27217 Mdot
.19641 .27231 Mdot
.19646 .27245 Mdot
.19651 .27258 Mdot
.19655 .27272 Mdot
.1966 .27286 Mdot
.19665 .27299 Mdot
.1967 .27313 Mdot
.19674 .27327 Mdot
.19679 .27341 Mdot
.19684 .27354 Mdot
.19689 .27368 Mdot
.19694 .27382 Mdot
.19698 .27396 Mdot
.19703 .27409 Mdot
.19708 .27423 Mdot
.19713 .27437 Mdot
.19717 .27451 Mdot
.19722 .27464 Mdot
.19727 .27478 Mdot
.19732 .27492 Mdot
.19736 .27506 Mdot
.19741 .2752 Mdot
.19746 .27533 Mdot
.19751 .27547 Mdot
.19755 .27561 Mdot
.1976 .27575 Mdot
.19765 .27589 Mdot
.1977 .27602 Mdot
.19774 .27616 Mdot
.19779 .2763 Mdot
.19784 .27644 Mdot
.19789 .27658 Mdot
.19793 .27672 Mdot
.19798 .27685 Mdot
.19803 .27699 Mdot
.19808 .27713 Mdot
.19813 .27727 Mdot
.19817 .27741 Mdot
.19822 .27755 Mdot
.19827 .27769 Mdot
.19832 .27783 Mdot
.19836 .27796 Mdot
.19841 .2781 Mdot
.19846 .27824 Mdot
.19851 .27838 Mdot
.19855 .27852 Mdot
.1986 .27866 Mdot
.19865 .2788 Mdot
.1987 .27894 Mdot
.19874 .27907 Mdot
.19879 .27921 Mdot
.19884 .27935 Mdot
.19889 .27949 Mdot
.19893 .27963 Mdot
.19898 .27977 Mdot
.19903 .27991 Mdot
.19908 .28005 Mdot
.19913 .28019 Mdot
.19917 .28033 Mdot
.19922 .28047 Mdot
.19927 .28061 Mdot
.19932 .28075 Mdot
.19936 .28088 Mdot
.19941 .28102 Mdot
.19946 .28116 Mdot
.19951 .2813 Mdot
.19955 .28144 Mdot
.1996 .28158 Mdot
.19965 .28172 Mdot
.1997 .28186 Mdot
.19974 .282 Mdot
.19979 .28214 Mdot
.19984 .28228 Mdot
.19989 .28242 Mdot
.19993 .28256 Mdot
.19998 .2827 Mdot
.20003 .28284 Mdot
.20008 .28298 Mdot
.20013 .28312 Mdot
.20017 .28326 Mdot
.20022 .2834 Mdot
.20027 .28354 Mdot
.20032 .28368 Mdot
.20036 .28382 Mdot
.20041 .28396 Mdot
.20046 .2841 Mdot
.20051 .28424 Mdot
.20055 .28439 Mdot
.2006 .28453 Mdot
.20065 .28467 Mdot
.2007 .28481 Mdot
.20074 .28495 Mdot
.20079 .28509 Mdot
.20084 .28523 Mdot
.20089 .28537 Mdot
.20093 .28551 Mdot
.20098 .28565 Mdot
.20103 .28579 Mdot
.20108 .28593 Mdot
.20113 .28607 Mdot
.20117 .28622 Mdot
.20122 .28636 Mdot
.20127 .2865 Mdot
.20132 .28664 Mdot
.20136 .28678 Mdot
.20141 .28692 Mdot
.20146 .28706 Mdot
.20151 .2872 Mdot
.20155 .28734 Mdot
.2016 .28749 Mdot
.20165 .28763 Mdot
.2017 .28777 Mdot
.20174 .28791 Mdot
.20179 .28805 Mdot
.20184 .28819 Mdot
.20189 .28833 Mdot
.20193 .28848 Mdot
.20198 .28862 Mdot
.20203 .28876 Mdot
.20208 .2889 Mdot
.20213 .28904 Mdot
.20217 .28918 Mdot
.20222 .28932 Mdot
.20227 .28947 Mdot
.20232 .28961 Mdot
.20236 .28975 Mdot
.20241 .28989 Mdot
.20246 .29003 Mdot
.20251 .29017 Mdot
.20255 .29032 Mdot
.2026 .29046 Mdot
.20265 .2906 Mdot
.2027 .29074 Mdot
.20274 .29088 Mdot
.20279 .29102 Mdot
.20284 .29117 Mdot
.20289 .29131 Mdot
.20293 .29145 Mdot
.20298 .29159 Mdot
.20303 .29174 Mdot
.20308 .29188 Mdot
.20312 .29202 Mdot
.20317 .29216 Mdot
.20322 .2923 Mdot
.20327 .29245 Mdot
.20332 .29259 Mdot
.20336 .29273 Mdot
.20341 .29287 Mdot
.20346 .29301 Mdot
.20351 .29316 Mdot
.20355 .2933 Mdot
.2036 .29344 Mdot
.20365 .29358 Mdot
.2037 .29373 Mdot
.20374 .29387 Mdot
.20379 .29401 Mdot
.20384 .29415 Mdot
.20389 .29429 Mdot
.20393 .29444 Mdot
.20398 .29458 Mdot
.20403 .29472 Mdot
.20408 .29486 Mdot
.20412 .29501 Mdot
.20417 .29515 Mdot
.20422 .29529 Mdot
.20427 .29543 Mdot
.20432 .29558 Mdot
.20436 .29572 Mdot
.20441 .29586 Mdot
.20446 .296 Mdot
.20451 .29615 Mdot
.20455 .29629 Mdot
.2046 .29643 Mdot
.20465 .29657 Mdot
.2047 .29672 Mdot
.20474 .29686 Mdot
.20479 .297 Mdot
.20484 .29715 Mdot
.20489 .29729 Mdot
.20493 .29743 Mdot
.20498 .29757 Mdot
.20503 .29772 Mdot
.20508 .29786 Mdot
.20512 .298 Mdot
.20517 .29814 Mdot
.20522 .29829 Mdot
.20527 .29843 Mdot
.20532 .29857 Mdot
.20536 .29872 Mdot
.20541 .29886 Mdot
.20546 .299 Mdot
.20551 .29914 Mdot
.20555 .29929 Mdot
.2056 .29943 Mdot
.20565 .29957 Mdot
.2057 .29972 Mdot
.20574 .29986 Mdot
.20579 .3 Mdot
.20584 .30014 Mdot
.20589 .30029 Mdot
.20593 .30043 Mdot
.20598 .30057 Mdot
.20603 .30072 Mdot
.20608 .30086 Mdot
.20612 .301 Mdot
.20617 .30115 Mdot
.20622 .30129 Mdot
.20627 .30143 Mdot
.20632 .30157 Mdot
.20636 .30172 Mdot
.20641 .30186 Mdot
.20646 .302 Mdot
.20651 .30215 Mdot
.20655 .30229 Mdot
.2066 .30243 Mdot
.20665 .30258 Mdot
.2067 .30272 Mdot
.20674 .30286 Mdot
.20679 .30301 Mdot
.20684 .30315 Mdot
.20689 .30329 Mdot
.20693 .30344 Mdot
.20698 .30358 Mdot
.20703 .30372 Mdot
.20708 .30386 Mdot
.20712 .30401 Mdot
.20717 .30415 Mdot
.20722 .30429 Mdot
.20727 .30444 Mdot
.20731 .30458 Mdot
.20736 .30472 Mdot
.20741 .30487 Mdot
.20746 .30501 Mdot
.20751 .30515 Mdot
.20755 .3053 Mdot
.2076 .30544 Mdot
.20765 .30558 Mdot
.2077 .30573 Mdot
.20774 .30587 Mdot
.20779 .30601 Mdot
.20784 .30616 Mdot
.20789 .3063 Mdot
.20793 .30644 Mdot
.20798 .30659 Mdot
.20803 .30673 Mdot
.20808 .30687 Mdot
.20812 .30702 Mdot
.20817 .30716 Mdot
.20822 .3073 Mdot
.20827 .30745 Mdot
.20831 .30759 Mdot
.20836 .30773 Mdot
.20841 .30787 Mdot
.20846 .30802 Mdot
.20851 .30816 Mdot
.20855 .3083 Mdot
.2086 .30845 Mdot
.20865 .30859 Mdot
.2087 .30873 Mdot
.20874 .30888 Mdot
.20879 .30902 Mdot
.20884 .30916 Mdot
.20889 .30931 Mdot
.20893 .30945 Mdot
.20898 .30959 Mdot
.20903 .30974 Mdot
.20908 .30988 Mdot
.20912 .31002 Mdot
.20917 .31016 Mdot
.20922 .31031 Mdot
.20927 .31045 Mdot
.20931 .31059 Mdot
.20936 .31074 Mdot
.20941 .31088 Mdot
.20946 .31102 Mdot
.20951 .31117 Mdot
.20955 .31131 Mdot
.2096 .31145 Mdot
.20965 .3116 Mdot
.2097 .31174 Mdot
.20974 .31188 Mdot
.20979 .31202 Mdot
.20984 .31217 Mdot
.20989 .31231 Mdot
.20993 .31245 Mdot
.20998 .3126 Mdot
.21003 .31274 Mdot
.21008 .31288 Mdot
.21012 .31302 Mdot
.21017 .31317 Mdot
.21022 .31331 Mdot
.21027 .31345 Mdot
.21031 .3136 Mdot
.21036 .31374 Mdot
.21041 .31388 Mdot
.21046 .31402 Mdot
.21051 .31417 Mdot
.21055 .31431 Mdot
.2106 .31445 Mdot
.21065 .3146 Mdot
.2107 .31474 Mdot
.21074 .31488 Mdot
.21079 .31503 Mdot
.21084 .31517 Mdot
.21089 .31531 Mdot
.21093 .31545 Mdot
.21098 .3156 Mdot
.21103 .31574 Mdot
.21108 .31588 Mdot
.21112 .31602 Mdot
.21117 .31617 Mdot
.21122 .31631 Mdot
.21127 .31645 Mdot
.21131 .3166 Mdot
.21136 .31674 Mdot
.21141 .31688 Mdot
.21146 .31702 Mdot
.21151 .31717 Mdot
.21155 .31731 Mdot
.2116 .31745 Mdot
.21165 .31759 Mdot
.2117 .31774 Mdot
.21174 .31788 Mdot
.21179 .31802 Mdot
.21184 .31816 Mdot
.21189 .3183 Mdot
.21193 .31845 Mdot
.21198 .31859 Mdot
.21203 .31873 Mdot
.21208 .31887 Mdot
.21212 .31902 Mdot
.21217 .31916 Mdot
.21222 .3193 Mdot
.21227 .31944 Mdot
.21231 .31959 Mdot
.21236 .31973 Mdot
.21241 .31987 Mdot
.21246 .32001 Mdot
.2125 .32015 Mdot
.21255 .3203 Mdot
.2126 .32044 Mdot
.21265 .32058 Mdot
.2127 .32072 Mdot
.21274 .32086 Mdot
.21279 .32101 Mdot
.21284 .32115 Mdot
.21289 .32129 Mdot
.21293 .32143 Mdot
.21298 .32157 Mdot
.21303 .32172 Mdot
.21308 .32186 Mdot
.21312 .322 Mdot
.21317 .32214 Mdot
.21322 .32228 Mdot
.21327 .32242 Mdot
.21331 .32257 Mdot
.21336 .32271 Mdot
.21341 .32285 Mdot
.21346 .32299 Mdot
.2135 .32313 Mdot
.21355 .32327 Mdot
.2136 .32342 Mdot
.21365 .32356 Mdot
.2137 .3237 Mdot
.21374 .32384 Mdot
.21379 .32398 Mdot
.21384 .32412 Mdot
.21389 .32426 Mdot
.21393 .32441 Mdot
.21398 .32455 Mdot
.21403 .32469 Mdot
.21408 .32483 Mdot
.21412 .32497 Mdot
.21417 .32511 Mdot
.21422 .32525 Mdot
.21427 .3254 Mdot
.21431 .32554 Mdot
.21436 .32568 Mdot
.21441 .32582 Mdot
.21446 .32596 Mdot
.2145 .3261 Mdot
.21455 .32624 Mdot
.2146 .32638 Mdot
.21465 .32652 Mdot
.2147 .32667 Mdot
.21474 .32681 Mdot
.21479 .32695 Mdot
.21484 .32709 Mdot
.21489 .32723 Mdot
.21493 .32737 Mdot
.21498 .32751 Mdot
.21503 .32765 Mdot
.21508 .32779 Mdot
.21512 .32793 Mdot
.21517 .32807 Mdot
.21522 .32821 Mdot
.21527 .32835 Mdot
.21531 .32849 Mdot
.21536 .32863 Mdot
.21541 .32878 Mdot
.21546 .32892 Mdot
.2155 .32906 Mdot
.21555 .3292 Mdot
.2156 .32934 Mdot
.21565 .32948 Mdot
.2157 .32962 Mdot
.21574 .32976 Mdot
.21579 .3299 Mdot
.21584 .33004 Mdot
.21589 .33018 Mdot
.21593 .33032 Mdot
.21598 .33046 Mdot
.21603 .3306 Mdot
.21608 .33074 Mdot
.21612 .33088 Mdot
.21617 .33102 Mdot
.21622 .33116 Mdot
.21627 .3313 Mdot
.21631 .33144 Mdot
.21636 .33158 Mdot
.21641 .33172 Mdot
.21646 .33186 Mdot
.2165 .332 Mdot
.21655 .33214 Mdot
.2166 .33228 Mdot
.21665 .33242 Mdot
.21669 .33255 Mdot
.21674 .33269 Mdot
.21679 .33283 Mdot
.21684 .33297 Mdot
.21689 .33311 Mdot
.21693 .33325 Mdot
.21698 .33339 Mdot
.21703 .33353 Mdot
.21708 .33367 Mdot
.21712 .33381 Mdot
.21717 .33394 Mdot
.21722 .33408 Mdot
.21727 .33422 Mdot
.21731 .33436 Mdot
.21736 .3345 Mdot
.21741 .33464 Mdot
.21746 .33478 Mdot
.2175 .33491 Mdot
.21755 .33505 Mdot
.2176 .33519 Mdot
.21765 .33533 Mdot
.21769 .33547 Mdot
.21774 .33561 Mdot
.21779 .33574 Mdot
.21784 .33588 Mdot
.21789 .33602 Mdot
.21793 .33616 Mdot
.21798 .3363 Mdot
.21803 .33644 Mdot
.21808 .33657 Mdot
.21812 .33671 Mdot
.21817 .33685 Mdot
.21822 .33699 Mdot
.21827 .33712 Mdot
.21831 .33726 Mdot
.21836 .3374 Mdot
.21841 .33754 Mdot
.21846 .33768 Mdot
.2185 .33781 Mdot
.21855 .33795 Mdot
.2186 .33809 Mdot
.21865 .33822 Mdot
.21869 .33836 Mdot
.21874 .3385 Mdot
.21879 .33864 Mdot
.21884 .33877 Mdot
.21889 .33891 Mdot
.21893 .33905 Mdot
.21898 .33918 Mdot
.21903 .33932 Mdot
.21908 .33946 Mdot
.21912 .3396 Mdot
.21917 .33973 Mdot
.21922 .33987 Mdot
.21927 .34001 Mdot
.21931 .34014 Mdot
.21936 .34028 Mdot
.21941 .34042 Mdot
.21946 .34055 Mdot
.2195 .34069 Mdot
.21955 .34082 Mdot
.2196 .34096 Mdot
.21965 .3411 Mdot
.21969 .34123 Mdot
.21974 .34137 Mdot
.21979 .3415 Mdot
.21984 .34164 Mdot
.21989 .34178 Mdot
.21993 .34191 Mdot
.21998 .34205 Mdot
.22003 .34218 Mdot
.22008 .34232 Mdot
.22012 .34245 Mdot
.22017 .34259 Mdot
.22022 .34273 Mdot
.22027 .34286 Mdot
.22031 .343 Mdot
.22036 .34313 Mdot
.22041 .34327 Mdot
.22046 .3434 Mdot
.2205 .34354 Mdot
.22055 .34367 Mdot
.2206 .34381 Mdot
.22065 .34394 Mdot
.22069 .34408 Mdot
.22074 .34421 Mdot
.22079 .34435 Mdot
.22084 .34448 Mdot
.22089 .34462 Mdot
.22093 .34475 Mdot
.22098 .34489 Mdot
.22103 .34502 Mdot
.22108 .34516 Mdot
.22112 .34529 Mdot
.22117 .34542 Mdot
.22122 .34556 Mdot
.22127 .34569 Mdot
.22131 .34583 Mdot
.22136 .34596 Mdot
.22141 .3461 Mdot
.22146 .34623 Mdot
.2215 .34636 Mdot
.22155 .3465 Mdot
.2216 .34663 Mdot
.22165 .34677 Mdot
.22169 .3469 Mdot
.22174 .34703 Mdot
.22179 .34717 Mdot
.22184 .3473 Mdot
.22188 .34743 Mdot
.22193 .34757 Mdot
.22198 .3477 Mdot
.22203 .34783 Mdot
.22208 .34797 Mdot
.22212 .3481 Mdot
.22217 .34823 Mdot
.22222 .34836 Mdot
.22227 .3485 Mdot
.22231 .34863 Mdot
.22236 .34876 Mdot
.22241 .3489 Mdot
.22246 .34903 Mdot
.2225 .34916 Mdot
.22255 .34929 Mdot
.2226 .34942 Mdot
.22265 .34956 Mdot
.22269 .34969 Mdot
.22274 .34982 Mdot
.22279 .34995 Mdot
.22284 .35009 Mdot
.22288 .35022 Mdot
.22293 .35035 Mdot
.22298 .35048 Mdot
.22303 .35061 Mdot
.22308 .35074 Mdot
.22312 .35088 Mdot
.22317 .35101 Mdot
.22322 .35114 Mdot
.22327 .35127 Mdot
.22331 .3514 Mdot
.22336 .35153 Mdot
.22341 .35166 Mdot
.22346 .35179 Mdot
.2235 .35192 Mdot
.22355 .35206 Mdot
.2236 .35219 Mdot
.22365 .35232 Mdot
.22369 .35245 Mdot
.22374 .35258 Mdot
.22379 .35271 Mdot
.22384 .35284 Mdot
.22388 .35297 Mdot
.22393 .3531 Mdot
.22398 .35323 Mdot
.22403 .35336 Mdot
.22408 .35349 Mdot
.22412 .35362 Mdot
.22417 .35375 Mdot
.22422 .35388 Mdot
.22427 .35401 Mdot
.22431 .35414 Mdot
.22436 .35427 Mdot
.22441 .3544 Mdot
.22446 .35452 Mdot
.2245 .35465 Mdot
.22455 .35478 Mdot
.2246 .35491 Mdot
.22465 .35504 Mdot
.22469 .35517 Mdot
.22474 .3553 Mdot
.22479 .35543 Mdot
.22484 .35556 Mdot
.22488 .35568 Mdot
.22493 .35581 Mdot
.22498 .35594 Mdot
.22503 .35607 Mdot
.22508 .3562 Mdot
.22512 .35633 Mdot
.22517 .35645 Mdot
.22522 .35658 Mdot
.22527 .35671 Mdot
.22531 .35684 Mdot
.22536 .35696 Mdot
.22541 .35709 Mdot
.22546 .35722 Mdot
.2255 .35735 Mdot
.22555 .35747 Mdot
.2256 .3576 Mdot
.22565 .35773 Mdot
.22569 .35785 Mdot
.22574 .35798 Mdot
.22579 .35811 Mdot
.22584 .35823 Mdot
.22588 .35836 Mdot
.22593 .35849 Mdot
.22598 .35861 Mdot
.22603 .35874 Mdot
.22608 .35887 Mdot
.22612 .35899 Mdot
.22617 .35912 Mdot
.22622 .35924 Mdot
.22627 .35937 Mdot
.22631 .3595 Mdot
.22636 .35962 Mdot
.22641 .35975 Mdot
.22646 .35987 Mdot
.2265 .36 Mdot
.22655 .36012 Mdot
.2266 .36025 Mdot
.22665 .36037 Mdot
.22669 .3605 Mdot
.22674 .36062 Mdot
.22679 .36075 Mdot
.22684 .36087 Mdot
.22688 .361 Mdot
.22693 .36112 Mdot
.22698 .36125 Mdot
.22703 .36137 Mdot
.22707 .36149 Mdot
.22712 .36162 Mdot
.22717 .36174 Mdot
.22722 .36187 Mdot
.22727 .36199 Mdot
.22731 .36211 Mdot
.22736 .36224 Mdot
.22741 .36236 Mdot
.22746 .36248 Mdot
.2275 .36261 Mdot
.22755 .36273 Mdot
.2276 .36285 Mdot
.22765 .36298 Mdot
.22769 .3631 Mdot
.22774 .36322 Mdot
.22779 .36334 Mdot
.22784 .36347 Mdot
.22788 .36359 Mdot
.22793 .36371 Mdot
.22798 .36383 Mdot
.22803 .36395 Mdot
.22807 .36408 Mdot
.22812 .3642 Mdot
.22817 .36432 Mdot
.22822 .36444 Mdot
.22827 .36456 Mdot
.22831 .36468 Mdot
.22836 .36481 Mdot
.22841 .36493 Mdot
.22846 .36505 Mdot
.2285 .36517 Mdot
.22855 .36529 Mdot
.2286 .36541 Mdot
.22865 .36553 Mdot
.22869 .36565 Mdot
.22874 .36577 Mdot
.22879 .36589 Mdot
.22884 .36601 Mdot
.22888 .36613 Mdot
.22893 .36625 Mdot
.22898 .36637 Mdot
.22903 .36649 Mdot
.22907 .36661 Mdot
.22912 .36673 Mdot
.22917 .36685 Mdot
.22922 .36697 Mdot
.22927 .36709 Mdot
.22931 .36721 Mdot
.22936 .36733 Mdot
.22941 .36745 Mdot
.22946 .36757 Mdot
.2295 .36768 Mdot
.22955 .3678 Mdot
.2296 .36792 Mdot
.22965 .36804 Mdot
.22969 .36816 Mdot
.22974 .36828 Mdot
.22979 .36839 Mdot
.22984 .36851 Mdot
.22988 .36863 Mdot
.22993 .36875 Mdot
.22998 .36887 Mdot
.23003 .36898 Mdot
.23007 .3691 Mdot
.23012 .36922 Mdot
.23017 .36934 Mdot
.23022 .36945 Mdot
.23027 .36957 Mdot
.23031 .36969 Mdot
.23036 .3698 Mdot
.23041 .36992 Mdot
.23046 .37004 Mdot
.2305 .37015 Mdot
.23055 .37027 Mdot
.2306 .37038 Mdot
.23065 .3705 Mdot
.23069 .37062 Mdot
.23074 .37073 Mdot
.23079 .37085 Mdot
.23084 .37096 Mdot
.23088 .37108 Mdot
.23093 .37119 Mdot
.23098 .37131 Mdot
.23103 .37142 Mdot
.23107 .37154 Mdot
.23112 .37165 Mdot
.23117 .37177 Mdot
.23122 .37188 Mdot
.23126 .372 Mdot
.23131 .37211 Mdot
.23136 .37223 Mdot
.23141 .37234 Mdot
.23146 .37246 Mdot
.2315 .37257 Mdot
.23155 .37268 Mdot
.2316 .3728 Mdot
.23165 .37291 Mdot
.23169 .37303 Mdot
.23174 .37314 Mdot
.23179 .37325 Mdot
.23184 .37337 Mdot
.23188 .37348 Mdot
.23193 .37359 Mdot
.23198 .37371 Mdot
.23203 .37382 Mdot
.23207 .37393 Mdot
.23212 .37404 Mdot
.23217 .37416 Mdot
.23222 .37427 Mdot
.23226 .37438 Mdot
.23231 .37449 Mdot
.23236 .3746 Mdot
.23241 .37472 Mdot
.23246 .37483 Mdot
.2325 .37494 Mdot
.23255 .37505 Mdot
.2326 .37516 Mdot
.23265 .37527 Mdot
.23269 .37538 Mdot
.23274 .3755 Mdot
.23279 .37561 Mdot
.23284 .37572 Mdot
.23288 .37583 Mdot
.23293 .37594 Mdot
.23298 .37605 Mdot
.23303 .37616 Mdot
.23307 .37627 Mdot
.23312 .37638 Mdot
.23317 .37649 Mdot
.23322 .3766 Mdot
.23326 .37671 Mdot
.23331 .37682 Mdot
.23336 .37693 Mdot
.23341 .37703 Mdot
.23346 .37714 Mdot
.2335 .37725 Mdot
.23355 .37736 Mdot
.2336 .37747 Mdot
.23365 .37758 Mdot
.23369 .37769 Mdot
.23374 .37779 Mdot
.23379 .3779 Mdot
.23384 .37801 Mdot
.23388 .37812 Mdot
.23393 .37823 Mdot
.23398 .37833 Mdot
.23403 .37844 Mdot
.23407 .37855 Mdot
.23412 .37866 Mdot
.23417 .37876 Mdot
.23422 .37887 Mdot
.23426 .37898 Mdot
.23431 .37908 Mdot
.23436 .37919 Mdot
.23441 .3793 Mdot
.23446 .3794 Mdot
.2345 .37951 Mdot
.23455 .37961 Mdot
.2346 .37972 Mdot
.23465 .37982 Mdot
.23469 .37993 Mdot
.23474 .38004 Mdot
.23479 .38014 Mdot
.23484 .38025 Mdot
.23488 .38035 Mdot
.23493 .38046 Mdot
.23498 .38056 Mdot
.23503 .38066 Mdot
.23507 .38077 Mdot
.23512 .38087 Mdot
.23517 .38098 Mdot
.23522 .38108 Mdot
.23526 .38118 Mdot
.23531 .38129 Mdot
.23536 .38139 Mdot
.23541 .38149 Mdot
.23546 .3816 Mdot
.2355 .3817 Mdot
.23555 .3818 Mdot
.2356 .38191 Mdot
.23565 .38201 Mdot
.23569 .38211 Mdot
.23574 .38221 Mdot
.23579 .38232 Mdot
.23584 .38242 Mdot
.23588 .38252 Mdot
.23593 .38262 Mdot
.23598 .38272 Mdot
.23603 .38283 Mdot
.23607 .38293 Mdot
.23612 .38303 Mdot
.23617 .38313 Mdot
.23622 .38323 Mdot
.23626 .38333 Mdot
.23631 .38343 Mdot
.23636 .38353 Mdot
.23641 .38363 Mdot
.23645 .38373 Mdot
.2365 .38383 Mdot
.23655 .38393 Mdot
.2366 .38403 Mdot
.23665 .38413 Mdot
.23669 .38423 Mdot
.23674 .38433 Mdot
.23679 .38443 Mdot
.23684 .38453 Mdot
.23688 .38463 Mdot
.23693 .38473 Mdot
.23698 .38483 Mdot
.23703 .38493 Mdot
.23707 .38503 Mdot
.23712 .38512 Mdot
.23717 .38522 Mdot
.23722 .38532 Mdot
.23726 .38542 Mdot
.23731 .38552 Mdot
.23736 .38561 Mdot
.23741 .38571 Mdot
.23745 .38581 Mdot
.2375 .38591 Mdot
.23755 .386 Mdot
.2376 .3861 Mdot
.23765 .3862 Mdot
.23769 .38629 Mdot
.23774 .38639 Mdot
.23779 .38649 Mdot
.23784 .38658 Mdot
.23788 .38668 Mdot
.23793 .38677 Mdot
.23798 .38687 Mdot
.23803 .38696 Mdot
.23807 .38706 Mdot
.23812 .38716 Mdot
.23817 .38725 Mdot
.23822 .38735 Mdot
.23826 .38744 Mdot
.23831 .38753 Mdot
.23836 .38763 Mdot
.23841 .38772 Mdot
.23845 .38782 Mdot
.2385 .38791 Mdot
.23855 .38801 Mdot
.2386 .3881 Mdot
.23865 .38819 Mdot
.23869 .38829 Mdot
.23874 .38838 Mdot
.23879 .38847 Mdot
.23884 .38856 Mdot
.23888 .38866 Mdot
.23893 .38875 Mdot
.23898 .38884 Mdot
.23903 .38894 Mdot
.23907 .38903 Mdot
.23912 .38912 Mdot
.23917 .38921 Mdot
.23922 .3893 Mdot
.23926 .38939 Mdot
.23931 .38949 Mdot
.23936 .38958 Mdot
.23941 .38967 Mdot
.23945 .38976 Mdot
.2395 .38985 Mdot
.23955 .38994 Mdot
.2396 .39003 Mdot
.23965 .39012 Mdot
.23969 .39021 Mdot
.23974 .3903 Mdot
.23979 .39039 Mdot
.23984 .39048 Mdot
.23988 .39057 Mdot
.23993 .39066 Mdot
.23998 .39075 Mdot
.24003 .39084 Mdot
.24007 .39093 Mdot
.24012 .39102 Mdot
.24017 .39111 Mdot
.24022 .39119 Mdot
.24026 .39128 Mdot
.24031 .39137 Mdot
.24036 .39146 Mdot
.24041 .39155 Mdot
.24045 .39163 Mdot
.2405 .39172 Mdot
.24055 .39181 Mdot
.2406 .3919 Mdot
.24064 .39198 Mdot
.24069 .39207 Mdot
.24074 .39216 Mdot
.24079 .39225 Mdot
.24084 .39233 Mdot
.24088 .39242 Mdot
.24093 .3925 Mdot
.24098 .39259 Mdot
.24103 .39268 Mdot
.24107 .39276 Mdot
.24112 .39285 Mdot
.24117 .39293 Mdot
.24122 .39302 Mdot
.24126 .3931 Mdot
.24131 .39319 Mdot
.24136 .39327 Mdot
.24141 .39336 Mdot
.24145 .39344 Mdot
.2415 .39353 Mdot
.24155 .39361 Mdot
.2416 .3937 Mdot
.24164 .39378 Mdot
.24169 .39386 Mdot
.24174 .39395 Mdot
.24179 .39403 Mdot
.24184 .39411 Mdot
.24188 .3942 Mdot
.24193 .39428 Mdot
.24198 .39436 Mdot
.24203 .39444 Mdot
.24207 .39453 Mdot
.24212 .39461 Mdot
.24217 .39469 Mdot
.24222 .39477 Mdot
.24226 .39486 Mdot
.24231 .39494 Mdot
.24236 .39502 Mdot
.24241 .3951 Mdot
.24245 .39518 Mdot
.2425 .39526 Mdot
.24255 .39534 Mdot
.2426 .39542 Mdot
.24264 .3955 Mdot
.24269 .39558 Mdot
.24274 .39566 Mdot
.24279 .39574 Mdot
.24284 .39582 Mdot
.24288 .3959 Mdot
.24293 .39598 Mdot
.24298 .39606 Mdot
.24303 .39614 Mdot
.24307 .39622 Mdot
.24312 .3963 Mdot
.24317 .39637 Mdot
.24322 .39645 Mdot
.24326 .39653 Mdot
.24331 .39661 Mdot
.24336 .39669 Mdot
.24341 .39676 Mdot
.24345 .39684 Mdot
.2435 .39692 Mdot
.24355 .397 Mdot
.2436 .39707 Mdot
.24364 .39715 Mdot
.24369 .39723 Mdot
.24374 .3973 Mdot
.24379 .39738 Mdot
.24384 .39745 Mdot
.24388 .39753 Mdot
.24393 .3976 Mdot
.24398 .39768 Mdot
.24403 .39776 Mdot
.24407 .39783 Mdot
.24412 .39791 Mdot
.24417 .39798 Mdot
.24422 .39805 Mdot
.24426 .39813 Mdot
.24431 .3982 Mdot
.24436 .39828 Mdot
.24441 .39835 Mdot
.24445 .39843 Mdot
.2445 .3985 Mdot
.24455 .39857 Mdot
.2446 .39865 Mdot
.24464 .39872 Mdot
.24469 .39879 Mdot
.24474 .39886 Mdot
.24479 .39894 Mdot
.24484 .39901 Mdot
.24488 .39908 Mdot
.24493 .39915 Mdot
.24498 .39922 Mdot
.24503 .3993 Mdot
.24507 .39937 Mdot
.24512 .39944 Mdot
.24517 .39951 Mdot
.24522 .39958 Mdot
.24526 .39965 Mdot
.24531 .39972 Mdot
.24536 .39979 Mdot
.24541 .39986 Mdot
.24545 .39993 Mdot
.2455 .4 Mdot
.24555 .40007 Mdot
.2456 .40014 Mdot
.24564 .40021 Mdot
.24569 .40028 Mdot
.24574 .40035 Mdot
.24579 .40042 Mdot
.24583 .40049 Mdot
.24588 .40056 Mdot
.24593 .40063 Mdot
.24598 .40069 Mdot
.24603 .40076 Mdot
.24607 .40083 Mdot
.24612 .4009 Mdot
.24617 .40097 Mdot
.24622 .40103 Mdot
.24626 .4011 Mdot
.24631 .40117 Mdot
.24636 .40123 Mdot
.24641 .4013 Mdot
.24645 .40137 Mdot
.2465 .40143 Mdot
.24655 .4015 Mdot
.2466 .40157 Mdot
.24664 .40163 Mdot
.24669 .4017 Mdot
.24674 .40176 Mdot
.24679 .40183 Mdot
.24683 .4019 Mdot
.24688 .40196 Mdot
.24693 .40202 Mdot
.24698 .40209 Mdot
.24703 .40215 Mdot
.24707 .40222 Mdot
.24712 .40228 Mdot
.24717 .40235 Mdot
.24722 .40241 Mdot
.24726 .40247 Mdot
.24731 .40254 Mdot
.24736 .4026 Mdot
.24741 .40266 Mdot
.24745 .40273 Mdot
.2475 .40279 Mdot
.24755 .40285 Mdot
.2476 .40291 Mdot
.24764 .40298 Mdot
.24769 .40304 Mdot
.24774 .4031 Mdot
.24779 .40316 Mdot
.24783 .40322 Mdot
.24788 .40328 Mdot
.24793 .40335 Mdot
.24798 .40341 Mdot
.24803 .40347 Mdot
.24807 .40353 Mdot
.24812 .40359 Mdot
.24817 .40365 Mdot
.24822 .40371 Mdot
.24826 .40377 Mdot
.24831 .40383 Mdot
.24836 .40389 Mdot
.24841 .40395 Mdot
.24845 .40401 Mdot
.2485 .40407 Mdot
.24855 .40412 Mdot
.2486 .40418 Mdot
.24864 .40424 Mdot
.24869 .4043 Mdot
.24874 .40436 Mdot
.24879 .40442 Mdot
.24883 .40447 Mdot
.24888 .40453 Mdot
.24893 .40459 Mdot
.24898 .40465 Mdot
.24903 .4047 Mdot
.24907 .40476 Mdot
.24912 .40482 Mdot
.24917 .40487 Mdot
.24922 .40493 Mdot
.24926 .40499 Mdot
.24931 .40504 Mdot
.24936 .4051 Mdot
.24941 .40515 Mdot
.24945 .40521 Mdot
.2495 .40526 Mdot
.24955 .40532 Mdot
.2496 .40537 Mdot
.24964 .40543 Mdot
.24969 .40548 Mdot
.24974 .40554 Mdot
.24979 .40559 Mdot
.24983 .40564 Mdot
.24988 .4057 Mdot
.24993 .40575 Mdot
.24998 .40581 Mdot
.25002 .40586 Mdot
.25007 .40591 Mdot
.25012 .40596 Mdot
.25017 .40602 Mdot
.25022 .40607 Mdot
.25026 .40612 Mdot
.25031 .40617 Mdot
.25036 .40623 Mdot
.25041 .40628 Mdot
.25045 .40633 Mdot
.2505 .40638 Mdot
.25055 .40643 Mdot
.2506 .40648 Mdot
.25064 .40653 Mdot
.25069 .40658 Mdot
.25074 .40663 Mdot
.25079 .40668 Mdot
.25083 .40673 Mdot
.25088 .40678 Mdot
.25093 .40683 Mdot
.25098 .40688 Mdot
.25102 .40693 Mdot
.25107 .40698 Mdot
.25112 .40703 Mdot
.25117 .40708 Mdot
.25122 .40713 Mdot
.25126 .40718 Mdot
.25131 .40722 Mdot
.25136 .40727 Mdot
.25141 .40732 Mdot
.25145 .40737 Mdot
.2515 .40741 Mdot
.25155 .40746 Mdot
.2516 .40751 Mdot
.25164 .40756 Mdot
.25169 .4076 Mdot
.25174 .40765 Mdot
.25179 .4077 Mdot
.25183 .40774 Mdot
.25188 .40779 Mdot
.25193 .40783 Mdot
.25198 .40788 Mdot
.25202 .40792 Mdot
.25207 .40797 Mdot
.25212 .40801 Mdot
.25217 .40806 Mdot
.25222 .4081 Mdot
.25226 .40815 Mdot
.25231 .40819 Mdot
.25236 .40823 Mdot
.25241 .40828 Mdot
.25245 .40832 Mdot
.2525 .40836 Mdot
.25255 .40841 Mdot
.2526 .40845 Mdot
.25264 .40849 Mdot
.25269 .40854 Mdot
.25274 .40858 Mdot
.25279 .40862 Mdot
.25283 .40866 Mdot
.25288 .4087 Mdot
.25293 .40875 Mdot
.25298 .40879 Mdot
.25302 .40883 Mdot
.25307 .40887 Mdot
.25312 .40891 Mdot
.25317 .40895 Mdot
.25322 .40899 Mdot
.25326 .40903 Mdot
.25331 .40907 Mdot
.25336 .40911 Mdot
.25341 .40915 Mdot
.25345 .40919 Mdot
.2535 .40923 Mdot
.25355 .40927 Mdot
.2536 .40931 Mdot
.25364 .40934 Mdot
.25369 .40938 Mdot
.25374 .40942 Mdot
.25379 .40946 Mdot
.25383 .4095 Mdot
.25388 .40953 Mdot
.25393 .40957 Mdot
.25398 .40961 Mdot
.25402 .40964 Mdot
.25407 .40968 Mdot
.25412 .40972 Mdot
.25417 .40976 Mdot
.25422 .40979 Mdot
.25426 .40983 Mdot
.25431 .40986 Mdot
.25436 .4099 Mdot
.25441 .40993 Mdot
.25445 .40997 Mdot
.2545 .41001 Mdot
.25455 .41004 Mdot
.2546 .41007 Mdot
.25464 .41011 Mdot
.25469 .41014 Mdot
.25474 .41018 Mdot
.25479 .41021 Mdot
.25483 .41025 Mdot
.25488 .41028 Mdot
.25493 .41031 Mdot
.25498 .41035 Mdot
.25502 .41038 Mdot
.25507 .41041 Mdot
.25512 .41044 Mdot
.25517 .41048 Mdot
.25521 .41051 Mdot
.25526 .41054 Mdot
.25531 .41057 Mdot
.25536 .4106 Mdot
.25541 .41064 Mdot
.25545 .41067 Mdot
.2555 .4107 Mdot
.25555 .41073 Mdot
.2556 .41076 Mdot
.25564 .41079 Mdot
.25569 .41082 Mdot
.25574 .41085 Mdot
.25579 .41088 Mdot
.25583 .41091 Mdot
.25588 .41094 Mdot
.25593 .41097 Mdot
.25598 .411 Mdot
.25602 .41103 Mdot
.25607 .41105 Mdot
.25612 .41108 Mdot
.25617 .41111 Mdot
.25621 .41114 Mdot
.25626 .41117 Mdot
.25631 .4112 Mdot
.25636 .41122 Mdot
.25641 .41125 Mdot
.25645 .41128 Mdot
.2565 .41131 Mdot
.25655 .41133 Mdot
.2566 .41136 Mdot
.25664 .41139 Mdot
.25669 .41141 Mdot
.25674 .41144 Mdot
.25679 .41146 Mdot
.25683 .41149 Mdot
.25688 .41151 Mdot
.25693 .41154 Mdot
.25698 .41157 Mdot
.25702 .41159 Mdot
.25707 .41161 Mdot
.25712 .41164 Mdot
.25717 .41166 Mdot
.25721 .41169 Mdot
.25726 .41171 Mdot
.25731 .41174 Mdot
.25736 .41176 Mdot
.25741 .41178 Mdot
.25745 .41181 Mdot
.2575 .41183 Mdot
.25755 .41185 Mdot
.2576 .41187 Mdot
.25764 .4119 Mdot
.25769 .41192 Mdot
.25774 .41194 Mdot
.25779 .41196 Mdot
.25783 .41198 Mdot
.25788 .41201 Mdot
.25793 .41203 Mdot
.25798 .41205 Mdot
.25802 .41207 Mdot
.25807 .41209 Mdot
.25812 .41211 Mdot
.25817 .41213 Mdot
.25821 .41215 Mdot
.25826 .41217 Mdot
.25831 .41219 Mdot
.25836 .41221 Mdot
.25841 .41223 Mdot
.25845 .41225 Mdot
.2585 .41227 Mdot
.25855 .41229 Mdot
.2586 .4123 Mdot
.25864 .41232 Mdot
.25869 .41234 Mdot
.25874 .41236 Mdot
.25879 .41237 Mdot
.25883 .41239 Mdot
.25888 .41241 Mdot
.25893 .41243 Mdot
.25898 .41244 Mdot
.25902 .41246 Mdot
.25907 .41248 Mdot
.25912 .41249 Mdot
.25917 .41251 Mdot
.25921 .41252 Mdot
.25926 .41254 Mdot
.25931 .41255 Mdot
.25936 .41257 Mdot
.25941 .41258 Mdot
.25945 .4126 Mdot
.2595 .41261 Mdot
.25955 .41263 Mdot
.2596 .41264 Mdot
.25964 .41266 Mdot
.25969 .41267 Mdot
.25974 .41268 Mdot
.25979 .4127 Mdot
.25983 .41271 Mdot
.25988 .41272 Mdot
.25993 .41273 Mdot
.25998 .41275 Mdot
.26002 .41276 Mdot
.26007 .41277 Mdot
.26012 .41278 Mdot
.26017 .4128 Mdot
.26021 .41281 Mdot
.26026 .41282 Mdot
.26031 .41283 Mdot
.26036 .41284 Mdot
.2604 .41285 Mdot
.26045 .41286 Mdot
.2605 .41287 Mdot
.26055 .41288 Mdot
.2606 .41289 Mdot
.26064 .4129 Mdot
.26069 .41291 Mdot
.26074 .41292 Mdot
.26079 .41293 Mdot
.26083 .41294 Mdot
.26088 .41295 Mdot
.26093 .41296 Mdot
.26098 .41296 Mdot
.26102 .41297 Mdot
.26107 .41298 Mdot
.26112 .41299 Mdot
.26117 .413 Mdot
.26121 .413 Mdot
.26126 .41301 Mdot
.26131 .41302 Mdot
.26136 .41302 Mdot
.2614 .41303 Mdot
.26145 .41304 Mdot
.2615 .41304 Mdot
.26155 .41305 Mdot
.2616 .41305 Mdot
.26164 .41306 Mdot
.26169 .41306 Mdot
.26174 .41307 Mdot
.26179 .41307 Mdot
.26183 .41308 Mdot
.26188 .41308 Mdot
.26193 .41309 Mdot
.26198 .41309 Mdot
.26202 .4131 Mdot
.26207 .4131 Mdot
.26212 .4131 Mdot
.26217 .41311 Mdot
.26221 .41311 Mdot
.26226 .41311 Mdot
.26231 .41312 Mdot
.26236 .41312 Mdot
.2624 .41312 Mdot
.26245 .41312 Mdot
.2625 .41312 Mdot
.26255 .41313 Mdot
.2626 .41313 Mdot
.26264 .41313 Mdot
.26269 .41313 Mdot
.26274 .41313 Mdot
.26279 .41313 Mdot
.26283 .41313 Mdot
.26288 .41313 Mdot
.26293 .41313 Mdot
.26298 .41313 Mdot
.26302 .41313 Mdot
.26307 .41313 Mdot
.26312 .41313 Mdot
.26317 .41313 Mdot
.26321 .41312 Mdot
.26326 .41312 Mdot
.26331 .41312 Mdot
.26336 .41312 Mdot
.2634 .41312 Mdot
.26345 .41311 Mdot
.2635 .41311 Mdot
.26355 .41311 Mdot
.2636 .41311 Mdot
.26364 .4131 Mdot
.26369 .4131 Mdot
.26374 .4131 Mdot
.26379 .41309 Mdot
.26383 .41309 Mdot
.26388 .41308 Mdot
.26393 .41308 Mdot
.26398 .41307 Mdot
.26402 .41307 Mdot
.26407 .41306 Mdot
.26412 .41306 Mdot
.26417 .41305 Mdot
.26421 .41305 Mdot
.26426 .41304 Mdot
.26431 .41304 Mdot
.26436 .41303 Mdot
.2644 .41302 Mdot
.26445 .41302 Mdot
.2645 .41301 Mdot
.26455 .413 Mdot
.26459 .41299 Mdot
.26464 .41299 Mdot
.26469 .41298 Mdot
.26474 .41297 Mdot
.26479 .41296 Mdot
.26483 .41295 Mdot
.26488 .41295 Mdot
.26493 .41294 Mdot
.26498 .41293 Mdot
.26502 .41292 Mdot
.26507 .41291 Mdot
.26512 .4129 Mdot
.26517 .41289 Mdot
.26521 .41288 Mdot
.26526 .41287 Mdot
.26531 .41286 Mdot
.26536 .41285 Mdot
.2654 .41284 Mdot
.26545 .41283 Mdot
.2655 .41282 Mdot
.26555 .4128 Mdot
.26559 .41279 Mdot
.26564 .41278 Mdot
.26569 .41277 Mdot
.26574 .41276 Mdot
.26579 .41274 Mdot
.26583 .41273 Mdot
.26588 .41272 Mdot
.26593 .41271 Mdot
.26598 .41269 Mdot
.26602 .41268 Mdot
.26607 .41267 Mdot
.26612 .41265 Mdot
.26617 .41264 Mdot
.26621 .41262 Mdot
.26626 .41261 Mdot
.26631 .41259 Mdot
.26636 .41258 Mdot
.2664 .41257 Mdot
.26645 .41255 Mdot
.2665 .41253 Mdot
.26655 .41252 Mdot
.26659 .4125 Mdot
.26664 .41249 Mdot
.26669 .41247 Mdot
.26674 .41245 Mdot
.26679 .41244 Mdot
.26683 .41242 Mdot
.26688 .4124 Mdot
.26693 .41239 Mdot
.26698 .41237 Mdot
.26702 .41235 Mdot
.26707 .41233 Mdot
.26712 .41231 Mdot
.26717 .4123 Mdot
.26721 .41228 Mdot
.26726 .41226 Mdot
.26731 .41224 Mdot
.26736 .41222 Mdot
.2674 .4122 Mdot
.26745 .41218 Mdot
.2675 .41216 Mdot
.26755 .41214 Mdot
.26759 .41212 Mdot
.26764 .4121 Mdot
.26769 .41208 Mdot
.26774 .41206 Mdot
.26779 .41204 Mdot
.26783 .41202 Mdot
.26788 .41199 Mdot
.26793 .41197 Mdot
.26798 .41195 Mdot
.26802 .41193 Mdot
.26807 .41191 Mdot
.26812 .41188 Mdot
.26817 .41186 Mdot
.26821 .41184 Mdot
.26826 .41181 Mdot
.26831 .41179 Mdot
.26836 .41177 Mdot
.2684 .41174 Mdot
.26845 .41172 Mdot
.2685 .41169 Mdot
.26855 .41167 Mdot
.26859 .41165 Mdot
.26864 .41162 Mdot
.26869 .41159 Mdot
.26874 .41157 Mdot
.26879 .41154 Mdot
.26883 .41152 Mdot
.26888 .41149 Mdot
.26893 .41147 Mdot
.26898 .41144 Mdot
.26902 .41141 Mdot
.26907 .41139 Mdot
.26912 .41136 Mdot
.26917 .41133 Mdot
.26921 .4113 Mdot
.26926 .41128 Mdot
.26931 .41125 Mdot
.26936 .41122 Mdot
.2694 .41119 Mdot
.26945 .41116 Mdot
.2695 .41113 Mdot
.26955 .4111 Mdot
.26959 .41108 Mdot
.26964 .41105 Mdot
.26969 .41102 Mdot
.26974 .41099 Mdot
.26978 .41096 Mdot
.26983 .41093 Mdot
.26988 .4109 Mdot
.26993 .41086 Mdot
.26998 .41083 Mdot
.27002 .4108 Mdot
.27007 .41077 Mdot
.27012 .41074 Mdot
.27017 .41071 Mdot
.27021 .41068 Mdot
.27026 .41064 Mdot
.27031 .41061 Mdot
.27036 .41058 Mdot
.2704 .41055 Mdot
.27045 .41051 Mdot
.2705 .41048 Mdot
.27055 .41045 Mdot
.27059 .41041 Mdot
.27064 .41038 Mdot
.27069 .41034 Mdot
.27074 .41031 Mdot
.27078 .41028 Mdot
.27083 .41024 Mdot
.27088 .41021 Mdot
.27093 .41017 Mdot
.27098 .41014 Mdot
.27102 .4101 Mdot
.27107 .41006 Mdot
.27112 .41003 Mdot
.27117 .40999 Mdot
.27121 .40996 Mdot
.27126 .40992 Mdot
.27131 .40988 Mdot
.27136 .40985 Mdot
.2714 .40981 Mdot
.27145 .40977 Mdot
.2715 .40973 Mdot
.27155 .4097 Mdot
.27159 .40966 Mdot
.27164 .40962 Mdot
.27169 .40958 Mdot
.27174 .40954 Mdot
.27178 .4095 Mdot
.27183 .40946 Mdot
.27188 .40943 Mdot
.27193 .40939 Mdot
.27198 .40935 Mdot
.27202 .40931 Mdot
.27207 .40927 Mdot
.27212 .40923 Mdot
.27217 .40919 Mdot
.27221 .40915 Mdot
.27226 .4091 Mdot
.27231 .40906 Mdot
.27236 .40902 Mdot
.2724 .40898 Mdot
.27245 .40894 Mdot
.2725 .4089 Mdot
.27255 .40885 Mdot
.27259 .40881 Mdot
.27264 .40877 Mdot
.27269 .40873 Mdot
.27274 .40868 Mdot
.27278 .40864 Mdot
.27283 .4086 Mdot
.27288 .40855 Mdot
.27293 .40851 Mdot
.27298 .40846 Mdot
.27302 .40842 Mdot
.27307 .40838 Mdot
.27312 .40833 Mdot
.27317 .40829 Mdot
.27321 .40824 Mdot
.27326 .40819 Mdot
.27331 .40815 Mdot
.27336 .4081 Mdot
.2734 .40806 Mdot
.27345 .40801 Mdot
.2735 .40796 Mdot
.27355 .40792 Mdot
.27359 .40787 Mdot
.27364 .40782 Mdot
.27369 .40778 Mdot
.27374 .40773 Mdot
.27378 .40768 Mdot
.27383 .40763 Mdot
.27388 .40759 Mdot
.27393 .40754 Mdot
.27397 .40749 Mdot
.27402 .40744 Mdot
.27407 .40739 Mdot
.27412 .40734 Mdot
.27417 .40729 Mdot
.27421 .40724 Mdot
.27426 .40719 Mdot
.27431 .40714 Mdot
.27436 .40709 Mdot
.2744 .40704 Mdot
.27445 .40699 Mdot
.2745 .40694 Mdot
.27455 .40689 Mdot
.27459 .40684 Mdot
.27464 .40679 Mdot
.27469 .40673 Mdot
.27474 .40668 Mdot
.27478 .40663 Mdot
.27483 .40658 Mdot
.27488 .40653 Mdot
.27493 .40647 Mdot
.27497 .40642 Mdot
.27502 .40637 Mdot
.27507 .40631 Mdot
.27512 .40626 Mdot
.27517 .40621 Mdot
.27521 .40615 Mdot
.27526 .4061 Mdot
.27531 .40604 Mdot
.27536 .40599 Mdot
.2754 .40593 Mdot
.27545 .40588 Mdot
.2755 .40582 Mdot
.27555 .40577 Mdot
.27559 .40571 Mdot
.27564 .40565 Mdot
.27569 .4056 Mdot
.27574 .40554 Mdot
.27578 .40548 Mdot
.27583 .40543 Mdot
.27588 .40537 Mdot
.27593 .40531 Mdot
.27597 .40526 Mdot
.27602 .4052 Mdot
.27607 .40514 Mdot
.27612 .40508 Mdot
.27617 .40502 Mdot
.27621 .40497 Mdot
.27626 .40491 Mdot
.27631 .40485 Mdot
.27636 .40479 Mdot
.2764 .40473 Mdot
.27645 .40467 Mdot
.2765 .40461 Mdot
.27655 .40455 Mdot
.27659 .40449 Mdot
.27664 .40443 Mdot
.27669 .40437 Mdot
.27674 .40431 Mdot
.27678 .40425 Mdot
.27683 .40419 Mdot
.27688 .40412 Mdot
.27693 .40406 Mdot
.27697 .404 Mdot
.27702 .40394 Mdot
.27707 .40388 Mdot
.27712 .40381 Mdot
.27717 .40375 Mdot
.27721 .40369 Mdot
.27726 .40363 Mdot
.27731 .40356 Mdot
.27736 .4035 Mdot
.2774 .40344 Mdot
.27745 .40337 Mdot
.2775 .40331 Mdot
.27755 .40324 Mdot
.27759 .40318 Mdot
.27764 .40311 Mdot
.27769 .40305 Mdot
.27774 .40299 Mdot
.27778 .40292 Mdot
.27783 .40285 Mdot
.27788 .40279 Mdot
.27793 .40272 Mdot
.27797 .40266 Mdot
.27802 .40259 Mdot
.27807 .40252 Mdot
.27812 .40246 Mdot
.27817 .40239 Mdot
.27821 .40232 Mdot
.27826 .40226 Mdot
.27831 .40219 Mdot
.27836 .40212 Mdot
.2784 .40205 Mdot
.27845 .40199 Mdot
.2785 .40192 Mdot
.27855 .40185 Mdot
.27859 .40178 Mdot
.27864 .40171 Mdot
.27869 .40164 Mdot
.27874 .40157 Mdot
.27878 .4015 Mdot
.27883 .40143 Mdot
.27888 .40136 Mdot
.27893 .40129 Mdot
.27897 .40122 Mdot
.27902 .40115 Mdot
.27907 .40108 Mdot
.27912 .40101 Mdot
.27916 .40094 Mdot
.27921 .40087 Mdot
.27926 .4008 Mdot
.27931 .40072 Mdot
.27936 .40065 Mdot
.2794 .40058 Mdot
.27945 .40051 Mdot
.2795 .40044 Mdot
.27955 .40036 Mdot
.27959 .40029 Mdot
.27964 .40022 Mdot
.27969 .40014 Mdot
.27974 .40007 Mdot
.27978 .39999 Mdot
.27983 .39992 Mdot
.27988 .39985 Mdot
.27993 .39977 Mdot
.27997 .3997 Mdot
.28002 .39962 Mdot
.28007 .39955 Mdot
.28012 .39947 Mdot
.28016 .3994 Mdot
.28021 .39932 Mdot
.28026 .39924 Mdot
.28031 .39917 Mdot
.28036 .39909 Mdot
.2804 .39902 Mdot
.28045 .39894 Mdot
.2805 .39886 Mdot
.28055 .39878 Mdot
.28059 .39871 Mdot
.28064 .39863 Mdot
.28069 .39855 Mdot
.28074 .39847 Mdot
.28078 .39839 Mdot
.28083 .39832 Mdot
.28088 .39824 Mdot
.28093 .39816 Mdot
.28097 .39808 Mdot
.28102 .398 Mdot
.28107 .39792 Mdot
.28112 .39784 Mdot
.28116 .39776 Mdot
.28121 .39768 Mdot
.28126 .3976 Mdot
.28131 .39752 Mdot
.28136 .39744 Mdot
.2814 .39736 Mdot
.28145 .39728 Mdot
.2815 .3972 Mdot
.28155 .39711 Mdot
.28159 .39703 Mdot
.28164 .39695 Mdot
.28169 .39687 Mdot
.28174 .39679 Mdot
.28178 .3967 Mdot
.28183 .39662 Mdot
.28188 .39654 Mdot
.28193 .39645 Mdot
.28197 .39637 Mdot
.28202 .39629 Mdot
.28207 .3962 Mdot
.28212 .39612 Mdot
.28216 .39604 Mdot
.28221 .39595 Mdot
.28226 .39587 Mdot
.28231 .39578 Mdot
.28236 .3957 Mdot
.2824 .39561 Mdot
.28245 .39553 Mdot
.2825 .39544 Mdot
.28255 .39536 Mdot
.28259 .39527 Mdot
.28264 .39518 Mdot
.28269 .3951 Mdot
.28274 .39501 Mdot
.28278 .39492 Mdot
.28283 .39484 Mdot
.28288 .39475 Mdot
.28293 .39466 Mdot
.28297 .39458 Mdot
.28302 .39449 Mdot
.28307 .3944 Mdot
.28312 .39431 Mdot
.28316 .39422 Mdot
.28321 .39414 Mdot
.28326 .39405 Mdot
.28331 .39396 Mdot
.28335 .39387 Mdot
.2834 .39378 Mdot
.28345 .39369 Mdot
.2835 .3936 Mdot
.28355 .39351 Mdot
.28359 .39342 Mdot
.28364 .39333 Mdot
.28369 .39324 Mdot
.28374 .39315 Mdot
.28378 .39306 Mdot
.28383 .39297 Mdot
.28388 .39288 Mdot
.28393 .39279 Mdot
.28397 .3927 Mdot
.28402 .3926 Mdot
.28407 .39251 Mdot
.28412 .39242 Mdot
.28416 .39233 Mdot
.28421 .39224 Mdot
.28426 .39214 Mdot
.28431 .39205 Mdot
.28435 .39196 Mdot
.2844 .39186 Mdot
.28445 .39177 Mdot
.2845 .39168 Mdot
.28455 .39158 Mdot
.28459 .39149 Mdot
.28464 .39139 Mdot
.28469 .3913 Mdot
.28474 .39121 Mdot
.28478 .39111 Mdot
.28483 .39102 Mdot
.28488 .39092 Mdot
.28493 .39083 Mdot
.28497 .39073 Mdot
.28502 .39064 Mdot
.28507 .39054 Mdot
.28512 .39044 Mdot
.28516 .39035 Mdot
.28521 .39025 Mdot
.28526 .39015 Mdot
.28531 .39006 Mdot
.28535 .38996 Mdot
.2854 .38986 Mdot
.28545 .38977 Mdot
.2855 .38967 Mdot
.28555 .38957 Mdot
.28559 .38947 Mdot
.28564 .38937 Mdot
.28569 .38928 Mdot
.28574 .38918 Mdot
.28578 .38908 Mdot
.28583 .38898 Mdot
.28588 .38888 Mdot
.28593 .38878 Mdot
.28597 .38868 Mdot
.28602 .38858 Mdot
.28607 .38848 Mdot
.28612 .38838 Mdot
.28616 .38828 Mdot
.28621 .38818 Mdot
.28626 .38808 Mdot
.28631 .38798 Mdot
.28635 .38788 Mdot
.2864 .38778 Mdot
.28645 .38768 Mdot
.2865 .38758 Mdot
.28655 .38748 Mdot
.28659 .38738 Mdot
.28664 .38727 Mdot
.28669 .38717 Mdot
.28674 .38707 Mdot
.28678 .38697 Mdot
.28683 .38686 Mdot
.28688 .38676 Mdot
.28693 .38666 Mdot
.28697 .38655 Mdot
.28702 .38645 Mdot
.28707 .38635 Mdot
.28712 .38624 Mdot
.28716 .38614 Mdot
.28721 .38604 Mdot
.28726 .38593 Mdot
.28731 .38583 Mdot
.28735 .38572 Mdot
.2874 .38562 Mdot
.28745 .38551 Mdot
.2875 .38541 Mdot
.28755 .3853 Mdot
.28759 .38519 Mdot
.28764 .38509 Mdot
.28769 .38498 Mdot
.28774 .38488 Mdot
.28778 .38477 Mdot
.28783 .38466 Mdot
.28788 .38456 Mdot
.28793 .38445 Mdot
.28797 .38434 Mdot
.28802 .38424 Mdot
.28807 .38413 Mdot
.28812 .38402 Mdot
.28816 .38391 Mdot
.28821 .38381 Mdot
.28826 .3837 Mdot
.28831 .38359 Mdot
.28835 .38348 Mdot
.2884 .38337 Mdot
.28845 .38326 Mdot
.2885 .38315 Mdot
.28854 .38305 Mdot
.28859 .38294 Mdot
.28864 .38283 Mdot
.28869 .38272 Mdot
.28874 .38261 Mdot
.28878 .3825 Mdot
.28883 .38239 Mdot
.28888 .38228 Mdot
.28893 .38217 Mdot
.28897 .38205 Mdot
.28902 .38194 Mdot
.28907 .38183 Mdot
.28912 .38172 Mdot
.28916 .38161 Mdot
.28921 .3815 Mdot
.28926 .38139 Mdot
.28931 .38127 Mdot
.28935 .38116 Mdot
.2894 .38105 Mdot
.28945 .38094 Mdot
.2895 .38083 Mdot
.28954 .38071 Mdot
.28959 .3806 Mdot
.28964 .38049 Mdot
.28969 .38037 Mdot
.28974 .38026 Mdot
.28978 .38015 Mdot
.28983 .38003 Mdot
.28988 .37992 Mdot
.28993 .3798 Mdot
.28997 .37969 Mdot
.29002 .37957 Mdot
.29007 .37946 Mdot
.29012 .37935 Mdot
.29016 .37923 Mdot
.29021 .37911 Mdot
.29026 .379 Mdot
.29031 .37888 Mdot
.29035 .37877 Mdot
.2904 .37865 Mdot
.29045 .37854 Mdot
.2905 .37842 Mdot
.29054 .3783 Mdot
.29059 .37819 Mdot
.29064 .37807 Mdot
.29069 .37795 Mdot
.29074 .37784 Mdot
.29078 .37772 Mdot
.29083 .3776 Mdot
.29088 .37748 Mdot
.29093 .37737 Mdot
.29097 .37725 Mdot
.29102 .37713 Mdot
.29107 .37701 Mdot
.29112 .37689 Mdot
.29116 .37677 Mdot
.29121 .37666 Mdot
.29126 .37654 Mdot
.29131 .37642 Mdot
.29135 .3763 Mdot
.2914 .37618 Mdot
.29145 .37606 Mdot
.2915 .37594 Mdot
.29154 .37582 Mdot
.29159 .3757 Mdot
.29164 .37558 Mdot
.29169 .37546 Mdot
.29174 .37534 Mdot
.29178 .37522 Mdot
.29183 .3751 Mdot
.29188 .37498 Mdot
.29193 .37486 Mdot
.29197 .37473 Mdot
.29202 .37461 Mdot
.29207 .37449 Mdot
.29212 .37437 Mdot
.29216 .37425 Mdot
.29221 .37413 Mdot
.29226 .374 Mdot
.29231 .37388 Mdot
.29235 .37376 Mdot
.2924 .37364 Mdot
.29245 .37351 Mdot
.2925 .37339 Mdot
.29254 .37327 Mdot
.29259 .37314 Mdot
.29264 .37302 Mdot
.29269 .3729 Mdot
.29274 .37277 Mdot
.29278 .37265 Mdot
.29283 .37252 Mdot
.29288 .3724 Mdot
.29293 .37227 Mdot
.29297 .37215 Mdot
.29302 .37203 Mdot
.29307 .3719 Mdot
.29312 .37178 Mdot
.29316 .37165 Mdot
.29321 .37152 Mdot
.29326 .3714 Mdot
.29331 .37127 Mdot
.29335 .37115 Mdot
.2934 .37102 Mdot
.29345 .37089 Mdot
.2935 .37077 Mdot
.29354 .37064 Mdot
.29359 .37051 Mdot
.29364 .37039 Mdot
.29369 .37026 Mdot
.29373 .37013 Mdot
.29378 .37001 Mdot
.29383 .36988 Mdot
.29388 .36975 Mdot
.29393 .36962 Mdot
.29397 .3695 Mdot
.29402 .36937 Mdot
.29407 .36924 Mdot
.29412 .36911 Mdot
.29416 .36898 Mdot
.29421 .36885 Mdot
.29426 .36872 Mdot
.29431 .36859 Mdot
.29435 .36847 Mdot
.2944 .36834 Mdot
.29445 .36821 Mdot
.2945 .36808 Mdot
.29454 .36795 Mdot
.29459 .36782 Mdot
.29464 .36769 Mdot
.29469 .36756 Mdot
.29473 .36743 Mdot
.29478 .36729 Mdot
.29483 .36716 Mdot
.29488 .36703 Mdot
.29493 .3669 Mdot
.29497 .36677 Mdot
.29502 .36664 Mdot
.29507 .36651 Mdot
.29512 .36637 Mdot
.29516 .36624 Mdot
.29521 .36611 Mdot
.29526 .36598 Mdot
.29531 .36585 Mdot
.29535 .36571 Mdot
.2954 .36558 Mdot
.29545 .36545 Mdot
.2955 .36531 Mdot
.29554 .36518 Mdot
.29559 .36505 Mdot
.29564 .36491 Mdot
.29569 .36478 Mdot
.29573 .36465 Mdot
.29578 .36451 Mdot
.29583 .36438 Mdot
.29588 .36424 Mdot
.29593 .36411 Mdot
.29597 .36398 Mdot
.29602 .36384 Mdot
.29607 .36371 Mdot
.29612 .36357 Mdot
.29616 .36344 Mdot
.29621 .3633 Mdot
.29626 .36317 Mdot
.29631 .36303 Mdot
.29635 .36289 Mdot
.2964 .36276 Mdot
.29645 .36262 Mdot
.2965 .36249 Mdot
.29654 .36235 Mdot
.29659 .36221 Mdot
.29664 .36208 Mdot
.29669 .36194 Mdot
.29673 .3618 Mdot
.29678 .36167 Mdot
.29683 .36153 Mdot
.29688 .36139 Mdot
.29693 .36126 Mdot
.29697 .36112 Mdot
.29702 .36098 Mdot
.29707 .36084 Mdot
.29712 .36071 Mdot
.29716 .36057 Mdot
.29721 .36043 Mdot
.29726 .36029 Mdot
.29731 .36015 Mdot
.29735 .36001 Mdot
.2974 .35988 Mdot
.29745 .35974 Mdot
.2975 .3596 Mdot
.29754 .35946 Mdot
.29759 .35932 Mdot
.29764 .35918 Mdot
.29769 .35904 Mdot
.29773 .3589 Mdot
.29778 .35876 Mdot
.29783 .35862 Mdot
.29788 .35848 Mdot
.29792 .35834 Mdot
.29797 .3582 Mdot
.29802 .35806 Mdot
.29807 .35792 Mdot
.29812 .35778 Mdot
.29816 .35764 Mdot
.29821 .35749 Mdot
.29826 .35735 Mdot
.29831 .35721 Mdot
.29835 .35707 Mdot
.2984 .35693 Mdot
.29845 .35679 Mdot
.2985 .35664 Mdot
.29854 .3565 Mdot
.29859 .35636 Mdot
.29864 .35622 Mdot
.29869 .35607 Mdot
.29873 .35593 Mdot
.29878 .35579 Mdot
.29883 .35565 Mdot
.29888 .3555 Mdot
.29892 .35536 Mdot
.29897 .35522 Mdot
.29902 .35507 Mdot
.29907 .35493 Mdot
.29912 .35478 Mdot
.29916 .35464 Mdot
.29921 .3545 Mdot
.29926 .35435 Mdot
.29931 .35421 Mdot
.29935 .35406 Mdot
.2994 .35392 Mdot
.29945 .35377 Mdot
.2995 .35363 Mdot
.29954 .35348 Mdot
.29959 .35334 Mdot
.29964 .35319 Mdot
.29969 .35304 Mdot
.29973 .3529 Mdot
.29978 .35275 Mdot
.29983 .35261 Mdot
.29988 .35246 Mdot
.29992 .35231 Mdot
.29997 .35217 Mdot
.30002 .35202 Mdot
.30007 .35188 Mdot
.30012 .35173 Mdot
.30016 .35158 Mdot
.30021 .35143 Mdot
.30026 .35129 Mdot
.30031 .35114 Mdot
.30035 .35099 Mdot
.3004 .35085 Mdot
.30045 .3507 Mdot
.3005 .35055 Mdot
.30054 .3504 Mdot
.30059 .35025 Mdot
.30064 .35011 Mdot
.30069 .34996 Mdot
.30073 .34981 Mdot
.30078 .34966 Mdot
.30083 .34951 Mdot
.30088 .34936 Mdot
.30092 .34921 Mdot
.30097 .34906 Mdot
.30102 .34892 Mdot
.30107 .34877 Mdot
.30112 .34862 Mdot
.30116 .34847 Mdot
.30121 .34832 Mdot
.30126 .34817 Mdot
.30131 .34802 Mdot
.30135 .34787 Mdot
.3014 .34772 Mdot
.30145 .34757 Mdot
.3015 .34742 Mdot
.30154 .34727 Mdot
.30159 .34711 Mdot
.30164 .34696 Mdot
.30169 .34681 Mdot
.30173 .34666 Mdot
.30178 .34651 Mdot
.30183 .34636 Mdot
.30188 .34621 Mdot
.30192 .34606 Mdot
.30197 .3459 Mdot
.30202 .34575 Mdot
.30207 .3456 Mdot
.30212 .34545 Mdot
.30216 .3453 Mdot
.30221 .34514 Mdot
.30226 .34499 Mdot
.30231 .34484 Mdot
.30235 .34469 Mdot
.3024 .34453 Mdot
.30245 .34438 Mdot
.3025 .34423 Mdot
.30254 .34407 Mdot
.30259 .34392 Mdot
.30264 .34377 Mdot
.30269 .34361 Mdot
.30273 .34346 Mdot
.30278 .34331 Mdot
.30283 .34315 Mdot
.30288 .343 Mdot
.30292 .34284 Mdot
.30297 .34269 Mdot
.30302 .34254 Mdot
.30307 .34238 Mdot
.30311 .34223 Mdot
.30316 .34207 Mdot
.30321 .34192 Mdot
.30326 .34176 Mdot
.30331 .34161 Mdot
.30335 .34145 Mdot
.3034 .3413 Mdot
.30345 .34114 Mdot
.3035 .34099 Mdot
.30354 .34083 Mdot
.30359 .34068 Mdot
.30364 .34052 Mdot
.30369 .34036 Mdot
.30373 .34021 Mdot
.30378 .34005 Mdot
.30383 .3399 Mdot
.30388 .33974 Mdot
.30392 .33958 Mdot
.30397 .33943 Mdot
.30402 .33927 Mdot
.30407 .33911 Mdot
.30411 .33896 Mdot
.30416 .3388 Mdot
.30421 .33864 Mdot
.30426 .33848 Mdot
.30431 .33833 Mdot
.30435 .33817 Mdot
.3044 .33801 Mdot
.30445 .33785 Mdot
.3045 .3377 Mdot
.30454 .33754 Mdot
.30459 .33738 Mdot
.30464 .33722 Mdot
.30469 .33707 Mdot
.30473 .33691 Mdot
.30478 .33675 Mdot
.30483 .33659 Mdot
.30488 .33643 Mdot
.30492 .33627 Mdot
.30497 .33611 Mdot
.30502 .33596 Mdot
.30507 .3358 Mdot
.30511 .33564 Mdot
.30516 .33548 Mdot
.30521 .33532 Mdot
.30526 .33516 Mdot
.30531 .335 Mdot
.30535 .33484 Mdot
.3054 .33468 Mdot
.30545 .33452 Mdot
.3055 .33436 Mdot
.30554 .3342 Mdot
.30559 .33404 Mdot
.30564 .33388 Mdot
.30569 .33372 Mdot
.30573 .33356 Mdot
.30578 .3334 Mdot
.30583 .33324 Mdot
.30588 .33308 Mdot
.30592 .33292 Mdot
.30597 .33276 Mdot
.30602 .33259 Mdot
.30607 .33243 Mdot
.30611 .33227 Mdot
.30616 .33211 Mdot
.30621 .33195 Mdot
.30626 .33179 Mdot
.30631 .33163 Mdot
.30635 .33146 Mdot
.3064 .3313 Mdot
.30645 .33114 Mdot
.3065 .33098 Mdot
.30654 .33082 Mdot
.30659 .33065 Mdot
.30664 .33049 Mdot
.30669 .33033 Mdot
.30673 .33017 Mdot
.30678 .33 Mdot
.30683 .32984 Mdot
.30688 .32968 Mdot
.30692 .32952 Mdot
.30697 .32935 Mdot
.30702 .32919 Mdot
.30707 .32903 Mdot
.30711 .32886 Mdot
.30716 .3287 Mdot
.30721 .32854 Mdot
.30726 .32837 Mdot
.3073 .32821 Mdot
.30735 .32805 Mdot
.3074 .32788 Mdot
.30745 .32772 Mdot
.3075 .32756 Mdot
.30754 .32739 Mdot
.30759 .32723 Mdot
.30764 .32706 Mdot
.30769 .3269 Mdot
.30773 .32673 Mdot
.30778 .32657 Mdot
.30783 .3264 Mdot
.30788 .32624 Mdot
.30792 .32607 Mdot
.30797 .32591 Mdot
.30802 .32574 Mdot
.30807 .32558 Mdot
.30811 .32541 Mdot
.30816 .32525 Mdot
.30821 .32508 Mdot
.30826 .32492 Mdot
.3083 .32475 Mdot
.30835 .32459 Mdot
.3084 .32442 Mdot
.30845 .32426 Mdot
.3085 .32409 Mdot
.30854 .32392 Mdot
.30859 .32376 Mdot
.30864 .32359 Mdot
.30869 .32342 Mdot
.30873 .32326 Mdot
.30878 .32309 Mdot
.30883 .32293 Mdot
.30888 .32276 Mdot
.30892 .32259 Mdot
.30897 .32243 Mdot
.30902 .32226 Mdot
.30907 .32209 Mdot
.30911 .32192 Mdot
.30916 .32176 Mdot
.30921 .32159 Mdot
.30926 .32142 Mdot
.3093 .32126 Mdot
.30935 .32109 Mdot
.3094 .32092 Mdot
.30945 .32075 Mdot
.3095 .32059 Mdot
.30954 .32042 Mdot
.30959 .32025 Mdot
.30964 .32008 Mdot
.30969 .31991 Mdot
.30973 .31975 Mdot
.30978 .31958 Mdot
.30983 .31941 Mdot
.30988 .31924 Mdot
.30992 .31907 Mdot
.30997 .3189 Mdot
.31002 .31874 Mdot
.31007 .31857 Mdot
.31011 .3184 Mdot
.31016 .31823 Mdot
.31021 .31806 Mdot
.31026 .31789 Mdot
.3103 .31772 Mdot
.31035 .31755 Mdot
.3104 .31738 Mdot
.31045 .31721 Mdot
.3105 .31705 Mdot
.31054 .31688 Mdot
.31059 .31671 Mdot
.31064 .31654 Mdot
.31069 .31637 Mdot
.31073 .3162 Mdot
.31078 .31603 Mdot
.31083 .31586 Mdot
.31088 .31569 Mdot
.31092 .31552 Mdot
.31097 .31535 Mdot
.31102 .31518 Mdot
.31107 .31501 Mdot
.31111 .31484 Mdot
.31116 .31467 Mdot
.31121 .3145 Mdot
.31126 .31433 Mdot
.3113 .31416 Mdot
.31135 .31399 Mdot
.3114 .31381 Mdot
.31145 .31364 Mdot
.3115 .31347 Mdot
.31154 .3133 Mdot
.31159 .31313 Mdot
.31164 .31296 Mdot
.31169 .31279 Mdot
.31173 .31262 Mdot
.31178 .31245 Mdot
.31183 .31228 Mdot
.31188 .3121 Mdot
.31192 .31193 Mdot
.31197 .31176 Mdot
.31202 .31159 Mdot
.31207 .31142 Mdot
.31211 .31125 Mdot
.31216 .31108 Mdot
.31221 .3109 Mdot
.31226 .31073 Mdot
.3123 .31056 Mdot
.31235 .31039 Mdot
.3124 .31022 Mdot
.31245 .31004 Mdot
.31249 .30987 Mdot
.31254 .3097 Mdot
.31259 .30953 Mdot
.31264 .30936 Mdot
.31269 .30918 Mdot
.31273 .30901 Mdot
.31278 .30884 Mdot
.31283 .30867 Mdot
.31288 .30849 Mdot
.31292 .30832 Mdot
.31297 .30815 Mdot
.31302 .30798 Mdot
.31307 .3078 Mdot
.31311 .30763 Mdot
.31316 .30746 Mdot
.31321 .30728 Mdot
.31326 .30711 Mdot
.3133 .30694 Mdot
.31335 .30677 Mdot
.3134 .30659 Mdot
.31345 .30642 Mdot
.31349 .30625 Mdot
.31354 .30607 Mdot
.31359 .3059 Mdot
.31364 .30573 Mdot
.31369 .30555 Mdot
.31373 .30538 Mdot
.31378 .30521 Mdot
.31383 .30503 Mdot
.31388 .30486 Mdot
.31392 .30468 Mdot
.31397 .30451 Mdot
.31402 .30434 Mdot
.31407 .30416 Mdot
.31411 .30399 Mdot
.31416 .30381 Mdot
.31421 .30364 Mdot
.31426 .30347 Mdot
.3143 .30329 Mdot
.31435 .30312 Mdot
.3144 .30294 Mdot
.31445 .30277 Mdot
.31449 .30259 Mdot
.31454 .30242 Mdot
.31459 .30225 Mdot
.31464 .30207 Mdot
.31469 .3019 Mdot
.31473 .30172 Mdot
.31478 .30155 Mdot
.31483 .30137 Mdot
.31488 .3012 Mdot
.31492 .30102 Mdot
.31497 .30085 Mdot
.31502 .30067 Mdot
.31507 .3005 Mdot
.31511 .30032 Mdot
.31516 .30015 Mdot
.31521 .29997 Mdot
.31526 .2998 Mdot
.3153 .29962 Mdot
.31535 .29945 Mdot
.3154 .29927 Mdot
.31545 .2991 Mdot
.31549 .29892 Mdot
.31554 .29874 Mdot
.31559 .29857 Mdot
.31564 .29839 Mdot
.31569 .29822 Mdot
.31573 .29804 Mdot
.31578 .29787 Mdot
.31583 .29769 Mdot
.31588 .29751 Mdot
.31592 .29734 Mdot
.31597 .29716 Mdot
.31602 .29699 Mdot
.31607 .29681 Mdot
.31611 .29663 Mdot
.31616 .29646 Mdot
.31621 .29628 Mdot
.31626 .2961 Mdot
.3163 .29593 Mdot
.31635 .29575 Mdot
.3164 .29557 Mdot
.31645 .2954 Mdot
.31649 .29522 Mdot
.31654 .29504 Mdot
.31659 .29487 Mdot
.31664 .29469 Mdot
.31668 .29451 Mdot
.31673 .29434 Mdot
.31678 .29416 Mdot
.31683 .29398 Mdot
.31688 .29381 Mdot
.31692 .29363 Mdot
.31697 .29345 Mdot
.31702 .29328 Mdot
.31707 .2931 Mdot
.31711 .29292 Mdot
.31716 .29274 Mdot
.31721 .29257 Mdot
.31726 .29239 Mdot
.3173 .29221 Mdot
.31735 .29204 Mdot
.3174 .29186 Mdot
.31745 .29168 Mdot
.31749 .2915 Mdot
.31754 .29133 Mdot
.31759 .29115 Mdot
.31764 .29097 Mdot
.31768 .29079 Mdot
.31773 .29062 Mdot
.31778 .29044 Mdot
.31783 .29026 Mdot
.31788 .29008 Mdot
.31792 .2899 Mdot
.31797 .28973 Mdot
.31802 .28955 Mdot
.31807 .28937 Mdot
.31811 .28919 Mdot
.31816 .28902 Mdot
.31821 .28884 Mdot
.31826 .28866 Mdot
.3183 .28848 Mdot
.31835 .2883 Mdot
.3184 .28813 Mdot
.31845 .28795 Mdot
.31849 .28777 Mdot
.31854 .28759 Mdot
.31859 .28741 Mdot
.31864 .28723 Mdot
.31868 .28706 Mdot
.31873 .28688 Mdot
.31878 .2867 Mdot
.31883 .28652 Mdot
.31888 .28634 Mdot
.31892 .28616 Mdot
.31897 .28599 Mdot
.31902 .28581 Mdot
.31907 .28563 Mdot
.31911 .28545 Mdot
.31916 .28527 Mdot
.31921 .28509 Mdot
.31926 .28491 Mdot
.3193 .28474 Mdot
.31935 .28456 Mdot
.3194 .28438 Mdot
.31945 .2842 Mdot
.31949 .28402 Mdot
.31954 .28384 Mdot
.31959 .28366 Mdot
.31964 .28348 Mdot
.31968 .28331 Mdot
.31973 .28313 Mdot
.31978 .28295 Mdot
.31983 .28277 Mdot
.31988 .28259 Mdot
.31992 .28241 Mdot
.31997 .28223 Mdot
.32002 .28205 Mdot
.32007 .28187 Mdot
.32011 .2817 Mdot
.32016 .28152 Mdot
.32021 .28134 Mdot
.32026 .28116 Mdot
.3203 .28098 Mdot
.32035 .2808 Mdot
.3204 .28062 Mdot
.32045 .28044 Mdot
.32049 .28026 Mdot
.32054 .28009 Mdot
.32059 .27991 Mdot
.32064 .27973 Mdot
.32068 .27955 Mdot
.32073 .27937 Mdot
.32078 .27919 Mdot
.32083 .27901 Mdot
.32088 .27883 Mdot
.32092 .27865 Mdot
.32097 .27847 Mdot
.32102 .2783 Mdot
.32107 .27812 Mdot
.32111 .27794 Mdot
.32116 .27776 Mdot
.32121 .27758 Mdot
.32126 .2774 Mdot
.3213 .27722 Mdot
.32135 .27704 Mdot
.3214 .27686 Mdot
.32145 .27668 Mdot
.32149 .2765 Mdot
.32154 .27633 Mdot
.32159 .27615 Mdot
.32164 .27597 Mdot
.32168 .27579 Mdot
.32173 .27561 Mdot
.32178 .27543 Mdot
.32183 .27525 Mdot
.32187 .27507 Mdot
.32192 .27489 Mdot
.32197 .27471 Mdot
.32202 .27453 Mdot
.32207 .27435 Mdot
.32211 .27418 Mdot
.32216 .274 Mdot
.32221 .27382 Mdot
.32226 .27364 Mdot
.3223 .27346 Mdot
.32235 .27328 Mdot
.3224 .2731 Mdot
.32245 .27292 Mdot
.32249 .27274 Mdot
.32254 .27256 Mdot
.32259 .27238 Mdot
.32264 .2722 Mdot
.32268 .27202 Mdot
.32273 .27184 Mdot
.32278 .27167 Mdot
.32283 .27149 Mdot
.32287 .27131 Mdot
.32292 .27113 Mdot
.32297 .27095 Mdot
.32302 .27077 Mdot
.32307 .27059 Mdot
.32311 .27041 Mdot
.32316 .27023 Mdot
.32321 .27005 Mdot
.32326 .26987 Mdot
.3233 .26969 Mdot
.32335 .26951 Mdot
.3234 .26933 Mdot
.32345 .26915 Mdot
.32349 .26898 Mdot
.32354 .2688 Mdot
.32359 .26862 Mdot
.32364 .26844 Mdot
.32368 .26826 Mdot
.32373 .26808 Mdot
.32378 .2679 Mdot
.32383 .26772 Mdot
.32387 .26754 Mdot
.32392 .26736 Mdot
.32397 .26718 Mdot
.32402 .267 Mdot
.32407 .26682 Mdot
.32411 .26664 Mdot
.32416 .26646 Mdot
.32421 .26629 Mdot
.32426 .26611 Mdot
.3243 .26593 Mdot
.32435 .26575 Mdot
.3244 .26557 Mdot
.32445 .26539 Mdot
.32449 .26521 Mdot
.32454 .26503 Mdot
.32459 .26485 Mdot
.32464 .26467 Mdot
.32468 .26449 Mdot
.32473 .26431 Mdot
.32478 .26414 Mdot
.32483 .26396 Mdot
.32487 .26378 Mdot
.32492 .2636 Mdot
.32497 .26342 Mdot
.32502 .26324 Mdot
.32507 .26306 Mdot
.32511 .26288 Mdot
.32516 .2627 Mdot
.32521 .26252 Mdot
.32526 .26235 Mdot
.3253 .26217 Mdot
.32535 .26199 Mdot
.3254 .26181 Mdot
.32545 .26163 Mdot
.32549 .26145 Mdot
.32554 .26127 Mdot
.32559 .26109 Mdot
.32564 .26091 Mdot
.32568 .26074 Mdot
.32573 .26056 Mdot
.32578 .26038 Mdot
.32583 .2602 Mdot
.32587 .26002 Mdot
.32592 .25984 Mdot
.32597 .25966 Mdot
.32602 .25948 Mdot
.32607 .25931 Mdot
.32611 .25913 Mdot
.32616 .25895 Mdot
.32621 .25877 Mdot
.32626 .25859 Mdot
.3263 .25841 Mdot
.32635 .25824 Mdot
.3264 .25806 Mdot
.32645 .25788 Mdot
.32649 .2577 Mdot
.32654 .25752 Mdot
.32659 .25734 Mdot
.32664 .25717 Mdot
.32668 .25699 Mdot
.32673 .25681 Mdot
.32678 .25663 Mdot
.32683 .25645 Mdot
.32687 .25627 Mdot
.32692 .2561 Mdot
.32697 .25592 Mdot
.32702 .25574 Mdot
.32706 .25556 Mdot
.32711 .25538 Mdot
.32716 .25521 Mdot
.32721 .25503 Mdot
.32726 .25485 Mdot
.3273 .25467 Mdot
.32735 .2545 Mdot
.3274 .25432 Mdot
.32745 .25414 Mdot
.32749 .25396 Mdot
.32754 .25378 Mdot
.32759 .25361 Mdot
.32764 .25343 Mdot
.32768 .25325 Mdot
.32773 .25307 Mdot
.32778 .2529 Mdot
.32783 .25272 Mdot
.32787 .25254 Mdot
.32792 .25236 Mdot
.32797 .25219 Mdot
.32802 .25201 Mdot
.32806 .25183 Mdot
.32811 .25166 Mdot
.32816 .25148 Mdot
.32821 .2513 Mdot
.32826 .25112 Mdot
.3283 .25095 Mdot
.32835 .25077 Mdot
.3284 .25059 Mdot
.32845 .25042 Mdot
.32849 .25024 Mdot
.32854 .25006 Mdot
.32859 .24989 Mdot
.32864 .24971 Mdot
.32868 .24953 Mdot
.32873 .24935 Mdot
.32878 .24918 Mdot
.32883 .249 Mdot
.32887 .24883 Mdot
.32892 .24865 Mdot
.32897 .24847 Mdot
.32902 .2483 Mdot
.32906 .24812 Mdot
.32911 .24794 Mdot
.32916 .24777 Mdot
.32921 .24759 Mdot
.32926 .24742 Mdot
.3293 .24724 Mdot
.32935 .24706 Mdot
.3294 .24689 Mdot
.32945 .24671 Mdot
.32949 .24654 Mdot
.32954 .24636 Mdot
.32959 .24618 Mdot
.32964 .24601 Mdot
.32968 .24583 Mdot
.32973 .24566 Mdot
.32978 .24548 Mdot
.32983 .24531 Mdot
.32987 .24513 Mdot
.32992 .24496 Mdot
.32997 .24478 Mdot
.33002 .24461 Mdot
.33006 .24443 Mdot
.33011 .24426 Mdot
.33016 .24408 Mdot
.33021 .2439 Mdot
.33026 .24373 Mdot
.3303 .24355 Mdot
.33035 .24338 Mdot
.3304 .24321 Mdot
.33045 .24303 Mdot
.33049 .24286 Mdot
.33054 .24268 Mdot
.33059 .24251 Mdot
.33064 .24233 Mdot
.33068 .24216 Mdot
.33073 .24198 Mdot
.33078 .24181 Mdot
.33083 .24163 Mdot
.33087 .24146 Mdot
.33092 .24129 Mdot
.33097 .24111 Mdot
.33102 .24094 Mdot
.33106 .24076 Mdot
.33111 .24059 Mdot
.33116 .24042 Mdot
.33121 .24024 Mdot
.33125 .24007 Mdot
.3313 .2399 Mdot
.33135 .23972 Mdot
.3314 .23955 Mdot
.33145 .23937 Mdot
.33149 .2392 Mdot
.33154 .23903 Mdot
.33159 .23885 Mdot
.33164 .23868 Mdot
.33168 .23851 Mdot
.33173 .23834 Mdot
.33178 .23816 Mdot
.33183 .23799 Mdot
.33187 .23782 Mdot
.33192 .23764 Mdot
.33197 .23747 Mdot
.33202 .2373 Mdot
.33206 .23713 Mdot
.33211 .23695 Mdot
.33216 .23678 Mdot
.33221 .23661 Mdot
.33225 .23644 Mdot
.3323 .23626 Mdot
.33235 .23609 Mdot
.3324 .23592 Mdot
.33245 .23575 Mdot
.33249 .23558 Mdot
.33254 .2354 Mdot
.33259 .23523 Mdot
.33264 .23506 Mdot
.33268 .23489 Mdot
.33273 .23472 Mdot
.33278 .23454 Mdot
.33283 .23437 Mdot
.33287 .2342 Mdot
.33292 .23403 Mdot
.33297 .23386 Mdot
.33302 .23369 Mdot
.33306 .23352 Mdot
.33311 .23335 Mdot
.33316 .23317 Mdot
.33321 .233 Mdot
.33325 .23283 Mdot
.3333 .23266 Mdot
.33335 .23249 Mdot
.3334 .23232 Mdot
.33345 .23215 Mdot
.33349 .23198 Mdot
.33354 .23181 Mdot
.33359 .23164 Mdot
.33364 .23147 Mdot
.33368 .2313 Mdot
.33373 .23113 Mdot
.33378 .23096 Mdot
.33383 .23079 Mdot
.33387 .23062 Mdot
.33392 .23045 Mdot
.33397 .23028 Mdot
.33402 .23011 Mdot
.33406 .22994 Mdot
.33411 .22977 Mdot
.33416 .2296 Mdot
.33421 .22943 Mdot
.33425 .22927 Mdot
.3343 .2291 Mdot
.33435 .22893 Mdot
.3344 .22876 Mdot
.33445 .22859 Mdot
.33449 .22842 Mdot
.33454 .22825 Mdot
.33459 .22808 Mdot
.33464 .22792 Mdot
.33468 .22775 Mdot
.33473 .22758 Mdot
.33478 .22741 Mdot
.33483 .22724 Mdot
.33487 .22708 Mdot
.33492 .22691 Mdot
.33497 .22674 Mdot
.33502 .22657 Mdot
.33506 .22641 Mdot
.33511 .22624 Mdot
.33516 .22607 Mdot
.33521 .2259 Mdot
.33525 .22574 Mdot
.3353 .22557 Mdot
.33535 .2254 Mdot
.3354 .22524 Mdot
.33545 .22507 Mdot
.33549 .2249 Mdot
.33554 .22474 Mdot
.33559 .22457 Mdot
.33564 .2244 Mdot
.33568 .22424 Mdot
.33573 .22407 Mdot
.33578 .2239 Mdot
.33583 .22374 Mdot
.33587 .22357 Mdot
.33592 .22341 Mdot
.33597 .22324 Mdot
.33602 .22307 Mdot
.33606 .22291 Mdot
.33611 .22274 Mdot
.33616 .22258 Mdot
.33621 .22241 Mdot
.33625 .22225 Mdot
.3363 .22208 Mdot
.33635 .22192 Mdot
.3364 .22175 Mdot
.33644 .22159 Mdot
.33649 .22142 Mdot
.33654 .22126 Mdot
.33659 .22109 Mdot
.33664 .22093 Mdot
.33668 .22076 Mdot
.33673 .2206 Mdot
.33678 .22044 Mdot
.33683 .22027 Mdot
.33687 .22011 Mdot
.33692 .21994 Mdot
.33697 .21978 Mdot
.33702 .21962 Mdot
.33706 .21945 Mdot
.33711 .21929 Mdot
.33716 .21913 Mdot
.33721 .21896 Mdot
.33725 .2188 Mdot
.3373 .21864 Mdot
.33735 .21847 Mdot
.3374 .21831 Mdot
.33744 .21815 Mdot
.33749 .21798 Mdot
.33754 .21782 Mdot
.33759 .21766 Mdot
.33764 .2175 Mdot
.33768 .21733 Mdot
.33773 .21717 Mdot
.33778 .21701 Mdot
.33783 .21685 Mdot
.33787 .21669 Mdot
.33792 .21652 Mdot
.33797 .21636 Mdot
.33802 .2162 Mdot
.33806 .21604 Mdot
.33811 .21588 Mdot
.33816 .21572 Mdot
.33821 .21555 Mdot
.33825 .21539 Mdot
.3383 .21523 Mdot
.33835 .21507 Mdot
.3384 .21491 Mdot
.33844 .21475 Mdot
.33849 .21459 Mdot
.33854 .21443 Mdot
.33859 .21427 Mdot
.33864 .21411 Mdot
.33868 .21395 Mdot
.33873 .21379 Mdot
.33878 .21363 Mdot
.33883 .21347 Mdot
.33887 .21331 Mdot
.33892 .21315 Mdot
.33897 .21299 Mdot
.33902 .21283 Mdot
.33906 .21267 Mdot
.33911 .21251 Mdot
.33916 .21235 Mdot
.33921 .21219 Mdot
.33925 .21203 Mdot
.3393 .21187 Mdot
.33935 .21172 Mdot
.3394 .21156 Mdot
.33944 .2114 Mdot
.33949 .21124 Mdot
.33954 .21108 Mdot
.33959 .21092 Mdot
.33964 .21077 Mdot
.33968 .21061 Mdot
.33973 .21045 Mdot
.33978 .21029 Mdot
.33983 .21014 Mdot
.33987 .20998 Mdot
.33992 .20982 Mdot
.33997 .20966 Mdot
.34002 .20951 Mdot
.34006 .20935 Mdot
.34011 .20919 Mdot
.34016 .20904 Mdot
.34021 .20888 Mdot
.34025 .20872 Mdot
.3403 .20857 Mdot
.34035 .20841 Mdot
.3404 .20826 Mdot
.34044 .2081 Mdot
.34049 .20794 Mdot
.34054 .20779 Mdot
.34059 .20763 Mdot
.34063 .20748 Mdot
.34068 .20732 Mdot
.34073 .20717 Mdot
.34078 .20701 Mdot
.34083 .20686 Mdot
.34087 .2067 Mdot
.34092 .20655 Mdot
.34097 .20639 Mdot
.34102 .20624 Mdot
.34106 .20608 Mdot
.34111 .20593 Mdot
.34116 .20577 Mdot
.34121 .20562 Mdot
.34125 .20547 Mdot
.3413 .20531 Mdot
.34135 .20516 Mdot
.3414 .20501 Mdot
.34144 .20485 Mdot
.34149 .2047 Mdot
.34154 .20455 Mdot
.34159 .20439 Mdot
.34163 .20424 Mdot
.34168 .20409 Mdot
.34173 .20393 Mdot
.34178 .20378 Mdot
.34183 .20363 Mdot
.34187 .20348 Mdot
.34192 .20332 Mdot
.34197 .20317 Mdot
.34202 .20302 Mdot
.34206 .20287 Mdot
.34211 .20272 Mdot
.34216 .20257 Mdot
.34221 .20241 Mdot
.34225 .20226 Mdot
.3423 .20211 Mdot
.34235 .20196 Mdot
.3424 .20181 Mdot
.34244 .20166 Mdot
.34249 .20151 Mdot
.34254 .20136 Mdot
.34259 .20121 Mdot
.34263 .20106 Mdot
.34268 .20091 Mdot
.34273 .20076 Mdot
.34278 .20061 Mdot
.34283 .20046 Mdot
.34287 .20031 Mdot
.34292 .20016 Mdot
.34297 .20001 Mdot
.34302 .19986 Mdot
.34306 .19971 Mdot
.34311 .19956 Mdot
.34316 .19941 Mdot
.34321 .19926 Mdot
.34325 .19912 Mdot
.3433 .19897 Mdot
.34335 .19882 Mdot
.3434 .19867 Mdot
.34344 .19852 Mdot
.34349 .19838 Mdot
.34354 .19823 Mdot
.34359 .19808 Mdot
.34363 .19794 Mdot
.34368 .19779 Mdot
.34373 .19764 Mdot
.34378 .19749 Mdot
.34383 .19735 Mdot
.34387 .1972 Mdot
.34392 .19706 Mdot
.34397 .19691 Mdot
.34402 .19676 Mdot
.34406 .19662 Mdot
.34411 .19647 Mdot
.34416 .19633 Mdot
.34421 .19618 Mdot
.34425 .19603 Mdot
.3443 .19589 Mdot
.34435 .19574 Mdot
.3444 .1956 Mdot
.34444 .19545 Mdot
.34449 .19531 Mdot
.34454 .19516 Mdot
.34459 .19502 Mdot
.34463 .19488 Mdot
.34468 .19473 Mdot
.34473 .19459 Mdot
.34478 .19444 Mdot
.34483 .1943 Mdot
.34487 .19416 Mdot
.34492 .19401 Mdot
.34497 .19387 Mdot
.34502 .19373 Mdot
.34506 .19358 Mdot
.34511 .19344 Mdot
.34516 .1933 Mdot
.34521 .19315 Mdot
.34525 .19301 Mdot
.3453 .19287 Mdot
.34535 .19273 Mdot
.3454 .19259 Mdot
.34544 .19244 Mdot
.34549 .1923 Mdot
.34554 .19216 Mdot
.34559 .19202 Mdot
.34563 .19188 Mdot
.34568 .19174 Mdot
.34573 .1916 Mdot
.34578 .19146 Mdot
.34582 .19132 Mdot
.34587 .19117 Mdot
.34592 .19103 Mdot
.34597 .19089 Mdot
.34602 .19075 Mdot
.34606 .19061 Mdot
.34611 .19047 Mdot
.34616 .19033 Mdot
.34621 .1902 Mdot
.34625 .19006 Mdot
.3463 .18992 Mdot
.34635 .18978 Mdot
.3464 .18964 Mdot
.34644 .1895 Mdot
.34649 .18936 Mdot
.34654 .18922 Mdot
.34659 .18909 Mdot
.34663 .18895 Mdot
.34668 .18881 Mdot
.34673 .18867 Mdot
.34678 .18853 Mdot
.34682 .1884 Mdot
.34687 .18826 Mdot
.34692 .18812 Mdot
.34697 .18799 Mdot
.34702 .18785 Mdot
.34706 .18771 Mdot
.34711 .18758 Mdot
.34716 .18744 Mdot
.34721 .1873 Mdot
.34725 .18717 Mdot
.3473 .18703 Mdot
.34735 .1869 Mdot
.3474 .18676 Mdot
.34744 .18663 Mdot
.34749 .18649 Mdot
.34754 .18636 Mdot
.34759 .18622 Mdot
.34763 .18609 Mdot
.34768 .18595 Mdot
.34773 .18582 Mdot
.34778 .18568 Mdot
.34782 .18555 Mdot
.34787 .18542 Mdot
.34792 .18528 Mdot
.34797 .18515 Mdot
.34802 .18502 Mdot
.34806 .18488 Mdot
.34811 .18475 Mdot
.34816 .18462 Mdot
.34821 .18449 Mdot
.34825 .18435 Mdot
.3483 .18422 Mdot
.34835 .18409 Mdot
.3484 .18396 Mdot
.34844 .18383 Mdot
.34849 .18369 Mdot
.34854 .18356 Mdot
.34859 .18343 Mdot
.34863 .1833 Mdot
.34868 .18317 Mdot
.34873 .18304 Mdot
.34878 .18291 Mdot
.34882 .18278 Mdot
.34887 .18265 Mdot
.34892 .18252 Mdot
.34897 .18239 Mdot
.34902 .18226 Mdot
.34906 .18213 Mdot
.34911 .182 Mdot
.34916 .18187 Mdot
.34921 .18174 Mdot
.34925 .18161 Mdot
.3493 .18148 Mdot
.34935 .18135 Mdot
.3494 .18123 Mdot
.34944 .1811 Mdot
.34949 .18097 Mdot
.34954 .18084 Mdot
.34959 .18072 Mdot
.34963 .18059 Mdot
.34968 .18046 Mdot
.34973 .18033 Mdot
.34978 .18021 Mdot
.34982 .18008 Mdot
.34987 .17995 Mdot
.34992 .17983 Mdot
.34997 .1797 Mdot
.35001 .17957 Mdot
.35006 .17945 Mdot
.35011 .17932 Mdot
.35016 .1792 Mdot
.35021 .17907 Mdot
.35025 .17895 Mdot
.3503 .17882 Mdot
.35035 .1787 Mdot
.3504 .17857 Mdot
.35044 .17845 Mdot
.35049 .17833 Mdot
.35054 .1782 Mdot
.35059 .17808 Mdot
.35063 .17795 Mdot
.35068 .17783 Mdot
.35073 .17771 Mdot
.35078 .17758 Mdot
.35082 .17746 Mdot
.35087 .17734 Mdot
.35092 .17722 Mdot
.35097 .17709 Mdot
.35101 .17697 Mdot
.35106 .17685 Mdot
.35111 .17673 Mdot
.35116 .17661 Mdot
.35121 .17649 Mdot
.35125 .17636 Mdot
.3513 .17624 Mdot
.35135 .17612 Mdot
.3514 .176 Mdot
.35144 .17588 Mdot
.35149 .17576 Mdot
.35154 .17564 Mdot
.35159 .17552 Mdot
.35163 .1754 Mdot
.35168 .17528 Mdot
.35173 .17516 Mdot
.35178 .17504 Mdot
.35182 .17492 Mdot
.35187 .17481 Mdot
.35192 .17469 Mdot
.35197 .17457 Mdot
.35201 .17445 Mdot
.35206 .17433 Mdot
.35211 .17421 Mdot
.35216 .1741 Mdot
.35221 .17398 Mdot
.35225 .17386 Mdot
.3523 .17374 Mdot
.35235 .17363 Mdot
.3524 .17351 Mdot
.35244 .17339 Mdot
.35249 .17328 Mdot
.35254 .17316 Mdot
.35259 .17305 Mdot
.35263 .17293 Mdot
.35268 .17281 Mdot
.35273 .1727 Mdot
.35278 .17258 Mdot
.35282 .17247 Mdot
.35287 .17235 Mdot
.35292 .17224 Mdot
.35297 .17213 Mdot
.35301 .17201 Mdot
.35306 .1719 Mdot
.35311 .17178 Mdot
.35316 .17167 Mdot
.35321 .17156 Mdot
.35325 .17144 Mdot
.3533 .17133 Mdot
.35335 .17122 Mdot
.3534 .17111 Mdot
.35344 .17099 Mdot
.35349 .17088 Mdot
.35354 .17077 Mdot
.35359 .17066 Mdot
.35363 .17055 Mdot
.35368 .17044 Mdot
.35373 .17032 Mdot
.35378 .17021 Mdot
.35382 .1701 Mdot
.35387 .16999 Mdot
.35392 .16988 Mdot
.35397 .16977 Mdot
.35401 .16966 Mdot
.35406 .16955 Mdot
.35411 .16944 Mdot
.35416 .16933 Mdot
.35421 .16922 Mdot
.35425 .16912 Mdot
.3543 .16901 Mdot
.35435 .1689 Mdot
.3544 .16879 Mdot
.35444 .16868 Mdot
.35449 .16857 Mdot
.35454 .16847 Mdot
.35459 .16836 Mdot
.35463 .16825 Mdot
.35468 .16814 Mdot
.35473 .16804 Mdot
.35478 .16793 Mdot
.35482 .16782 Mdot
.35487 .16772 Mdot
.35492 .16761 Mdot
.35497 .1675 Mdot
.35501 .1674 Mdot
.35506 .16729 Mdot
.35511 .16719 Mdot
.35516 .16708 Mdot
.3552 .16698 Mdot
.35525 .16687 Mdot
.3553 .16677 Mdot
.35535 .16666 Mdot
.3554 .16656 Mdot
.35544 .16645 Mdot
.35549 .16635 Mdot
.35554 .16625 Mdot
.35559 .16614 Mdot
.35563 .16604 Mdot
.35568 .16594 Mdot
.35573 .16583 Mdot
.35578 .16573 Mdot
.35582 .16563 Mdot
.35587 .16553 Mdot
.35592 .16542 Mdot
.35597 .16532 Mdot
.35601 .16522 Mdot
.35606 .16512 Mdot
.35611 .16502 Mdot
.35616 .16492 Mdot
.3562 .16482 Mdot
.35625 .16472 Mdot
.3563 .16462 Mdot
.35635 .16451 Mdot
.3564 .16442 Mdot
.35644 .16432 Mdot
.35649 .16422 Mdot
.35654 .16412 Mdot
.35659 .16402 Mdot
.35663 .16392 Mdot
.35668 .16382 Mdot
.35673 .16372 Mdot
.35678 .16362 Mdot
.35682 .16352 Mdot
.35687 .16343 Mdot
.35692 .16333 Mdot
.35697 .16323 Mdot
.35701 .16314 Mdot
.35706 .16304 Mdot
.35711 .16294 Mdot
.35716 .16284 Mdot
.3572 .16275 Mdot
.35725 .16265 Mdot
.3573 .16256 Mdot
.35735 .16246 Mdot
.3574 .16237 Mdot
.35744 .16227 Mdot
.35749 .16217 Mdot
.35754 .16208 Mdot
.35759 .16199 Mdot
.35763 .16189 Mdot
.35768 .1618 Mdot
.35773 .1617 Mdot
.35778 .16161 Mdot
.35782 .16152 Mdot
.35787 .16142 Mdot
.35792 .16133 Mdot
.35797 .16124 Mdot
.35801 .16114 Mdot
.35806 .16105 Mdot
.35811 .16096 Mdot
.35816 .16087 Mdot
.3582 .16077 Mdot
.35825 .16068 Mdot
.3583 .16059 Mdot
.35835 .1605 Mdot
.3584 .16041 Mdot
.35844 .16032 Mdot
.35849 .16023 Mdot
.35854 .16014 Mdot
.35859 .16005 Mdot
.35863 .15996 Mdot
.35868 .15987 Mdot
.35873 .15978 Mdot
.35878 .15969 Mdot
.35882 .1596 Mdot
.35887 .15951 Mdot
.35892 .15942 Mdot
.35897 .15934 Mdot
.35901 .15925 Mdot
.35906 .15916 Mdot
.35911 .15907 Mdot
.35916 .15898 Mdot
.3592 .1589 Mdot
.35925 .15881 Mdot
.3593 .15872 Mdot
.35935 .15864 Mdot
.3594 .15855 Mdot
.35944 .15847 Mdot
.35949 .15838 Mdot
.35954 .15829 Mdot
.35959 .15821 Mdot
.35963 .15812 Mdot
.35968 .15804 Mdot
.35973 .15795 Mdot
.35978 .15787 Mdot
.35982 .15778 Mdot
.35987 .1577 Mdot
.35992 .15762 Mdot
.35997 .15753 Mdot
.36001 .15745 Mdot
.36006 .15737 Mdot
.36011 .15728 Mdot
.36016 .1572 Mdot
.3602 .15712 Mdot
.36025 .15704 Mdot
.3603 .15695 Mdot
.36035 .15687 Mdot
.36039 .15679 Mdot
.36044 .15671 Mdot
.36049 .15663 Mdot
.36054 .15655 Mdot
.36059 .15647 Mdot
.36063 .15639 Mdot
.36068 .15631 Mdot
.36073 .15623 Mdot
.36078 .15615 Mdot
.36082 .15607 Mdot
.36087 .15599 Mdot
.36092 .15591 Mdot
.36097 .15583 Mdot
.36101 .15575 Mdot
.36106 .15567 Mdot
.36111 .1556 Mdot
.36116 .15552 Mdot
.3612 .15544 Mdot
.36125 .15536 Mdot
.3613 .15529 Mdot
.36135 .15521 Mdot
.36139 .15513 Mdot
.36144 .15505 Mdot
.36149 .15498 Mdot
.36154 .1549 Mdot
.36159 .15483 Mdot
.36163 .15475 Mdot
.36168 .15468 Mdot
.36173 .1546 Mdot
.36178 .15453 Mdot
.36182 .15445 Mdot
.36187 .15438 Mdot
.36192 .1543 Mdot
.36197 .15423 Mdot
.36201 .15415 Mdot
.36206 .15408 Mdot
.36211 .15401 Mdot
.36216 .15393 Mdot
.3622 .15386 Mdot
.36225 .15379 Mdot
.3623 .15372 Mdot
.36235 .15364 Mdot
.36239 .15357 Mdot
.36244 .1535 Mdot
.36249 .15343 Mdot
.36254 .15336 Mdot
.36259 .15329 Mdot
.36263 .15322 Mdot
.36268 .15315 Mdot
.36273 .15308 Mdot
.36278 .15301 Mdot
.36282 .15294 Mdot
.36287 .15287 Mdot
.36292 .1528 Mdot
.36297 .15273 Mdot
.36301 .15266 Mdot
.36306 .15259 Mdot
.36311 .15253 Mdot
.36316 .15246 Mdot
.3632 .15239 Mdot
.36325 .15232 Mdot
.3633 .15225 Mdot
.36335 .15219 Mdot
.36339 .15212 Mdot
.36344 .15205 Mdot
.36349 .15199 Mdot
.36354 .15192 Mdot
.36359 .15186 Mdot
.36363 .15179 Mdot
.36368 .15173 Mdot
.36373 .15166 Mdot
.36378 .1516 Mdot
.36382 .15153 Mdot
.36387 .15147 Mdot
.36392 .1514 Mdot
.36397 .15134 Mdot
.36401 .15128 Mdot
.36406 .15121 Mdot
.36411 .15115 Mdot
.36416 .15109 Mdot
.3642 .15102 Mdot
.36425 .15096 Mdot
.3643 .1509 Mdot
.36435 .15084 Mdot
.36439 .15077 Mdot
.36444 .15071 Mdot
.36449 .15065 Mdot
.36454 .15059 Mdot
.36458 .15053 Mdot
.36463 .15047 Mdot
.36468 .15041 Mdot
.36473 .15035 Mdot
.36478 .15029 Mdot
.36482 .15023 Mdot
.36487 .15017 Mdot
.36492 .15011 Mdot
.36497 .15005 Mdot
.36501 .14999 Mdot
.36506 .14993 Mdot
.36511 .14987 Mdot
.36516 .14982 Mdot
.3652 .14976 Mdot
.36525 .1497 Mdot
.3653 .14964 Mdot
.36535 .14959 Mdot
.36539 .14953 Mdot
.36544 .14947 Mdot
.36549 .14942 Mdot
.36554 .14936 Mdot
.36558 .14931 Mdot
.36563 .14925 Mdot
.36568 .14919 Mdot
.36573 .14914 Mdot
.36578 .14908 Mdot
.36582 .14903 Mdot
.36587 .14897 Mdot
.36592 .14892 Mdot
.36597 .14887 Mdot
.36601 .14881 Mdot
.36606 .14876 Mdot
.36611 .14871 Mdot
.36616 .14865 Mdot
.3662 .1486 Mdot
.36625 .14855 Mdot
.3663 .1485 Mdot
.36635 .14844 Mdot
.36639 .14839 Mdot
.36644 .14834 Mdot
.36649 .14829 Mdot
.36654 .14824 Mdot
.36658 .14819 Mdot
.36663 .14814 Mdot
.36668 .14809 Mdot
.36673 .14803 Mdot
.36678 .14799 Mdot
.36682 .14794 Mdot
.36687 .14789 Mdot
.36692 .14784 Mdot
.36697 .14779 Mdot
.36701 .14774 Mdot
.36706 .14769 Mdot
.36711 .14764 Mdot
.36716 .1476 Mdot
.3672 .14755 Mdot
.36725 .1475 Mdot
.3673 .14745 Mdot
.36735 .14741 Mdot
.36739 .14736 Mdot
.36744 .14731 Mdot
.36749 .14727 Mdot
.36754 .14722 Mdot
.36758 .14718 Mdot
.36763 .14713 Mdot
.36768 .14709 Mdot
.36773 .14704 Mdot
.36778 .147 Mdot
.36782 .14695 Mdot
.36787 .14691 Mdot
.36792 .14686 Mdot
.36797 .14682 Mdot
.36801 .14678 Mdot
.36806 .14673 Mdot
.36811 .14669 Mdot
.36816 .14665 Mdot
.3682 .14661 Mdot
.36825 .14656 Mdot
.3683 .14652 Mdot
.36835 .14648 Mdot
.36839 .14644 Mdot
.36844 .1464 Mdot
.36849 .14636 Mdot
.36854 .14632 Mdot
.36858 .14628 Mdot
.36863 .14624 Mdot
.36868 .1462 Mdot
.36873 .14616 Mdot
.36878 .14612 Mdot
.36882 .14608 Mdot
.36887 .14604 Mdot
.36892 .146 Mdot
.36897 .14596 Mdot
.36901 .14592 Mdot
.36906 .14589 Mdot
.36911 .14585 Mdot
.36916 .14581 Mdot
.3692 .14578 Mdot
.36925 .14574 Mdot
.3693 .1457 Mdot
.36935 .14567 Mdot
.36939 .14563 Mdot
.36944 .1456 Mdot
.36949 .14556 Mdot
.36954 .14553 Mdot
.36958 .14549 Mdot
.36963 .14546 Mdot
.36968 .14542 Mdot
.36973 .14539 Mdot
.36977 .14536 Mdot
.36982 .14532 Mdot
.36987 .14529 Mdot
.36992 .14526 Mdot
.36997 .14522 Mdot
.37001 .14519 Mdot
.37006 .14516 Mdot
.37011 .14513 Mdot
.37016 .1451 Mdot
.3702 .14506 Mdot
.37025 .14503 Mdot
.3703 .145 Mdot
.37035 .14497 Mdot
.37039 .14494 Mdot
.37044 .14491 Mdot
.37049 .14488 Mdot
.37054 .14485 Mdot
.37058 .14482 Mdot
.37063 .14479 Mdot
.37068 .14477 Mdot
.37073 .14474 Mdot
.37077 .14471 Mdot
.37082 .14468 Mdot
.37087 .14465 Mdot
.37092 .14463 Mdot
.37097 .1446 Mdot
.37101 .14457 Mdot
.37106 .14455 Mdot
.37111 .14452 Mdot
.37116 .14449 Mdot
.3712 .14447 Mdot
.37125 .14444 Mdot
.3713 .14442 Mdot
.37135 .14439 Mdot
.37139 .14437 Mdot
.37144 .14434 Mdot
.37149 .14432 Mdot
.37154 .1443 Mdot
.37158 .14427 Mdot
.37163 .14425 Mdot
.37168 .14423 Mdot
.37173 .1442 Mdot
.37177 .14418 Mdot
.37182 .14416 Mdot
.37187 .14414 Mdot
.37192 .14411 Mdot
.37197 .14409 Mdot
.37201 .14407 Mdot
.37206 .14405 Mdot
.37211 .14403 Mdot
.37216 .14401 Mdot
.3722 .14399 Mdot
.37225 .14397 Mdot
.3723 .14395 Mdot
.37235 .14393 Mdot
.37239 .14391 Mdot
.37244 .14389 Mdot
.37249 .14387 Mdot
.37254 .14385 Mdot
.37258 .14383 Mdot
.37263 .14382 Mdot
.37268 .1438 Mdot
.37273 .14378 Mdot
.37277 .14376 Mdot
.37282 .14375 Mdot
.37287 .14373 Mdot
.37292 .14371 Mdot
.37297 .1437 Mdot
.37301 .14368 Mdot
.37306 .14367 Mdot
.37311 .14365 Mdot
.37316 .14364 Mdot
.3732 .14362 Mdot
.37325 .14361 Mdot
.3733 .14359 Mdot
.37335 .14358 Mdot
.37339 .14356 Mdot
.37344 .14355 Mdot
.37349 .14354 Mdot
.37354 .14352 Mdot
.37358 .14351 Mdot
.37363 .1435 Mdot
.37368 .14349 Mdot
.37373 .14348 Mdot
.37377 .14346 Mdot
.37382 .14345 Mdot
.37387 .14344 Mdot
.37392 .14343 Mdot
.37396 .14342 Mdot
.37401 .14341 Mdot
.37406 .1434 Mdot
.37411 .14339 Mdot
.37416 .14338 Mdot
.3742 .14337 Mdot
.37425 .14336 Mdot
.3743 .14335 Mdot
.37435 .14335 Mdot
.37439 .14334 Mdot
.37444 .14333 Mdot
.37449 .14332 Mdot
.37454 .14332 Mdot
.37458 .14331 Mdot
.37463 .1433 Mdot
.37468 .14329 Mdot
.37473 .14329 Mdot
.37477 .14328 Mdot
.37482 .14328 Mdot
.37487 .14327 Mdot
.37492 .14327 Mdot
.37496 .14326 Mdot
.37501 .14326 Mdot
.37506 .14325 Mdot
.37511 .14325 Mdot
.37516 .14324 Mdot
.3752 .14324 Mdot
.37525 .14324 Mdot
.3753 .14323 Mdot
.37535 .14323 Mdot
.37539 .14323 Mdot
.37544 .14323 Mdot
.37549 .14322 Mdot
.37554 .14322 Mdot
.37558 .14322 Mdot
.37563 .14322 Mdot
.37568 .14322 Mdot
.37573 .14322 Mdot
.37577 .14322 Mdot
.37582 .14322 Mdot
.37587 .14322 Mdot
.37592 .14322 Mdot
.37596 .14322 Mdot
.37601 .14322 Mdot
.37606 .14322 Mdot
.37611 .14322 Mdot
.37616 .14323 Mdot
.3762 .14323 Mdot
.37625 .14323 Mdot
.3763 .14323 Mdot
.37635 .14324 Mdot
.37639 .14324 Mdot
.37644 .14324 Mdot
.37649 .14325 Mdot
.37654 .14325 Mdot
.37658 .14326 Mdot
.37663 .14326 Mdot
.37668 .14327 Mdot
.37673 .14327 Mdot
.37677 .14328 Mdot
.37682 .14328 Mdot
.37687 .14329 Mdot
.37692 .14329 Mdot
.37696 .1433 Mdot
.37701 .14331 Mdot
.37706 .14332 Mdot
.37711 .14332 Mdot
.37716 .14333 Mdot
.3772 .14334 Mdot
.37725 .14335 Mdot
.3773 .14335 Mdot
.37735 .14336 Mdot
.37739 .14337 Mdot
.37744 .14338 Mdot
.37749 .14339 Mdot
.37754 .1434 Mdot
.37758 .14341 Mdot
.37763 .14342 Mdot
.37768 .14343 Mdot
.37773 .14344 Mdot
.37777 .14346 Mdot
.37782 .14347 Mdot
.37787 .14348 Mdot
.37792 .14349 Mdot
.37796 .1435 Mdot
.37801 .14352 Mdot
.37806 .14353 Mdot
.37811 .14354 Mdot
.37816 .14356 Mdot
.3782 .14357 Mdot
.37825 .14358 Mdot
.3783 .1436 Mdot
.37835 .14361 Mdot
.37839 .14363 Mdot
.37844 .14364 Mdot
.37849 .14366 Mdot
.37854 .14367 Mdot
.37858 .14369 Mdot
.37863 .1437 Mdot
.37868 .14372 Mdot
.37873 .14374 Mdot
.37877 .14375 Mdot
.37882 .14377 Mdot
.37887 .14379 Mdot
.37892 .14381 Mdot
.37896 .14383 Mdot
.37901 .14384 Mdot
.37906 .14386 Mdot
.37911 .14388 Mdot
.37915 .1439 Mdot
.3792 .14392 Mdot
.37925 .14394 Mdot
.3793 .14396 Mdot
.37935 .14398 Mdot
.37939 .144 Mdot
.37944 .14402 Mdot
.37949 .14404 Mdot
.37954 .14406 Mdot
.37958 .14408 Mdot
.37963 .14411 Mdot
.37968 .14413 Mdot
.37973 .14415 Mdot
.37977 .14417 Mdot
.37982 .1442 Mdot
.37987 .14422 Mdot
.37992 .14424 Mdot
.37996 .14427 Mdot
.38001 .14429 Mdot
.38006 .14431 Mdot
.38011 .14434 Mdot
.38015 .14436 Mdot
.3802 .14439 Mdot
.38025 .14441 Mdot
.3803 .14444 Mdot
.38035 .14446 Mdot
.38039 .14449 Mdot
.38044 .14452 Mdot
.38049 .14454 Mdot
.38054 .14457 Mdot
.38058 .1446 Mdot
.38063 .14462 Mdot
.38068 .14465 Mdot
.38073 .14468 Mdot
.38077 .14471 Mdot
.38082 .14474 Mdot
.38087 .14477 Mdot
.38092 .1448 Mdot
.38096 .14482 Mdot
.38101 .14485 Mdot
.38106 .14488 Mdot
.38111 .14491 Mdot
.38115 .14494 Mdot
.3812 .14498 Mdot
.38125 .14501 Mdot
.3813 .14504 Mdot
.38135 .14507 Mdot
.38139 .1451 Mdot
.38144 .14513 Mdot
.38149 .14517 Mdot
.38154 .1452 Mdot
.38158 .14523 Mdot
.38163 .14526 Mdot
.38168 .1453 Mdot
.38173 .14533 Mdot
.38177 .14537 Mdot
.38182 .1454 Mdot
.38187 .14543 Mdot
.38192 .14547 Mdot
.38196 .1455 Mdot
.38201 .14554 Mdot
.38206 .14558 Mdot
.38211 .14561 Mdot
.38215 .14565 Mdot
.3822 .14568 Mdot
.38225 .14572 Mdot
.3823 .14576 Mdot
.38235 .1458 Mdot
.38239 .14583 Mdot
.38244 .14587 Mdot
.38249 .14591 Mdot
.38254 .14595 Mdot
.38258 .14599 Mdot
.38263 .14602 Mdot
.38268 .14606 Mdot
.38273 .1461 Mdot
.38277 .14614 Mdot
.38282 .14618 Mdot
.38287 .14622 Mdot
.38292 .14626 Mdot
.38296 .1463 Mdot
.38301 .14635 Mdot
.38306 .14639 Mdot
.38311 .14643 Mdot
.38315 .14647 Mdot
.3832 .14651 Mdot
.38325 .14656 Mdot
.3833 .1466 Mdot
.38334 .14664 Mdot
.38339 .14668 Mdot
.38344 .14673 Mdot
.38349 .14677 Mdot
.38354 .14682 Mdot
.38358 .14686 Mdot
.38363 .14691 Mdot
.38368 .14695 Mdot
.38373 .147 Mdot
.38377 .14704 Mdot
.38382 .14709 Mdot
.38387 .14713 Mdot
.38392 .14718 Mdot
.38396 .14723 Mdot
.38401 .14727 Mdot
.38406 .14732 Mdot
.38411 .14737 Mdot
.38415 .14741 Mdot
.3842 .14746 Mdot
.38425 .14751 Mdot
.3843 .14756 Mdot
.38434 .14761 Mdot
.38439 .14766 Mdot
.38444 .14771 Mdot
.38449 .14776 Mdot
.38454 .14781 Mdot
.38458 .14786 Mdot
.38463 .14791 Mdot
.38468 .14796 Mdot
.38473 .14801 Mdot
.38477 .14806 Mdot
.38482 .14811 Mdot
.38487 .14816 Mdot
.38492 .14822 Mdot
.38496 .14827 Mdot
.38501 .14832 Mdot
.38506 .14837 Mdot
.38511 .14843 Mdot
.38515 .14848 Mdot
.3852 .14853 Mdot
.38525 .14859 Mdot
.3853 .14864 Mdot
.38534 .1487 Mdot
.38539 .14875 Mdot
.38544 .14881 Mdot
.38549 .14886 Mdot
.38554 .14892 Mdot
.38558 .14897 Mdot
.38563 .14903 Mdot
.38568 .14909 Mdot
.38573 .14914 Mdot
.38577 .1492 Mdot
.38582 .14926 Mdot
.38587 .14932 Mdot
.38592 .14937 Mdot
.38596 .14943 Mdot
.38601 .14949 Mdot
.38606 .14955 Mdot
.38611 .14961 Mdot
.38615 .14967 Mdot
.3862 .14973 Mdot
.38625 .14979 Mdot
.3863 .14985 Mdot
.38634 .14991 Mdot
.38639 .14997 Mdot
.38644 .15003 Mdot
.38649 .15009 Mdot
.38654 .15015 Mdot
.38658 .15021 Mdot
.38663 .15027 Mdot
.38668 .15034 Mdot
.38673 .1504 Mdot
.38677 .15046 Mdot
.38682 .15052 Mdot
.38687 .15059 Mdot
.38692 .15065 Mdot
.38696 .15071 Mdot
.38701 .15078 Mdot
.38706 .15084 Mdot
.38711 .15091 Mdot
.38715 .15097 Mdot
.3872 .15104 Mdot
.38725 .1511 Mdot
.3873 .15117 Mdot
.38734 .15123 Mdot
.38739 .1513 Mdot
.38744 .15137 Mdot
.38749 .15143 Mdot
.38754 .1515 Mdot
.38758 .15157 Mdot
.38763 .15164 Mdot
.38768 .1517 Mdot
.38773 .15177 Mdot
.38777 .15184 Mdot
.38782 .15191 Mdot
.38787 .15198 Mdot
.38792 .15205 Mdot
.38796 .15212 Mdot
.38801 .15219 Mdot
.38806 .15226 Mdot
.38811 .15233 Mdot
.38815 .1524 Mdot
.3882 .15247 Mdot
.38825 .15254 Mdot
.3883 .15261 Mdot
.38834 .15268 Mdot
.38839 .15275 Mdot
.38844 .15282 Mdot
.38849 .1529 Mdot
.38853 .15297 Mdot
.38858 .15304 Mdot
.38863 .15312 Mdot
.38868 .15319 Mdot
.38873 .15326 Mdot
.38877 .15334 Mdot
.38882 .15341 Mdot
.38887 .15348 Mdot
.38892 .15356 Mdot
.38896 .15363 Mdot
.38901 .15371 Mdot
.38906 .15378 Mdot
.38911 .15386 Mdot
.38915 .15394 Mdot
.3892 .15401 Mdot
.38925 .15409 Mdot
.3893 .15416 Mdot
.38934 .15424 Mdot
.38939 .15432 Mdot
.38944 .1544 Mdot
.38949 .15447 Mdot
.38953 .15455 Mdot
.38958 .15463 Mdot
.38963 .15471 Mdot
.38968 .15479 Mdot
.38973 .15487 Mdot
.38977 .15494 Mdot
.38982 .15502 Mdot
.38987 .1551 Mdot
.38992 .15518 Mdot
.38996 .15526 Mdot
.39001 .15534 Mdot
.39006 .15542 Mdot
.39011 .15551 Mdot
.39015 .15559 Mdot
.3902 .15567 Mdot
.39025 .15575 Mdot
.3903 .15583 Mdot
.39034 .15591 Mdot
.39039 .156 Mdot
.39044 .15608 Mdot
.39049 .15616 Mdot
.39053 .15625 Mdot
.39058 .15633 Mdot
.39063 .15641 Mdot
.39068 .1565 Mdot
.39073 .15658 Mdot
.39077 .15667 Mdot
.39082 .15675 Mdot
.39087 .15684 Mdot
.39092 .15692 Mdot
.39096 .15701 Mdot
.39101 .15709 Mdot
.39106 .15718 Mdot
.39111 .15727 Mdot
.39115 .15735 Mdot
.3912 .15744 Mdot
.39125 .15753 Mdot
.3913 .15761 Mdot
.39134 .1577 Mdot
.39139 .15779 Mdot
.39144 .15788 Mdot
.39149 .15797 Mdot
.39153 .15805 Mdot
.39158 .15814 Mdot
.39163 .15823 Mdot
.39168 .15832 Mdot
.39173 .15841 Mdot
.39177 .1585 Mdot
.39182 .15859 Mdot
.39187 .15868 Mdot
.39192 .15877 Mdot
.39196 .15886 Mdot
.39201 .15895 Mdot
.39206 .15905 Mdot
.39211 .15914 Mdot
.39215 .15923 Mdot
.3922 .15932 Mdot
.39225 .15941 Mdot
.3923 .15951 Mdot
.39234 .1596 Mdot
.39239 .15969 Mdot
.39244 .15979 Mdot
.39249 .15988 Mdot
.39253 .15998 Mdot
.39258 .16007 Mdot
.39263 .16017 Mdot
.39268 .16026 Mdot
.39273 .16036 Mdot
.39277 .16045 Mdot
.39282 .16055 Mdot
.39287 .16064 Mdot
.39292 .16074 Mdot
.39296 .16083 Mdot
.39301 .16093 Mdot
.39306 .16103 Mdot
.39311 .16113 Mdot
.39315 .16122 Mdot
.3932 .16132 Mdot
.39325 .16142 Mdot
.3933 .16152 Mdot
.39334 .16161 Mdot
.39339 .16171 Mdot
.39344 .16181 Mdot
.39349 .16191 Mdot
.39353 .16201 Mdot
.39358 .16211 Mdot
.39363 .16221 Mdot
.39368 .16231 Mdot
.39372 .16241 Mdot
.39377 .16251 Mdot
.39382 .16261 Mdot
.39387 .16271 Mdot
.39392 .16282 Mdot
.39396 .16292 Mdot
.39401 .16302 Mdot
.39406 .16312 Mdot
.39411 .16322 Mdot
.39415 .16333 Mdot
.3942 .16343 Mdot
.39425 .16353 Mdot
.3943 .16364 Mdot
.39434 .16374 Mdot
.39439 .16384 Mdot
.39444 .16395 Mdot
.39449 .16405 Mdot
.39453 .16416 Mdot
.39458 .16426 Mdot
.39463 .16437 Mdot
.39468 .16447 Mdot
.39472 .16458 Mdot
.39477 .16468 Mdot
.39482 .16479 Mdot
.39487 .1649 Mdot
.39492 .165 Mdot
.39496 .16511 Mdot
.39501 .16522 Mdot
.39506 .16532 Mdot
.39511 .16543 Mdot
.39515 .16554 Mdot
.3952 .16565 Mdot
.39525 .16576 Mdot
.3953 .16586 Mdot
.39534 .16597 Mdot
.39539 .16608 Mdot
.39544 .16619 Mdot
.39549 .1663 Mdot
.39553 .16641 Mdot
.39558 .16652 Mdot
.39563 .16663 Mdot
.39568 .16674 Mdot
.39572 .16685 Mdot
.39577 .16696 Mdot
.39582 .16707 Mdot
.39587 .16719 Mdot
.39592 .1673 Mdot
.39596 .16741 Mdot
.39601 .16752 Mdot
.39606 .16763 Mdot
.39611 .16775 Mdot
.39615 .16786 Mdot
.3962 .16797 Mdot
.39625 .16809 Mdot
.3963 .1682 Mdot
.39634 .16831 Mdot
.39639 .16843 Mdot
.39644 .16854 Mdot
.39649 .16866 Mdot
.39653 .16877 Mdot
.39658 .16889 Mdot
.39663 .169 Mdot
.39668 .16912 Mdot
.39672 .16923 Mdot
.39677 .16935 Mdot
.39682 .16947 Mdot
.39687 .16958 Mdot
.39692 .1697 Mdot
.39696 .16982 Mdot
.39701 .16993 Mdot
.39706 .17005 Mdot
.39711 .17017 Mdot
.39715 .17029 Mdot
.3972 .1704 Mdot
.39725 .17052 Mdot
.3973 .17064 Mdot
.39734 .17076 Mdot
.39739 .17088 Mdot
.39744 .171 Mdot
.39749 .17112 Mdot
.39753 .17124 Mdot
.39758 .17136 Mdot
.39763 .17148 Mdot
.39768 .1716 Mdot
.39772 .17172 Mdot
.39777 .17184 Mdot
.39782 .17196 Mdot
.39787 .17208 Mdot
.39791 .1722 Mdot
.39796 .17233 Mdot
.39801 .17245 Mdot
.39806 .17257 Mdot
.39811 .17269 Mdot
.39815 .17282 Mdot
.3982 .17294 Mdot
.39825 .17306 Mdot
.3983 .17319 Mdot
.39834 .17331 Mdot
.39839 .17344 Mdot
.39844 .17356 Mdot
.39849 .17369 Mdot
.39853 .17381 Mdot
.39858 .17394 Mdot
.39863 .17406 Mdot
.39868 .17419 Mdot
.39872 .17431 Mdot
.39877 .17444 Mdot
.39882 .17457 Mdot
.39887 .17469 Mdot
.39891 .17482 Mdot
.39896 .17495 Mdot
.39901 .17507 Mdot
.39906 .1752 Mdot
.39911 .17533 Mdot
.39915 .17546 Mdot
.3992 .17559 Mdot
.39925 .17571 Mdot
.3993 .17584 Mdot
.39934 .17597 Mdot
.39939 .1761 Mdot
.39944 .17623 Mdot
.39949 .17636 Mdot
.39953 .17649 Mdot
.39958 .17662 Mdot
.39963 .17675 Mdot
.39968 .17688 Mdot
.39972 .17701 Mdot
.39977 .17714 Mdot
.39982 .17727 Mdot
.39987 .1774 Mdot
.39991 .17754 Mdot
.39996 .17767 Mdot
.40001 .1778 Mdot
.40006 .17793 Mdot
.40011 .17807 Mdot
.40015 .1782 Mdot
.4002 .17833 Mdot
.40025 .17847 Mdot
.4003 .1786 Mdot
.40034 .17873 Mdot
.40039 .17887 Mdot
.40044 .179 Mdot
.40049 .17914 Mdot
.40053 .17927 Mdot
.40058 .17941 Mdot
.40063 .17954 Mdot
.40068 .17968 Mdot
.40072 .17981 Mdot
.40077 .17995 Mdot
.40082 .18008 Mdot
.40087 .18022 Mdot
.40091 .18035 Mdot
.40096 .18049 Mdot
.40101 .18063 Mdot
.40106 .18077 Mdot
.40111 .1809 Mdot
.40115 .18104 Mdot
.4012 .18118 Mdot
.40125 .18132 Mdot
.4013 .18145 Mdot
.40134 .18159 Mdot
.40139 .18173 Mdot
.40144 .18187 Mdot
.40149 .18201 Mdot
.40153 .18215 Mdot
.40158 .18229 Mdot
.40163 .18243 Mdot
.40168 .18257 Mdot
.40172 .18271 Mdot
.40177 .18285 Mdot
.40182 .18299 Mdot
.40187 .18313 Mdot
.40191 .18327 Mdot
.40196 .18341 Mdot
.40201 .18355 Mdot
.40206 .18369 Mdot
.40211 .18383 Mdot
.40215 .18398 Mdot
.4022 .18412 Mdot
.40225 .18426 Mdot
.4023 .1844 Mdot
.40234 .18455 Mdot
.40239 .18469 Mdot
.40244 .18483 Mdot
.40249 .18498 Mdot
.40253 .18512 Mdot
.40258 .18527 Mdot
.40263 .18541 Mdot
.40268 .18555 Mdot
.40272 .1857 Mdot
.40277 .18584 Mdot
.40282 .18599 Mdot
.40287 .18613 Mdot
.40291 .18628 Mdot
.40296 .18643 Mdot
.40301 .18657 Mdot
.40306 .18672 Mdot
.4031 .18687 Mdot
.40315 .18701 Mdot
.4032 .18716 Mdot
.40325 .18731 Mdot
.4033 .18745 Mdot
.40334 .1876 Mdot
.40339 .18775 Mdot
.40344 .1879 Mdot
.40349 .18805 Mdot
.40353 .18819 Mdot
.40358 .18834 Mdot
.40363 .18849 Mdot
.40368 .18864 Mdot
.40372 .18879 Mdot
.40377 .18894 Mdot
.40382 .18909 Mdot
.40387 .18924 Mdot
.40391 .18939 Mdot
.40396 .18954 Mdot
.40401 .18969 Mdot
.40406 .18984 Mdot
.4041 .18999 Mdot
.40415 .19015 Mdot
.4042 .1903 Mdot
.40425 .19045 Mdot
.4043 .1906 Mdot
.40434 .19075 Mdot
.40439 .19091 Mdot
.40444 .19106 Mdot
.40449 .19121 Mdot
.40453 .19136 Mdot
.40458 .19152 Mdot
.40463 .19167 Mdot
.40468 .19182 Mdot
.40472 .19198 Mdot
.40477 .19213 Mdot
.40482 .19229 Mdot
.40487 .19244 Mdot
.40491 .1926 Mdot
.40496 .19275 Mdot
.40501 .19291 Mdot
.40506 .19306 Mdot
.4051 .19322 Mdot
.40515 .19337 Mdot
.4052 .19353 Mdot
.40525 .19368 Mdot
.4053 .19384 Mdot
.40534 .194 Mdot
.40539 .19415 Mdot
.40544 .19431 Mdot
.40549 .19447 Mdot
.40553 .19462 Mdot
.40558 .19478 Mdot
.40563 .19494 Mdot
.40568 .1951 Mdot
.40572 .19525 Mdot
.40577 .19541 Mdot
.40582 .19557 Mdot
.40587 .19573 Mdot
.40591 .19589 Mdot
.40596 .19605 Mdot
.40601 .19621 Mdot
.40606 .19637 Mdot
.4061 .19653 Mdot
.40615 .19669 Mdot
.4062 .19685 Mdot
.40625 .19701 Mdot
.4063 .19717 Mdot
.40634 .19733 Mdot
.40639 .19749 Mdot
.40644 .19765 Mdot
.40649 .19781 Mdot
.40653 .19797 Mdot
.40658 .19813 Mdot
.40663 .1983 Mdot
.40668 .19846 Mdot
.40672 .19862 Mdot
.40677 .19878 Mdot
.40682 .19895 Mdot
.40687 .19911 Mdot
.40691 .19927 Mdot
.40696 .19944 Mdot
.40701 .1996 Mdot
.40706 .19976 Mdot
.4071 .19993 Mdot
.40715 .20009 Mdot
.4072 .20026 Mdot
.40725 .20042 Mdot
.40729 .20058 Mdot
.40734 .20075 Mdot
.40739 .20091 Mdot
.40744 .20108 Mdot
.40749 .20124 Mdot
.40753 .20141 Mdot
.40758 .20158 Mdot
.40763 .20174 Mdot
.40768 .20191 Mdot
.40772 .20208 Mdot
.40777 .20224 Mdot
.40782 .20241 Mdot
.40787 .20258 Mdot
.40791 .20274 Mdot
.40796 .20291 Mdot
.40801 .20308 Mdot
.40806 .20325 Mdot
.4081 .20341 Mdot
.40815 .20358 Mdot
.4082 .20375 Mdot
.40825 .20392 Mdot
.40829 .20409 Mdot
.40834 .20426 Mdot
.40839 .20443 Mdot
.40844 .2046 Mdot
.40849 .20477 Mdot
.40853 .20493 Mdot
.40858 .2051 Mdot
.40863 .20527 Mdot
.40868 .20544 Mdot
.40872 .20561 Mdot
.40877 .20579 Mdot
.40882 .20596 Mdot
.40887 .20613 Mdot
.40891 .2063 Mdot
.40896 .20647 Mdot
.40901 .20664 Mdot
.40906 .20681 Mdot
.4091 .20698 Mdot
.40915 .20716 Mdot
.4092 .20733 Mdot
.40925 .2075 Mdot
.40929 .20767 Mdot
.40934 .20784 Mdot
.40939 .20802 Mdot
.40944 .20819 Mdot
.40949 .20836 Mdot
.40953 .20854 Mdot
.40958 .20871 Mdot
.40963 .20888 Mdot
.40968 .20906 Mdot
.40972 .20923 Mdot
.40977 .20941 Mdot
.40982 .20958 Mdot
.40987 .20976 Mdot
.40991 .20993 Mdot
.40996 .21011 Mdot
.41001 .21028 Mdot
.41006 .21046 Mdot
.4101 .21063 Mdot
.41015 .21081 Mdot
.4102 .21098 Mdot
.41025 .21116 Mdot
.41029 .21134 Mdot
.41034 .21151 Mdot
.41039 .21169 Mdot
.41044 .21186 Mdot
.41049 .21204 Mdot
.41053 .21222 Mdot
.41058 .2124 Mdot
.41063 .21257 Mdot
.41068 .21275 Mdot
.41072 .21293 Mdot
.41077 .21311 Mdot
.41082 .21329 Mdot
.41087 .21346 Mdot
.41091 .21364 Mdot
.41096 .21382 Mdot
.41101 .214 Mdot
.41106 .21418 Mdot
.4111 .21436 Mdot
.41115 .21454 Mdot
.4112 .21472 Mdot
.41125 .2149 Mdot
.41129 .21508 Mdot
.41134 .21526 Mdot
.41139 .21544 Mdot
.41144 .21562 Mdot
.41149 .2158 Mdot
.41153 .21598 Mdot
.41158 .21616 Mdot
.41163 .21634 Mdot
.41168 .21652 Mdot
.41172 .2167 Mdot
.41177 .21688 Mdot
.41182 .21707 Mdot
.41187 .21725 Mdot
.41191 .21743 Mdot
.41196 .21761 Mdot
.41201 .21779 Mdot
.41206 .21798 Mdot
.4121 .21816 Mdot
.41215 .21834 Mdot
.4122 .21853 Mdot
.41225 .21871 Mdot
.41229 .21889 Mdot
.41234 .21908 Mdot
.41239 .21926 Mdot
.41244 .21944 Mdot
.41248 .21963 Mdot
.41253 .21981 Mdot
.41258 .22 Mdot
.41263 .22018 Mdot
.41268 .22037 Mdot
.41272 .22055 Mdot
.41277 .22074 Mdot
.41282 .22092 Mdot
.41287 .22111 Mdot
.41291 .22129 Mdot
.41296 .22148 Mdot
.41301 .22166 Mdot
.41306 .22185 Mdot
.4131 .22204 Mdot
.41315 .22222 Mdot
.4132 .22241 Mdot
.41325 .2226 Mdot
.41329 .22278 Mdot
.41334 .22297 Mdot
.41339 .22316 Mdot
.41344 .22334 Mdot
.41348 .22353 Mdot
.41353 .22372 Mdot
.41358 .22391 Mdot
.41363 .22409 Mdot
.41368 .22428 Mdot
.41372 .22447 Mdot
.41377 .22466 Mdot
.41382 .22485 Mdot
.41387 .22504 Mdot
.41391 .22522 Mdot
.41396 .22541 Mdot
.41401 .2256 Mdot
.41406 .22579 Mdot
.4141 .22598 Mdot
.41415 .22617 Mdot
.4142 .22636 Mdot
.41425 .22655 Mdot
.41429 .22674 Mdot
.41434 .22693 Mdot
.41439 .22712 Mdot
.41444 .22731 Mdot
.41448 .2275 Mdot
.41453 .22769 Mdot
.41458 .22789 Mdot
.41463 .22808 Mdot
.41468 .22827 Mdot
.41472 .22846 Mdot
.41477 .22865 Mdot
.41482 .22884 Mdot
.41487 .22904 Mdot
.41491 .22923 Mdot
.41496 .22942 Mdot
.41501 .22961 Mdot
.41506 .22981 Mdot
.4151 .23 Mdot
.41515 .23019 Mdot
.4152 .23038 Mdot
.41525 .23058 Mdot
.41529 .23077 Mdot
.41534 .23096 Mdot
.41539 .23116 Mdot
.41544 .23135 Mdot
.41548 .23155 Mdot
.41553 .23174 Mdot
.41558 .23193 Mdot
.41563 .23213 Mdot
.41568 .23232 Mdot
.41572 .23252 Mdot
.41577 .23271 Mdot
.41582 .23291 Mdot
.41587 .2331 Mdot
.41591 .2333 Mdot
.41596 .23349 Mdot
.41601 .23369 Mdot
.41606 .23388 Mdot
.4161 .23408 Mdot
.41615 .23428 Mdot
.4162 .23447 Mdot
.41625 .23467 Mdot
.41629 .23487 Mdot
.41634 .23506 Mdot
.41639 .23526 Mdot
.41644 .23546 Mdot
.41648 .23565 Mdot
.41653 .23585 Mdot
.41658 .23605 Mdot
.41663 .23625 Mdot
.41667 .23644 Mdot
.41672 .23664 Mdot
.41677 .23684 Mdot
.41682 .23704 Mdot
.41687 .23723 Mdot
.41691 .23743 Mdot
.41696 .23763 Mdot
.41701 .23783 Mdot
.41706 .23803 Mdot
.4171 .23823 Mdot
.41715 .23842 Mdot
.4172 .23862 Mdot
.41725 .23882 Mdot
.41729 .23902 Mdot
.41734 .23922 Mdot
.41739 .23942 Mdot
.41744 .23962 Mdot
.41748 .23982 Mdot
.41753 .24002 Mdot
.41758 .24022 Mdot
.41763 .24042 Mdot
.41767 .24062 Mdot
.41772 .24082 Mdot
.41777 .24102 Mdot
.41782 .24122 Mdot
.41787 .24142 Mdot
.41791 .24162 Mdot
.41796 .24182 Mdot
.41801 .24203 Mdot
.41806 .24223 Mdot
.4181 .24243 Mdot
.41815 .24263 Mdot
.4182 .24283 Mdot
.41825 .24303 Mdot
.41829 .24324 Mdot
.41834 .24344 Mdot
.41839 .24364 Mdot
.41844 .24384 Mdot
.41848 .24404 Mdot
.41853 .24425 Mdot
.41858 .24445 Mdot
.41863 .24465 Mdot
.41867 .24486 Mdot
.41872 .24506 Mdot
.41877 .24526 Mdot
.41882 .24546 Mdot
.41887 .24567 Mdot
.41891 .24587 Mdot
.41896 .24608 Mdot
.41901 .24628 Mdot
.41906 .24648 Mdot
.4191 .24669 Mdot
.41915 .24689 Mdot
.4192 .2471 Mdot
.41925 .2473 Mdot
.41929 .2475 Mdot
.41934 .24771 Mdot
.41939 .24791 Mdot
.41944 .24812 Mdot
.41948 .24832 Mdot
.41953 .24853 Mdot
.41958 .24873 Mdot
.41963 .24894 Mdot
.41967 .24914 Mdot
.41972 .24935 Mdot
.41977 .24955 Mdot
.41982 .24976 Mdot
.41987 .24997 Mdot
.41991 .25017 Mdot
.41996 .25038 Mdot
.42001 .25058 Mdot
.42006 .25079 Mdot
.4201 .251 Mdot
.42015 .2512 Mdot
.4202 .25141 Mdot
.42025 .25162 Mdot
.42029 .25182 Mdot
.42034 .25203 Mdot
.42039 .25224 Mdot
.42044 .25244 Mdot
.42048 .25265 Mdot
.42053 .25286 Mdot
.42058 .25307 Mdot
.42063 .25327 Mdot
.42067 .25348 Mdot
.42072 .25369 Mdot
.42077 .2539 Mdot
.42082 .25411 Mdot
.42087 .25431 Mdot
.42091 .25452 Mdot
.42096 .25473 Mdot
.42101 .25494 Mdot
.42106 .25515 Mdot
.4211 .25536 Mdot
.42115 .25556 Mdot
.4212 .25577 Mdot
.42125 .25598 Mdot
.42129 .25619 Mdot
.42134 .2564 Mdot
.42139 .25661 Mdot
.42144 .25682 Mdot
.42148 .25703 Mdot
.42153 .25724 Mdot
.42158 .25745 Mdot
.42163 .25766 Mdot
.42167 .25787 Mdot
.42172 .25808 Mdot
.42177 .25829 Mdot
.42182 .2585 Mdot
.42186 .25871 Mdot
.42191 .25892 Mdot
.42196 .25913 Mdot
.42201 .25934 Mdot
.42206 .25955 Mdot
.4221 .25976 Mdot
.42215 .25997 Mdot
.4222 .26018 Mdot
.42225 .26039 Mdot
.42229 .26061 Mdot
.42234 .26082 Mdot
.42239 .26103 Mdot
.42244 .26124 Mdot
.42248 .26145 Mdot
.42253 .26166 Mdot
.42258 .26187 Mdot
.42263 .26209 Mdot
.42267 .2623 Mdot
.42272 .26251 Mdot
.42277 .26272 Mdot
.42282 .26293 Mdot
.42286 .26315 Mdot
.42291 .26336 Mdot
.42296 .26357 Mdot
.42301 .26378 Mdot
.42306 .26399 Mdot
.4231 .26421 Mdot
.42315 .26442 Mdot
.4232 .26463 Mdot
.42325 .26485 Mdot
.42329 .26506 Mdot
.42334 .26527 Mdot
.42339 .26548 Mdot
.42344 .2657 Mdot
.42348 .26591 Mdot
.42353 .26612 Mdot
.42358 .26634 Mdot
.42363 .26655 Mdot
.42367 .26676 Mdot
.42372 .26698 Mdot
.42377 .26719 Mdot
.42382 .26741 Mdot
.42386 .26762 Mdot
.42391 .26783 Mdot
.42396 .26805 Mdot
.42401 .26826 Mdot
.42406 .26847 Mdot
.4241 .26869 Mdot
.42415 .2689 Mdot
.4242 .26912 Mdot
.42425 .26933 Mdot
.42429 .26955 Mdot
.42434 .26976 Mdot
.42439 .26998 Mdot
.42444 .27019 Mdot
.42448 .2704 Mdot
.42453 .27062 Mdot
.42458 .27083 Mdot
.42463 .27105 Mdot
.42467 .27126 Mdot
.42472 .27148 Mdot
.42477 .2717 Mdot
.42482 .27191 Mdot
.42486 .27213 Mdot
.42491 .27234 Mdot
.42496 .27256 Mdot
.42501 .27277 Mdot
.42506 .27299 Mdot
.4251 .2732 Mdot
.42515 .27342 Mdot
.4252 .27364 Mdot
.42525 .27385 Mdot
.42529 .27407 Mdot
.42534 .27428 Mdot
.42539 .2745 Mdot
.42544 .27472 Mdot
.42548 .27493 Mdot
.42553 .27515 Mdot
.42558 .27537 Mdot
.42563 .27558 Mdot
.42567 .2758 Mdot
.42572 .27602 Mdot
.42577 .27623 Mdot
.42582 .27645 Mdot
.42586 .27667 Mdot
.42591 .27689 Mdot
.42596 .2771 Mdot
.42601 .27732 Mdot
.42606 .27754 Mdot
.4261 .27775 Mdot
.42615 .27797 Mdot
.4262 .27819 Mdot
.42625 .27841 Mdot
.42629 .27862 Mdot
.42634 .27884 Mdot
.42639 .27906 Mdot
.42644 .27928 Mdot
.42648 .2795 Mdot
.42653 .27971 Mdot
.42658 .27993 Mdot
.42663 .28015 Mdot
.42667 .28037 Mdot
.42672 .28059 Mdot
.42677 .2808 Mdot
.42682 .28102 Mdot
.42686 .28124 Mdot
.42691 .28146 Mdot
.42696 .28168 Mdot
.42701 .2819 Mdot
.42705 .28212 Mdot
.4271 .28233 Mdot
.42715 .28255 Mdot
.4272 .28277 Mdot
.42725 .28299 Mdot
.42729 .28321 Mdot
.42734 .28343 Mdot
.42739 .28365 Mdot
.42744 .28387 Mdot
.42748 .28409 Mdot
.42753 .28431 Mdot
.42758 .28452 Mdot
.42763 .28474 Mdot
.42767 .28496 Mdot
.42772 .28518 Mdot
.42777 .2854 Mdot
.42782 .28562 Mdot
.42786 .28584 Mdot
.42791 .28606 Mdot
.42796 .28628 Mdot
.42801 .2865 Mdot
.42805 .28672 Mdot
.4281 .28694 Mdot
.42815 .28716 Mdot
.4282 .28738 Mdot
.42825 .2876 Mdot
.42829 .28782 Mdot
.42834 .28804 Mdot
.42839 .28826 Mdot
.42844 .28848 Mdot
.42848 .2887 Mdot
.42853 .28892 Mdot
.42858 .28914 Mdot
.42863 .28936 Mdot
.42867 .28958 Mdot
.42872 .2898 Mdot
.42877 .29002 Mdot
.42882 .29024 Mdot
.42886 .29046 Mdot
.42891 .29068 Mdot
.42896 .2909 Mdot
.42901 .29112 Mdot
.42905 .29135 Mdot
.4291 .29157 Mdot
.42915 .29179 Mdot
.4292 .29201 Mdot
.42925 .29223 Mdot
.42929 .29245 Mdot
.42934 .29267 Mdot
.42939 .29289 Mdot
.42944 .29311 Mdot
.42948 .29333 Mdot
.42953 .29355 Mdot
.42958 .29377 Mdot
.42963 .29399 Mdot
.42967 .29422 Mdot
.42972 .29444 Mdot
.42977 .29466 Mdot
.42982 .29488 Mdot
.42986 .2951 Mdot
.42991 .29532 Mdot
.42996 .29554 Mdot
.43001 .29576 Mdot
.43005 .29598 Mdot
.4301 .29621 Mdot
.43015 .29643 Mdot
.4302 .29665 Mdot
.43025 .29687 Mdot
.43029 .29709 Mdot
.43034 .29731 Mdot
.43039 .29753 Mdot
.43044 .29776 Mdot
.43048 .29798 Mdot
.43053 .2982 Mdot
.43058 .29842 Mdot
.43063 .29864 Mdot
.43067 .29886 Mdot
.43072 .29908 Mdot
.43077 .29931 Mdot
.43082 .29953 Mdot
.43086 .29975 Mdot
.43091 .29997 Mdot
.43096 .30019 Mdot
.43101 .30041 Mdot
.43105 .30064 Mdot
.4311 .30086 Mdot
.43115 .30108 Mdot
.4312 .3013 Mdot
.43124 .30152 Mdot
.43129 .30175 Mdot
.43134 .30197 Mdot
.43139 .30219 Mdot
.43144 .30241 Mdot
.43148 .30263 Mdot
.43153 .30285 Mdot
.43158 .30308 Mdot
.43163 .3033 Mdot
.43167 .30352 Mdot
.43172 .30374 Mdot
.43177 .30396 Mdot
.43182 .30419 Mdot
.43186 .30441 Mdot
.43191 .30463 Mdot
.43196 .30485 Mdot
.43201 .30507 Mdot
.43205 .3053 Mdot
.4321 .30552 Mdot
.43215 .30574 Mdot
.4322 .30596 Mdot
.43224 .30619 Mdot
.43229 .30641 Mdot
.43234 .30663 Mdot
.43239 .30685 Mdot
.43244 .30707 Mdot
.43248 .3073 Mdot
.43253 .30752 Mdot
.43258 .30774 Mdot
.43263 .30796 Mdot
.43267 .30819 Mdot
.43272 .30841 Mdot
.43277 .30863 Mdot
.43282 .30885 Mdot
.43286 .30907 Mdot
.43291 .3093 Mdot
.43296 .30952 Mdot
.43301 .30974 Mdot
.43305 .30996 Mdot
.4331 .31019 Mdot
.43315 .31041 Mdot
.4332 .31063 Mdot
.43324 .31085 Mdot
.43329 .31108 Mdot
.43334 .3113 Mdot
.43339 .31152 Mdot
.43344 .31174 Mdot
.43348 .31196 Mdot
.43353 .31219 Mdot
.43358 .31241 Mdot
.43363 .31263 Mdot
.43367 .31285 Mdot
.43372 .31308 Mdot
.43377 .3133 Mdot
.43382 .31352 Mdot
.43386 .31374 Mdot
.43391 .31397 Mdot
.43396 .31419 Mdot
.43401 .31441 Mdot
.43405 .31463 Mdot
.4341 .31485 Mdot
.43415 .31508 Mdot
.4342 .3153 Mdot
.43424 .31552 Mdot
.43429 .31574 Mdot
.43434 .31597 Mdot
.43439 .31619 Mdot
.43444 .31641 Mdot
.43448 .31663 Mdot
.43453 .31685 Mdot
.43458 .31708 Mdot
.43463 .3173 Mdot
.43467 .31752 Mdot
.43472 .31774 Mdot
.43477 .31796 Mdot
.43482 .31819 Mdot
.43486 .31841 Mdot
.43491 .31863 Mdot
.43496 .31885 Mdot
.43501 .31908 Mdot
.43505 .3193 Mdot
.4351 .31952 Mdot
.43515 .31974 Mdot
.4352 .31996 Mdot
.43524 .32019 Mdot
.43529 .32041 Mdot
.43534 .32063 Mdot
.43539 .32085 Mdot
.43544 .32108 Mdot
.43548 .3213 Mdot
.43553 .32152 Mdot
.43558 .32174 Mdot
.43563 .32196 Mdot
.43567 .32219 Mdot
.43572 .32241 Mdot
.43577 .32263 Mdot
.43582 .32285 Mdot
.43586 .32307 Mdot
.43591 .3233 Mdot
.43596 .32352 Mdot
.43601 .32374 Mdot
.43605 .32396 Mdot
.4361 .32418 Mdot
.43615 .3244 Mdot
.4362 .32463 Mdot
.43624 .32485 Mdot
.43629 .32507 Mdot
.43634 .32529 Mdot
.43639 .32551 Mdot
.43643 .32573 Mdot
.43648 .32595 Mdot
.43653 .32618 Mdot
.43658 .3264 Mdot
.43663 .32662 Mdot
.43667 .32684 Mdot
.43672 .32706 Mdot
.43677 .32728 Mdot
.43682 .3275 Mdot
.43686 .32772 Mdot
.43691 .32795 Mdot
.43696 .32817 Mdot
.43701 .32839 Mdot
.43705 .32861 Mdot
.4371 .32883 Mdot
.43715 .32905 Mdot
.4372 .32927 Mdot
.43724 .32949 Mdot
.43729 .32971 Mdot
.43734 .32993 Mdot
.43739 .33016 Mdot
.43743 .33038 Mdot
.43748 .3306 Mdot
.43753 .33082 Mdot
.43758 .33104 Mdot
.43763 .33126 Mdot
.43767 .33148 Mdot
.43772 .3317 Mdot
.43777 .33192 Mdot
.43782 .33214 Mdot
.43786 .33236 Mdot
.43791 .33258 Mdot
.43796 .3328 Mdot
.43801 .33302 Mdot
.43805 .33324 Mdot
.4381 .33346 Mdot
.43815 .33368 Mdot
.4382 .3339 Mdot
.43824 .33412 Mdot
.43829 .33434 Mdot
.43834 .33456 Mdot
.43839 .33478 Mdot
.43843 .335 Mdot
.43848 .33522 Mdot
.43853 .33544 Mdot
.43858 .33566 Mdot
.43863 .33588 Mdot
.43867 .3361 Mdot
.43872 .33632 Mdot
.43877 .33654 Mdot
.43882 .33676 Mdot
.43886 .33698 Mdot
.43891 .3372 Mdot
.43896 .33742 Mdot
.43901 .33764 Mdot
.43905 .33786 Mdot
.4391 .33808 Mdot
.43915 .3383 Mdot
.4392 .33852 Mdot
.43924 .33874 Mdot
.43929 .33896 Mdot
.43934 .33917 Mdot
.43939 .33939 Mdot
.43943 .33961 Mdot
.43948 .33983 Mdot
.43953 .34005 Mdot
.43958 .34027 Mdot
.43963 .34049 Mdot
.43967 .34071 Mdot
.43972 .34092 Mdot
.43977 .34114 Mdot
.43982 .34136 Mdot
.43986 .34158 Mdot
.43991 .3418 Mdot
.43996 .34202 Mdot
.44001 .34224 Mdot
.44005 .34245 Mdot
.4401 .34267 Mdot
.44015 .34289 Mdot
.4402 .34311 Mdot
.44024 .34333 Mdot
.44029 .34354 Mdot
.44034 .34376 Mdot
.44039 .34398 Mdot
.44043 .3442 Mdot
.44048 .34442 Mdot
.44053 .34463 Mdot
.44058 .34485 Mdot
.44062 .34507 Mdot
.44067 .34529 Mdot
.44072 .3455 Mdot
.44077 .34572 Mdot
.44082 .34594 Mdot
.44086 .34616 Mdot
.44091 .34637 Mdot
.44096 .34659 Mdot
.44101 .34681 Mdot
.44105 .34702 Mdot
.4411 .34724 Mdot
.44115 .34746 Mdot
.4412 .34768 Mdot
.44124 .34789 Mdot
.44129 .34811 Mdot
.44134 .34833 Mdot
.44139 .34854 Mdot
.44143 .34876 Mdot
.44148 .34897 Mdot
.44153 .34919 Mdot
.44158 .34941 Mdot
.44162 .34962 Mdot
.44167 .34984 Mdot
.44172 .35006 Mdot
.44177 .35027 Mdot
.44182 .35049 Mdot
.44186 .3507 Mdot
.44191 .35092 Mdot
.44196 .35113 Mdot
.44201 .35135 Mdot
.44205 .35157 Mdot
.4421 .35178 Mdot
.44215 .352 Mdot
.4422 .35221 Mdot
.44224 .35243 Mdot
.44229 .35264 Mdot
.44234 .35286 Mdot
.44239 .35307 Mdot
.44243 .35329 Mdot
.44248 .3535 Mdot
.44253 .35371 Mdot
.44258 .35393 Mdot
.44262 .35414 Mdot
.44267 .35436 Mdot
.44272 .35457 Mdot
.44277 .35479 Mdot
.44282 .355 Mdot
.44286 .35521 Mdot
.44291 .35543 Mdot
.44296 .35564 Mdot
.44301 .35585 Mdot
.44305 .35607 Mdot
.4431 .35628 Mdot
.44315 .3565 Mdot
.4432 .35671 Mdot
.44324 .35692 Mdot
.44329 .35713 Mdot
.44334 .35735 Mdot
.44339 .35756 Mdot
.44343 .35777 Mdot
.44348 .35799 Mdot
.44353 .3582 Mdot
.44358 .35841 Mdot
.44362 .35862 Mdot
.44367 .35884 Mdot
.44372 .35905 Mdot
.44377 .35926 Mdot
.44382 .35947 Mdot
.44386 .35969 Mdot
.44391 .3599 Mdot
.44396 .36011 Mdot
.44401 .36032 Mdot
.44405 .36053 Mdot
.4441 .36074 Mdot
.44415 .36096 Mdot
.4442 .36117 Mdot
.44424 .36138 Mdot
.44429 .36159 Mdot
.44434 .3618 Mdot
.44439 .36201 Mdot
.44443 .36222 Mdot
.44448 .36243 Mdot
.44453 .36264 Mdot
.44458 .36286 Mdot
.44462 .36307 Mdot
.44467 .36328 Mdot
.44472 .36349 Mdot
.44477 .3637 Mdot
.44482 .36391 Mdot
.44486 .36412 Mdot
.44491 .36433 Mdot
.44496 .36454 Mdot
.44501 .36475 Mdot
.44505 .36495 Mdot
.4451 .36516 Mdot
.44515 .36537 Mdot
.4452 .36558 Mdot
.44524 .36579 Mdot
.44529 .366 Mdot
.44534 .36621 Mdot
.44539 .36642 Mdot
.44543 .36663 Mdot
.44548 .36684 Mdot
.44553 .36704 Mdot
.44558 .36725 Mdot
.44562 .36746 Mdot
.44567 .36767 Mdot
.44572 .36788 Mdot
.44577 .36808 Mdot
.44581 .36829 Mdot
.44586 .3685 Mdot
.44591 .36871 Mdot
.44596 .36892 Mdot
.44601 .36912 Mdot
.44605 .36933 Mdot
.4461 .36954 Mdot
.44615 .36974 Mdot
.4462 .36995 Mdot
.44624 .37016 Mdot
.44629 .37036 Mdot
.44634 .37057 Mdot
.44639 .37078 Mdot
.44643 .37098 Mdot
.44648 .37119 Mdot
.44653 .37139 Mdot
.44658 .3716 Mdot
.44662 .37181 Mdot
.44667 .37201 Mdot
.44672 .37222 Mdot
.44677 .37242 Mdot
.44681 .37263 Mdot
.44686 .37283 Mdot
.44691 .37304 Mdot
.44696 .37324 Mdot
.44701 .37345 Mdot
.44705 .37365 Mdot
.4471 .37386 Mdot
.44715 .37406 Mdot
.4472 .37427 Mdot
.44724 .37447 Mdot
.44729 .37468 Mdot
.44734 .37488 Mdot
.44739 .37508 Mdot
.44743 .37529 Mdot
.44748 .37549 Mdot
.44753 .3757 Mdot
.44758 .3759 Mdot
.44762 .3761 Mdot
.44767 .37631 Mdot
.44772 .37651 Mdot
.44777 .37671 Mdot
.44781 .37692 Mdot
.44786 .37712 Mdot
.44791 .37732 Mdot
.44796 .37752 Mdot
.44801 .37773 Mdot
.44805 .37793 Mdot
.4481 .37813 Mdot
.44815 .37833 Mdot
.4482 .37853 Mdot
.44824 .37874 Mdot
.44829 .37894 Mdot
.44834 .37914 Mdot
.44839 .37934 Mdot
.44843 .37954 Mdot
.44848 .37974 Mdot
.44853 .37994 Mdot
.44858 .38014 Mdot
.44862 .38035 Mdot
.44867 .38055 Mdot
.44872 .38075 Mdot
.44877 .38095 Mdot
.44881 .38115 Mdot
.44886 .38135 Mdot
.44891 .38155 Mdot
.44896 .38175 Mdot
.44901 .38195 Mdot
.44905 .38215 Mdot
.4491 .38235 Mdot
.44915 .38254 Mdot
.4492 .38274 Mdot
.44924 .38294 Mdot
.44929 .38314 Mdot
.44934 .38334 Mdot
.44939 .38354 Mdot
.44943 .38374 Mdot
.44948 .38394 Mdot
.44953 .38413 Mdot
.44958 .38433 Mdot
.44962 .38453 Mdot
.44967 .38473 Mdot
.44972 .38493 Mdot
.44977 .38512 Mdot
.44981 .38532 Mdot
.44986 .38552 Mdot
.44991 .38571 Mdot
.44996 .38591 Mdot
.45 .38611 Mdot
.45005 .3863 Mdot
.4501 .3865 Mdot
.45015 .3867 Mdot
.4502 .38689 Mdot
.45024 .38709 Mdot
.45029 .38729 Mdot
.45034 .38748 Mdot
.45039 .38768 Mdot
.45043 .38787 Mdot
.45048 .38807 Mdot
.45053 .38826 Mdot
.45058 .38846 Mdot
.45062 .38865 Mdot
.45067 .38885 Mdot
.45072 .38904 Mdot
.45077 .38924 Mdot
.45081 .38943 Mdot
.45086 .38962 Mdot
.45091 .38982 Mdot
.45096 .39001 Mdot
.451 .39021 Mdot
.45105 .3904 Mdot
.4511 .39059 Mdot
.45115 .39079 Mdot
.4512 .39098 Mdot
.45124 .39117 Mdot
.45129 .39137 Mdot
.45134 .39156 Mdot
.45139 .39175 Mdot
.45143 .39194 Mdot
.45148 .39214 Mdot
.45153 .39233 Mdot
.45158 .39252 Mdot
.45162 .39271 Mdot
.45167 .3929 Mdot
.45172 .39309 Mdot
.45177 .39329 Mdot
.45181 .39348 Mdot
.45186 .39367 Mdot
.45191 .39386 Mdot
.45196 .39405 Mdot
.452 .39424 Mdot
.45205 .39443 Mdot
.4521 .39462 Mdot
.45215 .39481 Mdot
.4522 .395 Mdot
.45224 .39519 Mdot
.45229 .39538 Mdot
.45234 .39557 Mdot
.45239 .39576 Mdot
.45243 .39595 Mdot
.45248 .39614 Mdot
.45253 .39633 Mdot
.45258 .39651 Mdot
.45262 .3967 Mdot
.45267 .39689 Mdot
.45272 .39708 Mdot
.45277 .39727 Mdot
.45281 .39746 Mdot
.45286 .39764 Mdot
.45291 .39783 Mdot
.45296 .39802 Mdot
.453 .3982 Mdot
.45305 .39839 Mdot
.4531 .39858 Mdot
.45315 .39877 Mdot
.4532 .39895 Mdot
.45324 .39914 Mdot
.45329 .39932 Mdot
.45334 .39951 Mdot
.45339 .3997 Mdot
.45343 .39988 Mdot
.45348 .40007 Mdot
.45353 .40025 Mdot
.45358 .40044 Mdot
.45362 .40062 Mdot
.45367 .40081 Mdot
.45372 .40099 Mdot
.45377 .40118 Mdot
.45381 .40136 Mdot
.45386 .40154 Mdot
.45391 .40173 Mdot
.45396 .40191 Mdot
.454 .40209 Mdot
.45405 .40228 Mdot
.4541 .40246 Mdot
.45415 .40264 Mdot
.4542 .40283 Mdot
.45424 .40301 Mdot
.45429 .40319 Mdot
.45434 .40337 Mdot
.45439 .40356 Mdot
.45443 .40374 Mdot
.45448 .40392 Mdot
.45453 .4041 Mdot
.45458 .40428 Mdot
.45462 .40447 Mdot
.45467 .40465 Mdot
.45472 .40483 Mdot
.45477 .40501 Mdot
.45481 .40519 Mdot
.45486 .40537 Mdot
.45491 .40555 Mdot
.45496 .40573 Mdot
.455 .40591 Mdot
.45505 .40609 Mdot
.4551 .40627 Mdot
.45515 .40645 Mdot
.45519 .40663 Mdot
.45524 .40681 Mdot
.45529 .40698 Mdot
.45534 .40716 Mdot
.45539 .40734 Mdot
.45543 .40752 Mdot
.45548 .4077 Mdot
.45553 .40788 Mdot
.45558 .40805 Mdot
.45562 .40823 Mdot
.45567 .40841 Mdot
.45572 .40859 Mdot
.45577 .40876 Mdot
.45581 .40894 Mdot
.45586 .40912 Mdot
.45591 .40929 Mdot
.45596 .40947 Mdot
.456 .40965 Mdot
.45605 .40982 Mdot
.4561 .41 Mdot
.45615 .41017 Mdot
.45619 .41035 Mdot
.45624 .41052 Mdot
.45629 .4107 Mdot
.45634 .41087 Mdot
.45639 .41105 Mdot
.45643 .41122 Mdot
.45648 .4114 Mdot
.45653 .41157 Mdot
.45658 .41174 Mdot
.45662 .41192 Mdot
.45667 .41209 Mdot
.45672 .41226 Mdot
.45677 .41244 Mdot
.45681 .41261 Mdot
.45686 .41278 Mdot
.45691 .41296 Mdot
.45696 .41313 Mdot
.457 .4133 Mdot
.45705 .41347 Mdot
.4571 .41364 Mdot
.45715 .41382 Mdot
.45719 .41399 Mdot
.45724 .41416 Mdot
.45729 .41433 Mdot
.45734 .4145 Mdot
.45739 .41467 Mdot
.45743 .41484 Mdot
.45748 .41501 Mdot
.45753 .41518 Mdot
.45758 .41535 Mdot
.45762 .41552 Mdot
.45767 .41569 Mdot
.45772 .41586 Mdot
.45777 .41603 Mdot
.45781 .4162 Mdot
.45786 .41637 Mdot
.45791 .41653 Mdot
.45796 .4167 Mdot
.458 .41687 Mdot
.45805 .41704 Mdot
.4581 .41721 Mdot
.45815 .41737 Mdot
.45819 .41754 Mdot
.45824 .41771 Mdot
.45829 .41787 Mdot
.45834 .41804 Mdot
.45839 .41821 Mdot
.45843 .41837 Mdot
.45848 .41854 Mdot
.45853 .41871 Mdot
.45858 .41887 Mdot
.45862 .41904 Mdot
.45867 .4192 Mdot
.45872 .41937 Mdot
.45877 .41953 Mdot
.45881 .4197 Mdot
.45886 .41986 Mdot
.45891 .42003 Mdot
.45896 .42019 Mdot
.459 .42035 Mdot
.45905 .42052 Mdot
.4591 .42068 Mdot
.45915 .42085 Mdot
.45919 .42101 Mdot
.45924 .42117 Mdot
.45929 .42133 Mdot
.45934 .4215 Mdot
.45939 .42166 Mdot
.45943 .42182 Mdot
.45948 .42198 Mdot
.45953 .42214 Mdot
.45958 .42231 Mdot
.45962 .42247 Mdot
.45967 .42263 Mdot
.45972 .42279 Mdot
.45977 .42295 Mdot
.45981 .42311 Mdot
.45986 .42327 Mdot
.45991 .42343 Mdot
.45996 .42359 Mdot
.46 .42375 Mdot
.46005 .42391 Mdot
.4601 .42407 Mdot
.46015 .42422 Mdot
.46019 .42438 Mdot
.46024 .42454 Mdot
.46029 .4247 Mdot
.46034 .42486 Mdot
.46038 .42501 Mdot
.46043 .42517 Mdot
.46048 .42533 Mdot
.46053 .42548 Mdot
.46058 .42564 Mdot
.46062 .4258 Mdot
.46067 .42595 Mdot
.46072 .42611 Mdot
.46077 .42627 Mdot
.46081 .42642 Mdot
.46086 .42658 Mdot
.46091 .42673 Mdot
.46096 .42689 Mdot
.461 .42704 Mdot
.46105 .4272 Mdot
.4611 .42735 Mdot
.46115 .4275 Mdot
.46119 .42766 Mdot
.46124 .42781 Mdot
.46129 .42796 Mdot
.46134 .42812 Mdot
.46138 .42827 Mdot
.46143 .42842 Mdot
.46148 .42857 Mdot
.46153 .42873 Mdot
.46158 .42888 Mdot
.46162 .42903 Mdot
.46167 .42918 Mdot
.46172 .42933 Mdot
.46177 .42948 Mdot
.46181 .42963 Mdot
.46186 .42978 Mdot
.46191 .42993 Mdot
.46196 .43008 Mdot
.462 .43023 Mdot
.46205 .43038 Mdot
.4621 .43053 Mdot
.46215 .43068 Mdot
.46219 .43083 Mdot
.46224 .43098 Mdot
.46229 .43113 Mdot
.46234 .43128 Mdot
.46238 .43142 Mdot
.46243 .43157 Mdot
.46248 .43172 Mdot
.46253 .43187 Mdot
.46258 .43201 Mdot
.46262 .43216 Mdot
.46267 .43231 Mdot
.46272 .43245 Mdot
.46277 .4326 Mdot
.46281 .43274 Mdot
.46286 .43289 Mdot
.46291 .43304 Mdot
.46296 .43318 Mdot
.463 .43333 Mdot
.46305 .43347 Mdot
.4631 .43362 Mdot
.46315 .43376 Mdot
.46319 .4339 Mdot
.46324 .43405 Mdot
.46329 .43419 Mdot
.46334 .43433 Mdot
.46338 .43448 Mdot
.46343 .43462 Mdot
.46348 .43476 Mdot
.46353 .43491 Mdot
.46358 .43505 Mdot
.46362 .43519 Mdot
.46367 .43533 Mdot
.46372 .43547 Mdot
.46377 .43561 Mdot
.46381 .43576 Mdot
.46386 .4359 Mdot
.46391 .43604 Mdot
.46396 .43618 Mdot
.464 .43632 Mdot
.46405 .43646 Mdot
.4641 .4366 Mdot
.46415 .43674 Mdot
.46419 .43688 Mdot
.46424 .43702 Mdot
.46429 .43715 Mdot
.46434 .43729 Mdot
.46438 .43743 Mdot
.46443 .43757 Mdot
.46448 .43771 Mdot
.46453 .43784 Mdot
.46457 .43798 Mdot
.46462 .43812 Mdot
.46467 .43826 Mdot
.46472 .43839 Mdot
.46477 .43853 Mdot
.46481 .43866 Mdot
.46486 .4388 Mdot
.46491 .43894 Mdot
.46496 .43907 Mdot
.465 .43921 Mdot
.46505 .43934 Mdot
.4651 .43948 Mdot
.46515 .43961 Mdot
.46519 .43974 Mdot
.46524 .43988 Mdot
.46529 .44001 Mdot
.46534 .44015 Mdot
.46538 .44028 Mdot
.46543 .44041 Mdot
.46548 .44054 Mdot
.46553 .44068 Mdot
.46557 .44081 Mdot
.46562 .44094 Mdot
.46567 .44107 Mdot
.46572 .4412 Mdot
.46577 .44133 Mdot
.46581 .44146 Mdot
.46586 .44159 Mdot
.46591 .44172 Mdot
.46596 .44185 Mdot
.466 .44198 Mdot
.46605 .44211 Mdot
.4661 .44224 Mdot
.46615 .44237 Mdot
.46619 .4425 Mdot
.46624 .44263 Mdot
.46629 .44276 Mdot
.46634 .44289 Mdot
.46638 .44301 Mdot
.46643 .44314 Mdot
.46648 .44327 Mdot
.46653 .4434 Mdot
.46657 .44352 Mdot
.46662 .44365 Mdot
.46667 .44377 Mdot
.46672 .4439 Mdot
.46677 .44403 Mdot
.46681 .44415 Mdot
.46686 .44428 Mdot
.46691 .4444 Mdot
.46696 .44453 Mdot
.467 .44465 Mdot
.46705 .44477 Mdot
.4671 .4449 Mdot
.46715 .44502 Mdot
.46719 .44514 Mdot
.46724 .44527 Mdot
.46729 .44539 Mdot
.46734 .44551 Mdot
.46738 .44563 Mdot
.46743 .44576 Mdot
.46748 .44588 Mdot
.46753 .446 Mdot
.46757 .44612 Mdot
.46762 .44624 Mdot
.46767 .44636 Mdot
.46772 .44648 Mdot
.46777 .4466 Mdot
.46781 .44672 Mdot
.46786 .44684 Mdot
.46791 .44696 Mdot
.46796 .44708 Mdot
.468 .4472 Mdot
.46805 .44732 Mdot
.4681 .44743 Mdot
.46815 .44755 Mdot
.46819 .44767 Mdot
.46824 .44779 Mdot
.46829 .4479 Mdot
.46834 .44802 Mdot
.46838 .44814 Mdot
.46843 .44825 Mdot
.46848 .44837 Mdot
.46853 .44848 Mdot
.46857 .4486 Mdot
.46862 .44871 Mdot
.46867 .44883 Mdot
.46872 .44894 Mdot
.46877 .44906 Mdot
.46881 .44917 Mdot
.46886 .44929 Mdot
.46891 .4494 Mdot
.46896 .44951 Mdot
.469 .44963 Mdot
.46905 .44974 Mdot
.4691 .44985 Mdot
.46915 .44996 Mdot
.46919 .45007 Mdot
.46924 .45019 Mdot
.46929 .4503 Mdot
.46934 .45041 Mdot
.46938 .45052 Mdot
.46943 .45063 Mdot
.46948 .45074 Mdot
.46953 .45085 Mdot
.46957 .45096 Mdot
.46962 .45107 Mdot
.46967 .45118 Mdot
.46972 .45129 Mdot
.46976 .4514 Mdot
.46981 .4515 Mdot
.46986 .45161 Mdot
.46991 .45172 Mdot
.46996 .45183 Mdot
.47 .45193 Mdot
.47005 .45204 Mdot
.4701 .45215 Mdot
.47015 .45225 Mdot
.47019 .45236 Mdot
.47024 .45247 Mdot
.47029 .45257 Mdot
.47034 .45268 Mdot
.47038 .45278 Mdot
.47043 .45289 Mdot
.47048 .45299 Mdot
.47053 .45309 Mdot
.47057 .4532 Mdot
.47062 .4533 Mdot
.47067 .45341 Mdot
.47072 .45351 Mdot
.47076 .45361 Mdot
.47081 .45371 Mdot
.47086 .45382 Mdot
.47091 .45392 Mdot
.47096 .45402 Mdot
.471 .45412 Mdot
.47105 .45422 Mdot
.4711 .45432 Mdot
.47115 .45442 Mdot
.47119 .45452 Mdot
.47124 .45462 Mdot
.47129 .45472 Mdot
.47134 .45482 Mdot
.47138 .45492 Mdot
.47143 .45502 Mdot
.47148 .45512 Mdot
.47153 .45521 Mdot
.47157 .45531 Mdot
.47162 .45541 Mdot
.47167 .45551 Mdot
.47172 .4556 Mdot
.47176 .4557 Mdot
.47181 .4558 Mdot
.47186 .45589 Mdot
.47191 .45599 Mdot
.47196 .45608 Mdot
.472 .45618 Mdot
.47205 .45627 Mdot
.4721 .45637 Mdot
.47215 .45646 Mdot
.47219 .45656 Mdot
.47224 .45665 Mdot
.47229 .45674 Mdot
.47234 .45684 Mdot
.47238 .45693 Mdot
.47243 .45702 Mdot
.47248 .45712 Mdot
.47253 .45721 Mdot
.47257 .4573 Mdot
.47262 .45739 Mdot
.47267 .45748 Mdot
.47272 .45757 Mdot
.47276 .45766 Mdot
.47281 .45775 Mdot
.47286 .45784 Mdot
.47291 .45793 Mdot
.47296 .45802 Mdot
.473 .45811 Mdot
.47305 .4582 Mdot
.4731 .45829 Mdot
.47315 .45838 Mdot
.47319 .45846 Mdot
.47324 .45855 Mdot
.47329 .45864 Mdot
.47334 .45873 Mdot
.47338 .45881 Mdot
.47343 .4589 Mdot
.47348 .45898 Mdot
.47353 .45907 Mdot
.47357 .45916 Mdot
.47362 .45924 Mdot
.47367 .45933 Mdot
.47372 .45941 Mdot
.47376 .4595 Mdot
.47381 .45958 Mdot
.47386 .45966 Mdot
.47391 .45975 Mdot
.47395 .45983 Mdot
.474 .45991 Mdot
.47405 .46 Mdot
.4741 .46008 Mdot
.47415 .46016 Mdot
.47419 .46024 Mdot
.47424 .46032 Mdot
.47429 .4604 Mdot
.47434 .46048 Mdot
.47438 .46057 Mdot
.47443 .46065 Mdot
.47448 .46073 Mdot
.47453 .46081 Mdot
.47457 .46088 Mdot
.47462 .46096 Mdot
.47467 .46104 Mdot
.47472 .46112 Mdot
.47476 .4612 Mdot
.47481 .46128 Mdot
.47486 .46135 Mdot
.47491 .46143 Mdot
.47495 .46151 Mdot
.475 .46158 Mdot
.47505 .46166 Mdot
.4751 .46174 Mdot
.47515 .46181 Mdot
.47519 .46189 Mdot
.47524 .46196 Mdot
.47529 .46204 Mdot
.47534 .46211 Mdot
.47538 .46219 Mdot
.47543 .46226 Mdot
.47548 .46233 Mdot
.47553 .46241 Mdot
.47557 .46248 Mdot
.47562 .46255 Mdot
.47567 .46263 Mdot
.47572 .4627 Mdot
.47576 .46277 Mdot
.47581 .46284 Mdot
.47586 .46291 Mdot
.47591 .46298 Mdot
.47595 .46305 Mdot
.476 .46312 Mdot
.47605 .46319 Mdot
.4761 .46326 Mdot
.47615 .46333 Mdot
.47619 .4634 Mdot
.47624 .46347 Mdot
.47629 .46354 Mdot
.47634 .46361 Mdot
.47638 .46367 Mdot
.47643 .46374 Mdot
.47648 .46381 Mdot
.47653 .46387 Mdot
.47657 .46394 Mdot
.47662 .46401 Mdot
.47667 .46407 Mdot
.47672 .46414 Mdot
.47676 .4642 Mdot
.47681 .46427 Mdot
.47686 .46433 Mdot
.47691 .4644 Mdot
.47695 .46446 Mdot
.477 .46453 Mdot
.47705 .46459 Mdot
.4771 .46465 Mdot
.47715 .46471 Mdot
.47719 .46478 Mdot
.47724 .46484 Mdot
.47729 .4649 Mdot
.47734 .46496 Mdot
.47738 .46502 Mdot
.47743 .46508 Mdot
.47748 .46515 Mdot
.47753 .46521 Mdot
.47757 .46527 Mdot
.47762 .46533 Mdot
.47767 .46538 Mdot
.47772 .46544 Mdot
.47776 .4655 Mdot
.47781 .46556 Mdot
.47786 .46562 Mdot
.47791 .46568 Mdot
.47795 .46573 Mdot
.478 .46579 Mdot
.47805 .46585 Mdot
.4781 .4659 Mdot
.47815 .46596 Mdot
.47819 .46602 Mdot
.47824 .46607 Mdot
.47829 .46613 Mdot
.47834 .46618 Mdot
.47838 .46624 Mdot
.47843 .46629 Mdot
.47848 .46635 Mdot
.47853 .4664 Mdot
.47857 .46645 Mdot
.47862 .46651 Mdot
.47867 .46656 Mdot
.47872 .46661 Mdot
.47876 .46666 Mdot
.47881 .46671 Mdot
.47886 .46677 Mdot
.47891 .46682 Mdot
.47895 .46687 Mdot
.479 .46692 Mdot
.47905 .46697 Mdot
.4791 .46702 Mdot
.47914 .46707 Mdot
.47919 .46712 Mdot
.47924 .46717 Mdot
.47929 .46722 Mdot
.47934 .46726 Mdot
.47938 .46731 Mdot
.47943 .46736 Mdot
.47948 .46741 Mdot
.47953 .46746 Mdot
.47957 .4675 Mdot
.47962 .46755 Mdot
.47967 .4676 Mdot
.47972 .46764 Mdot
.47976 .46769 Mdot
.47981 .46773 Mdot
.47986 .46778 Mdot
.47991 .46782 Mdot
.47995 .46787 Mdot
.48 .46791 Mdot
.48005 .46795 Mdot
.4801 .468 Mdot
.48014 .46804 Mdot
.48019 .46808 Mdot
.48024 .46813 Mdot
.48029 .46817 Mdot
.48034 .46821 Mdot
.48038 .46825 Mdot
.48043 .46829 Mdot
.48048 .46834 Mdot
.48053 .46838 Mdot
.48057 .46842 Mdot
.48062 .46846 Mdot
.48067 .4685 Mdot
.48072 .46854 Mdot
.48076 .46857 Mdot
.48081 .46861 Mdot
.48086 .46865 Mdot
.48091 .46869 Mdot
.48095 .46873 Mdot
.481 .46876 Mdot
.48105 .4688 Mdot
.4811 .46884 Mdot
.48114 .46888 Mdot
.48119 .46891 Mdot
.48124 .46895 Mdot
.48129 .46898 Mdot
.48134 .46902 Mdot
.48138 .46905 Mdot
.48143 .46909 Mdot
.48148 .46912 Mdot
.48153 .46916 Mdot
.48157 .46919 Mdot
.48162 .46922 Mdot
.48167 .46925 Mdot
.48172 .46929 Mdot
.48176 .46932 Mdot
.48181 .46935 Mdot
.48186 .46938 Mdot
.48191 .46941 Mdot
.48195 .46945 Mdot
.482 .46948 Mdot
.48205 .46951 Mdot
.4821 .46954 Mdot
.48214 .46957 Mdot
.48219 .4696 Mdot
.48224 .46962 Mdot
.48229 .46965 Mdot
.48234 .46968 Mdot
.48238 .46971 Mdot
.48243 .46974 Mdot
.48248 .46976 Mdot
.48253 .46979 Mdot
.48257 .46982 Mdot
.48262 .46984 Mdot
.48267 .46987 Mdot
.48272 .4699 Mdot
.48276 .46992 Mdot
.48281 .46995 Mdot
.48286 .46997 Mdot
.48291 .47 Mdot
.48295 .47002 Mdot
.483 .47004 Mdot
.48305 .47007 Mdot
.4831 .47009 Mdot
.48314 .47011 Mdot
.48319 .47014 Mdot
.48324 .47016 Mdot
.48329 .47018 Mdot
.48333 .4702 Mdot
.48338 .47022 Mdot
.48343 .47024 Mdot
.48348 .47026 Mdot
.48353 .47028 Mdot
.48357 .4703 Mdot
.48362 .47032 Mdot
.48367 .47034 Mdot
.48372 .47036 Mdot
.48376 .47038 Mdot
.48381 .4704 Mdot
.48386 .47041 Mdot
.48391 .47043 Mdot
.48395 .47045 Mdot
.484 .47047 Mdot
.48405 .47048 Mdot
.4841 .4705 Mdot
.48414 .47051 Mdot
.48419 .47053 Mdot
.48424 .47055 Mdot
.48429 .47056 Mdot
.48433 .47057 Mdot
.48438 .47059 Mdot
.48443 .4706 Mdot
.48448 .47062 Mdot
.48453 .47063 Mdot
.48457 .47064 Mdot
.48462 .47065 Mdot
.48467 .47067 Mdot
.48472 .47068 Mdot
.48476 .47069 Mdot
.48481 .4707 Mdot
.48486 .47071 Mdot
.48491 .47072 Mdot
.48495 .47073 Mdot
.485 .47074 Mdot
.48505 .47075 Mdot
.4851 .47076 Mdot
.48514 .47077 Mdot
.48519 .47078 Mdot
.48524 .47079 Mdot
.48529 .47079 Mdot
.48533 .4708 Mdot
.48538 .47081 Mdot
.48543 .47082 Mdot
.48548 .47082 Mdot
.48553 .47083 Mdot
.48557 .47084 Mdot
.48562 .47084 Mdot
.48567 .47085 Mdot
.48572 .47085 Mdot
.48576 .47086 Mdot
.48581 .47086 Mdot
.48586 .47086 Mdot
.48591 .47087 Mdot
.48595 .47087 Mdot
.486 .47087 Mdot
.48605 .47088 Mdot
.4861 .47088 Mdot
.48614 .47088 Mdot
.48619 .47088 Mdot
.48624 .47088 Mdot
.48629 .47089 Mdot
.48633 .47089 Mdot
.48638 .47089 Mdot
.48643 .47089 Mdot
.48648 .47089 Mdot
.48653 .47089 Mdot
.48657 .47088 Mdot
.48662 .47088 Mdot
.48667 .47088 Mdot
.48672 .47088 Mdot
.48676 .47088 Mdot
.48681 .47087 Mdot
.48686 .47087 Mdot
.48691 .47087 Mdot
.48695 .47086 Mdot
.487 .47086 Mdot
.48705 .47086 Mdot
.4871 .47085 Mdot
.48714 .47085 Mdot
.48719 .47084 Mdot
.48724 .47083 Mdot
.48729 .47083 Mdot
.48733 .47082 Mdot
.48738 .47082 Mdot
.48743 .47081 Mdot
.48748 .4708 Mdot
.48753 .47079 Mdot
.48757 .47079 Mdot
.48762 .47078 Mdot
.48767 .47077 Mdot
.48772 .47076 Mdot
.48776 .47075 Mdot
.48781 .47074 Mdot
.48786 .47073 Mdot
.48791 .47072 Mdot
.48795 .47071 Mdot
.488 .4707 Mdot
.48805 .47069 Mdot
.4881 .47067 Mdot
.48814 .47066 Mdot
.48819 .47065 Mdot
.48824 .47064 Mdot
.48829 .47062 Mdot
.48833 .47061 Mdot
.48838 .4706 Mdot
.48843 .47058 Mdot
.48848 .47057 Mdot
.48852 .47055 Mdot
.48857 .47054 Mdot
.48862 .47052 Mdot
.48867 .47051 Mdot
.48872 .47049 Mdot
.48876 .47047 Mdot
.48881 .47046 Mdot
.48886 .47044 Mdot
.48891 .47042 Mdot
.48895 .47041 Mdot
.489 .47039 Mdot
.48905 .47037 Mdot
.4891 .47035 Mdot
.48914 .47033 Mdot
.48919 .47031 Mdot
.48924 .47029 Mdot
.48929 .47027 Mdot
.48933 .47025 Mdot
.48938 .47023 Mdot
.48943 .47021 Mdot
.48948 .47019 Mdot
.48952 .47017 Mdot
.48957 .47014 Mdot
.48962 .47012 Mdot
.48967 .4701 Mdot
.48972 .47007 Mdot
.48976 .47005 Mdot
.48981 .47003 Mdot
.48986 .47 Mdot
.48991 .46998 Mdot
.48995 .46995 Mdot
.49 .46993 Mdot
.49005 .4699 Mdot
.4901 .46988 Mdot
.49014 .46985 Mdot
.49019 .46982 Mdot
.49024 .4698 Mdot
.49029 .46977 Mdot
.49033 .46974 Mdot
.49038 .46971 Mdot
.49043 .46969 Mdot
.49048 .46966 Mdot
.49052 .46963 Mdot
.49057 .4696 Mdot
.49062 .46957 Mdot
.49067 .46954 Mdot
.49072 .46951 Mdot
.49076 .46948 Mdot
.49081 .46945 Mdot
.49086 .46942 Mdot
.49091 .46939 Mdot
.49095 .46935 Mdot
.491 .46932 Mdot
.49105 .46929 Mdot
.4911 .46926 Mdot
.49114 .46922 Mdot
.49119 .46919 Mdot
.49124 .46916 Mdot
.49129 .46912 Mdot
.49133 .46909 Mdot
.49138 .46905 Mdot
.49143 .46902 Mdot
.49148 .46898 Mdot
.49152 .46894 Mdot
.49157 .46891 Mdot
.49162 .46887 Mdot
.49167 .46883 Mdot
.49172 .4688 Mdot
.49176 .46876 Mdot
.49181 .46872 Mdot
.49186 .46868 Mdot
.49191 .46864 Mdot
.49195 .46861 Mdot
.492 .46857 Mdot
.49205 .46853 Mdot
.4921 .46849 Mdot
.49214 .46845 Mdot
.49219 .4684 Mdot
.49224 .46836 Mdot
.49229 .46832 Mdot
.49233 .46828 Mdot
.49238 .46824 Mdot
.49243 .4682 Mdot
.49248 .46815 Mdot
.49252 .46811 Mdot
.49257 .46807 Mdot
.49262 .46802 Mdot
.49267 .46798 Mdot
.49272 .46793 Mdot
.49276 .46789 Mdot
.49281 .46784 Mdot
.49286 .4678 Mdot
.49291 .46775 Mdot
.49295 .46771 Mdot
.493 .46766 Mdot
.49305 .46761 Mdot
.4931 .46757 Mdot
.49314 .46752 Mdot
.49319 .46747 Mdot
.49324 .46742 Mdot
.49329 .46737 Mdot
.49333 .46732 Mdot
.49338 .46728 Mdot
.49343 .46723 Mdot
.49348 .46718 Mdot
.49352 .46713 Mdot
.49357 .46707 Mdot
.49362 .46702 Mdot
.49367 .46697 Mdot
.49371 .46692 Mdot
.49376 .46687 Mdot
.49381 .46682 Mdot
.49386 .46676 Mdot
.49391 .46671 Mdot
.49395 .46666 Mdot
.494 .4666 Mdot
.49405 .46655 Mdot
.4941 .4665 Mdot
.49414 .46644 Mdot
.49419 .46639 Mdot
.49424 .46633 Mdot
.49429 .46628 Mdot
.49433 .46622 Mdot
.49438 .46616 Mdot
.49443 .46611 Mdot
.49448 .46605 Mdot
.49452 .46599 Mdot
.49457 .46593 Mdot
.49462 .46588 Mdot
.49467 .46582 Mdot
.49471 .46576 Mdot
.49476 .4657 Mdot
.49481 .46564 Mdot
.49486 .46558 Mdot
.49491 .46552 Mdot
.49495 .46546 Mdot
.495 .4654 Mdot
.49505 .46534 Mdot
.4951 .46528 Mdot
.49514 .46521 Mdot
.49519 .46515 Mdot
.49524 .46509 Mdot
.49529 .46503 Mdot
.49533 .46496 Mdot
.49538 .4649 Mdot
.49543 .46484 Mdot
.49548 .46477 Mdot
.49552 .46471 Mdot
.49557 .46464 Mdot
.49562 .46458 Mdot
.49567 .46451 Mdot
.49571 .46445 Mdot
.49576 .46438 Mdot
.49581 .46431 Mdot
.49586 .46425 Mdot
.49591 .46418 Mdot
.49595 .46411 Mdot
.496 .46404 Mdot
.49605 .46398 Mdot
.4961 .46391 Mdot
.49614 .46384 Mdot
.49619 .46377 Mdot
.49624 .4637 Mdot
.49629 .46363 Mdot
.49633 .46356 Mdot
.49638 .46349 Mdot
.49643 .46342 Mdot
.49648 .46335 Mdot
.49652 .46328 Mdot
.49657 .4632 Mdot
.49662 .46313 Mdot
.49667 .46306 Mdot
.49671 .46299 Mdot
.49676 .46291 Mdot
.49681 .46284 Mdot
.49686 .46277 Mdot
.49691 .46269 Mdot
.49695 .46262 Mdot
.497 .46254 Mdot
.49705 .46247 Mdot
.4971 .46239 Mdot
.49714 .46232 Mdot
.49719 .46224 Mdot
.49724 .46216 Mdot
.49729 .46209 Mdot
.49733 .46201 Mdot
.49738 .46193 Mdot
.49743 .46186 Mdot
.49748 .46178 Mdot
.49752 .4617 Mdot
.49757 .46162 Mdot
.49762 .46154 Mdot
.49767 .46146 Mdot
.49771 .46138 Mdot
.49776 .4613 Mdot
.49781 .46122 Mdot
.49786 .46114 Mdot
.4979 .46106 Mdot
.49795 .46098 Mdot
.498 .4609 Mdot
.49805 .46081 Mdot
.4981 .46073 Mdot
.49814 .46065 Mdot
.49819 .46057 Mdot
.49824 .46048 Mdot
.49829 .4604 Mdot
.49833 .46032 Mdot
.49838 .46023 Mdot
.49843 .46015 Mdot
.49848 .46006 Mdot
.49852 .45998 Mdot
.49857 .45989 Mdot
.49862 .4598 Mdot
.49867 .45972 Mdot
.49871 .45963 Mdot
.49876 .45954 Mdot
.49881 .45946 Mdot
.49886 .45937 Mdot
.4989 .45928 Mdot
.49895 .45919 Mdot
.499 .4591 Mdot
.49905 .45901 Mdot
.4991 .45892 Mdot
.49914 .45883 Mdot
.49919 .45874 Mdot
.49924 .45865 Mdot
.49929 .45856 Mdot
.49933 .45847 Mdot
.49938 .45838 Mdot
.49943 .45829 Mdot
.49948 .4582 Mdot
.49952 .4581 Mdot
.49957 .45801 Mdot
.49962 .45792 Mdot
.49967 .45783 Mdot
.49971 .45773 Mdot
.49976 .45764 Mdot
.49981 .45754 Mdot
.49986 .45745 Mdot
.4999 .45735 Mdot
.49995 .45726 Mdot
.5 .45716 Mdot
.50005 .45707 Mdot
.5001 .45697 Mdot
.50014 .45687 Mdot
.50019 .45678 Mdot
.50024 .45668 Mdot
.50029 .45658 Mdot
.50033 .45648 Mdot
.50038 .45639 Mdot
.50043 .45629 Mdot
.50048 .45619 Mdot
.50052 .45609 Mdot
.50057 .45599 Mdot
.50062 .45589 Mdot
.50067 .45579 Mdot
.50071 .45569 Mdot
.50076 .45559 Mdot
.50081 .45549 Mdot
.50086 .45539 Mdot
.5009 .45529 Mdot
.50095 .45518 Mdot
.501 .45508 Mdot
.50105 .45498 Mdot
.5011 .45488 Mdot
.50114 .45477 Mdot
.50119 .45467 Mdot
.50124 .45456 Mdot
.50129 .45446 Mdot
.50133 .45436 Mdot
.50138 .45425 Mdot
.50143 .45415 Mdot
.50148 .45404 Mdot
.50152 .45393 Mdot
.50157 .45383 Mdot
.50162 .45372 Mdot
.50167 .45361 Mdot
.50171 .45351 Mdot
.50176 .4534 Mdot
.50181 .45329 Mdot
.50186 .45318 Mdot
.5019 .45307 Mdot
.50195 .45297 Mdot
.502 .45286 Mdot
.50205 .45275 Mdot
.5021 .45264 Mdot
.50214 .45253 Mdot
.50219 .45242 Mdot
.50224 .45231 Mdot
.50229 .4522 Mdot
.50233 .45208 Mdot
.50238 .45197 Mdot
.50243 .45186 Mdot
.50248 .45175 Mdot
.50252 .45164 Mdot
.50257 .45152 Mdot
.50262 .45141 Mdot
.50267 .4513 Mdot
.50271 .45118 Mdot
.50276 .45107 Mdot
.50281 .45095 Mdot
.50286 .45084 Mdot
.5029 .45072 Mdot
.50295 .45061 Mdot
.503 .45049 Mdot
.50305 .45038 Mdot
.50309 .45026 Mdot
.50314 .45014 Mdot
.50319 .45003 Mdot
.50324 .44991 Mdot
.50329 .44979 Mdot
.50333 .44967 Mdot
.50338 .44955 Mdot
.50343 .44944 Mdot
.50348 .44932 Mdot
.50352 .4492 Mdot
.50357 .44908 Mdot
.50362 .44896 Mdot
.50367 .44884 Mdot
.50371 .44872 Mdot
.50376 .4486 Mdot
.50381 .44848 Mdot
.50386 .44835 Mdot
.5039 .44823 Mdot
.50395 .44811 Mdot
.504 .44799 Mdot
.50405 .44787 Mdot
.50409 .44774 Mdot
.50414 .44762 Mdot
.50419 .4475 Mdot
.50424 .44737 Mdot
.50429 .44725 Mdot
.50433 .44712 Mdot
.50438 .447 Mdot
.50443 .44687 Mdot
.50448 .44675 Mdot
.50452 .44662 Mdot
.50457 .4465 Mdot
.50462 .44637 Mdot
.50467 .44624 Mdot
.50471 .44612 Mdot
.50476 .44599 Mdot
.50481 .44586 Mdot
.50486 .44573 Mdot
.5049 .44561 Mdot
.50495 .44548 Mdot
.505 .44535 Mdot
.50505 .44522 Mdot
.50509 .44509 Mdot
.50514 .44496 Mdot
.50519 .44483 Mdot
.50524 .4447 Mdot
.50529 .44457 Mdot
.50533 .44444 Mdot
.50538 .44431 Mdot
.50543 .44418 Mdot
.50548 .44404 Mdot
.50552 .44391 Mdot
.50557 .44378 Mdot
.50562 .44365 Mdot
.50567 .44351 Mdot
.50571 .44338 Mdot
.50576 .44325 Mdot
.50581 .44311 Mdot
.50586 .44298 Mdot
.5059 .44284 Mdot
.50595 .44271 Mdot
.506 .44257 Mdot
.50605 .44244 Mdot
.50609 .4423 Mdot
.50614 .44217 Mdot
.50619 .44203 Mdot
.50624 .44189 Mdot
.50629 .44176 Mdot
.50633 .44162 Mdot
.50638 .44148 Mdot
.50643 .44134 Mdot
.50648 .44121 Mdot
.50652 .44107 Mdot
.50657 .44093 Mdot
.50662 .44079 Mdot
.50667 .44065 Mdot
.50671 .44051 Mdot
.50676 .44037 Mdot
.50681 .44023 Mdot
.50686 .44009 Mdot
.5069 .43995 Mdot
.50695 .43981 Mdot
.507 .43966 Mdot
.50705 .43952 Mdot
.50709 .43938 Mdot
.50714 .43924 Mdot
.50719 .4391 Mdot
.50724 .43895 Mdot
.50728 .43881 Mdot
.50733 .43867 Mdot
.50738 .43852 Mdot
.50743 .43838 Mdot
.50748 .43823 Mdot
.50752 .43809 Mdot
.50757 .43794 Mdot
.50762 .4378 Mdot
.50767 .43765 Mdot
.50771 .43751 Mdot
.50776 .43736 Mdot
.50781 .43722 Mdot
.50786 .43707 Mdot
.5079 .43692 Mdot
.50795 .43677 Mdot
.508 .43663 Mdot
.50805 .43648 Mdot
.50809 .43633 Mdot
.50814 .43618 Mdot
.50819 .43603 Mdot
.50824 .43589 Mdot
.50828 .43574 Mdot
.50833 .43559 Mdot
.50838 .43544 Mdot
.50843 .43529 Mdot
.50848 .43514 Mdot
.50852 .43499 Mdot
.50857 .43483 Mdot
.50862 .43468 Mdot
.50867 .43453 Mdot
.50871 .43438 Mdot
.50876 .43423 Mdot
.50881 .43407 Mdot
.50886 .43392 Mdot
.5089 .43377 Mdot
.50895 .43362 Mdot
.509 .43346 Mdot
.50905 .43331 Mdot
.50909 .43315 Mdot
.50914 .433 Mdot
.50919 .43284 Mdot
.50924 .43269 Mdot
.50928 .43253 Mdot
.50933 .43238 Mdot
.50938 .43222 Mdot
.50943 .43207 Mdot
.50948 .43191 Mdot
.50952 .43175 Mdot
.50957 .4316 Mdot
.50962 .43144 Mdot
.50967 .43128 Mdot
.50971 .43112 Mdot
.50976 .43096 Mdot
.50981 .43081 Mdot
.50986 .43065 Mdot
.5099 .43049 Mdot
.50995 .43033 Mdot
.51 .43017 Mdot
.51005 .43001 Mdot
.51009 .42985 Mdot
.51014 .42969 Mdot
.51019 .42953 Mdot
.51024 .42937 Mdot
.51028 .42921 Mdot
.51033 .42904 Mdot
.51038 .42888 Mdot
.51043 .42872 Mdot
.51048 .42856 Mdot
.51052 .42839 Mdot
.51057 .42823 Mdot
.51062 .42807 Mdot
.51067 .4279 Mdot
.51071 .42774 Mdot
.51076 .42758 Mdot
.51081 .42741 Mdot
.51086 .42725 Mdot
.5109 .42708 Mdot
.51095 .42692 Mdot
.511 .42675 Mdot
.51105 .42659 Mdot
.51109 .42642 Mdot
.51114 .42625 Mdot
.51119 .42609 Mdot
.51124 .42592 Mdot
.51128 .42575 Mdot
.51133 .42558 Mdot
.51138 .42542 Mdot
.51143 .42525 Mdot
.51148 .42508 Mdot
.51152 .42491 Mdot
.51157 .42474 Mdot
.51162 .42457 Mdot
.51167 .4244 Mdot
.51171 .42423 Mdot
.51176 .42406 Mdot
.51181 .42389 Mdot
.51186 .42372 Mdot
.5119 .42355 Mdot
.51195 .42338 Mdot
.512 .42321 Mdot
.51205 .42304 Mdot
.51209 .42286 Mdot
.51214 .42269 Mdot
.51219 .42252 Mdot
.51224 .42235 Mdot
.51228 .42217 Mdot
.51233 .422 Mdot
.51238 .42183 Mdot
.51243 .42165 Mdot
.51247 .42148 Mdot
.51252 .4213 Mdot
.51257 .42113 Mdot
.51262 .42095 Mdot
.51267 .42078 Mdot
.51271 .4206 Mdot
.51276 .42043 Mdot
.51281 .42025 Mdot
.51286 .42007 Mdot
.5129 .4199 Mdot
.51295 .41972 Mdot
.513 .41954 Mdot
.51305 .41937 Mdot
.51309 .41919 Mdot
.51314 .41901 Mdot
.51319 .41883 Mdot
.51324 .41865 Mdot
.51328 .41847 Mdot
.51333 .41829 Mdot
.51338 .41811 Mdot
.51343 .41794 Mdot
.51347 .41776 Mdot
.51352 .41757 Mdot
.51357 .41739 Mdot
.51362 .41721 Mdot
.51367 .41703 Mdot
.51371 .41685 Mdot
.51376 .41667 Mdot
.51381 .41649 Mdot
.51386 .41631 Mdot
.5139 .41612 Mdot
.51395 .41594 Mdot
.514 .41576 Mdot
.51405 .41557 Mdot
.51409 .41539 Mdot
.51414 .41521 Mdot
.51419 .41502 Mdot
.51424 .41484 Mdot
.51428 .41465 Mdot
.51433 .41447 Mdot
.51438 .41428 Mdot
.51443 .4141 Mdot
.51447 .41391 Mdot
.51452 .41373 Mdot
.51457 .41354 Mdot
.51462 .41335 Mdot
.51467 .41317 Mdot
.51471 .41298 Mdot
.51476 .41279 Mdot
.51481 .41261 Mdot
.51486 .41242 Mdot
.5149 .41223 Mdot
.51495 .41204 Mdot
.515 .41185 Mdot
.51505 .41166 Mdot
.51509 .41148 Mdot
.51514 .41129 Mdot
.51519 .4111 Mdot
.51524 .41091 Mdot
.51528 .41072 Mdot
.51533 .41053 Mdot
.51538 .41034 Mdot
.51543 .41015 Mdot
.51547 .40996 Mdot
.51552 .40976 Mdot
.51557 .40957 Mdot
.51562 .40938 Mdot
.51567 .40919 Mdot
.51571 .409 Mdot
.51576 .4088 Mdot
.51581 .40861 Mdot
.51586 .40842 Mdot
.5159 .40823 Mdot
.51595 .40803 Mdot
.516 .40784 Mdot
.51605 .40764 Mdot
.51609 .40745 Mdot
.51614 .40726 Mdot
.51619 .40706 Mdot
.51624 .40687 Mdot
.51628 .40667 Mdot
.51633 .40648 Mdot
.51638 .40628 Mdot
.51643 .40608 Mdot
.51647 .40589 Mdot
.51652 .40569 Mdot
.51657 .4055 Mdot
.51662 .4053 Mdot
.51667 .4051 Mdot
.51671 .4049 Mdot
.51676 .40471 Mdot
.51681 .40451 Mdot
.51686 .40431 Mdot
.5169 .40411 Mdot
.51695 .40392 Mdot
.517 .40372 Mdot
.51705 .40352 Mdot
.51709 .40332 Mdot
.51714 .40312 Mdot
.51719 .40292 Mdot
.51724 .40272 Mdot
.51728 .40252 Mdot
.51733 .40232 Mdot
.51738 .40212 Mdot
.51743 .40192 Mdot
.51747 .40172 Mdot
.51752 .40152 Mdot
.51757 .40131 Mdot
.51762 .40111 Mdot
.51766 .40091 Mdot
.51771 .40071 Mdot
.51776 .40051 Mdot
.51781 .4003 Mdot
.51786 .4001 Mdot
.5179 .3999 Mdot
.51795 .39969 Mdot
.518 .39949 Mdot
.51805 .39929 Mdot
.51809 .39908 Mdot
.51814 .39888 Mdot
.51819 .39867 Mdot
.51824 .39847 Mdot
.51828 .39826 Mdot
.51833 .39806 Mdot
.51838 .39785 Mdot
.51843 .39765 Mdot
.51847 .39744 Mdot
.51852 .39724 Mdot
.51857 .39703 Mdot
.51862 .39682 Mdot
.51866 .39662 Mdot
.51871 .39641 Mdot
.51876 .3962 Mdot
.51881 .396 Mdot
.51886 .39579 Mdot
.5189 .39558 Mdot
.51895 .39537 Mdot
.519 .39516 Mdot
.51905 .39495 Mdot
.51909 .39475 Mdot
.51914 .39454 Mdot
.51919 .39433 Mdot
.51924 .39412 Mdot
.51928 .39391 Mdot
.51933 .3937 Mdot
.51938 .39349 Mdot
.51943 .39328 Mdot
.51947 .39307 Mdot
.51952 .39286 Mdot
.51957 .39265 Mdot
.51962 .39243 Mdot
.51966 .39222 Mdot
.51971 .39201 Mdot
.51976 .3918 Mdot
.51981 .39159 Mdot
.51986 .39138 Mdot
.5199 .39116 Mdot
.51995 .39095 Mdot
.52 .39074 Mdot
.52005 .39052 Mdot
.52009 .39031 Mdot
.52014 .3901 Mdot
.52019 .38988 Mdot
.52024 .38967 Mdot
.52028 .38946 Mdot
.52033 .38924 Mdot
.52038 .38903 Mdot
.52043 .38881 Mdot
.52047 .3886 Mdot
.52052 .38838 Mdot
.52057 .38817 Mdot
.52062 .38795 Mdot
.52066 .38773 Mdot
.52071 .38752 Mdot
.52076 .3873 Mdot
.52081 .38708 Mdot
.52086 .38687 Mdot
.5209 .38665 Mdot
.52095 .38643 Mdot
.521 .38622 Mdot
.52105 .386 Mdot
.52109 .38578 Mdot
.52114 .38556 Mdot
.52119 .38534 Mdot
.52124 .38512 Mdot
.52128 .3849 Mdot
.52133 .38469 Mdot
.52138 .38447 Mdot
.52143 .38425 Mdot
.52147 .38403 Mdot
.52152 .38381 Mdot
.52157 .38359 Mdot
.52162 .38337 Mdot
.52166 .38315 Mdot
.52171 .38293 Mdot
.52176 .3827 Mdot
.52181 .38248 Mdot
.52185 .38226 Mdot
.5219 .38204 Mdot
.52195 .38182 Mdot
.522 .3816 Mdot
.52205 .38137 Mdot
.52209 .38115 Mdot
.52214 .38093 Mdot
.52219 .38071 Mdot
.52224 .38048 Mdot
.52228 .38026 Mdot
.52233 .38004 Mdot
.52238 .37981 Mdot
.52243 .37959 Mdot
.52247 .37937 Mdot
.52252 .37914 Mdot
.52257 .37892 Mdot
.52262 .37869 Mdot
.52266 .37847 Mdot
.52271 .37824 Mdot
.52276 .37802 Mdot
.52281 .37779 Mdot
.52285 .37757 Mdot
.5229 .37734 Mdot
.52295 .37711 Mdot
.523 .37689 Mdot
.52305 .37666 Mdot
.52309 .37644 Mdot
.52314 .37621 Mdot
.52319 .37598 Mdot
.52324 .37576 Mdot
.52328 .37553 Mdot
.52333 .3753 Mdot
.52338 .37507 Mdot
.52343 .37485 Mdot
.52347 .37462 Mdot
.52352 .37439 Mdot
.52357 .37416 Mdot
.52362 .37393 Mdot
.52366 .3737 Mdot
.52371 .37348 Mdot
.52376 .37325 Mdot
.52381 .37302 Mdot
.52385 .37279 Mdot
.5239 .37256 Mdot
.52395 .37233 Mdot
.524 .3721 Mdot
.52405 .37187 Mdot
.52409 .37164 Mdot
.52414 .37141 Mdot
.52419 .37118 Mdot
.52424 .37095 Mdot
.52428 .37071 Mdot
.52433 .37048 Mdot
.52438 .37025 Mdot
.52443 .37002 Mdot
.52447 .36979 Mdot
.52452 .36956 Mdot
.52457 .36932 Mdot
.52462 .36909 Mdot
.52466 .36886 Mdot
.52471 .36863 Mdot
.52476 .36839 Mdot
.52481 .36816 Mdot
.52485 .36793 Mdot
.5249 .36769 Mdot
.52495 .36746 Mdot
.525 .36722 Mdot
.52505 .36699 Mdot
.52509 .36676 Mdot
.52514 .36652 Mdot
.52519 .36629 Mdot
.52524 .36605 Mdot
.52528 .36582 Mdot
.52533 .36558 Mdot
.52538 .36535 Mdot
.52543 .36511 Mdot
.52547 .36488 Mdot
.52552 .36464 Mdot
.52557 .3644 Mdot
.52562 .36417 Mdot
.52566 .36393 Mdot
.52571 .3637 Mdot
.52576 .36346 Mdot
.52581 .36322 Mdot
.52585 .36298 Mdot
.5259 .36275 Mdot
.52595 .36251 Mdot
.526 .36227 Mdot
.52605 .36204 Mdot
.52609 .3618 Mdot
.52614 .36156 Mdot
.52619 .36132 Mdot
.52624 .36108 Mdot
.52628 .36084 Mdot
.52633 .36061 Mdot
.52638 .36037 Mdot
.52643 .36013 Mdot
.52647 .35989 Mdot
.52652 .35965 Mdot
.52657 .35941 Mdot
.52662 .35917 Mdot
.52666 .35893 Mdot
.52671 .35869 Mdot
.52676 .35845 Mdot
.52681 .35821 Mdot
.52685 .35797 Mdot
.5269 .35773 Mdot
.52695 .35749 Mdot
.527 .35725 Mdot
.52704 .357 Mdot
.52709 .35676 Mdot
.52714 .35652 Mdot
.52719 .35628 Mdot
.52724 .35604 Mdot
.52728 .3558 Mdot
.52733 .35555 Mdot
.52738 .35531 Mdot
.52743 .35507 Mdot
.52747 .35483 Mdot
.52752 .35458 Mdot
.52757 .35434 Mdot
.52762 .3541 Mdot
.52766 .35386 Mdot
.52771 .35361 Mdot
.52776 .35337 Mdot
.52781 .35313 Mdot
.52785 .35288 Mdot
.5279 .35264 Mdot
.52795 .35239 Mdot
.528 .35215 Mdot
.52804 .3519 Mdot
.52809 .35166 Mdot
.52814 .35142 Mdot
.52819 .35117 Mdot
.52824 .35093 Mdot
.52828 .35068 Mdot
.52833 .35044 Mdot
.52838 .35019 Mdot
.52843 .34994 Mdot
.52847 .3497 Mdot
.52852 .34945 Mdot
.52857 .34921 Mdot
.52862 .34896 Mdot
.52866 .34871 Mdot
.52871 .34847 Mdot
.52876 .34822 Mdot
.52881 .34797 Mdot
.52885 .34773 Mdot
.5289 .34748 Mdot
.52895 .34723 Mdot
.529 .34699 Mdot
.52904 .34674 Mdot
.52909 .34649 Mdot
.52914 .34624 Mdot
.52919 .34599 Mdot
.52924 .34575 Mdot
.52928 .3455 Mdot
.52933 .34525 Mdot
.52938 .345 Mdot
.52943 .34475 Mdot
.52947 .3445 Mdot
.52952 .34426 Mdot
.52957 .34401 Mdot
.52962 .34376 Mdot
.52966 .34351 Mdot
.52971 .34326 Mdot
.52976 .34301 Mdot
.52981 .34276 Mdot
.52985 .34251 Mdot
.5299 .34226 Mdot
.52995 .34201 Mdot
.53 .34176 Mdot
.53004 .34151 Mdot
.53009 .34126 Mdot
.53014 .34101 Mdot
.53019 .34076 Mdot
.53024 .34051 Mdot
.53028 .34026 Mdot
.53033 .34 Mdot
.53038 .33975 Mdot
.53043 .3395 Mdot
.53047 .33925 Mdot
.53052 .339 Mdot
.53057 .33875 Mdot
.53062 .33849 Mdot
.53066 .33824 Mdot
.53071 .33799 Mdot
.53076 .33774 Mdot
.53081 .33749 Mdot
.53085 .33723 Mdot
.5309 .33698 Mdot
.53095 .33673 Mdot
.531 .33647 Mdot
.53104 .33622 Mdot
.53109 .33597 Mdot
.53114 .33571 Mdot
.53119 .33546 Mdot
.53123 .33521 Mdot
.53128 .33495 Mdot
.53133 .3347 Mdot
.53138 .33445 Mdot
.53143 .33419 Mdot
.53147 .33394 Mdot
.53152 .33368 Mdot
.53157 .33343 Mdot
.53162 .33317 Mdot
.53166 .33292 Mdot
.53171 .33266 Mdot
.53176 .33241 Mdot
.53181 .33216 Mdot
.53185 .3319 Mdot
.5319 .33165 Mdot
.53195 .33139 Mdot
.532 .33113 Mdot
.53204 .33088 Mdot
.53209 .33062 Mdot
.53214 .33037 Mdot
.53219 .33011 Mdot
.53223 .32986 Mdot
.53228 .3296 Mdot
.53233 .32934 Mdot
.53238 .32909 Mdot
.53243 .32883 Mdot
.53247 .32857 Mdot
.53252 .32832 Mdot
.53257 .32806 Mdot
.53262 .3278 Mdot
.53266 .32755 Mdot
.53271 .32729 Mdot
.53276 .32703 Mdot
.53281 .32678 Mdot
.53285 .32652 Mdot
.5329 .32626 Mdot
.53295 .326 Mdot
.533 .32575 Mdot
.53304 .32549 Mdot
.53309 .32523 Mdot
.53314 .32497 Mdot
.53319 .32471 Mdot
.53323 .32446 Mdot
.53328 .3242 Mdot
.53333 .32394 Mdot
.53338 .32368 Mdot
.53343 .32342 Mdot
.53347 .32316 Mdot
.53352 .32291 Mdot
.53357 .32265 Mdot
.53362 .32239 Mdot
.53366 .32213 Mdot
.53371 .32187 Mdot
.53376 .32161 Mdot
.53381 .32135 Mdot
.53385 .32109 Mdot
.5339 .32083 Mdot
.53395 .32057 Mdot
.534 .32031 Mdot
.53404 .32005 Mdot
.53409 .31979 Mdot
.53414 .31953 Mdot
.53419 .31927 Mdot
.53423 .31901 Mdot
.53428 .31875 Mdot
.53433 .31849 Mdot
.53438 .31823 Mdot
.53443 .31797 Mdot
.53447 .31771 Mdot
.53452 .31745 Mdot
.53457 .31719 Mdot
.53462 .31693 Mdot
.53466 .31667 Mdot
.53471 .3164 Mdot
.53476 .31614 Mdot
.53481 .31588 Mdot
.53485 .31562 Mdot
.5349 .31536 Mdot
.53495 .3151 Mdot
.535 .31484 Mdot
.53504 .31458 Mdot
.53509 .31431 Mdot
.53514 .31405 Mdot
.53519 .31379 Mdot
.53523 .31353 Mdot
.53528 .31327 Mdot
.53533 .313 Mdot
.53538 .31274 Mdot
.53543 .31248 Mdot
.53547 .31222 Mdot
.53552 .31195 Mdot
.53557 .31169 Mdot
.53562 .31143 Mdot
.53566 .31117 Mdot
.53571 .3109 Mdot
.53576 .31064 Mdot
.53581 .31038 Mdot
.53585 .31011 Mdot
.5359 .30985 Mdot
.53595 .30959 Mdot
.536 .30932 Mdot
.53604 .30906 Mdot
.53609 .3088 Mdot
.53614 .30853 Mdot
.53619 .30827 Mdot
.53623 .30801 Mdot
.53628 .30774 Mdot
.53633 .30748 Mdot
.53638 .30722 Mdot
.53642 .30695 Mdot
.53647 .30669 Mdot
.53652 .30642 Mdot
.53657 .30616 Mdot
.53662 .3059 Mdot
.53666 .30563 Mdot
.53671 .30537 Mdot
.53676 .3051 Mdot
.53681 .30484 Mdot
.53685 .30458 Mdot
.5369 .30431 Mdot
.53695 .30405 Mdot
.537 .30378 Mdot
.53704 .30352 Mdot
.53709 .30325 Mdot
.53714 .30299 Mdot
.53719 .30272 Mdot
.53723 .30246 Mdot
.53728 .30219 Mdot
.53733 .30193 Mdot
.53738 .30166 Mdot
.53742 .3014 Mdot
.53747 .30113 Mdot
.53752 .30087 Mdot
.53757 .3006 Mdot
.53762 .30034 Mdot
.53766 .30007 Mdot
.53771 .29981 Mdot
.53776 .29954 Mdot
.53781 .29927 Mdot
.53785 .29901 Mdot
.5379 .29874 Mdot
.53795 .29848 Mdot
.538 .29821 Mdot
.53804 .29794 Mdot
.53809 .29768 Mdot
.53814 .29741 Mdot
.53819 .29715 Mdot
.53823 .29688 Mdot
.53828 .29661 Mdot
.53833 .29635 Mdot
.53838 .29608 Mdot
.53842 .29582 Mdot
.53847 .29555 Mdot
.53852 .29528 Mdot
.53857 .29502 Mdot
.53862 .29475 Mdot
.53866 .29448 Mdot
.53871 .29422 Mdot
.53876 .29395 Mdot
.53881 .29368 Mdot
.53885 .29342 Mdot
.5389 .29315 Mdot
.53895 .29288 Mdot
.539 .29262 Mdot
.53904 .29235 Mdot
.53909 .29208 Mdot
.53914 .29182 Mdot
.53919 .29155 Mdot
.53923 .29128 Mdot
.53928 .29102 Mdot
.53933 .29075 Mdot
.53938 .29048 Mdot
.53942 .29022 Mdot
.53947 .28995 Mdot
.53952 .28968 Mdot
.53957 .28941 Mdot
.53962 .28915 Mdot
.53966 .28888 Mdot
.53971 .28861 Mdot
.53976 .28834 Mdot
.53981 .28808 Mdot
.53985 .28781 Mdot
.5399 .28754 Mdot
.53995 .28728 Mdot
.54 .28701 Mdot
.54004 .28674 Mdot
.54009 .28647 Mdot
.54014 .28621 Mdot
.54019 .28594 Mdot
.54023 .28567 Mdot
.54028 .2854 Mdot
.54033 .28514 Mdot
.54038 .28487 Mdot
.54042 .2846 Mdot
.54047 .28433 Mdot
.54052 .28406 Mdot
.54057 .2838 Mdot
.54061 .28353 Mdot
.54066 .28326 Mdot
.54071 .28299 Mdot
.54076 .28273 Mdot
.54081 .28246 Mdot
.54085 .28219 Mdot
.5409 .28192 Mdot
.54095 .28165 Mdot
.541 .28139 Mdot
.54104 .28112 Mdot
.54109 .28085 Mdot
.54114 .28058 Mdot
.54119 .28031 Mdot
.54123 .28005 Mdot
.54128 .27978 Mdot
.54133 .27951 Mdot
.54138 .27924 Mdot
.54142 .27897 Mdot
.54147 .27871 Mdot
.54152 .27844 Mdot
.54157 .27817 Mdot
.54161 .2779 Mdot
.54166 .27763 Mdot
.54171 .27737 Mdot
.54176 .2771 Mdot
.54181 .27683 Mdot
.54185 .27656 Mdot
.5419 .27629 Mdot
.54195 .27603 Mdot
.542 .27576 Mdot
.54204 .27549 Mdot
.54209 .27522 Mdot
.54214 .27495 Mdot
.54219 .27469 Mdot
.54223 .27442 Mdot
.54228 .27415 Mdot
.54233 .27388 Mdot
.54238 .27361 Mdot
.54242 .27334 Mdot
.54247 .27308 Mdot
.54252 .27281 Mdot
.54257 .27254 Mdot
.54261 .27227 Mdot
.54266 .272 Mdot
.54271 .27174 Mdot
.54276 .27147 Mdot
.54281 .2712 Mdot
.54285 .27093 Mdot
.5429 .27066 Mdot
.54295 .27039 Mdot
.543 .27013 Mdot
.54304 .26986 Mdot
.54309 .26959 Mdot
.54314 .26932 Mdot
.54319 .26905 Mdot
.54323 .26879 Mdot
.54328 .26852 Mdot
.54333 .26825 Mdot
.54338 .26798 Mdot
.54342 .26771 Mdot
.54347 .26744 Mdot
.54352 .26718 Mdot
.54357 .26691 Mdot
.54361 .26664 Mdot
.54366 .26637 Mdot
.54371 .2661 Mdot
.54376 .26584 Mdot
.54381 .26557 Mdot
.54385 .2653 Mdot
.5439 .26503 Mdot
.54395 .26476 Mdot
.544 .26449 Mdot
.54404 .26423 Mdot
.54409 .26396 Mdot
.54414 .26369 Mdot
.54419 .26342 Mdot
.54423 .26315 Mdot
.54428 .26289 Mdot
.54433 .26262 Mdot
.54438 .26235 Mdot
.54442 .26208 Mdot
.54447 .26181 Mdot
.54452 .26155 Mdot
.54457 .26128 Mdot
.54461 .26101 Mdot
.54466 .26074 Mdot
.54471 .26048 Mdot
.54476 .26021 Mdot
.54481 .25994 Mdot
.54485 .25967 Mdot
.5449 .2594 Mdot
.54495 .25914 Mdot
.545 .25887 Mdot
.54504 .2586 Mdot
.54509 .25833 Mdot
.54514 .25807 Mdot
.54519 .2578 Mdot
.54523 .25753 Mdot
.54528 .25726 Mdot
.54533 .257 Mdot
.54538 .25673 Mdot
.54542 .25646 Mdot
.54547 .25619 Mdot
.54552 .25593 Mdot
.54557 .25566 Mdot
.54561 .25539 Mdot
.54566 .25512 Mdot
.54571 .25486 Mdot
.54576 .25459 Mdot
.5458 .25432 Mdot
.54585 .25406 Mdot
.5459 .25379 Mdot
.54595 .25352 Mdot
.546 .25325 Mdot
.54604 .25299 Mdot
.54609 .25272 Mdot
.54614 .25245 Mdot
.54619 .25219 Mdot
.54623 .25192 Mdot
.54628 .25165 Mdot
.54633 .25139 Mdot
.54638 .25112 Mdot
.54642 .25085 Mdot
.54647 .25059 Mdot
.54652 .25032 Mdot
.54657 .25005 Mdot
.54661 .24979 Mdot
.54666 .24952 Mdot
.54671 .24925 Mdot
.54676 .24899 Mdot
.5468 .24872 Mdot
.54685 .24845 Mdot
.5469 .24819 Mdot
.54695 .24792 Mdot
.547 .24766 Mdot
.54704 .24739 Mdot
.54709 .24712 Mdot
.54714 .24686 Mdot
.54719 .24659 Mdot
.54723 .24633 Mdot
.54728 .24606 Mdot
.54733 .24579 Mdot
.54738 .24553 Mdot
.54742 .24526 Mdot
.54747 .245 Mdot
.54752 .24473 Mdot
.54757 .24446 Mdot
.54761 .2442 Mdot
.54766 .24393 Mdot
.54771 .24367 Mdot
.54776 .2434 Mdot
.5478 .24313 Mdot
.54785 .24287 Mdot
.5479 .2426 Mdot
.54795 .24234 Mdot
.548 .24207 Mdot
.54804 .24181 Mdot
.54809 .24154 Mdot
.54814 .24128 Mdot
.54819 .24101 Mdot
.54823 .24075 Mdot
.54828 .24048 Mdot
.54833 .24022 Mdot
.54838 .23995 Mdot
.54842 .23969 Mdot
.54847 .23942 Mdot
.54852 .23916 Mdot
.54857 .2389 Mdot
.54861 .23863 Mdot
.54866 .23837 Mdot
.54871 .2381 Mdot
.54876 .23784 Mdot
.5488 .23757 Mdot
.54885 .23731 Mdot
.5489 .23705 Mdot
.54895 .23678 Mdot
.549 .23652 Mdot
.54904 .23625 Mdot
.54909 .23599 Mdot
.54914 .23573 Mdot
.54919 .23546 Mdot
.54923 .2352 Mdot
.54928 .23494 Mdot
.54933 .23467 Mdot
.54938 .23441 Mdot
.54942 .23415 Mdot
.54947 .23388 Mdot
.54952 .23362 Mdot
.54957 .23336 Mdot
.54961 .23309 Mdot
.54966 .23283 Mdot
.54971 .23257 Mdot
.54976 .2323 Mdot
.5498 .23204 Mdot
.54985 .23178 Mdot
.5499 .23152 Mdot
.54995 .23125 Mdot
.55 .23099 Mdot
.55004 .23073 Mdot
.55009 .23047 Mdot
.55014 .2302 Mdot
.55019 .22994 Mdot
.55023 .22968 Mdot
.55028 .22942 Mdot
.55033 .22916 Mdot
.55038 .22889 Mdot
.55042 .22863 Mdot
.55047 .22837 Mdot
.55052 .22811 Mdot
.55057 .22785 Mdot
.55061 .22759 Mdot
.55066 .22732 Mdot
.55071 .22706 Mdot
.55076 .2268 Mdot
.5508 .22654 Mdot
.55085 .22628 Mdot
.5509 .22602 Mdot
.55095 .22576 Mdot
.55099 .2255 Mdot
.55104 .22524 Mdot
.55109 .22498 Mdot
.55114 .22472 Mdot
.55119 .22445 Mdot
.55123 .22419 Mdot
.55128 .22393 Mdot
.55133 .22367 Mdot
.55138 .22341 Mdot
.55142 .22315 Mdot
.55147 .22289 Mdot
.55152 .22263 Mdot
.55157 .22237 Mdot
.55161 .22211 Mdot
.55166 .22186 Mdot
.55171 .2216 Mdot
.55176 .22134 Mdot
.5518 .22108 Mdot
.55185 .22082 Mdot
.5519 .22056 Mdot
.55195 .2203 Mdot
.55199 .22004 Mdot
.55204 .21978 Mdot
.55209 .21952 Mdot
.55214 .21927 Mdot
.55219 .21901 Mdot
.55223 .21875 Mdot
.55228 .21849 Mdot
.55233 .21823 Mdot
.55238 .21798 Mdot
.55242 .21772 Mdot
.55247 .21746 Mdot
.55252 .2172 Mdot
.55257 .21694 Mdot
.55261 .21669 Mdot
.55266 .21643 Mdot
.55271 .21617 Mdot
.55276 .21591 Mdot
.5528 .21566 Mdot
.55285 .2154 Mdot
.5529 .21514 Mdot
.55295 .21489 Mdot
.55299 .21463 Mdot
.55304 .21437 Mdot
.55309 .21412 Mdot
.55314 .21386 Mdot
.55319 .2136 Mdot
.55323 .21335 Mdot
.55328 .21309 Mdot
.55333 .21284 Mdot
.55338 .21258 Mdot
.55342 .21233 Mdot
.55347 .21207 Mdot
.55352 .21181 Mdot
.55357 .21156 Mdot
.55361 .2113 Mdot
.55366 .21105 Mdot
.55371 .21079 Mdot
.55376 .21054 Mdot
.5538 .21028 Mdot
.55385 .21003 Mdot
.5539 .20978 Mdot
.55395 .20952 Mdot
.55399 .20927 Mdot
.55404 .20901 Mdot
.55409 .20876 Mdot
.55414 .20851 Mdot
.55419 .20825 Mdot
.55423 .208 Mdot
.55428 .20774 Mdot
.55433 .20749 Mdot
.55438 .20724 Mdot
.55442 .20698 Mdot
.55447 .20673 Mdot
.55452 .20648 Mdot
.55457 .20623 Mdot
.55461 .20597 Mdot
.55466 .20572 Mdot
.55471 .20547 Mdot
.55476 .20522 Mdot
.5548 .20496 Mdot
.55485 .20471 Mdot
.5549 .20446 Mdot
.55495 .20421 Mdot
.55499 .20396 Mdot
.55504 .2037 Mdot
.55509 .20345 Mdot
.55514 .2032 Mdot
.55518 .20295 Mdot
.55523 .2027 Mdot
.55528 .20245 Mdot
.55533 .2022 Mdot
.55538 .20195 Mdot
.55542 .2017 Mdot
.55547 .20145 Mdot
.55552 .2012 Mdot
.55557 .20095 Mdot
.55561 .2007 Mdot
.55566 .20045 Mdot
.55571 .2002 Mdot
.55576 .19995 Mdot
.5558 .1997 Mdot
.55585 .19945 Mdot
.5559 .1992 Mdot
.55595 .19895 Mdot
.55599 .1987 Mdot
.55604 .19845 Mdot
.55609 .1982 Mdot
.55614 .19795 Mdot
.55618 .19771 Mdot
.55623 .19746 Mdot
.55628 .19721 Mdot
.55633 .19696 Mdot
.55638 .19671 Mdot
.55642 .19647 Mdot
.55647 .19622 Mdot
.55652 .19597 Mdot
.55657 .19572 Mdot
.55661 .19548 Mdot
.55666 .19523 Mdot
.55671 .19498 Mdot
.55676 .19473 Mdot
.5568 .19449 Mdot
.55685 .19424 Mdot
.5569 .19399 Mdot
.55695 .19375 Mdot
.55699 .1935 Mdot
.55704 .19326 Mdot
.55709 .19301 Mdot
.55714 .19277 Mdot
.55718 .19252 Mdot
.55723 .19227 Mdot
.55728 .19203 Mdot
.55733 .19178 Mdot
.55738 .19154 Mdot
.55742 .19129 Mdot
.55747 .19105 Mdot
.55752 .1908 Mdot
.55757 .19056 Mdot
.55761 .19032 Mdot
.55766 .19007 Mdot
.55771 .18983 Mdot
.55776 .18958 Mdot
.5578 .18934 Mdot
.55785 .1891 Mdot
.5579 .18885 Mdot
.55795 .18861 Mdot
.55799 .18837 Mdot
.55804 .18813 Mdot
.55809 .18788 Mdot
.55814 .18764 Mdot
.55818 .1874 Mdot
.55823 .18716 Mdot
.55828 .18692 Mdot
.55833 .18667 Mdot
.55838 .18643 Mdot
.55842 .18619 Mdot
.55847 .18595 Mdot
.55852 .18571 Mdot
.55857 .18547 Mdot
.55861 .18523 Mdot
.55866 .18499 Mdot
.55871 .18475 Mdot
.55876 .18451 Mdot
.5588 .18427 Mdot
.55885 .18403 Mdot
.5589 .18379 Mdot
.55895 .18355 Mdot
.55899 .18331 Mdot
.55904 .18307 Mdot
.55909 .18283 Mdot
.55914 .18259 Mdot
.55918 .18235 Mdot
.55923 .18212 Mdot
.55928 .18188 Mdot
.55933 .18164 Mdot
.55938 .1814 Mdot
.55942 .18116 Mdot
.55947 .18093 Mdot
.55952 .18069 Mdot
.55957 .18045 Mdot
.55961 .18022 Mdot
.55966 .17998 Mdot
.55971 .17974 Mdot
.55976 .17951 Mdot
.5598 .17927 Mdot
.55985 .17904 Mdot
.5599 .1788 Mdot
.55995 .17856 Mdot
.55999 .17833 Mdot
.56004 .17809 Mdot
.56009 .17786 Mdot
.56014 .17762 Mdot
.56018 .17739 Mdot
.56023 .17715 Mdot
.56028 .17692 Mdot
.56033 .17669 Mdot
.56037 .17645 Mdot
.56042 .17622 Mdot
.56047 .17599 Mdot
.56052 .17575 Mdot
.56057 .17552 Mdot
.56061 .17529 Mdot
.56066 .17505 Mdot
.56071 .17482 Mdot
.56076 .17459 Mdot
.5608 .17436 Mdot
.56085 .17412 Mdot
.5609 .17389 Mdot
.56095 .17366 Mdot
.56099 .17343 Mdot
.56104 .1732 Mdot
.56109 .17297 Mdot
.56114 .17274 Mdot
.56118 .17251 Mdot
.56123 .17228 Mdot
.56128 .17205 Mdot
.56133 .17182 Mdot
.56137 .17159 Mdot
.56142 .17136 Mdot
.56147 .17113 Mdot
.56152 .1709 Mdot
.56157 .17067 Mdot
.56161 .17044 Mdot
.56166 .17021 Mdot
.56171 .16998 Mdot
.56176 .16976 Mdot
.5618 .16953 Mdot
.56185 .1693 Mdot
.5619 .16907 Mdot
.56195 .16885 Mdot
.56199 .16862 Mdot
.56204 .16839 Mdot
.56209 .16817 Mdot
.56214 .16794 Mdot
.56218 .16771 Mdot
.56223 .16749 Mdot
.56228 .16726 Mdot
.56233 .16704 Mdot
.56237 .16681 Mdot
.56242 .16659 Mdot
.56247 .16636 Mdot
.56252 .16614 Mdot
.56257 .16591 Mdot
.56261 .16569 Mdot
.56266 .16546 Mdot
.56271 .16524 Mdot
.56276 .16502 Mdot
.5628 .16479 Mdot
.56285 .16457 Mdot
.5629 .16435 Mdot
.56295 .16412 Mdot
.56299 .1639 Mdot
.56304 .16368 Mdot
.56309 .16346 Mdot
.56314 .16323 Mdot
.56318 .16301 Mdot
.56323 .16279 Mdot
.56328 .16257 Mdot
.56333 .16235 Mdot
.56337 .16213 Mdot
.56342 .16191 Mdot
.56347 .16169 Mdot
.56352 .16147 Mdot
.56357 .16125 Mdot
.56361 .16103 Mdot
.56366 .16081 Mdot
.56371 .16059 Mdot
.56376 .16037 Mdot
.5638 .16015 Mdot
.56385 .15993 Mdot
.5639 .15971 Mdot
.56395 .15949 Mdot
.56399 .15927 Mdot
.56404 .15906 Mdot
.56409 .15884 Mdot
.56414 .15862 Mdot
.56418 .1584 Mdot
.56423 .15819 Mdot
.56428 .15797 Mdot
.56433 .15775 Mdot
.56437 .15754 Mdot
.56442 .15732 Mdot
.56447 .15711 Mdot
.56452 .15689 Mdot
.56456 .15667 Mdot
.56461 .15646 Mdot
.56466 .15624 Mdot
.56471 .15603 Mdot
.56476 .15582 Mdot
.5648 .1556 Mdot
.56485 .15539 Mdot
.5649 .15517 Mdot
.56495 .15496 Mdot
.56499 .15475 Mdot
.56504 .15453 Mdot
.56509 .15432 Mdot
.56514 .15411 Mdot
.56518 .15389 Mdot
.56523 .15368 Mdot
.56528 .15347 Mdot
.56533 .15326 Mdot
.56537 .15305 Mdot
.56542 .15284 Mdot
.56547 .15262 Mdot
.56552 .15241 Mdot
.56556 .1522 Mdot
.56561 .15199 Mdot
.56566 .15178 Mdot
.56571 .15157 Mdot
.56576 .15136 Mdot
.5658 .15115 Mdot
.56585 .15094 Mdot
.5659 .15074 Mdot
.56595 .15053 Mdot
.56599 .15032 Mdot
.56604 .15011 Mdot
.56609 .1499 Mdot
.56614 .14969 Mdot
.56618 .14949 Mdot
.56623 .14928 Mdot
.56628 .14907 Mdot
.56633 .14887 Mdot
.56637 .14866 Mdot
.56642 .14845 Mdot
.56647 .14825 Mdot
.56652 .14804 Mdot
.56656 .14783 Mdot
.56661 .14763 Mdot
.56666 .14742 Mdot
.56671 .14722 Mdot
.56676 .14701 Mdot
.5668 .14681 Mdot
.56685 .1466 Mdot
.5669 .1464 Mdot
.56695 .1462 Mdot
.56699 .14599 Mdot
.56704 .14579 Mdot
.56709 .14558 Mdot
.56714 .14538 Mdot
.56718 .14518 Mdot
.56723 .14498 Mdot
.56728 .14477 Mdot
.56733 .14457 Mdot
.56737 .14437 Mdot
.56742 .14417 Mdot
.56747 .14397 Mdot
.56752 .14377 Mdot
.56756 .14357 Mdot
.56761 .14337 Mdot
.56766 .14317 Mdot
.56771 .14297 Mdot
.56776 .14277 Mdot
.5678 .14257 Mdot
.56785 .14237 Mdot
.5679 .14217 Mdot
.56795 .14197 Mdot
.56799 .14177 Mdot
.56804 .14157 Mdot
.56809 .14138 Mdot
.56814 .14118 Mdot
.56818 .14098 Mdot
.56823 .14078 Mdot
.56828 .14059 Mdot
.56833 .14039 Mdot
.56837 .14019 Mdot
.56842 .14 Mdot
.56847 .1398 Mdot
.56852 .13961 Mdot
.56856 .13941 Mdot
.56861 .13922 Mdot
.56866 .13902 Mdot
.56871 .13883 Mdot
.56876 .13863 Mdot
.5688 .13844 Mdot
.56885 .13824 Mdot
.5689 .13805 Mdot
.56895 .13786 Mdot
.56899 .13766 Mdot
.56904 .13747 Mdot
.56909 .13728 Mdot
.56914 .13709 Mdot
.56918 .1369 Mdot
.56923 .1367 Mdot
.56928 .13651 Mdot
.56933 .13632 Mdot
.56937 .13613 Mdot
.56942 .13594 Mdot
.56947 .13575 Mdot
.56952 .13556 Mdot
.56956 .13537 Mdot
.56961 .13518 Mdot
.56966 .13499 Mdot
.56971 .1348 Mdot
.56975 .13461 Mdot
.5698 .13443 Mdot
.56985 .13424 Mdot
.5699 .13405 Mdot
.56995 .13386 Mdot
.56999 .13368 Mdot
.57004 .13349 Mdot
.57009 .1333 Mdot
.57014 .13312 Mdot
.57018 .13293 Mdot
.57023 .13274 Mdot
.57028 .13256 Mdot
.57033 .13237 Mdot
.57037 .13219 Mdot
.57042 .132 Mdot
.57047 .13182 Mdot
.57052 .13163 Mdot
.57056 .13145 Mdot
.57061 .13127 Mdot
.57066 .13108 Mdot
.57071 .1309 Mdot
.57075 .13072 Mdot
.5708 .13053 Mdot
.57085 .13035 Mdot
.5709 .13017 Mdot
.57095 .12999 Mdot
.57099 .12981 Mdot
.57104 .12962 Mdot
.57109 .12944 Mdot
.57114 .12926 Mdot
.57118 .12908 Mdot
.57123 .1289 Mdot
.57128 .12872 Mdot
.57133 .12854 Mdot
.57137 .12836 Mdot
.57142 .12818 Mdot
.57147 .12801 Mdot
.57152 .12783 Mdot
.57156 .12765 Mdot
.57161 .12747 Mdot
.57166 .12729 Mdot
.57171 .12712 Mdot
.57175 .12694 Mdot
.5718 .12676 Mdot
.57185 .12659 Mdot
.5719 .12641 Mdot
.57195 .12623 Mdot
.57199 .12606 Mdot
.57204 .12588 Mdot
.57209 .12571 Mdot
.57214 .12553 Mdot
.57218 .12536 Mdot
.57223 .12519 Mdot
.57228 .12501 Mdot
.57233 .12484 Mdot
.57237 .12466 Mdot
.57242 .12449 Mdot
.57247 .12432 Mdot
.57252 .12415 Mdot
.57256 .12397 Mdot
.57261 .1238 Mdot
.57266 .12363 Mdot
.57271 .12346 Mdot
.57275 .12329 Mdot
.5728 .12312 Mdot
.57285 .12295 Mdot
.5729 .12278 Mdot
.57295 .12261 Mdot
.57299 .12244 Mdot
.57304 .12227 Mdot
.57309 .1221 Mdot
.57314 .12193 Mdot
.57318 .12177 Mdot
.57323 .1216 Mdot
.57328 .12143 Mdot
.57333 .12126 Mdot
.57337 .1211 Mdot
.57342 .12093 Mdot
.57347 .12076 Mdot
.57352 .1206 Mdot
.57356 .12043 Mdot
.57361 .12026 Mdot
.57366 .1201 Mdot
.57371 .11993 Mdot
.57375 .11977 Mdot
.5738 .1196 Mdot
.57385 .11944 Mdot
.5739 .11928 Mdot
.57394 .11911 Mdot
.57399 .11895 Mdot
.57404 .11879 Mdot
.57409 .11863 Mdot
.57414 .11846 Mdot
.57418 .1183 Mdot
.57423 .11814 Mdot
.57428 .11798 Mdot
.57433 .11782 Mdot
.57437 .11766 Mdot
.57442 .1175 Mdot
.57447 .11734 Mdot
.57452 .11718 Mdot
.57456 .11702 Mdot
.57461 .11686 Mdot
.57466 .1167 Mdot
.57471 .11654 Mdot
.57475 .11638 Mdot
.5748 .11622 Mdot
.57485 .11607 Mdot
.5749 .11591 Mdot
.57494 .11575 Mdot
.57499 .1156 Mdot
.57504 .11544 Mdot
.57509 .11528 Mdot
.57514 .11513 Mdot
.57518 .11497 Mdot
.57523 .11482 Mdot
.57528 .11466 Mdot
.57533 .11451 Mdot
.57537 .11436 Mdot
.57542 .1142 Mdot
.57547 .11405 Mdot
.57552 .1139 Mdot
.57556 .11374 Mdot
.57561 .11359 Mdot
.57566 .11344 Mdot
.57571 .11329 Mdot
.57575 .11313 Mdot
.5758 .11298 Mdot
.57585 .11283 Mdot
.5759 .11268 Mdot
.57594 .11253 Mdot
.57599 .11238 Mdot
.57604 .11223 Mdot
.57609 .11208 Mdot
.57614 .11193 Mdot
.57618 .11179 Mdot
.57623 .11164 Mdot
.57628 .11149 Mdot
.57633 .11134 Mdot
.57637 .1112 Mdot
.57642 .11105 Mdot
.57647 .1109 Mdot
.57652 .11076 Mdot
.57656 .11061 Mdot
.57661 .11046 Mdot
.57666 .11032 Mdot
.57671 .11017 Mdot
.57675 .11003 Mdot
.5768 .10989 Mdot
.57685 .10974 Mdot
.5769 .1096 Mdot
.57694 .10945 Mdot
.57699 .10931 Mdot
.57704 .10917 Mdot
.57709 .10903 Mdot
.57714 .10888 Mdot
.57718 .10874 Mdot
.57723 .1086 Mdot
.57728 .10846 Mdot
.57733 .10832 Mdot
.57737 .10818 Mdot
.57742 .10804 Mdot
.57747 .1079 Mdot
.57752 .10776 Mdot
.57756 .10762 Mdot
.57761 .10748 Mdot
.57766 .10734 Mdot
.57771 .10721 Mdot
.57775 .10707 Mdot
.5778 .10693 Mdot
.57785 .10679 Mdot
.5779 .10666 Mdot
.57794 .10652 Mdot
.57799 .10638 Mdot
.57804 .10625 Mdot
.57809 .10611 Mdot
.57814 .10598 Mdot
.57818 .10584 Mdot
.57823 .10571 Mdot
.57828 .10557 Mdot
.57833 .10544 Mdot
.57837 .10531 Mdot
.57842 .10517 Mdot
.57847 .10504 Mdot
.57852 .10491 Mdot
.57856 .10478 Mdot
.57861 .10465 Mdot
.57866 .10451 Mdot
.57871 .10438 Mdot
.57875 .10425 Mdot
.5788 .10412 Mdot
.57885 .10399 Mdot
.5789 .10386 Mdot
.57894 .10373 Mdot
.57899 .1036 Mdot
.57904 .10347 Mdot
.57909 .10335 Mdot
.57913 .10322 Mdot
.57918 .10309 Mdot
.57923 .10296 Mdot
.57928 .10284 Mdot
.57933 .10271 Mdot
.57937 .10258 Mdot
.57942 .10246 Mdot
.57947 .10233 Mdot
.57952 .10221 Mdot
.57956 .10208 Mdot
.57961 .10196 Mdot
.57966 .10183 Mdot
.57971 .10171 Mdot
.57975 .10158 Mdot
.5798 .10146 Mdot
.57985 .10134 Mdot
.5799 .10122 Mdot
.57994 .10109 Mdot
.57999 .10097 Mdot
.58004 .10085 Mdot
.58009 .10073 Mdot
.58013 .10061 Mdot
.58018 .10049 Mdot
.58023 .10037 Mdot
.58028 .10025 Mdot
.58033 .10013 Mdot
.58037 .10001 Mdot
.58042 .09989 Mdot
.58047 .09977 Mdot
.58052 .09965 Mdot
.58056 .09953 Mdot
.58061 .09942 Mdot
.58066 .0993 Mdot
.58071 .09918 Mdot
.58075 .09907 Mdot
.5808 .09895 Mdot
.58085 .09883 Mdot
.5809 .09872 Mdot
.58094 .0986 Mdot
.58099 .09849 Mdot
.58104 .09837 Mdot
.58109 .09826 Mdot
.58113 .09815 Mdot
.58118 .09803 Mdot
.58123 .09792 Mdot
.58128 .09781 Mdot
.58133 .09769 Mdot
.58137 .09758 Mdot
.58142 .09747 Mdot
.58147 .09736 Mdot
.58152 .09725 Mdot
.58156 .09714 Mdot
.58161 .09703 Mdot
.58166 .09692 Mdot
.58171 .09681 Mdot
.58175 .0967 Mdot
.5818 .09659 Mdot
.58185 .09648 Mdot
.5819 .09638 Mdot
.58194 .09627 Mdot
.58199 .09616 Mdot
.58204 .09605 Mdot
.58209 .09595 Mdot
.58213 .09584 Mdot
.58218 .09574 Mdot
.58223 .09563 Mdot
.58228 .09552 Mdot
.58233 .09542 Mdot
.58237 .09532 Mdot
.58242 .09521 Mdot
.58247 .09511 Mdot
.58252 .095 Mdot
.58256 .0949 Mdot
.58261 .0948 Mdot
.58266 .0947 Mdot
.58271 .09459 Mdot
.58275 .09449 Mdot
.5828 .09439 Mdot
.58285 .09429 Mdot
.5829 .09419 Mdot
.58294 .09409 Mdot
.58299 .09399 Mdot
.58304 .09389 Mdot
.58309 .09379 Mdot
.58313 .09369 Mdot
.58318 .0936 Mdot
.58323 .0935 Mdot
.58328 .0934 Mdot
.58333 .0933 Mdot
.58337 .09321 Mdot
.58342 .09311 Mdot
.58347 .09301 Mdot
.58352 .09292 Mdot
.58356 .09282 Mdot
.58361 .09273 Mdot
.58366 .09263 Mdot
.58371 .09254 Mdot
.58375 .09244 Mdot
.5838 .09235 Mdot
.58385 .09226 Mdot
.5839 .09216 Mdot
.58394 .09207 Mdot
.58399 .09198 Mdot
.58404 .09189 Mdot
.58409 .0918 Mdot
.58413 .0917 Mdot
.58418 .09161 Mdot
.58423 .09152 Mdot
.58428 .09143 Mdot
.58432 .09134 Mdot
.58437 .09125 Mdot
.58442 .09117 Mdot
.58447 .09108 Mdot
.58452 .09099 Mdot
.58456 .0909 Mdot
.58461 .09081 Mdot
.58466 .09073 Mdot
.58471 .09064 Mdot
.58475 .09055 Mdot
.5848 .09047 Mdot
.58485 .09038 Mdot
.5849 .0903 Mdot
.58494 .09021 Mdot
.58499 .09013 Mdot
.58504 .09004 Mdot
.58509 .08996 Mdot
.58513 .08988 Mdot
.58518 .08979 Mdot
.58523 .08971 Mdot
.58528 .08963 Mdot
.58532 .08955 Mdot
.58537 .08947 Mdot
.58542 .08939 Mdot
.58547 .0893 Mdot
.58552 .08922 Mdot
.58556 .08914 Mdot
.58561 .08907 Mdot
.58566 .08899 Mdot
.58571 .08891 Mdot
.58575 .08883 Mdot
.5858 .08875 Mdot
.58585 .08867 Mdot
.5859 .0886 Mdot
.58594 .08852 Mdot
.58599 .08844 Mdot
.58604 .08837 Mdot
.58609 .08829 Mdot
.58613 .08821 Mdot
.58618 .08814 Mdot
.58623 .08806 Mdot
.58628 .08799 Mdot
.58632 .08792 Mdot
.58637 .08784 Mdot
.58642 .08777 Mdot
.58647 .0877 Mdot
.58652 .08762 Mdot
.58656 .08755 Mdot
.58661 .08748 Mdot
.58666 .08741 Mdot
.58671 .08734 Mdot
.58675 .08727 Mdot
.5868 .0872 Mdot
.58685 .08713 Mdot
.5869 .08706 Mdot
.58694 .08699 Mdot
.58699 .08692 Mdot
.58704 .08685 Mdot
.58709 .08678 Mdot
.58713 .08672 Mdot
.58718 .08665 Mdot
.58723 .08658 Mdot
.58728 .08652 Mdot
.58732 .08645 Mdot
.58737 .08638 Mdot
.58742 .08632 Mdot
.58747 .08625 Mdot
.58752 .08619 Mdot
.58756 .08612 Mdot
.58761 .08606 Mdot
.58766 .086 Mdot
.58771 .08593 Mdot
.58775 .08587 Mdot
.5878 .08581 Mdot
.58785 .08575 Mdot
.5879 .08569 Mdot
.58794 .08562 Mdot
.58799 .08556 Mdot
.58804 .0855 Mdot
.58809 .08544 Mdot
.58813 .08538 Mdot
.58818 .08532 Mdot
.58823 .08527 Mdot
.58828 .08521 Mdot
.58832 .08515 Mdot
.58837 .08509 Mdot
.58842 .08503 Mdot
.58847 .08498 Mdot
.58851 .08492 Mdot
.58856 .08487 Mdot
.58861 .08481 Mdot
.58866 .08475 Mdot
.58871 .0847 Mdot
.58875 .08465 Mdot
.5888 .08459 Mdot
.58885 .08454 Mdot
.5889 .08448 Mdot
.58894 .08443 Mdot
.58899 .08438 Mdot
.58904 .08433 Mdot
.58909 .08428 Mdot
.58913 .08422 Mdot
.58918 .08417 Mdot
.58923 .08412 Mdot
.58928 .08407 Mdot
.58932 .08402 Mdot
.58937 .08397 Mdot
.58942 .08392 Mdot
.58947 .08388 Mdot
.58951 .08383 Mdot
.58956 .08378 Mdot
.58961 .08373 Mdot
.58966 .08369 Mdot
.58971 .08364 Mdot
.58975 .08359 Mdot
.5898 .08355 Mdot
.58985 .0835 Mdot
.5899 .08346 Mdot
.58994 .08341 Mdot
.58999 .08337 Mdot
.59004 .08332 Mdot
.59009 .08328 Mdot
.59013 .08324 Mdot
.59018 .08319 Mdot
.59023 .08315 Mdot
.59028 .08311 Mdot
.59032 .08307 Mdot
.59037 .08303 Mdot
.59042 .08298 Mdot
.59047 .08294 Mdot
.59051 .0829 Mdot
.59056 .08286 Mdot
.59061 .08283 Mdot
.59066 .08279 Mdot
.59071 .08275 Mdot
.59075 .08271 Mdot
.5908 .08267 Mdot
.59085 .08263 Mdot
.5909 .0826 Mdot
.59094 .08256 Mdot
.59099 .08253 Mdot
.59104 .08249 Mdot
.59109 .08245 Mdot
.59113 .08242 Mdot
.59118 .08238 Mdot
.59123 .08235 Mdot
.59128 .08232 Mdot
.59132 .08228 Mdot
.59137 .08225 Mdot
.59142 .08222 Mdot
.59147 .08219 Mdot
.59151 .08215 Mdot
.59156 .08212 Mdot
.59161 .08209 Mdot
.59166 .08206 Mdot
.59171 .08203 Mdot
.59175 .082 Mdot
.5918 .08197 Mdot
.59185 .08194 Mdot
.5919 .08192 Mdot
.59194 .08189 Mdot
.59199 .08186 Mdot
.59204 .08183 Mdot
.59209 .08181 Mdot
.59213 .08178 Mdot
.59218 .08175 Mdot
.59223 .08173 Mdot
.59228 .0817 Mdot
.59232 .08168 Mdot
.59237 .08165 Mdot
.59242 .08163 Mdot
.59247 .0816 Mdot
.59251 .08158 Mdot
.59256 .08156 Mdot
.59261 .08153 Mdot
.59266 .08151 Mdot
.59271 .08149 Mdot
.59275 .08147 Mdot
.5928 .08145 Mdot
.59285 .08143 Mdot
.5929 .08141 Mdot
.59294 .08139 Mdot
.59299 .08137 Mdot
.59304 .08135 Mdot
.59309 .08133 Mdot
.59313 .08131 Mdot
.59318 .08129 Mdot
.59323 .08128 Mdot
.59328 .08126 Mdot
.59332 .08124 Mdot
.59337 .08123 Mdot
.59342 .08121 Mdot
.59347 .08119 Mdot
.59351 .08118 Mdot
.59356 .08116 Mdot
.59361 .08115 Mdot
.59366 .08114 Mdot
.5937 .08112 Mdot
.59375 .08111 Mdot
.5938 .0811 Mdot
.59385 .08108 Mdot
.5939 .08107 Mdot
.59394 .08106 Mdot
.59399 .08105 Mdot
.59404 .08104 Mdot
.59409 .08103 Mdot
.59413 .08102 Mdot
.59418 .08101 Mdot
.59423 .081 Mdot
.59428 .08099 Mdot
.59432 .08098 Mdot
.59437 .08097 Mdot
.59442 .08096 Mdot
.59447 .08096 Mdot
.59451 .08095 Mdot
.59456 .08094 Mdot
.59461 .08094 Mdot
.59466 .08093 Mdot
.5947 .08093 Mdot
.59475 .08092 Mdot
.5948 .08092 Mdot
.59485 .08091 Mdot
.5949 .08091 Mdot
.59494 .08091 Mdot
.59499 .0809 Mdot
.59504 .0809 Mdot
.59509 .0809 Mdot
.59513 .0809 Mdot
.59518 .0809 Mdot
.59523 .08089 Mdot
.59528 .08089 Mdot
.59532 .08089 Mdot
.59537 .08089 Mdot
.59542 .0809 Mdot
.59547 .0809 Mdot
.59551 .0809 Mdot
.59556 .0809 Mdot
.59561 .0809 Mdot
.59566 .08091 Mdot
.5957 .08091 Mdot
.59575 .08091 Mdot
.5958 .08092 Mdot
.59585 .08092 Mdot
.5959 .08093 Mdot
.59594 .08093 Mdot
.59599 .08094 Mdot
.59604 .08094 Mdot
.59609 .08095 Mdot
.59613 .08096 Mdot
.59618 .08096 Mdot
.59623 .08097 Mdot
.59628 .08098 Mdot
.59632 .08099 Mdot
.59637 .08099 Mdot
.59642 .081 Mdot
.59647 .08101 Mdot
.59651 .08102 Mdot
.59656 .08103 Mdot
.59661 .08104 Mdot
.59666 .08106 Mdot
.5967 .08107 Mdot
.59675 .08108 Mdot
.5968 .08109 Mdot
.59685 .0811 Mdot
.5969 .08112 Mdot
.59694 .08113 Mdot
.59699 .08114 Mdot
.59704 .08116 Mdot
.59709 .08117 Mdot
.59713 .08119 Mdot
.59718 .0812 Mdot
.59723 .08122 Mdot
.59728 .08124 Mdot
.59732 .08125 Mdot
.59737 .08127 Mdot
.59742 .08129 Mdot
.59747 .08131 Mdot
.59751 .08133 Mdot
.59756 .08134 Mdot
.59761 .08136 Mdot
.59766 .08138 Mdot
.5977 .0814 Mdot
.59775 .08142 Mdot
.5978 .08144 Mdot
.59785 .08147 Mdot
.59789 .08149 Mdot
.59794 .08151 Mdot
.59799 .08153 Mdot
.59804 .08155 Mdot
.59809 .08158 Mdot
.59813 .0816 Mdot
.59818 .08163 Mdot
.59823 .08165 Mdot
.59828 .08167 Mdot
.59832 .0817 Mdot
.59837 .08173 Mdot
.59842 .08175 Mdot
.59847 .08178 Mdot
.59851 .08181 Mdot
.59856 .08183 Mdot
.59861 .08186 Mdot
.59866 .08189 Mdot
.5987 .08192 Mdot
.59875 .08195 Mdot
.5988 .08197 Mdot
.59885 .082 Mdot
.59889 .08203 Mdot
.59894 .08206 Mdot
.59899 .0821 Mdot
.59904 .08213 Mdot
.59909 .08216 Mdot
.59913 .08219 Mdot
.59918 .08222 Mdot
.59923 .08225 Mdot
.59928 .08229 Mdot
.59932 .08232 Mdot
.59937 .08236 Mdot
.59942 .08239 Mdot
.59947 .08242 Mdot
.59951 .08246 Mdot
.59956 .08249 Mdot
.59961 .08253 Mdot
.59966 .08257 Mdot
.5997 .0826 Mdot
.59975 .08264 Mdot
.5998 .08268 Mdot
.59985 .08272 Mdot
.59989 .08275 Mdot
.59994 .08279 Mdot
.59999 .08283 Mdot
.60004 .08287 Mdot
.60009 .08291 Mdot
.60013 .08295 Mdot
.60018 .08299 Mdot
.60023 .08303 Mdot
.60028 .08307 Mdot
.60032 .08312 Mdot
.60037 .08316 Mdot
.60042 .0832 Mdot
.60047 .08324 Mdot
.60051 .08329 Mdot
.60056 .08333 Mdot
.60061 .08338 Mdot
.60066 .08342 Mdot
.6007 .08347 Mdot
.60075 .08351 Mdot
.6008 .08356 Mdot
.60085 .0836 Mdot
.60089 .08365 Mdot
.60094 .0837 Mdot
.60099 .08374 Mdot
.60104 .08379 Mdot
.60109 .08384 Mdot
.60113 .08389 Mdot
.60118 .08394 Mdot
.60123 .08399 Mdot
.60128 .08404 Mdot
.60132 .08409 Mdot
.60137 .08414 Mdot
.60142 .08419 Mdot
.60147 .08424 Mdot
.60151 .08429 Mdot
.60156 .08435 Mdot
.60161 .0844 Mdot
.60166 .08445 Mdot
.6017 .0845 Mdot
.60175 .08456 Mdot
.6018 .08461 Mdot
.60185 .08467 Mdot
.60189 .08472 Mdot
.60194 .08478 Mdot
.60199 .08483 Mdot
.60204 .08489 Mdot
.60209 .08495 Mdot
.60213 .085 Mdot
.60218 .08506 Mdot
.60223 .08512 Mdot
.60228 .08518 Mdot
.60232 .08524 Mdot
.60237 .0853 Mdot
.60242 .08536 Mdot
.60247 .08542 Mdot
.60251 .08548 Mdot
.60256 .08554 Mdot
.60261 .0856 Mdot
.60266 .08566 Mdot
.6027 .08572 Mdot
.60275 .08578 Mdot
.6028 .08585 Mdot
.60285 .08591 Mdot
.60289 .08597 Mdot
.60294 .08604 Mdot
.60299 .0861 Mdot
.60304 .08617 Mdot
.60308 .08623 Mdot
.60313 .0863 Mdot
.60318 .08636 Mdot
.60323 .08643 Mdot
.60328 .0865 Mdot
.60332 .08656 Mdot
.60337 .08663 Mdot
.60342 .0867 Mdot
.60347 .08677 Mdot
.60351 .08684 Mdot
.60356 .08691 Mdot
.60361 .08698 Mdot
.60366 .08705 Mdot
.6037 .08712 Mdot
.60375 .08719 Mdot
.6038 .08726 Mdot
.60385 .08733 Mdot
.60389 .0874 Mdot
.60394 .08747 Mdot
.60399 .08755 Mdot
.60404 .08762 Mdot
.60408 .08769 Mdot
.60413 .08777 Mdot
.60418 .08784 Mdot
.60423 .08792 Mdot
.60428 .08799 Mdot
.60432 .08807 Mdot
.60437 .08814 Mdot
.60442 .08822 Mdot
.60447 .0883 Mdot
.60451 .08837 Mdot
.60456 .08845 Mdot
.60461 .08853 Mdot
.60466 .08861 Mdot
.6047 .08869 Mdot
.60475 .08877 Mdot
.6048 .08885 Mdot
.60485 .08893 Mdot
.60489 .08901 Mdot
.60494 .08909 Mdot
.60499 .08917 Mdot
.60504 .08925 Mdot
.60508 .08933 Mdot
.60513 .08941 Mdot
.60518 .0895 Mdot
.60523 .08958 Mdot
.60528 .08966 Mdot
.60532 .08975 Mdot
.60537 .08983 Mdot
.60542 .08992 Mdot
.60547 .09 Mdot
.60551 .09009 Mdot
.60556 .09017 Mdot
.60561 .09026 Mdot
.60566 .09035 Mdot
.6057 .09043 Mdot
.60575 .09052 Mdot
.6058 .09061 Mdot
.60585 .0907 Mdot
.60589 .09079 Mdot
.60594 .09088 Mdot
.60599 .09097 Mdot
.60604 .09106 Mdot
.60608 .09115 Mdot
.60613 .09124 Mdot
.60618 .09133 Mdot
.60623 .09142 Mdot
.60628 .09151 Mdot
.60632 .0916 Mdot
.60637 .0917 Mdot
.60642 .09179 Mdot
.60647 .09188 Mdot
.60651 .09198 Mdot
.60656 .09207 Mdot
.60661 .09216 Mdot
.60666 .09226 Mdot
.6067 .09236 Mdot
.60675 .09245 Mdot
.6068 .09255 Mdot
.60685 .09264 Mdot
.60689 .09274 Mdot
.60694 .09284 Mdot
.60699 .09294 Mdot
.60704 .09303 Mdot
.60708 .09313 Mdot
.60713 .09323 Mdot
.60718 .09333 Mdot
.60723 .09343 Mdot
.60727 .09353 Mdot
.60732 .09363 Mdot
.60737 .09373 Mdot
.60742 .09383 Mdot
.60747 .09393 Mdot
.60751 .09404 Mdot
.60756 .09414 Mdot
.60761 .09424 Mdot
.60766 .09435 Mdot
.6077 .09445 Mdot
.60775 .09455 Mdot
.6078 .09466 Mdot
.60785 .09476 Mdot
.60789 .09487 Mdot
.60794 .09497 Mdot
.60799 .09508 Mdot
.60804 .09519 Mdot
.60808 .09529 Mdot
.60813 .0954 Mdot
.60818 .09551 Mdot
.60823 .09562 Mdot
.60827 .09572 Mdot
.60832 .09583 Mdot
.60837 .09594 Mdot
.60842 .09605 Mdot
.60847 .09616 Mdot
.60851 .09627 Mdot
.60856 .09638 Mdot
.60861 .09649 Mdot
.60866 .0966 Mdot
.6087 .09672 Mdot
.60875 .09683 Mdot
.6088 .09694 Mdot
.60885 .09705 Mdot
.60889 .09717 Mdot
.60894 .09728 Mdot
.60899 .09739 Mdot
.60904 .09751 Mdot
.60908 .09762 Mdot
.60913 .09774 Mdot
.60918 .09785 Mdot
.60923 .09797 Mdot
.60927 .09809 Mdot
.60932 .0982 Mdot
.60937 .09832 Mdot
.60942 .09844 Mdot
.60947 .09856 Mdot
.60951 .09867 Mdot
.60956 .09879 Mdot
.60961 .09891 Mdot
.60966 .09903 Mdot
.6097 .09915 Mdot
.60975 .09927 Mdot
.6098 .09939 Mdot
.60985 .09951 Mdot
.60989 .09964 Mdot
.60994 .09976 Mdot
.60999 .09988 Mdot
.61004 .1 Mdot
.61008 .10012 Mdot
.61013 .10025 Mdot
.61018 .10037 Mdot
.61023 .10049 Mdot
.61027 .10062 Mdot
.61032 .10074 Mdot
.61037 .10087 Mdot
.61042 .10099 Mdot
.61047 .10112 Mdot
.61051 .10125 Mdot
.61056 .10137 Mdot
.61061 .1015 Mdot
.61066 .10163 Mdot
.6107 .10175 Mdot
.61075 .10188 Mdot
.6108 .10201 Mdot
.61085 .10214 Mdot
.61089 .10227 Mdot
.61094 .1024 Mdot
.61099 .10253 Mdot
.61104 .10266 Mdot
.61108 .10279 Mdot
.61113 .10292 Mdot
.61118 .10305 Mdot
.61123 .10319 Mdot
.61127 .10332 Mdot
.61132 .10345 Mdot
.61137 .10358 Mdot
.61142 .10372 Mdot
.61147 .10385 Mdot
.61151 .10399 Mdot
.61156 .10412 Mdot
.61161 .10426 Mdot
.61166 .10439 Mdot
.6117 .10453 Mdot
.61175 .10466 Mdot
.6118 .1048 Mdot
.61185 .10494 Mdot
.61189 .10507 Mdot
.61194 .10521 Mdot
.61199 .10535 Mdot
.61204 .10549 Mdot
.61208 .10562 Mdot
.61213 .10576 Mdot
.61218 .1059 Mdot
.61223 .10604 Mdot
.61227 .10618 Mdot
.61232 .10632 Mdot
.61237 .10646 Mdot
.61242 .10661 Mdot
.61246 .10675 Mdot
.61251 .10689 Mdot
.61256 .10703 Mdot
.61261 .10717 Mdot
.61266 .10732 Mdot
.6127 .10746 Mdot
.61275 .1076 Mdot
.6128 .10775 Mdot
.61285 .10789 Mdot
.61289 .10804 Mdot
.61294 .10818 Mdot
.61299 .10833 Mdot
.61304 .10847 Mdot
.61308 .10862 Mdot
.61313 .10877 Mdot
.61318 .10891 Mdot
.61323 .10906 Mdot
.61327 .10921 Mdot
.61332 .10936 Mdot
.61337 .10951 Mdot
.61342 .10966 Mdot
.61346 .1098 Mdot
.61351 .10995 Mdot
.61356 .1101 Mdot
.61361 .11025 Mdot
.61366 .11041 Mdot
.6137 .11056 Mdot
.61375 .11071 Mdot
.6138 .11086 Mdot
.61385 .11101 Mdot
.61389 .11116 Mdot
.61394 .11132 Mdot
.61399 .11147 Mdot
.61404 .11162 Mdot
.61408 .11178 Mdot
.61413 .11193 Mdot
.61418 .11209 Mdot
.61423 .11224 Mdot
.61427 .1124 Mdot
.61432 .11256 Mdot
.61437 .11271 Mdot
.61442 .11287 Mdot
.61446 .11303 Mdot
.61451 .11318 Mdot
.61456 .11334 Mdot
.61461 .1135 Mdot
.61466 .11366 Mdot
.6147 .11382 Mdot
.61475 .11397 Mdot
.6148 .11413 Mdot
.61485 .11429 Mdot
.61489 .11445 Mdot
.61494 .11462 Mdot
.61499 .11478 Mdot
.61504 .11494 Mdot
.61508 .1151 Mdot
.61513 .11526 Mdot
.61518 .11542 Mdot
.61523 .11559 Mdot
.61527 .11575 Mdot
.61532 .11591 Mdot
.61537 .11608 Mdot
.61542 .11624 Mdot
.61546 .11641 Mdot
.61551 .11657 Mdot
.61556 .11674 Mdot
.61561 .1169 Mdot
.61566 .11707 Mdot
.6157 .11724 Mdot
.61575 .1174 Mdot
.6158 .11757 Mdot
.61585 .11774 Mdot
.61589 .11791 Mdot
.61594 .11807 Mdot
.61599 .11824 Mdot
.61604 .11841 Mdot
.61608 .11858 Mdot
.61613 .11875 Mdot
.61618 .11892 Mdot
.61623 .11909 Mdot
.61627 .11926 Mdot
.61632 .11943 Mdot
.61637 .1196 Mdot
.61642 .11978 Mdot
.61646 .11995 Mdot
.61651 .12012 Mdot
.61656 .12029 Mdot
.61661 .12047 Mdot
.61666 .12064 Mdot
.6167 .12081 Mdot
.61675 .12099 Mdot
.6168 .12116 Mdot
.61685 .12134 Mdot
.61689 .12151 Mdot
.61694 .12169 Mdot
.61699 .12186 Mdot
.61704 .12204 Mdot
.61708 .12222 Mdot
.61713 .12239 Mdot
.61718 .12257 Mdot
.61723 .12275 Mdot
.61727 .12293 Mdot
.61732 .12311 Mdot
.61737 .12328 Mdot
.61742 .12346 Mdot
.61746 .12364 Mdot
.61751 .12382 Mdot
.61756 .124 Mdot
.61761 .12418 Mdot
.61765 .12436 Mdot
.6177 .12455 Mdot
.61775 .12473 Mdot
.6178 .12491 Mdot
.61785 .12509 Mdot
.61789 .12527 Mdot
.61794 .12546 Mdot
.61799 .12564 Mdot
.61804 .12582 Mdot
.61808 .12601 Mdot
.61813 .12619 Mdot
.61818 .12638 Mdot
.61823 .12656 Mdot
.61827 .12675 Mdot
.61832 .12693 Mdot
.61837 .12712 Mdot
.61842 .1273 Mdot
.61846 .12749 Mdot
.61851 .12768 Mdot
.61856 .12786 Mdot
.61861 .12805 Mdot
.61865 .12824 Mdot
.6187 .12843 Mdot
.61875 .12862 Mdot
.6188 .12881 Mdot
.61885 .129 Mdot
.61889 .12918 Mdot
.61894 .12937 Mdot
.61899 .12957 Mdot
.61904 .12976 Mdot
.61908 .12995 Mdot
.61913 .13014 Mdot
.61918 .13033 Mdot
.61923 .13052 Mdot
.61927 .13071 Mdot
.61932 .13091 Mdot
.61937 .1311 Mdot
.61942 .13129 Mdot
.61946 .13149 Mdot
.61951 .13168 Mdot
.61956 .13187 Mdot
.61961 .13207 Mdot
.61965 .13226 Mdot
.6197 .13246 Mdot
.61975 .13265 Mdot
.6198 .13285 Mdot
.61985 .13305 Mdot
.61989 .13324 Mdot
.61994 .13344 Mdot
.61999 .13364 Mdot
.62004 .13383 Mdot
.62008 .13403 Mdot
.62013 .13423 Mdot
.62018 .13443 Mdot
.62023 .13463 Mdot
.62027 .13483 Mdot
.62032 .13503 Mdot
.62037 .13523 Mdot
.62042 .13543 Mdot
.62046 .13563 Mdot
.62051 .13583 Mdot
.62056 .13603 Mdot
.62061 .13623 Mdot
.62065 .13643 Mdot
.6207 .13663 Mdot
.62075 .13684 Mdot
.6208 .13704 Mdot
.62085 .13724 Mdot
.62089 .13745 Mdot
.62094 .13765 Mdot
.62099 .13786 Mdot
.62104 .13806 Mdot
.62108 .13826 Mdot
.62113 .13847 Mdot
.62118 .13868 Mdot
.62123 .13888 Mdot
.62127 .13909 Mdot
.62132 .13929 Mdot
.62137 .1395 Mdot
.62142 .13971 Mdot
.62146 .13991 Mdot
.62151 .14012 Mdot
.62156 .14033 Mdot
.62161 .14054 Mdot
.62165 .14075 Mdot
.6217 .14096 Mdot
.62175 .14117 Mdot
.6218 .14137 Mdot
.62184 .14158 Mdot
.62189 .14179 Mdot
.62194 .14201 Mdot
.62199 .14222 Mdot
.62204 .14243 Mdot
.62208 .14264 Mdot
.62213 .14285 Mdot
.62218 .14306 Mdot
.62223 .14327 Mdot
.62227 .14349 Mdot
.62232 .1437 Mdot
.62237 .14391 Mdot
.62242 .14413 Mdot
.62246 .14434 Mdot
.62251 .14456 Mdot
.62256 .14477 Mdot
.62261 .14499 Mdot
.62265 .1452 Mdot
.6227 .14542 Mdot
.62275 .14563 Mdot
.6228 .14585 Mdot
.62284 .14606 Mdot
.62289 .14628 Mdot
.62294 .1465 Mdot
.62299 .14672 Mdot
.62304 .14693 Mdot
.62308 .14715 Mdot
.62313 .14737 Mdot
.62318 .14759 Mdot
.62323 .14781 Mdot
.62327 .14803 Mdot
.62332 .14825 Mdot
.62337 .14846 Mdot
.62342 .14868 Mdot
.62346 .14891 Mdot
.62351 .14913 Mdot
.62356 .14935 Mdot
.62361 .14957 Mdot
.62365 .14979 Mdot
.6237 .15001 Mdot
.62375 .15023 Mdot
.6238 .15045 Mdot
.62384 .15068 Mdot
.62389 .1509 Mdot
.62394 .15112 Mdot
.62399 .15135 Mdot
.62404 .15157 Mdot
.62408 .15179 Mdot
.62413 .15202 Mdot
.62418 .15224 Mdot
.62423 .15247 Mdot
.62427 .15269 Mdot
.62432 .15292 Mdot
.62437 .15314 Mdot
.62442 .15337 Mdot
.62446 .1536 Mdot
.62451 .15382 Mdot
.62456 .15405 Mdot
.62461 .15428 Mdot
.62465 .1545 Mdot
.6247 .15473 Mdot
.62475 .15496 Mdot
.6248 .15519 Mdot
.62484 .15542 Mdot
.62489 .15565 Mdot
.62494 .15588 Mdot
.62499 .1561 Mdot
.62504 .15633 Mdot
.62508 .15656 Mdot
.62513 .15679 Mdot
.62518 .15703 Mdot
.62523 .15726 Mdot
.62527 .15749 Mdot
.62532 .15772 Mdot
.62537 .15795 Mdot
.62542 .15818 Mdot
.62546 .15842 Mdot
.62551 .15865 Mdot
.62556 .15888 Mdot
.62561 .15911 Mdot
.62565 .15935 Mdot
.6257 .15958 Mdot
.62575 .15982 Mdot
.6258 .16005 Mdot
.62584 .16028 Mdot
.62589 .16052 Mdot
.62594 .16075 Mdot
.62599 .16099 Mdot
.62604 .16123 Mdot
.62608 .16146 Mdot
.62613 .1617 Mdot
.62618 .16193 Mdot
.62623 .16217 Mdot
.62627 .16241 Mdot
.62632 .16265 Mdot
.62637 .16288 Mdot
.62642 .16312 Mdot
.62646 .16336 Mdot
.62651 .1636 Mdot
.62656 .16384 Mdot
.62661 .16407 Mdot
.62665 .16431 Mdot
.6267 .16455 Mdot
.62675 .16479 Mdot
.6268 .16503 Mdot
.62684 .16527 Mdot
.62689 .16551 Mdot
.62694 .16576 Mdot
.62699 .166 Mdot
.62703 .16624 Mdot
.62708 .16648 Mdot
.62713 .16672 Mdot
.62718 .16696 Mdot
.62723 .16721 Mdot
.62727 .16745 Mdot
.62732 .16769 Mdot
.62737 .16793 Mdot
.62742 .16818 Mdot
.62746 .16842 Mdot
.62751 .16867 Mdot
.62756 .16891 Mdot
.62761 .16915 Mdot
.62765 .1694 Mdot
.6277 .16964 Mdot
.62775 .16989 Mdot
.6278 .17013 Mdot
.62784 .17038 Mdot
.62789 .17063 Mdot
.62794 .17087 Mdot
.62799 .17112 Mdot
.62803 .17137 Mdot
.62808 .17161 Mdot
.62813 .17186 Mdot
.62818 .17211 Mdot
.62823 .17236 Mdot
.62827 .1726 Mdot
.62832 .17285 Mdot
.62837 .1731 Mdot
.62842 .17335 Mdot
.62846 .1736 Mdot
.62851 .17385 Mdot
.62856 .1741 Mdot
.62861 .17435 Mdot
.62865 .1746 Mdot
.6287 .17485 Mdot
.62875 .1751 Mdot
.6288 .17535 Mdot
.62884 .1756 Mdot
.62889 .17585 Mdot
.62894 .1761 Mdot
.62899 .17636 Mdot
.62903 .17661 Mdot
.62908 .17686 Mdot
.62913 .17711 Mdot
.62918 .17737 Mdot
.62923 .17762 Mdot
.62927 .17787 Mdot
.62932 .17813 Mdot
.62937 .17838 Mdot
.62942 .17863 Mdot
.62946 .17889 Mdot
.62951 .17914 Mdot
.62956 .1794 Mdot
.62961 .17965 Mdot
.62965 .17991 Mdot
.6297 .18016 Mdot
.62975 .18042 Mdot
.6298 .18067 Mdot
.62984 .18093 Mdot
.62989 .18119 Mdot
.62994 .18144 Mdot
.62999 .1817 Mdot
.63003 .18196 Mdot
.63008 .18221 Mdot
.63013 .18247 Mdot
.63018 .18273 Mdot
.63023 .18299 Mdot
.63027 .18325 Mdot
.63032 .18351 Mdot
.63037 .18376 Mdot
.63042 .18402 Mdot
.63046 .18428 Mdot
.63051 .18454 Mdot
.63056 .1848 Mdot
.63061 .18506 Mdot
.63065 .18532 Mdot
.6307 .18558 Mdot
.63075 .18584 Mdot
.6308 .1861 Mdot
.63084 .18636 Mdot
.63089 .18663 Mdot
.63094 .18689 Mdot
.63099 .18715 Mdot
.63103 .18741 Mdot
.63108 .18767 Mdot
.63113 .18794 Mdot
.63118 .1882 Mdot
.63122 .18846 Mdot
.63127 .18872 Mdot
.63132 .18899 Mdot
.63137 .18925 Mdot
.63142 .18952 Mdot
.63146 .18978 Mdot
.63151 .19004 Mdot
.63156 .19031 Mdot
.63161 .19057 Mdot
.63165 .19084 Mdot
.6317 .1911 Mdot
.63175 .19137 Mdot
.6318 .19164 Mdot
.63184 .1919 Mdot
.63189 .19217 Mdot
.63194 .19243 Mdot
.63199 .1927 Mdot
.63203 .19297 Mdot
.63208 .19324 Mdot
.63213 .1935 Mdot
.63218 .19377 Mdot
.63222 .19404 Mdot
.63227 .19431 Mdot
.63232 .19457 Mdot
.63237 .19484 Mdot
.63242 .19511 Mdot
.63246 .19538 Mdot
.63251 .19565 Mdot
.63256 .19592 Mdot
.63261 .19619 Mdot
.63265 .19646 Mdot
.6327 .19673 Mdot
.63275 .197 Mdot
.6328 .19727 Mdot
.63284 .19754 Mdot
.63289 .19781 Mdot
.63294 .19808 Mdot
.63299 .19835 Mdot
.63303 .19863 Mdot
.63308 .1989 Mdot
.63313 .19917 Mdot
.63318 .19944 Mdot
.63322 .19971 Mdot
.63327 .19999 Mdot
.63332 .20026 Mdot
.63337 .20053 Mdot
.63342 .20081 Mdot
.63346 .20108 Mdot
.63351 .20135 Mdot
.63356 .20163 Mdot
.63361 .2019 Mdot
.63365 .20218 Mdot
.6337 .20245 Mdot
.63375 .20273 Mdot
.6338 .203 Mdot
.63384 .20328 Mdot
.63389 .20355 Mdot
.63394 .20383 Mdot
.63399 .2041 Mdot
.63403 .20438 Mdot
.63408 .20465 Mdot
.63413 .20493 Mdot
.63418 .20521 Mdot
.63422 .20548 Mdot
.63427 .20576 Mdot
.63432 .20604 Mdot
.63437 .20632 Mdot
.63442 .20659 Mdot
.63446 .20687 Mdot
.63451 .20715 Mdot
.63456 .20743 Mdot
.63461 .2077 Mdot
.63465 .20798 Mdot
.6347 .20826 Mdot
.63475 .20854 Mdot
.6348 .20882 Mdot
.63484 .2091 Mdot
.63489 .20938 Mdot
.63494 .20966 Mdot
.63499 .20994 Mdot
.63503 .21022 Mdot
.63508 .2105 Mdot
.63513 .21078 Mdot
.63518 .21106 Mdot
.63522 .21134 Mdot
.63527 .21162 Mdot
.63532 .2119 Mdot
.63537 .21219 Mdot
.63542 .21247 Mdot
.63546 .21275 Mdot
.63551 .21303 Mdot
.63556 .21331 Mdot
.63561 .2136 Mdot
.63565 .21388 Mdot
.6357 .21416 Mdot
.63575 .21444 Mdot
.6358 .21473 Mdot
.63584 .21501 Mdot
.63589 .21529 Mdot
.63594 .21558 Mdot
.63599 .21586 Mdot
.63603 .21615 Mdot
.63608 .21643 Mdot
.63613 .21671 Mdot
.63618 .217 Mdot
.63622 .21728 Mdot
.63627 .21757 Mdot
.63632 .21785 Mdot
.63637 .21814 Mdot
.63641 .21842 Mdot
.63646 .21871 Mdot
.63651 .219 Mdot
.63656 .21928 Mdot
.63661 .21957 Mdot
.63665 .21985 Mdot
.6367 .22014 Mdot
.63675 .22043 Mdot
.6368 .22071 Mdot
.63684 .221 Mdot
.63689 .22129 Mdot
.63694 .22158 Mdot
.63699 .22186 Mdot
.63703 .22215 Mdot
.63708 .22244 Mdot
.63713 .22273 Mdot
.63718 .22301 Mdot
.63722 .2233 Mdot
.63727 .22359 Mdot
.63732 .22388 Mdot
.63737 .22417 Mdot
.63741 .22446 Mdot
.63746 .22475 Mdot
.63751 .22504 Mdot
.63756 .22532 Mdot
.63761 .22561 Mdot
.63765 .2259 Mdot
.6377 .22619 Mdot
.63775 .22648 Mdot
.6378 .22677 Mdot
.63784 .22706 Mdot
.63789 .22735 Mdot
.63794 .22765 Mdot
.63799 .22794 Mdot
.63803 .22823 Mdot
.63808 .22852 Mdot
.63813 .22881 Mdot
.63818 .2291 Mdot
.63822 .22939 Mdot
.63827 .22968 Mdot
.63832 .22998 Mdot
.63837 .23027 Mdot
.63841 .23056 Mdot
.63846 .23085 Mdot
.63851 .23115 Mdot
.63856 .23144 Mdot
.63861 .23173 Mdot
.63865 .23202 Mdot
.6387 .23232 Mdot
.63875 .23261 Mdot
.6388 .2329 Mdot
.63884 .2332 Mdot
.63889 .23349 Mdot
.63894 .23379 Mdot
.63899 .23408 Mdot
.63903 .23437 Mdot
.63908 .23467 Mdot
.63913 .23496 Mdot
.63918 .23526 Mdot
.63922 .23555 Mdot
.63927 .23585 Mdot
.63932 .23614 Mdot
.63937 .23644 Mdot
.63941 .23673 Mdot
.63946 .23703 Mdot
.63951 .23732 Mdot
.63956 .23762 Mdot
.63961 .23791 Mdot
.63965 .23821 Mdot
.6397 .23851 Mdot
.63975 .2388 Mdot
.6398 .2391 Mdot
.63984 .2394 Mdot
.63989 .23969 Mdot
.63994 .23999 Mdot
.63999 .24029 Mdot
.64003 .24058 Mdot
.64008 .24088 Mdot
.64013 .24118 Mdot
.64018 .24148 Mdot
.64022 .24178 Mdot
.64027 .24207 Mdot
.64032 .24237 Mdot
.64037 .24267 Mdot
.64041 .24297 Mdot
.64046 .24327 Mdot
.64051 .24357 Mdot
.64056 .24386 Mdot
.6406 .24416 Mdot
.64065 .24446 Mdot
.6407 .24476 Mdot
.64075 .24506 Mdot
.6408 .24536 Mdot
.64084 .24566 Mdot
.64089 .24596 Mdot
.64094 .24626 Mdot
.64099 .24656 Mdot
.64103 .24686 Mdot
.64108 .24716 Mdot
.64113 .24746 Mdot
.64118 .24776 Mdot
.64122 .24806 Mdot
.64127 .24836 Mdot
.64132 .24866 Mdot
.64137 .24896 Mdot
.64141 .24926 Mdot
.64146 .24956 Mdot
.64151 .24987 Mdot
.64156 .25017 Mdot
.6416 .25047 Mdot
.64165 .25077 Mdot
.6417 .25107 Mdot
.64175 .25137 Mdot
.6418 .25167 Mdot
.64184 .25198 Mdot
.64189 .25228 Mdot
.64194 .25258 Mdot
.64199 .25288 Mdot
.64203 .25319 Mdot
.64208 .25349 Mdot
.64213 .25379 Mdot
.64218 .25409 Mdot
.64222 .2544 Mdot
.64227 .2547 Mdot
.64232 .255 Mdot
.64237 .2553 Mdot
.64241 .25561 Mdot
.64246 .25591 Mdot
.64251 .25621 Mdot
.64256 .25652 Mdot
.6426 .25682 Mdot
.64265 .25713 Mdot
.6427 .25743 Mdot
.64275 .25773 Mdot
.6428 .25804 Mdot
.64284 .25834 Mdot
.64289 .25865 Mdot
.64294 .25895 Mdot
.64299 .25925 Mdot
.64303 .25956 Mdot
.64308 .25986 Mdot
.64313 .26017 Mdot
.64318 .26047 Mdot
.64322 .26078 Mdot
.64327 .26108 Mdot
.64332 .26139 Mdot
.64337 .26169 Mdot
.64341 .262 Mdot
.64346 .26231 Mdot
.64351 .26261 Mdot
.64356 .26292 Mdot
.6436 .26322 Mdot
.64365 .26353 Mdot
.6437 .26383 Mdot
.64375 .26414 Mdot
.6438 .26445 Mdot
.64384 .26475 Mdot
.64389 .26506 Mdot
.64394 .26537 Mdot
.64399 .26567 Mdot
.64403 .26598 Mdot
.64408 .26629 Mdot
.64413 .26659 Mdot
.64418 .2669 Mdot
.64422 .26721 Mdot
.64427 .26751 Mdot
.64432 .26782 Mdot
.64437 .26813 Mdot
.64441 .26844 Mdot
.64446 .26874 Mdot
.64451 .26905 Mdot
.64456 .26936 Mdot
.6446 .26967 Mdot
.64465 .26997 Mdot
.6447 .27028 Mdot
.64475 .27059 Mdot
.6448 .2709 Mdot
.64484 .27121 Mdot
.64489 .27151 Mdot
.64494 .27182 Mdot
.64499 .27213 Mdot
.64503 .27244 Mdot
.64508 .27275 Mdot
.64513 .27306 Mdot
.64518 .27336 Mdot
.64522 .27367 Mdot
.64527 .27398 Mdot
.64532 .27429 Mdot
.64537 .2746 Mdot
.64541 .27491 Mdot
.64546 .27522 Mdot
.64551 .27553 Mdot
.64556 .27584 Mdot
.6456 .27615 Mdot
.64565 .27646 Mdot
.6457 .27676 Mdot
.64575 .27707 Mdot
.64579 .27738 Mdot
.64584 .27769 Mdot
.64589 .278 Mdot
.64594 .27831 Mdot
.64599 .27862 Mdot
.64603 .27893 Mdot
.64608 .27924 Mdot
.64613 .27955 Mdot
.64618 .27986 Mdot
.64622 .28017 Mdot
.64627 .28048 Mdot
.64632 .28079 Mdot
.64637 .2811 Mdot
.64641 .28141 Mdot
.64646 .28172 Mdot
.64651 .28203 Mdot
.64656 .28235 Mdot
.6466 .28266 Mdot
.64665 .28297 Mdot
.6467 .28328 Mdot
.64675 .28359 Mdot
.64679 .2839 Mdot
.64684 .28421 Mdot
.64689 .28452 Mdot
.64694 .28483 Mdot
.64699 .28514 Mdot
.64703 .28545 Mdot
.64708 .28576 Mdot
.64713 .28608 Mdot
.64718 .28639 Mdot
.64722 .2867 Mdot
.64727 .28701 Mdot
.64732 .28732 Mdot
.64737 .28763 Mdot
.64741 .28794 Mdot
.64746 .28825 Mdot
.64751 .28857 Mdot
.64756 .28888 Mdot
.6476 .28919 Mdot
.64765 .2895 Mdot
.6477 .28981 Mdot
.64775 .29012 Mdot
.64779 .29044 Mdot
.64784 .29075 Mdot
.64789 .29106 Mdot
.64794 .29137 Mdot
.64799 .29168 Mdot
.64803 .29199 Mdot
.64808 .29231 Mdot
.64813 .29262 Mdot
.64818 .29293 Mdot
.64822 .29324 Mdot
.64827 .29355 Mdot
.64832 .29387 Mdot
.64837 .29418 Mdot
.64841 .29449 Mdot
.64846 .2948 Mdot
.64851 .29512 Mdot
.64856 .29543 Mdot
.6486 .29574 Mdot
.64865 .29605 Mdot
.6487 .29636 Mdot
.64875 .29668 Mdot
.64879 .29699 Mdot
.64884 .2973 Mdot
.64889 .29761 Mdot
.64894 .29793 Mdot
.64899 .29824 Mdot
.64903 .29855 Mdot
.64908 .29887 Mdot
.64913 .29918 Mdot
.64918 .29949 Mdot
.64922 .2998 Mdot
.64927 .30012 Mdot
.64932 .30043 Mdot
.64937 .30074 Mdot
.64941 .30105 Mdot
.64946 .30137 Mdot
.64951 .30168 Mdot
.64956 .30199 Mdot
.6496 .3023 Mdot
.64965 .30262 Mdot
.6497 .30293 Mdot
.64975 .30324 Mdot
.64979 .30356 Mdot
.64984 .30387 Mdot
.64989 .30418 Mdot
.64994 .30449 Mdot
.64999 .30481 Mdot
.65003 .30512 Mdot
.65008 .30543 Mdot
.65013 .30575 Mdot
.65018 .30606 Mdot
.65022 .30637 Mdot
.65027 .30668 Mdot
.65032 .307 Mdot
.65037 .30731 Mdot
.65041 .30762 Mdot
.65046 .30794 Mdot
.65051 .30825 Mdot
.65056 .30856 Mdot
.6506 .30887 Mdot
.65065 .30919 Mdot
.6507 .3095 Mdot
.65075 .30981 Mdot
.65079 .31013 Mdot
.65084 .31044 Mdot
.65089 .31075 Mdot
.65094 .31107 Mdot
.65098 .31138 Mdot
.65103 .31169 Mdot
.65108 .312 Mdot
.65113 .31232 Mdot
.65118 .31263 Mdot
.65122 .31294 Mdot
.65127 .31326 Mdot
.65132 .31357 Mdot
.65137 .31388 Mdot
.65141 .3142 Mdot
.65146 .31451 Mdot
.65151 .31482 Mdot
.65156 .31514 Mdot
.6516 .31545 Mdot
.65165 .31576 Mdot
.6517 .31608 Mdot
.65175 .31639 Mdot
.65179 .3167 Mdot
.65184 .31701 Mdot
.65189 .31733 Mdot
.65194 .31764 Mdot
.65198 .31795 Mdot
.65203 .31827 Mdot
.65208 .31858 Mdot
.65213 .31889 Mdot
.65218 .31921 Mdot
.65222 .31952 Mdot
.65227 .31983 Mdot
.65232 .32014 Mdot
.65237 .32046 Mdot
.65241 .32077 Mdot
.65246 .32108 Mdot
.65251 .3214 Mdot
.65256 .32171 Mdot
.6526 .32202 Mdot
.65265 .32233 Mdot
.6527 .32265 Mdot
.65275 .32296 Mdot
.65279 .32327 Mdot
.65284 .32358 Mdot
.65289 .3239 Mdot
.65294 .32421 Mdot
.65298 .32452 Mdot
.65303 .32483 Mdot
.65308 .32515 Mdot
.65313 .32546 Mdot
.65318 .32577 Mdot
.65322 .32608 Mdot
.65327 .3264 Mdot
.65332 .32671 Mdot
.65337 .32702 Mdot
.65341 .32733 Mdot
.65346 .32765 Mdot
.65351 .32796 Mdot
.65356 .32827 Mdot
.6536 .32858 Mdot
.65365 .3289 Mdot
.6537 .32921 Mdot
.65375 .32952 Mdot
.65379 .32983 Mdot
.65384 .33014 Mdot
.65389 .33046 Mdot
.65394 .33077 Mdot
.65398 .33108 Mdot
.65403 .33139 Mdot
.65408 .3317 Mdot
.65413 .33202 Mdot
.65418 .33233 Mdot
.65422 .33264 Mdot
.65427 .33295 Mdot
.65432 .33326 Mdot
.65437 .33357 Mdot
.65441 .33388 Mdot
.65446 .3342 Mdot
.65451 .33451 Mdot
.65456 .33482 Mdot
.6546 .33513 Mdot
.65465 .33544 Mdot
.6547 .33575 Mdot
.65475 .33606 Mdot
.65479 .33637 Mdot
.65484 .33669 Mdot
.65489 .337 Mdot
.65494 .33731 Mdot
.65498 .33762 Mdot
.65503 .33793 Mdot
.65508 .33824 Mdot
.65513 .33855 Mdot
.65517 .33886 Mdot
.65522 .33917 Mdot
.65527 .33948 Mdot
.65532 .33979 Mdot
.65537 .3401 Mdot
.65541 .34041 Mdot
.65546 .34072 Mdot
.65551 .34103 Mdot
.65556 .34134 Mdot
.6556 .34165 Mdot
.65565 .34196 Mdot
.6557 .34227 Mdot
.65575 .34258 Mdot
.65579 .34289 Mdot
.65584 .3432 Mdot
.65589 .34351 Mdot
.65594 .34382 Mdot
.65598 .34413 Mdot
.65603 .34444 Mdot
.65608 .34475 Mdot
.65613 .34506 Mdot
.65617 .34537 Mdot
.65622 .34568 Mdot
.65627 .34599 Mdot
.65632 .3463 Mdot
.65637 .34661 Mdot
.65641 .34692 Mdot
.65646 .34723 Mdot
.65651 .34754 Mdot
.65656 .34785 Mdot
.6566 .34816 Mdot
.65665 .34847 Mdot
.6567 .34877 Mdot
.65675 .34908 Mdot
.65679 .34939 Mdot
.65684 .3497 Mdot
.65689 .35001 Mdot
.65694 .35032 Mdot
.65698 .35063 Mdot
.65703 .35093 Mdot
.65708 .35124 Mdot
.65713 .35155 Mdot
.65717 .35186 Mdot
.65722 .35217 Mdot
.65727 .35248 Mdot
.65732 .35278 Mdot
.65737 .35309 Mdot
.65741 .3534 Mdot
.65746 .35371 Mdot
.65751 .35401 Mdot
.65756 .35432 Mdot
.6576 .35463 Mdot
.65765 .35494 Mdot
.6577 .35524 Mdot
.65775 .35555 Mdot
.65779 .35586 Mdot
.65784 .35616 Mdot
.65789 .35647 Mdot
.65794 .35678 Mdot
.65798 .35708 Mdot
.65803 .35739 Mdot
.65808 .3577 Mdot
.65813 .358 Mdot
.65817 .35831 Mdot
.65822 .35862 Mdot
.65827 .35892 Mdot
.65832 .35923 Mdot
.65837 .35953 Mdot
.65841 .35984 Mdot
.65846 .36015 Mdot
.65851 .36045 Mdot
.65856 .36076 Mdot
.6586 .36106 Mdot
.65865 .36137 Mdot
.6587 .36167 Mdot
.65875 .36198 Mdot
.65879 .36228 Mdot
.65884 .36259 Mdot
.65889 .36289 Mdot
.65894 .3632 Mdot
.65898 .3635 Mdot
.65903 .36381 Mdot
.65908 .36411 Mdot
.65913 .36442 Mdot
.65917 .36472 Mdot
.65922 .36502 Mdot
.65927 .36533 Mdot
.65932 .36563 Mdot
.65937 .36594 Mdot
.65941 .36624 Mdot
.65946 .36654 Mdot
.65951 .36685 Mdot
.65956 .36715 Mdot
.6596 .36746 Mdot
.65965 .36776 Mdot
.6597 .36806 Mdot
.65975 .36837 Mdot
.65979 .36867 Mdot
.65984 .36897 Mdot
.65989 .36927 Mdot
.65994 .36958 Mdot
.65998 .36988 Mdot
.66003 .37018 Mdot
.66008 .37048 Mdot
.66013 .37079 Mdot
.66017 .37109 Mdot
.66022 .37139 Mdot
.66027 .37169 Mdot
.66032 .37199 Mdot
.66036 .3723 Mdot
.66041 .3726 Mdot
.66046 .3729 Mdot
.66051 .3732 Mdot
.66056 .3735 Mdot
.6606 .3738 Mdot
.66065 .3741 Mdot
.6607 .37441 Mdot
.66075 .37471 Mdot
.66079 .37501 Mdot
.66084 .37531 Mdot
.66089 .37561 Mdot
.66094 .37591 Mdot
.66098 .37621 Mdot
.66103 .37651 Mdot
.66108 .37681 Mdot
.66113 .37711 Mdot
.66117 .37741 Mdot
.66122 .37771 Mdot
.66127 .37801 Mdot
.66132 .37831 Mdot
.66136 .37861 Mdot
.66141 .37891 Mdot
.66146 .3792 Mdot
.66151 .3795 Mdot
.66156 .3798 Mdot
.6616 .3801 Mdot
.66165 .3804 Mdot
.6617 .3807 Mdot
.66175 .381 Mdot
.66179 .38129 Mdot
.66184 .38159 Mdot
.66189 .38189 Mdot
.66194 .38219 Mdot
.66198 .38249 Mdot
.66203 .38278 Mdot
.66208 .38308 Mdot
.66213 .38338 Mdot
.66217 .38367 Mdot
.66222 .38397 Mdot
.66227 .38427 Mdot
.66232 .38457 Mdot
.66236 .38486 Mdot
.66241 .38516 Mdot
.66246 .38545 Mdot
.66251 .38575 Mdot
.66256 .38605 Mdot
.6626 .38634 Mdot
.66265 .38664 Mdot
.6627 .38693 Mdot
.66275 .38723 Mdot
.66279 .38753 Mdot
.66284 .38782 Mdot
.66289 .38812 Mdot
.66294 .38841 Mdot
.66298 .38871 Mdot
.66303 .389 Mdot
.66308 .3893 Mdot
.66313 .38959 Mdot
.66317 .38988 Mdot
.66322 .39018 Mdot
.66327 .39047 Mdot
.66332 .39077 Mdot
.66336 .39106 Mdot
.66341 .39135 Mdot
.66346 .39165 Mdot
.66351 .39194 Mdot
.66356 .39223 Mdot
.6636 .39252 Mdot
.66365 .39282 Mdot
.6637 .39311 Mdot
.66375 .3934 Mdot
.66379 .39369 Mdot
.66384 .39399 Mdot
.66389 .39428 Mdot
.66394 .39457 Mdot
.66398 .39486 Mdot
.66403 .39515 Mdot
.66408 .39544 Mdot
.66413 .39573 Mdot
.66417 .39603 Mdot
.66422 .39632 Mdot
.66427 .39661 Mdot
.66432 .3969 Mdot
.66436 .39719 Mdot
.66441 .39748 Mdot
.66446 .39777 Mdot
.66451 .39806 Mdot
.66455 .39835 Mdot
.6646 .39864 Mdot
.66465 .39893 Mdot
.6647 .39921 Mdot
.66475 .3995 Mdot
.66479 .39979 Mdot
.66484 .40008 Mdot
.66489 .40037 Mdot
.66494 .40066 Mdot
.66498 .40095 Mdot
.66503 .40123 Mdot
.66508 .40152 Mdot
.66513 .40181 Mdot
.66517 .4021 Mdot
.66522 .40238 Mdot
.66527 .40267 Mdot
.66532 .40296 Mdot
.66536 .40324 Mdot
.66541 .40353 Mdot
.66546 .40382 Mdot
.66551 .4041 Mdot
.66555 .40439 Mdot
.6656 .40468 Mdot
.66565 .40496 Mdot
.6657 .40525 Mdot
.66575 .40553 Mdot
.66579 .40582 Mdot
.66584 .4061 Mdot
.66589 .40639 Mdot
.66594 .40667 Mdot
.66598 .40695 Mdot
.66603 .40724 Mdot
.66608 .40752 Mdot
.66613 .40781 Mdot
.66617 .40809 Mdot
.66622 .40837 Mdot
.66627 .40866 Mdot
.66632 .40894 Mdot
.66636 .40922 Mdot
.66641 .4095 Mdot
.66646 .40979 Mdot
.66651 .41007 Mdot
.66655 .41035 Mdot
.6666 .41063 Mdot
.66665 .41091 Mdot
.6667 .41119 Mdot
.66675 .41148 Mdot
.66679 .41176 Mdot
.66684 .41204 Mdot
.66689 .41232 Mdot
.66694 .4126 Mdot
.66698 .41288 Mdot
.66703 .41316 Mdot
.66708 .41344 Mdot
.66713 .41372 Mdot
.66717 .414 Mdot
.66722 .41428 Mdot
.66727 .41456 Mdot
.66732 .41484 Mdot
.66736 .41511 Mdot
.66741 .41539 Mdot
.66746 .41567 Mdot
.66751 .41595 Mdot
.66755 .41623 Mdot
.6676 .4165 Mdot
.66765 .41678 Mdot
.6677 .41706 Mdot
.66775 .41734 Mdot
.66779 .41761 Mdot
.66784 .41789 Mdot
.66789 .41816 Mdot
.66794 .41844 Mdot
.66798 .41872 Mdot
.66803 .41899 Mdot
.66808 .41927 Mdot
.66813 .41954 Mdot
.66817 .41982 Mdot
.66822 .42009 Mdot
.66827 .42037 Mdot
.66832 .42064 Mdot
.66836 .42092 Mdot
.66841 .42119 Mdot
.66846 .42146 Mdot
.66851 .42174 Mdot
.66855 .42201 Mdot
.6686 .42228 Mdot
.66865 .42256 Mdot
.6687 .42283 Mdot
.66875 .4231 Mdot
.66879 .42338 Mdot
.66884 .42365 Mdot
.66889 .42392 Mdot
.66894 .42419 Mdot
.66898 .42446 Mdot
.66903 .42473 Mdot
.66908 .425 Mdot
.66913 .42528 Mdot
.66917 .42555 Mdot
.66922 .42582 Mdot
.66927 .42609 Mdot
.66932 .42636 Mdot
.66936 .42663 Mdot
.66941 .4269 Mdot
.66946 .42716 Mdot
.66951 .42743 Mdot
.66955 .4277 Mdot
.6696 .42797 Mdot
.66965 .42824 Mdot
.6697 .42851 Mdot
.66974 .42878 Mdot
.66979 .42904 Mdot
.66984 .42931 Mdot
.66989 .42958 Mdot
.66994 .42984 Mdot
.66998 .43011 Mdot
.67003 .43038 Mdot
.67008 .43064 Mdot
.67013 .43091 Mdot
.67017 .43118 Mdot
.67022 .43144 Mdot
.67027 .43171 Mdot
.67032 .43197 Mdot
.67036 .43224 Mdot
.67041 .4325 Mdot
.67046 .43277 Mdot
.67051 .43303 Mdot
.67055 .43329 Mdot
.6706 .43356 Mdot
.67065 .43382 Mdot
.6707 .43408 Mdot
.67074 .43435 Mdot
.67079 .43461 Mdot
.67084 .43487 Mdot
.67089 .43513 Mdot
.67094 .4354 Mdot
.67098 .43566 Mdot
.67103 .43592 Mdot
.67108 .43618 Mdot
.67113 .43644 Mdot
.67117 .4367 Mdot
.67122 .43696 Mdot
.67127 .43722 Mdot
.67132 .43748 Mdot
.67136 .43774 Mdot
.67141 .438 Mdot
.67146 .43826 Mdot
.67151 .43852 Mdot
.67155 .43878 Mdot
.6716 .43904 Mdot
.67165 .43929 Mdot
.6717 .43955 Mdot
.67174 .43981 Mdot
.67179 .44007 Mdot
.67184 .44033 Mdot
.67189 .44058 Mdot
.67194 .44084 Mdot
.67198 .4411 Mdot
.67203 .44135 Mdot
.67208 .44161 Mdot
.67213 .44186 Mdot
.67217 .44212 Mdot
.67222 .44237 Mdot
.67227 .44263 Mdot
.67232 .44288 Mdot
.67236 .44314 Mdot
.67241 .44339 Mdot
.67246 .44365 Mdot
.67251 .4439 Mdot
.67255 .44415 Mdot
.6726 .44441 Mdot
.67265 .44466 Mdot
.6727 .44491 Mdot
.67274 .44516 Mdot
.67279 .44542 Mdot
.67284 .44567 Mdot
.67289 .44592 Mdot
.67294 .44617 Mdot
.67298 .44642 Mdot
.67303 .44667 Mdot
.67308 .44692 Mdot
.67313 .44717 Mdot
.67317 .44742 Mdot
.67322 .44767 Mdot
.67327 .44792 Mdot
.67332 .44817 Mdot
.67336 .44842 Mdot
.67341 .44867 Mdot
.67346 .44892 Mdot
.67351 .44916 Mdot
.67355 .44941 Mdot
.6736 .44966 Mdot
.67365 .44991 Mdot
.6737 .45015 Mdot
.67374 .4504 Mdot
.67379 .45065 Mdot
.67384 .45089 Mdot
.67389 .45114 Mdot
.67393 .45138 Mdot
.67398 .45163 Mdot
.67403 .45188 Mdot
.67408 .45212 Mdot
.67413 .45236 Mdot
.67417 .45261 Mdot
.67422 .45285 Mdot
.67427 .4531 Mdot
.67432 .45334 Mdot
.67436 .45358 Mdot
.67441 .45383 Mdot
.67446 .45407 Mdot
.67451 .45431 Mdot
.67455 .45455 Mdot
.6746 .45479 Mdot
.67465 .45504 Mdot
.6747 .45528 Mdot
.67474 .45552 Mdot
.67479 .45576 Mdot
.67484 .456 Mdot
.67489 .45624 Mdot
.67493 .45648 Mdot
.67498 .45672 Mdot
.67503 .45696 Mdot
.67508 .4572 Mdot
.67513 .45743 Mdot
.67517 .45767 Mdot
.67522 .45791 Mdot
.67527 .45815 Mdot
.67532 .45839 Mdot
.67536 .45862 Mdot
.67541 .45886 Mdot
.67546 .4591 Mdot
.67551 .45933 Mdot
.67555 .45957 Mdot
.6756 .4598 Mdot
.67565 .46004 Mdot
.6757 .46027 Mdot
.67574 .46051 Mdot
.67579 .46074 Mdot
.67584 .46098 Mdot
.67589 .46121 Mdot
.67593 .46145 Mdot
.67598 .46168 Mdot
.67603 .46191 Mdot
.67608 .46214 Mdot
.67613 .46238 Mdot
.67617 .46261 Mdot
.67622 .46284 Mdot
.67627 .46307 Mdot
.67632 .4633 Mdot
.67636 .46353 Mdot
.67641 .46377 Mdot
.67646 .464 Mdot
.67651 .46423 Mdot
.67655 .46446 Mdot
.6766 .46469 Mdot
.67665 .46491 Mdot
.6767 .46514 Mdot
.67674 .46537 Mdot
.67679 .4656 Mdot
.67684 .46583 Mdot
.67689 .46606 Mdot
.67693 .46628 Mdot
.67698 .46651 Mdot
.67703 .46674 Mdot
.67708 .46696 Mdot
.67713 .46719 Mdot
.67717 .46741 Mdot
.67722 .46764 Mdot
.67727 .46787 Mdot
.67732 .46809 Mdot
.67736 .46831 Mdot
.67741 .46854 Mdot
.67746 .46876 Mdot
.67751 .46899 Mdot
.67755 .46921 Mdot
.6776 .46943 Mdot
.67765 .46966 Mdot
.6777 .46988 Mdot
.67774 .4701 Mdot
.67779 .47032 Mdot
.67784 .47054 Mdot
.67789 .47076 Mdot
.67793 .47099 Mdot
.67798 .47121 Mdot
.67803 .47143 Mdot
.67808 .47165 Mdot
.67813 .47187 Mdot
.67817 .47208 Mdot
.67822 .4723 Mdot
.67827 .47252 Mdot
.67832 .47274 Mdot
.67836 .47296 Mdot
.67841 .47318 Mdot
.67846 .47339 Mdot
.67851 .47361 Mdot
.67855 .47383 Mdot
.6786 .47404 Mdot
.67865 .47426 Mdot
.6787 .47447 Mdot
.67874 .47469 Mdot
.67879 .4749 Mdot
.67884 .47512 Mdot
.67889 .47533 Mdot
.67893 .47555 Mdot
.67898 .47576 Mdot
.67903 .47597 Mdot
.67908 .47619 Mdot
.67912 .4764 Mdot
.67917 .47661 Mdot
.67922 .47682 Mdot
.67927 .47704 Mdot
.67932 .47725 Mdot
.67936 .47746 Mdot
.67941 .47767 Mdot
.67946 .47788 Mdot
.67951 .47809 Mdot
.67955 .4783 Mdot
.6796 .47851 Mdot
.67965 .47872 Mdot
.6797 .47893 Mdot
.67974 .47913 Mdot
.67979 .47934 Mdot
.67984 .47955 Mdot
.67989 .47976 Mdot
.67993 .47996 Mdot
.67998 .48017 Mdot
.68003 .48038 Mdot
.68008 .48058 Mdot
.68012 .48079 Mdot
.68017 .48099 Mdot
.68022 .4812 Mdot
.68027 .4814 Mdot
.68032 .48161 Mdot
.68036 .48181 Mdot
.68041 .48202 Mdot
.68046 .48222 Mdot
.68051 .48242 Mdot
.68055 .48262 Mdot
.6806 .48283 Mdot
.68065 .48303 Mdot
.6807 .48323 Mdot
.68074 .48343 Mdot
.68079 .48363 Mdot
.68084 .48383 Mdot
.68089 .48403 Mdot
.68093 .48423 Mdot
.68098 .48443 Mdot
.68103 .48463 Mdot
.68108 .48483 Mdot
.68112 .48503 Mdot
.68117 .48523 Mdot
.68122 .48542 Mdot
.68127 .48562 Mdot
.68132 .48582 Mdot
.68136 .48602 Mdot
.68141 .48621 Mdot
.68146 .48641 Mdot
.68151 .4866 Mdot
.68155 .4868 Mdot
.6816 .487 Mdot
.68165 .48719 Mdot
.6817 .48738 Mdot
.68174 .48758 Mdot
.68179 .48777 Mdot
.68184 .48797 Mdot
.68189 .48816 Mdot
.68193 .48835 Mdot
.68198 .48854 Mdot
.68203 .48874 Mdot
.68208 .48893 Mdot
.68212 .48912 Mdot
.68217 .48931 Mdot
.68222 .4895 Mdot
.68227 .48969 Mdot
.68232 .48988 Mdot
.68236 .49007 Mdot
.68241 .49026 Mdot
.68246 .49045 Mdot
.68251 .49064 Mdot
.68255 .49083 Mdot
.6826 .49101 Mdot
.68265 .4912 Mdot
.6827 .49139 Mdot
.68274 .49158 Mdot
.68279 .49176 Mdot
.68284 .49195 Mdot
.68289 .49213 Mdot
.68293 .49232 Mdot
.68298 .4925 Mdot
.68303 .49269 Mdot
.68308 .49287 Mdot
.68312 .49306 Mdot
.68317 .49324 Mdot
.68322 .49342 Mdot
.68327 .49361 Mdot
.68332 .49379 Mdot
.68336 .49397 Mdot
.68341 .49415 Mdot
.68346 .49433 Mdot
.68351 .49452 Mdot
.68355 .4947 Mdot
.6836 .49488 Mdot
.68365 .49506 Mdot
.6837 .49524 Mdot
.68374 .49541 Mdot
.68379 .49559 Mdot
.68384 .49577 Mdot
.68389 .49595 Mdot
.68393 .49613 Mdot
.68398 .4963 Mdot
.68403 .49648 Mdot
.68408 .49666 Mdot
.68412 .49683 Mdot
.68417 .49701 Mdot
.68422 .49719 Mdot
.68427 .49736 Mdot
.68431 .49754 Mdot
.68436 .49771 Mdot
.68441 .49788 Mdot
.68446 .49806 Mdot
.68451 .49823 Mdot
.68455 .4984 Mdot
.6846 .49858 Mdot
.68465 .49875 Mdot
.6847 .49892 Mdot
.68474 .49909 Mdot
.68479 .49926 Mdot
.68484 .49943 Mdot
.68489 .4996 Mdot
.68493 .49977 Mdot
.68498 .49994 Mdot
.68503 .50011 Mdot
.68508 .50028 Mdot
.68512 .50045 Mdot
.68517 .50062 Mdot
.68522 .50078 Mdot
.68527 .50095 Mdot
.68531 .50112 Mdot
.68536 .50129 Mdot
.68541 .50145 Mdot
.68546 .50162 Mdot
.68551 .50178 Mdot
.68555 .50195 Mdot
.6856 .50211 Mdot
.68565 .50228 Mdot
.6857 .50244 Mdot
.68574 .50261 Mdot
.68579 .50277 Mdot
.68584 .50293 Mdot
.68589 .50309 Mdot
.68593 .50326 Mdot
.68598 .50342 Mdot
.68603 .50358 Mdot
.68608 .50374 Mdot
.68612 .5039 Mdot
.68617 .50406 Mdot
.68622 .50422 Mdot
.68627 .50438 Mdot
.68631 .50454 Mdot
.68636 .5047 Mdot
.68641 .50486 Mdot
.68646 .50501 Mdot
.68651 .50517 Mdot
.68655 .50533 Mdot
.6866 .50549 Mdot
.68665 .50564 Mdot
.6867 .5058 Mdot
.68674 .50595 Mdot
.68679 .50611 Mdot
.68684 .50626 Mdot
.68689 .50642 Mdot
.68693 .50657 Mdot
.68698 .50673 Mdot
.68703 .50688 Mdot
.68708 .50703 Mdot
.68712 .50719 Mdot
.68717 .50734 Mdot
.68722 .50749 Mdot
.68727 .50764 Mdot
.68731 .50779 Mdot
.68736 .50794 Mdot
.68741 .50809 Mdot
.68746 .50824 Mdot
.68751 .50839 Mdot
.68755 .50854 Mdot
.6876 .50869 Mdot
.68765 .50884 Mdot
.6877 .50898 Mdot
.68774 .50913 Mdot
.68779 .50928 Mdot
.68784 .50943 Mdot
.68789 .50957 Mdot
.68793 .50972 Mdot
.68798 .50986 Mdot
.68803 .51001 Mdot
.68808 .51015 Mdot
.68812 .5103 Mdot
.68817 .51044 Mdot
.68822 .51059 Mdot
.68827 .51073 Mdot
.68831 .51087 Mdot
.68836 .51101 Mdot
.68841 .51116 Mdot
.68846 .5113 Mdot
.6885 .51144 Mdot
.68855 .51158 Mdot
.6886 .51172 Mdot
.68865 .51186 Mdot
.6887 .512 Mdot
.68874 .51214 Mdot
.68879 .51228 Mdot
.68884 .51241 Mdot
.68889 .51255 Mdot
.68893 .51269 Mdot
.68898 .51283 Mdot
.68903 .51296 Mdot
.68908 .5131 Mdot
.68912 .51324 Mdot
.68917 .51337 Mdot
.68922 .51351 Mdot
.68927 .51364 Mdot
.68931 .51378 Mdot
.68936 .51391 Mdot
.68941 .51404 Mdot
.68946 .51418 Mdot
.6895 .51431 Mdot
.68955 .51444 Mdot
.6896 .51457 Mdot
.68965 .5147 Mdot
.6897 .51484 Mdot
.68974 .51497 Mdot
.68979 .5151 Mdot
.68984 .51523 Mdot
.68989 .51536 Mdot
.68993 .51548 Mdot
.68998 .51561 Mdot
.69003 .51574 Mdot
.69008 .51587 Mdot
.69012 .516 Mdot
.69017 .51612 Mdot
.69022 .51625 Mdot
.69027 .51638 Mdot
.69031 .5165 Mdot
.69036 .51663 Mdot
.69041 .51675 Mdot
.69046 .51688 Mdot
.6905 .517 Mdot
.69055 .51712 Mdot
.6906 .51725 Mdot
.69065 .51737 Mdot
.6907 .51749 Mdot
.69074 .51761 Mdot
.69079 .51774 Mdot
.69084 .51786 Mdot
.69089 .51798 Mdot
.69093 .5181 Mdot
.69098 .51822 Mdot
.69103 .51834 Mdot
.69108 .51846 Mdot
.69112 .51858 Mdot
.69117 .51869 Mdot
.69122 .51881 Mdot
.69127 .51893 Mdot
.69131 .51905 Mdot
.69136 .51916 Mdot
.69141 .51928 Mdot
.69146 .5194 Mdot
.6915 .51951 Mdot
.69155 .51963 Mdot
.6916 .51974 Mdot
.69165 .51985 Mdot
.6917 .51997 Mdot
.69174 .52008 Mdot
.69179 .52019 Mdot
.69184 .52031 Mdot
.69189 .52042 Mdot
.69193 .52053 Mdot
.69198 .52064 Mdot
.69203 .52075 Mdot
.69208 .52086 Mdot
.69212 .52097 Mdot
.69217 .52108 Mdot
.69222 .52119 Mdot
.69227 .5213 Mdot
.69231 .52141 Mdot
.69236 .52152 Mdot
.69241 .52162 Mdot
.69246 .52173 Mdot
.6925 .52184 Mdot
.69255 .52194 Mdot
.6926 .52205 Mdot
.69265 .52215 Mdot
.6927 .52226 Mdot
.69274 .52236 Mdot
.69279 .52247 Mdot
.69284 .52257 Mdot
.69289 .52267 Mdot
.69293 .52277 Mdot
.69298 .52288 Mdot
.69303 .52298 Mdot
.69308 .52308 Mdot
.69312 .52318 Mdot
.69317 .52328 Mdot
.69322 .52338 Mdot
.69327 .52348 Mdot
.69331 .52358 Mdot
.69336 .52368 Mdot
.69341 .52378 Mdot
.69346 .52387 Mdot
.6935 .52397 Mdot
.69355 .52407 Mdot
.6936 .52416 Mdot
.69365 .52426 Mdot
.69369 .52435 Mdot
.69374 .52445 Mdot
.69379 .52454 Mdot
.69384 .52464 Mdot
.69389 .52473 Mdot
.69393 .52483 Mdot
.69398 .52492 Mdot
.69403 .52501 Mdot
.69408 .5251 Mdot
.69412 .5252 Mdot
.69417 .52529 Mdot
.69422 .52538 Mdot
.69427 .52547 Mdot
.69431 .52556 Mdot
.69436 .52565 Mdot
.69441 .52574 Mdot
.69446 .52583 Mdot
.6945 .52591 Mdot
.69455 .526 Mdot
.6946 .52609 Mdot
.69465 .52618 Mdot
.69469 .52626 Mdot
.69474 .52635 Mdot
.69479 .52643 Mdot
.69484 .52652 Mdot
.69489 .5266 Mdot
.69493 .52669 Mdot
.69498 .52677 Mdot
.69503 .52686 Mdot
.69508 .52694 Mdot
.69512 .52702 Mdot
.69517 .5271 Mdot
.69522 .52719 Mdot
.69527 .52727 Mdot
.69531 .52735 Mdot
.69536 .52743 Mdot
.69541 .52751 Mdot
.69546 .52759 Mdot
.6955 .52767 Mdot
.69555 .52775 Mdot
.6956 .52782 Mdot
.69565 .5279 Mdot
.69569 .52798 Mdot
.69574 .52806 Mdot
.69579 .52813 Mdot
.69584 .52821 Mdot
.69589 .52829 Mdot
.69593 .52836 Mdot
.69598 .52844 Mdot
.69603 .52851 Mdot
.69608 .52858 Mdot
.69612 .52866 Mdot
.69617 .52873 Mdot
.69622 .5288 Mdot
.69627 .52887 Mdot
.69631 .52895 Mdot
.69636 .52902 Mdot
.69641 .52909 Mdot
.69646 .52916 Mdot
.6965 .52923 Mdot
.69655 .5293 Mdot
.6966 .52936 Mdot
.69665 .52943 Mdot
.69669 .5295 Mdot
.69674 .52957 Mdot
.69679 .52963 Mdot
.69684 .5297 Mdot
.69689 .52977 Mdot
.69693 .52983 Mdot
.69698 .5299 Mdot
.69703 .52996 Mdot
.69708 .53003 Mdot
.69712 .53009 Mdot
.69717 .53015 Mdot
.69722 .53022 Mdot
.69727 .53028 Mdot
.69731 .53034 Mdot
.69736 .5304 Mdot
.69741 .53046 Mdot
.69746 .53052 Mdot
.6975 .53058 Mdot
.69755 .53064 Mdot
.6976 .5307 Mdot
.69765 .53076 Mdot
.69769 .53082 Mdot
.69774 .53088 Mdot
.69779 .53094 Mdot
.69784 .53099 Mdot
.69788 .53105 Mdot
.69793 .53111 Mdot
.69798 .53116 Mdot
.69803 .53122 Mdot
.69808 .53127 Mdot
.69812 .53133 Mdot
.69817 .53138 Mdot
.69822 .53143 Mdot
.69827 .53149 Mdot
.69831 .53154 Mdot
.69836 .53159 Mdot
.69841 .53164 Mdot
.69846 .53169 Mdot
.6985 .53174 Mdot
.69855 .53179 Mdot
.6986 .53184 Mdot
.69865 .53189 Mdot
.69869 .53194 Mdot
.69874 .53199 Mdot
.69879 .53204 Mdot
.69884 .53208 Mdot
.69888 .53213 Mdot
.69893 .53218 Mdot
.69898 .53222 Mdot
.69903 .53227 Mdot
.69908 .53231 Mdot
.69912 .53236 Mdot
.69917 .5324 Mdot
.69922 .53245 Mdot
.69927 .53249 Mdot
.69931 .53253 Mdot
.69936 .53258 Mdot
.69941 .53262 Mdot
.69946 .53266 Mdot
.6995 .5327 Mdot
.69955 .53274 Mdot
.6996 .53278 Mdot
.69965 .53282 Mdot
.69969 .53286 Mdot
.69974 .5329 Mdot
.69979 .53294 Mdot
.69984 .53297 Mdot
.69988 .53301 Mdot
.69993 .53305 Mdot
.69998 .53309 Mdot
.70003 .53312 Mdot
.70008 .53316 Mdot
.70012 .53319 Mdot
.70017 .53323 Mdot
.70022 .53326 Mdot
.70027 .53329 Mdot
.70031 .53333 Mdot
.70036 .53336 Mdot
.70041 .53339 Mdot
.70046 .53342 Mdot
.7005 .53346 Mdot
.70055 .53349 Mdot
.7006 .53352 Mdot
.70065 .53355 Mdot
.70069 .53358 Mdot
.70074 .53361 Mdot
.70079 .53363 Mdot
.70084 .53366 Mdot
.70088 .53369 Mdot
.70093 .53372 Mdot
.70098 .53374 Mdot
.70103 .53377 Mdot
.70108 .5338 Mdot
.70112 .53382 Mdot
.70117 .53385 Mdot
.70122 .53387 Mdot
.70127 .53389 Mdot
.70131 .53392 Mdot
.70136 .53394 Mdot
.70141 .53396 Mdot
.70146 .53399 Mdot
.7015 .53401 Mdot
.70155 .53403 Mdot
.7016 .53405 Mdot
.70165 .53407 Mdot
.70169 .53409 Mdot
.70174 .53411 Mdot
.70179 .53413 Mdot
.70184 .53415 Mdot
.70188 .53416 Mdot
.70193 .53418 Mdot
.70198 .5342 Mdot
.70203 .53422 Mdot
.70208 .53423 Mdot
.70212 .53425 Mdot
.70217 .53426 Mdot
.70222 .53428 Mdot
.70227 .53429 Mdot
.70231 .5343 Mdot
.70236 .53432 Mdot
.70241 .53433 Mdot
.70246 .53434 Mdot
.7025 .53435 Mdot
.70255 .53437 Mdot
.7026 .53438 Mdot
.70265 .53439 Mdot
.70269 .5344 Mdot
.70274 .53441 Mdot
.70279 .53442 Mdot
.70284 .53442 Mdot
.70288 .53443 Mdot
.70293 .53444 Mdot
.70298 .53445 Mdot
.70303 .53445 Mdot
.70307 .53446 Mdot
.70312 .53447 Mdot
.70317 .53447 Mdot
.70322 .53448 Mdot
.70327 .53448 Mdot
.70331 .53448 Mdot
.70336 .53449 Mdot
.70341 .53449 Mdot
.70346 .53449 Mdot
.7035 .53449 Mdot
.70355 .5345 Mdot
.7036 .5345 Mdot
.70365 .5345 Mdot
.70369 .5345 Mdot
.70374 .5345 Mdot
.70379 .5345 Mdot
.70384 .53449 Mdot
.70388 .53449 Mdot
.70393 .53449 Mdot
.70398 .53449 Mdot
.70403 .53448 Mdot
.70407 .53448 Mdot
.70412 .53448 Mdot
.70417 .53447 Mdot
.70422 .53447 Mdot
.70427 .53446 Mdot
.70431 .53446 Mdot
.70436 .53445 Mdot
.70441 .53444 Mdot
.70446 .53443 Mdot
.7045 .53443 Mdot
.70455 .53442 Mdot
.7046 .53441 Mdot
.70465 .5344 Mdot
.70469 .53439 Mdot
.70474 .53438 Mdot
.70479 .53437 Mdot
.70484 .53436 Mdot
.70488 .53435 Mdot
.70493 .53434 Mdot
.70498 .53432 Mdot
.70503 .53431 Mdot
.70507 .5343 Mdot
.70512 .53428 Mdot
.70517 .53427 Mdot
.70522 .53425 Mdot
.70527 .53424 Mdot
.70531 .53422 Mdot
.70536 .53421 Mdot
.70541 .53419 Mdot
.70546 .53417 Mdot
.7055 .53416 Mdot
.70555 .53414 Mdot
.7056 .53412 Mdot
.70565 .5341 Mdot
.70569 .53408 Mdot
.70574 .53406 Mdot
.70579 .53404 Mdot
.70584 .53402 Mdot
.70588 .534 Mdot
.70593 .53398 Mdot
.70598 .53395 Mdot
.70603 .53393 Mdot
.70607 .53391 Mdot
.70612 .53388 Mdot
.70617 .53386 Mdot
.70622 .53383 Mdot
.70627 .53381 Mdot
.70631 .53378 Mdot
.70636 .53376 Mdot
.70641 .53373 Mdot
.70646 .5337 Mdot
.7065 .53368 Mdot
.70655 .53365 Mdot
.7066 .53362 Mdot
.70665 .53359 Mdot
.70669 .53356 Mdot
.70674 .53353 Mdot
.70679 .5335 Mdot
.70684 .53347 Mdot
.70688 .53344 Mdot
.70693 .53341 Mdot
.70698 .53338 Mdot
.70703 .53334 Mdot
.70707 .53331 Mdot
.70712 .53328 Mdot
.70717 .53324 Mdot
.70722 .53321 Mdot
.70726 .53317 Mdot
.70731 .53314 Mdot
.70736 .5331 Mdot
.70741 .53307 Mdot
.70746 .53303 Mdot
.7075 .53299 Mdot
.70755 .53295 Mdot
.7076 .53292 Mdot
.70765 .53288 Mdot
.70769 .53284 Mdot
.70774 .5328 Mdot
.70779 .53276 Mdot
.70784 .53272 Mdot
.70788 .53268 Mdot
.70793 .53264 Mdot
.70798 .53259 Mdot
.70803 .53255 Mdot
.70807 .53251 Mdot
.70812 .53247 Mdot
.70817 .53242 Mdot
.70822 .53238 Mdot
.70826 .53233 Mdot
.70831 .53229 Mdot
.70836 .53224 Mdot
.70841 .5322 Mdot
.70846 .53215 Mdot
.7085 .5321 Mdot
.70855 .53206 Mdot
.7086 .53201 Mdot
.70865 .53196 Mdot
.70869 .53191 Mdot
.70874 .53186 Mdot
.70879 .53181 Mdot
.70884 .53176 Mdot
.70888 .53171 Mdot
.70893 .53166 Mdot
.70898 .53161 Mdot
.70903 .53156 Mdot
.70907 .5315 Mdot
.70912 .53145 Mdot
.70917 .5314 Mdot
.70922 .53134 Mdot
.70926 .53129 Mdot
.70931 .53123 Mdot
.70936 .53118 Mdot
.70941 .53112 Mdot
.70946 .53107 Mdot
.7095 .53101 Mdot
.70955 .53095 Mdot
.7096 .5309 Mdot
.70965 .53084 Mdot
.70969 .53078 Mdot
.70974 .53072 Mdot
.70979 .53066 Mdot
.70984 .5306 Mdot
.70988 .53054 Mdot
.70993 .53048 Mdot
.70998 .53042 Mdot
.71003 .53036 Mdot
.71007 .5303 Mdot
.71012 .53023 Mdot
.71017 .53017 Mdot
.71022 .53011 Mdot
.71026 .53004 Mdot
.71031 .52998 Mdot
.71036 .52991 Mdot
.71041 .52985 Mdot
.71046 .52978 Mdot
.7105 .52971 Mdot
.71055 .52965 Mdot
.7106 .52958 Mdot
.71065 .52951 Mdot
.71069 .52944 Mdot
.71074 .52938 Mdot
.71079 .52931 Mdot
.71084 .52924 Mdot
.71088 .52917 Mdot
.71093 .5291 Mdot
.71098 .52903 Mdot
.71103 .52895 Mdot
.71107 .52888 Mdot
.71112 .52881 Mdot
.71117 .52874 Mdot
.71122 .52866 Mdot
.71126 .52859 Mdot
.71131 .52852 Mdot
.71136 .52844 Mdot
.71141 .52837 Mdot
.71146 .52829 Mdot
.7115 .52821 Mdot
.71155 .52814 Mdot
.7116 .52806 Mdot
.71165 .52798 Mdot
.71169 .5279 Mdot
.71174 .52783 Mdot
.71179 .52775 Mdot
.71184 .52767 Mdot
.71188 .52759 Mdot
.71193 .52751 Mdot
.71198 .52743 Mdot
.71203 .52735 Mdot
.71207 .52726 Mdot
.71212 .52718 Mdot
.71217 .5271 Mdot
.71222 .52702 Mdot
.71226 .52693 Mdot
.71231 .52685 Mdot
.71236 .52677 Mdot
.71241 .52668 Mdot
.71245 .52659 Mdot
.7125 .52651 Mdot
.71255 .52642 Mdot
.7126 .52634 Mdot
.71265 .52625 Mdot
.71269 .52616 Mdot
.71274 .52607 Mdot
.71279 .52598 Mdot
.71284 .5259 Mdot
.71288 .52581 Mdot
.71293 .52572 Mdot
.71298 .52563 Mdot
.71303 .52553 Mdot
.71307 .52544 Mdot
.71312 .52535 Mdot
.71317 .52526 Mdot
.71322 .52517 Mdot
.71326 .52507 Mdot
.71331 .52498 Mdot
.71336 .52489 Mdot
.71341 .52479 Mdot
.71345 .5247 Mdot
.7135 .5246 Mdot
.71355 .5245 Mdot
.7136 .52441 Mdot
.71365 .52431 Mdot
.71369 .52421 Mdot
.71374 .52412 Mdot
.71379 .52402 Mdot
.71384 .52392 Mdot
.71388 .52382 Mdot
.71393 .52372 Mdot
.71398 .52362 Mdot
.71403 .52352 Mdot
.71407 .52342 Mdot
.71412 .52332 Mdot
.71417 .52321 Mdot
.71422 .52311 Mdot
.71426 .52301 Mdot
.71431 .52291 Mdot
.71436 .5228 Mdot
.71441 .5227 Mdot
.71445 .52259 Mdot
.7145 .52249 Mdot
.71455 .52238 Mdot
.7146 .52228 Mdot
.71465 .52217 Mdot
.71469 .52206 Mdot
.71474 .52196 Mdot
.71479 .52185 Mdot
.71484 .52174 Mdot
.71488 .52163 Mdot
.71493 .52152 Mdot
.71498 .52141 Mdot
.71503 .5213 Mdot
.71507 .52119 Mdot
.71512 .52108 Mdot
.71517 .52097 Mdot
.71522 .52086 Mdot
.71526 .52074 Mdot
.71531 .52063 Mdot
.71536 .52052 Mdot
.71541 .5204 Mdot
.71545 .52029 Mdot
.7155 .52017 Mdot
.71555 .52006 Mdot
.7156 .51994 Mdot
.71565 .51983 Mdot
.71569 .51971 Mdot
.71574 .51959 Mdot
.71579 .51948 Mdot
.71584 .51936 Mdot
.71588 .51924 Mdot
.71593 .51912 Mdot
.71598 .519 Mdot
.71603 .51888 Mdot
.71607 .51876 Mdot
.71612 .51864 Mdot
.71617 .51852 Mdot
.71622 .5184 Mdot
.71626 .51828 Mdot
.71631 .51816 Mdot
.71636 .51803 Mdot
.71641 .51791 Mdot
.71645 .51779 Mdot
.7165 .51766 Mdot
.71655 .51754 Mdot
.7166 .51741 Mdot
.71665 .51729 Mdot
.71669 .51716 Mdot
.71674 .51704 Mdot
.71679 .51691 Mdot
.71684 .51678 Mdot
.71688 .51665 Mdot
.71693 .51653 Mdot
.71698 .5164 Mdot
.71703 .51627 Mdot
.71707 .51614 Mdot
.71712 .51601 Mdot
.71717 .51588 Mdot
.71722 .51575 Mdot
.71726 .51562 Mdot
.71731 .51548 Mdot
.71736 .51535 Mdot
.71741 .51522 Mdot
.71745 .51509 Mdot
.7175 .51495 Mdot
.71755 .51482 Mdot
.7176 .51468 Mdot
.71764 .51455 Mdot
.71769 .51441 Mdot
.71774 .51428 Mdot
.71779 .51414 Mdot
.71784 .51401 Mdot
.71788 .51387 Mdot
.71793 .51373 Mdot
.71798 .51359 Mdot
.71803 .51346 Mdot
.71807 .51332 Mdot
.71812 .51318 Mdot
.71817 .51304 Mdot
.71822 .5129 Mdot
.71826 .51276 Mdot
.71831 .51262 Mdot
.71836 .51247 Mdot
.71841 .51233 Mdot
.71845 .51219 Mdot
.7185 .51205 Mdot
.71855 .5119 Mdot
.7186 .51176 Mdot
.71864 .51162 Mdot
.71869 .51147 Mdot
.71874 .51133 Mdot
.71879 .51118 Mdot
.71884 .51103 Mdot
.71888 .51089 Mdot
.71893 .51074 Mdot
.71898 .51059 Mdot
.71903 .51045 Mdot
.71907 .5103 Mdot
.71912 .51015 Mdot
.71917 .51 Mdot
.71922 .50985 Mdot
.71926 .5097 Mdot
.71931 .50955 Mdot
.71936 .5094 Mdot
.71941 .50925 Mdot
.71945 .5091 Mdot
.7195 .50895 Mdot
.71955 .5088 Mdot
.7196 .50864 Mdot
.71964 .50849 Mdot
.71969 .50834 Mdot
.71974 .50818 Mdot
.71979 .50803 Mdot
.71984 .50787 Mdot
.71988 .50772 Mdot
.71993 .50756 Mdot
.71998 .50741 Mdot
.72003 .50725 Mdot
.72007 .50709 Mdot
.72012 .50693 Mdot
.72017 .50678 Mdot
.72022 .50662 Mdot
.72026 .50646 Mdot
.72031 .5063 Mdot
.72036 .50614 Mdot
.72041 .50598 Mdot
.72045 .50582 Mdot
.7205 .50566 Mdot
.72055 .5055 Mdot
.7206 .50534 Mdot
.72064 .50517 Mdot
.72069 .50501 Mdot
.72074 .50485 Mdot
.72079 .50468 Mdot
.72084 .50452 Mdot
.72088 .50436 Mdot
.72093 .50419 Mdot
.72098 .50403 Mdot
.72103 .50386 Mdot
.72107 .5037 Mdot
.72112 .50353 Mdot
.72117 .50336 Mdot
.72122 .50319 Mdot
.72126 .50303 Mdot
.72131 .50286 Mdot
.72136 .50269 Mdot
.72141 .50252 Mdot
.72145 .50235 Mdot
.7215 .50218 Mdot
.72155 .50201 Mdot
.7216 .50184 Mdot
.72164 .50167 Mdot
.72169 .5015 Mdot
.72174 .50133 Mdot
.72179 .50115 Mdot
.72183 .50098 Mdot
.72188 .50081 Mdot
.72193 .50063 Mdot
.72198 .50046 Mdot
.72203 .50029 Mdot
.72207 .50011 Mdot
.72212 .49994 Mdot
.72217 .49976 Mdot
.72222 .49958 Mdot
.72226 .49941 Mdot
.72231 .49923 Mdot
.72236 .49905 Mdot
.72241 .49888 Mdot
.72245 .4987 Mdot
.7225 .49852 Mdot
.72255 .49834 Mdot
.7226 .49816 Mdot
.72264 .49798 Mdot
.72269 .4978 Mdot
.72274 .49762 Mdot
.72279 .49744 Mdot
.72283 .49726 Mdot
.72288 .49708 Mdot
.72293 .49689 Mdot
.72298 .49671 Mdot
.72303 .49653 Mdot
.72307 .49634 Mdot
.72312 .49616 Mdot
.72317 .49597 Mdot
.72322 .49579 Mdot
.72326 .4956 Mdot
.72331 .49542 Mdot
.72336 .49523 Mdot
.72341 .49505 Mdot
.72345 .49486 Mdot
.7235 .49467 Mdot
.72355 .49448 Mdot
.7236 .4943 Mdot
.72364 .49411 Mdot
.72369 .49392 Mdot
.72374 .49373 Mdot
.72379 .49354 Mdot
.72383 .49335 Mdot
.72388 .49316 Mdot
.72393 .49297 Mdot
.72398 .49278 Mdot
.72403 .49258 Mdot
.72407 .49239 Mdot
.72412 .4922 Mdot
.72417 .49201 Mdot
.72422 .49181 Mdot
.72426 .49162 Mdot
.72431 .49142 Mdot
.72436 .49123 Mdot
.72441 .49103 Mdot
.72445 .49084 Mdot
.7245 .49064 Mdot
.72455 .49045 Mdot
.7246 .49025 Mdot
.72464 .49005 Mdot
.72469 .48986 Mdot
.72474 .48966 Mdot
.72479 .48946 Mdot
.72483 .48926 Mdot
.72488 .48906 Mdot
.72493 .48886 Mdot
.72498 .48866 Mdot
.72503 .48846 Mdot
.72507 .48826 Mdot
.72512 .48806 Mdot
.72517 .48786 Mdot
.72522 .48765 Mdot
.72526 .48745 Mdot
.72531 .48725 Mdot
.72536 .48705 Mdot
.72541 .48684 Mdot
.72545 .48664 Mdot
.7255 .48643 Mdot
.72555 .48623 Mdot
.7256 .48602 Mdot
.72564 .48582 Mdot
.72569 .48561 Mdot
.72574 .4854 Mdot
.72579 .4852 Mdot
.72583 .48499 Mdot
.72588 .48478 Mdot
.72593 .48457 Mdot
.72598 .48436 Mdot
.72603 .48415 Mdot
.72607 .48394 Mdot
.72612 .48374 Mdot
.72617 .48352 Mdot
.72622 .48331 Mdot
.72626 .4831 Mdot
.72631 .48289 Mdot
.72636 .48268 Mdot
.72641 .48247 Mdot
.72645 .48225 Mdot
.7265 .48204 Mdot
.72655 .48183 Mdot
.7266 .48161 Mdot
.72664 .4814 Mdot
.72669 .48119 Mdot
.72674 .48097 Mdot
.72679 .48075 Mdot
.72683 .48054 Mdot
.72688 .48032 Mdot
.72693 .48011 Mdot
.72698 .47989 Mdot
.72702 .47967 Mdot
.72707 .47945 Mdot
.72712 .47924 Mdot
.72717 .47902 Mdot
.72722 .4788 Mdot
.72726 .47858 Mdot
.72731 .47836 Mdot
.72736 .47814 Mdot
.72741 .47792 Mdot
.72745 .4777 Mdot
.7275 .47748 Mdot
.72755 .47725 Mdot
.7276 .47703 Mdot
.72764 .47681 Mdot
.72769 .47659 Mdot
.72774 .47636 Mdot
.72779 .47614 Mdot
.72783 .47592 Mdot
.72788 .47569 Mdot
.72793 .47547 Mdot
.72798 .47524 Mdot
.72802 .47502 Mdot
.72807 .47479 Mdot
.72812 .47457 Mdot
.72817 .47434 Mdot
.72822 .47411 Mdot
.72826 .47389 Mdot
.72831 .47366 Mdot
.72836 .47343 Mdot
.72841 .4732 Mdot
.72845 .47297 Mdot
.7285 .47274 Mdot
.72855 .47251 Mdot
.7286 .47228 Mdot
.72864 .47205 Mdot
.72869 .47182 Mdot
.72874 .47159 Mdot
.72879 .47136 Mdot
.72883 .47113 Mdot
.72888 .4709 Mdot
.72893 .47066 Mdot
.72898 .47043 Mdot
.72902 .4702 Mdot
.72907 .46997 Mdot
.72912 .46973 Mdot
.72917 .4695 Mdot
.72922 .46926 Mdot
.72926 .46903 Mdot
.72931 .46879 Mdot
.72936 .46856 Mdot
.72941 .46832 Mdot
.72945 .46808 Mdot
.7295 .46785 Mdot
.72955 .46761 Mdot
.7296 .46737 Mdot
.72964 .46713 Mdot
.72969 .4669 Mdot
.72974 .46666 Mdot
.72979 .46642 Mdot
.72983 .46618 Mdot
.72988 .46594 Mdot
.72993 .4657 Mdot
.72998 .46546 Mdot
.73002 .46522 Mdot
.73007 .46498 Mdot
.73012 .46473 Mdot
.73017 .46449 Mdot
.73022 .46425 Mdot
.73026 .46401 Mdot
.73031 .46376 Mdot
.73036 .46352 Mdot
.73041 .46328 Mdot
.73045 .46303 Mdot
.7305 .46279 Mdot
.73055 .46254 Mdot
.7306 .4623 Mdot
.73064 .46205 Mdot
.73069 .46181 Mdot
.73074 .46156 Mdot
.73079 .46132 Mdot
.73083 .46107 Mdot
.73088 .46082 Mdot
.73093 .46057 Mdot
.73098 .46033 Mdot
.73102 .46008 Mdot
.73107 .45983 Mdot
.73112 .45958 Mdot
.73117 .45933 Mdot
.73121 .45908 Mdot
.73126 .45883 Mdot
.73131 .45858 Mdot
.73136 .45833 Mdot
.73141 .45808 Mdot
.73145 .45783 Mdot
.7315 .45757 Mdot
.73155 .45732 Mdot
.7316 .45707 Mdot
.73164 .45682 Mdot
.73169 .45656 Mdot
.73174 .45631 Mdot
.73179 .45606 Mdot
.73183 .4558 Mdot
.73188 .45555 Mdot
.73193 .45529 Mdot
.73198 .45504 Mdot
.73202 .45478 Mdot
.73207 .45452 Mdot
.73212 .45427 Mdot
.73217 .45401 Mdot
.73221 .45375 Mdot
.73226 .4535 Mdot
.73231 .45324 Mdot
.73236 .45298 Mdot
.73241 .45272 Mdot
.73245 .45246 Mdot
.7325 .4522 Mdot
.73255 .45195 Mdot
.7326 .45169 Mdot
.73264 .45143 Mdot
.73269 .45116 Mdot
.73274 .4509 Mdot
.73279 .45064 Mdot
.73283 .45038 Mdot
.73288 .45012 Mdot
.73293 .44986 Mdot
.73298 .44959 Mdot
.73302 .44933 Mdot
.73307 .44907 Mdot
.73312 .4488 Mdot
.73317 .44854 Mdot
.73321 .44828 Mdot
.73326 .44801 Mdot
.73331 .44775 Mdot
.73336 .44748 Mdot
.73341 .44721 Mdot
.73345 .44695 Mdot
.7335 .44668 Mdot
.73355 .44642 Mdot
.7336 .44615 Mdot
.73364 .44588 Mdot
.73369 .44561 Mdot
.73374 .44535 Mdot
.73379 .44508 Mdot
.73383 .44481 Mdot
.73388 .44454 Mdot
.73393 .44427 Mdot
.73398 .444 Mdot
.73402 .44373 Mdot
.73407 .44346 Mdot
.73412 .44319 Mdot
.73417 .44292 Mdot
.73421 .44265 Mdot
.73426 .44238 Mdot
.73431 .44211 Mdot
.73436 .44183 Mdot
.73441 .44156 Mdot
.73445 .44129 Mdot
.7345 .44102 Mdot
.73455 .44074 Mdot
.7346 .44047 Mdot
.73464 .4402 Mdot
.73469 .43992 Mdot
.73474 .43965 Mdot
.73479 .43937 Mdot
.73483 .4391 Mdot
.73488 .43882 Mdot
.73493 .43855 Mdot
.73498 .43827 Mdot
.73502 .43799 Mdot
.73507 .43772 Mdot
.73512 .43744 Mdot
.73517 .43716 Mdot
.73521 .43688 Mdot
.73526 .4366 Mdot
.73531 .43633 Mdot
.73536 .43605 Mdot
.73541 .43577 Mdot
.73545 .43549 Mdot
.7355 .43521 Mdot
.73555 .43493 Mdot
.7356 .43465 Mdot
.73564 .43437 Mdot
.73569 .43409 Mdot
.73574 .43381 Mdot
.73579 .43353 Mdot
.73583 .43324 Mdot
.73588 .43296 Mdot
.73593 .43268 Mdot
.73598 .4324 Mdot
.73602 .43212 Mdot
.73607 .43183 Mdot
.73612 .43155 Mdot
.73617 .43126 Mdot
.73621 .43098 Mdot
.73626 .4307 Mdot
.73631 .43041 Mdot
.73636 .43013 Mdot
.7364 .42984 Mdot
.73645 .42956 Mdot
.7365 .42927 Mdot
.73655 .42898 Mdot
.7366 .4287 Mdot
.73664 .42841 Mdot
.73669 .42812 Mdot
.73674 .42784 Mdot
.73679 .42755 Mdot
.73683 .42726 Mdot
.73688 .42697 Mdot
.73693 .42668 Mdot
.73698 .4264 Mdot
.73702 .42611 Mdot
.73707 .42582 Mdot
.73712 .42553 Mdot
.73717 .42524 Mdot
.73721 .42495 Mdot
.73726 .42466 Mdot
.73731 .42437 Mdot
.73736 .42407 Mdot
.7374 .42378 Mdot
.73745 .42349 Mdot
.7375 .4232 Mdot
.73755 .42291 Mdot
.7376 .42261 Mdot
.73764 .42232 Mdot
.73769 .42203 Mdot
.73774 .42174 Mdot
.73779 .42144 Mdot
.73783 .42115 Mdot
.73788 .42085 Mdot
.73793 .42056 Mdot
.73798 .42027 Mdot
.73802 .41997 Mdot
.73807 .41968 Mdot
.73812 .41938 Mdot
.73817 .41908 Mdot
.73821 .41879 Mdot
.73826 .41849 Mdot
.73831 .41819 Mdot
.73836 .4179 Mdot
.7384 .4176 Mdot
.73845 .4173 Mdot
.7385 .41701 Mdot
.73855 .41671 Mdot
.7386 .41641 Mdot
.73864 .41611 Mdot
.73869 .41581 Mdot
.73874 .41551 Mdot
.73879 .41521 Mdot
.73883 .41491 Mdot
.73888 .41461 Mdot
.73893 .41431 Mdot
.73898 .41401 Mdot
.73902 .41371 Mdot
.73907 .41341 Mdot
.73912 .41311 Mdot
.73917 .41281 Mdot
.73921 .41251 Mdot
.73926 .41221 Mdot
.73931 .4119 Mdot
.73936 .4116 Mdot
.7394 .4113 Mdot
.73945 .411 Mdot
.7395 .41069 Mdot
.73955 .41039 Mdot
.7396 .41009 Mdot
.73964 .40978 Mdot
.73969 .40948 Mdot
.73974 .40917 Mdot
.73979 .40887 Mdot
.73983 .40856 Mdot
.73988 .40826 Mdot
.73993 .40795 Mdot
.73998 .40764 Mdot
.74002 .40734 Mdot
.74007 .40703 Mdot
.74012 .40672 Mdot
.74017 .40642 Mdot
.74021 .40611 Mdot
.74026 .4058 Mdot
.74031 .40549 Mdot
.74036 .40519 Mdot
.7404 .40488 Mdot
.74045 .40457 Mdot
.7405 .40426 Mdot
.74055 .40395 Mdot
.74059 .40364 Mdot
.74064 .40333 Mdot
.74069 .40302 Mdot
.74074 .40271 Mdot
.74079 .4024 Mdot
.74083 .40209 Mdot
.74088 .40178 Mdot
.74093 .40147 Mdot
.74098 .40116 Mdot
.74102 .40084 Mdot
.74107 .40053 Mdot
.74112 .40022 Mdot
.74117 .39991 Mdot
.74121 .39959 Mdot
.74126 .39928 Mdot
.74131 .39897 Mdot
.74136 .39865 Mdot
.7414 .39834 Mdot
.74145 .39803 Mdot
.7415 .39771 Mdot
.74155 .3974 Mdot
.74159 .39708 Mdot
.74164 .39677 Mdot
.74169 .39646 Mdot
.74174 .39614 Mdot
.74179 .39582 Mdot
.74183 .39551 Mdot
.74188 .39519 Mdot
.74193 .39488 Mdot
.74198 .39456 Mdot
.74202 .39424 Mdot
.74207 .39393 Mdot
.74212 .39361 Mdot
.74217 .39329 Mdot
.74221 .39298 Mdot
.74226 .39266 Mdot
.74231 .39234 Mdot
.74236 .39202 Mdot
.7424 .3917 Mdot
.74245 .39138 Mdot
.7425 .39107 Mdot
.74255 .39075 Mdot
.74259 .39043 Mdot
.74264 .39011 Mdot
.74269 .38979 Mdot
.74274 .38947 Mdot
.74279 .38915 Mdot
.74283 .38883 Mdot
.74288 .38851 Mdot
.74293 .38819 Mdot
.74298 .38786 Mdot
.74302 .38754 Mdot
.74307 .38722 Mdot
.74312 .3869 Mdot
.74317 .38658 Mdot
.74321 .38626 Mdot
.74326 .38593 Mdot
.74331 .38561 Mdot
.74336 .38529 Mdot
.7434 .38496 Mdot
.74345 .38464 Mdot
.7435 .38432 Mdot
.74355 .38399 Mdot
.74359 .38367 Mdot
.74364 .38335 Mdot
.74369 .38302 Mdot
.74374 .3827 Mdot
.74379 .38237 Mdot
.74383 .38205 Mdot
.74388 .38172 Mdot
.74393 .3814 Mdot
.74398 .38107 Mdot
.74402 .38075 Mdot
.74407 .38042 Mdot
.74412 .38009 Mdot
.74417 .37977 Mdot
.74421 .37944 Mdot
.74426 .37911 Mdot
.74431 .37879 Mdot
.74436 .37846 Mdot
.7444 .37813 Mdot
.74445 .3778 Mdot
.7445 .37748 Mdot
.74455 .37715 Mdot
.74459 .37682 Mdot
.74464 .37649 Mdot
.74469 .37616 Mdot
.74474 .37583 Mdot
.74479 .3755 Mdot
.74483 .37518 Mdot
.74488 .37485 Mdot
.74493 .37452 Mdot
.74498 .37419 Mdot
.74502 .37386 Mdot
.74507 .37353 Mdot
.74512 .3732 Mdot
.74517 .37287 Mdot
.74521 .37254 Mdot
.74526 .37221 Mdot
.74531 .37187 Mdot
.74536 .37154 Mdot
.7454 .37121 Mdot
.74545 .37088 Mdot
.7455 .37055 Mdot
.74555 .37022 Mdot
.74559 .36988 Mdot
.74564 .36955 Mdot
.74569 .36922 Mdot
.74574 .36889 Mdot
.74578 .36855 Mdot
.74583 .36822 Mdot
.74588 .36789 Mdot
.74593 .36755 Mdot
.74598 .36722 Mdot
.74602 .36689 Mdot
.74607 .36655 Mdot
.74612 .36622 Mdot
.74617 .36588 Mdot
.74621 .36555 Mdot
.74626 .36521 Mdot
.74631 .36488 Mdot
.74636 .36454 Mdot
.7464 .36421 Mdot
.74645 .36387 Mdot
.7465 .36354 Mdot
.74655 .3632 Mdot
.74659 .36286 Mdot
.74664 .36253 Mdot
.74669 .36219 Mdot
.74674 .36186 Mdot
.74678 .36152 Mdot
.74683 .36118 Mdot
.74688 .36084 Mdot
.74693 .36051 Mdot
.74698 .36017 Mdot
.74702 .35983 Mdot
.74707 .35949 Mdot
.74712 .35916 Mdot
.74717 .35882 Mdot
.74721 .35848 Mdot
.74726 .35814 Mdot
.74731 .3578 Mdot
.74736 .35746 Mdot
.7474 .35712 Mdot
.74745 .35678 Mdot
.7475 .35644 Mdot
.74755 .35611 Mdot
.74759 .35577 Mdot
.74764 .35543 Mdot
.74769 .35509 Mdot
.74774 .35475 Mdot
.74778 .35441 Mdot
.74783 .35407 Mdot
.74788 .35372 Mdot
.74793 .35338 Mdot
.74798 .35304 Mdot
.74802 .3527 Mdot
.74807 .35236 Mdot
.74812 .35202 Mdot
.74817 .35168 Mdot
.74821 .35134 Mdot
.74826 .351 Mdot
.74831 .35065 Mdot
.74836 .35031 Mdot
.7484 .34997 Mdot
.74845 .34963 Mdot
.7485 .34928 Mdot
.74855 .34894 Mdot
.74859 .3486 Mdot
.74864 .34826 Mdot
.74869 .34791 Mdot
.74874 .34757 Mdot
.74878 .34723 Mdot
.74883 .34688 Mdot
.74888 .34654 Mdot
.74893 .34619 Mdot
.74898 .34585 Mdot
.74902 .34551 Mdot
.74907 .34516 Mdot
.74912 .34482 Mdot
.74917 .34447 Mdot
.74921 .34413 Mdot
.74926 .34378 Mdot
.74931 .34344 Mdot
.74936 .34309 Mdot
.7494 .34275 Mdot
.74945 .3424 Mdot
.7495 .34206 Mdot
.74955 .34171 Mdot
.74959 .34137 Mdot
.74964 .34102 Mdot
.74969 .34067 Mdot
.74974 .34033 Mdot
.74978 .33998 Mdot
.74983 .33963 Mdot
.74988 .33929 Mdot
.74993 .33894 Mdot
.74998 .33859 Mdot
.75002 .33825 Mdot
.75007 .3379 Mdot
.75012 .33755 Mdot
.75017 .3372 Mdot
.75021 .33686 Mdot
.75026 .33651 Mdot
.75031 .33616 Mdot
.75036 .33581 Mdot
.7504 .33546 Mdot
.75045 .33511 Mdot
.7505 .33477 Mdot
.75055 .33442 Mdot
.75059 .33407 Mdot
.75064 .33372 Mdot
.75069 .33337 Mdot
.75074 .33302 Mdot
.75078 .33267 Mdot
.75083 .33232 Mdot
.75088 .33197 Mdot
.75093 .33162 Mdot
.75097 .33127 Mdot
.75102 .33092 Mdot
.75107 .33057 Mdot
.75112 .33022 Mdot
.75117 .32987 Mdot
.75121 .32952 Mdot
.75126 .32917 Mdot
.75131 .32882 Mdot
.75136 .32847 Mdot
.7514 .32812 Mdot
.75145 .32777 Mdot
.7515 .32742 Mdot
.75155 .32707 Mdot
.75159 .32672 Mdot
.75164 .32636 Mdot
.75169 .32601 Mdot
.75174 .32566 Mdot
.75178 .32531 Mdot
.75183 .32496 Mdot
.75188 .32461 Mdot
.75193 .32425 Mdot
.75197 .3239 Mdot
.75202 .32355 Mdot
.75207 .3232 Mdot
.75212 .32284 Mdot
.75217 .32249 Mdot
.75221 .32214 Mdot
.75226 .32179 Mdot
.75231 .32143 Mdot
.75236 .32108 Mdot
.7524 .32073 Mdot
.75245 .32037 Mdot
.7525 .32002 Mdot
.75255 .31967 Mdot
.75259 .31931 Mdot
.75264 .31896 Mdot
.75269 .31861 Mdot
.75274 .31825 Mdot
.75278 .3179 Mdot
.75283 .31755 Mdot
.75288 .31719 Mdot
.75293 .31684 Mdot
.75297 .31648 Mdot
.75302 .31613 Mdot
.75307 .31577 Mdot
.75312 .31542 Mdot
.75317 .31507 Mdot
.75321 .31471 Mdot
.75326 .31436 Mdot
.75331 .314 Mdot
.75336 .31365 Mdot
.7534 .31329 Mdot
.75345 .31294 Mdot
.7535 .31258 Mdot
.75355 .31223 Mdot
.75359 .31187 Mdot
.75364 .31152 Mdot
.75369 .31116 Mdot
.75374 .31081 Mdot
.75378 .31045 Mdot
.75383 .3101 Mdot
.75388 .30974 Mdot
.75393 .30938 Mdot
.75397 .30903 Mdot
.75402 .30867 Mdot
.75407 .30832 Mdot
.75412 .30796 Mdot
.75417 .3076 Mdot
.75421 .30725 Mdot
.75426 .30689 Mdot
.75431 .30654 Mdot
.75436 .30618 Mdot
.7544 .30582 Mdot
.75445 .30547 Mdot
.7545 .30511 Mdot
.75455 .30475 Mdot
.75459 .3044 Mdot
.75464 .30404 Mdot
.75469 .30368 Mdot
.75474 .30333 Mdot
.75478 .30297 Mdot
.75483 .30261 Mdot
.75488 .30225 Mdot
.75493 .3019 Mdot
.75497 .30154 Mdot
.75502 .30118 Mdot
.75507 .30083 Mdot
.75512 .30047 Mdot
.75516 .30011 Mdot
.75521 .29975 Mdot
.75526 .2994 Mdot
.75531 .29904 Mdot
.75536 .29868 Mdot
.7554 .29832 Mdot
.75545 .29796 Mdot
.7555 .29761 Mdot
.75555 .29725 Mdot
.75559 .29689 Mdot
.75564 .29653 Mdot
.75569 .29617 Mdot
.75574 .29582 Mdot
.75578 .29546 Mdot
.75583 .2951 Mdot
.75588 .29474 Mdot
.75593 .29438 Mdot
.75597 .29403 Mdot
.75602 .29367 Mdot
.75607 .29331 Mdot
.75612 .29295 Mdot
.75616 .29259 Mdot
.75621 .29223 Mdot
.75626 .29187 Mdot
.75631 .29152 Mdot
.75636 .29116 Mdot
.7564 .2908 Mdot
.75645 .29044 Mdot
.7565 .29008 Mdot
.75655 .28972 Mdot
.75659 .28936 Mdot
.75664 .289 Mdot
.75669 .28864 Mdot
.75674 .28828 Mdot
.75678 .28793 Mdot
.75683 .28757 Mdot
.75688 .28721 Mdot
.75693 .28685 Mdot
.75697 .28649 Mdot
.75702 .28613 Mdot
.75707 .28577 Mdot
.75712 .28541 Mdot
.75716 .28505 Mdot
.75721 .28469 Mdot
.75726 .28433 Mdot
.75731 .28397 Mdot
.75736 .28361 Mdot
.7574 .28325 Mdot
.75745 .28289 Mdot
.7575 .28253 Mdot
.75755 .28217 Mdot
.75759 .28181 Mdot
.75764 .28145 Mdot
.75769 .2811 Mdot
.75774 .28074 Mdot
.75778 .28038 Mdot
.75783 .28002 Mdot
.75788 .27966 Mdot
.75793 .2793 Mdot
.75797 .27894 Mdot
.75802 .27858 Mdot
.75807 .27822 Mdot
.75812 .27786 Mdot
.75816 .2775 Mdot
.75821 .27714 Mdot
.75826 .27678 Mdot
.75831 .27642 Mdot
.75836 .27606 Mdot
.7584 .2757 Mdot
.75845 .27534 Mdot
.7585 .27498 Mdot
.75855 .27462 Mdot
.75859 .27426 Mdot
.75864 .2739 Mdot
.75869 .27354 Mdot
.75874 .27318 Mdot
.75878 .27282 Mdot
.75883 .27246 Mdot
.75888 .2721 Mdot
.75893 .27173 Mdot
.75897 .27137 Mdot
.75902 .27101 Mdot
.75907 .27065 Mdot
.75912 .27029 Mdot
.75916 .26993 Mdot
.75921 .26957 Mdot
.75926 .26921 Mdot
.75931 .26885 Mdot
.75936 .26849 Mdot
.7594 .26813 Mdot
.75945 .26777 Mdot
.7595 .26741 Mdot
.75955 .26705 Mdot
.75959 .26669 Mdot
.75964 .26633 Mdot
.75969 .26597 Mdot
.75974 .26561 Mdot
.75978 .26525 Mdot
.75983 .26489 Mdot
.75988 .26453 Mdot
.75993 .26417 Mdot
.75997 .26381 Mdot
.76002 .26345 Mdot
.76007 .26309 Mdot
.76012 .26273 Mdot
.76016 .26237 Mdot
.76021 .26201 Mdot
.76026 .26165 Mdot
.76031 .26129 Mdot
.76035 .26093 Mdot
.7604 .26057 Mdot
.76045 .26021 Mdot
.7605 .25985 Mdot
.76055 .25949 Mdot
.76059 .25914 Mdot
.76064 .25878 Mdot
.76069 .25842 Mdot
.76074 .25806 Mdot
.76078 .2577 Mdot
.76083 .25734 Mdot
.76088 .25698 Mdot
.76093 .25662 Mdot
.76097 .25626 Mdot
.76102 .2559 Mdot
.76107 .25554 Mdot
.76112 .25518 Mdot
.76116 .25482 Mdot
.76121 .25446 Mdot
.76126 .2541 Mdot
.76131 .25374 Mdot
.76135 .25338 Mdot
.7614 .25302 Mdot
.76145 .25266 Mdot
.7615 .2523 Mdot
.76155 .25195 Mdot
.76159 .25159 Mdot
.76164 .25123 Mdot
.76169 .25087 Mdot
.76174 .25051 Mdot
.76178 .25015 Mdot
.76183 .24979 Mdot
.76188 .24943 Mdot
.76193 .24907 Mdot
.76197 .24872 Mdot
.76202 .24836 Mdot
.76207 .248 Mdot
.76212 .24764 Mdot
.76216 .24728 Mdot
.76221 .24692 Mdot
.76226 .24656 Mdot
.76231 .2462 Mdot
.76235 .24585 Mdot
.7624 .24549 Mdot
.76245 .24513 Mdot
.7625 .24477 Mdot
.76255 .24441 Mdot
.76259 .24405 Mdot
.76264 .2437 Mdot
.76269 .24334 Mdot
.76274 .24298 Mdot
.76278 .24262 Mdot
.76283 .24226 Mdot
.76288 .24191 Mdot
.76293 .24155 Mdot
.76297 .24119 Mdot
.76302 .24083 Mdot
.76307 .24048 Mdot
.76312 .24012 Mdot
.76316 .23976 Mdot
.76321 .2394 Mdot
.76326 .23905 Mdot
.76331 .23869 Mdot
.76335 .23833 Mdot
.7634 .23797 Mdot
.76345 .23762 Mdot
.7635 .23726 Mdot
.76355 .2369 Mdot
.76359 .23655 Mdot
.76364 .23619 Mdot
.76369 .23583 Mdot
.76374 .23548 Mdot
.76378 .23512 Mdot
.76383 .23476 Mdot
.76388 .23441 Mdot
.76393 .23405 Mdot
.76397 .23369 Mdot
.76402 .23334 Mdot
.76407 .23298 Mdot
.76412 .23262 Mdot
.76416 .23227 Mdot
.76421 .23191 Mdot
.76426 .23156 Mdot
.76431 .2312 Mdot
.76435 .23084 Mdot
.7644 .23049 Mdot
.76445 .23013 Mdot
.7645 .22978 Mdot
.76454 .22942 Mdot
.76459 .22907 Mdot
.76464 .22871 Mdot
.76469 .22835 Mdot
.76474 .228 Mdot
.76478 .22764 Mdot
.76483 .22729 Mdot
.76488 .22693 Mdot
.76493 .22658 Mdot
.76497 .22622 Mdot
.76502 .22587 Mdot
.76507 .22551 Mdot
.76512 .22516 Mdot
.76516 .22481 Mdot
.76521 .22445 Mdot
.76526 .2241 Mdot
.76531 .22374 Mdot
.76535 .22339 Mdot
.7654 .22303 Mdot
.76545 .22268 Mdot
.7655 .22233 Mdot
.76554 .22197 Mdot
.76559 .22162 Mdot
.76564 .22126 Mdot
.76569 .22091 Mdot
.76574 .22056 Mdot
.76578 .2202 Mdot
.76583 .21985 Mdot
.76588 .2195 Mdot
.76593 .21914 Mdot
.76597 .21879 Mdot
.76602 .21844 Mdot
.76607 .21809 Mdot
.76612 .21773 Mdot
.76616 .21738 Mdot
.76621 .21703 Mdot
.76626 .21668 Mdot
.76631 .21632 Mdot
.76635 .21597 Mdot
.7664 .21562 Mdot
.76645 .21527 Mdot
.7665 .21492 Mdot
.76654 .21456 Mdot
.76659 .21421 Mdot
.76664 .21386 Mdot
.76669 .21351 Mdot
.76674 .21316 Mdot
.76678 .21281 Mdot
.76683 .21246 Mdot
.76688 .21211 Mdot
.76693 .21176 Mdot
.76697 .2114 Mdot
.76702 .21105 Mdot
.76707 .2107 Mdot
.76712 .21035 Mdot
.76716 .21 Mdot
.76721 .20965 Mdot
.76726 .2093 Mdot
.76731 .20895 Mdot
.76735 .2086 Mdot
.7674 .20825 Mdot
.76745 .20791 Mdot
.7675 .20756 Mdot
.76754 .20721 Mdot
.76759 .20686 Mdot
.76764 .20651 Mdot
.76769 .20616 Mdot
.76774 .20581 Mdot
.76778 .20546 Mdot
.76783 .20511 Mdot
.76788 .20477 Mdot
.76793 .20442 Mdot
.76797 .20407 Mdot
.76802 .20372 Mdot
.76807 .20337 Mdot
.76812 .20303 Mdot
.76816 .20268 Mdot
.76821 .20233 Mdot
.76826 .20198 Mdot
.76831 .20164 Mdot
.76835 .20129 Mdot
.7684 .20094 Mdot
.76845 .2006 Mdot
.7685 .20025 Mdot
.76854 .1999 Mdot
.76859 .19956 Mdot
.76864 .19921 Mdot
.76869 .19886 Mdot
.76874 .19852 Mdot
.76878 .19817 Mdot
.76883 .19783 Mdot
.76888 .19748 Mdot
.76893 .19713 Mdot
.76897 .19679 Mdot
.76902 .19644 Mdot
.76907 .1961 Mdot
.76912 .19575 Mdot
.76916 .19541 Mdot
.76921 .19506 Mdot
.76926 .19472 Mdot
.76931 .19438 Mdot
.76935 .19403 Mdot
.7694 .19369 Mdot
.76945 .19334 Mdot
.7695 .193 Mdot
.76954 .19266 Mdot
.76959 .19231 Mdot
.76964 .19197 Mdot
.76969 .19163 Mdot
.76973 .19128 Mdot
.76978 .19094 Mdot
.76983 .1906 Mdot
.76988 .19026 Mdot
.76993 .18991 Mdot
.76997 .18957 Mdot
.77002 .18923 Mdot
.77007 .18889 Mdot
.77012 .18855 Mdot
.77016 .18821 Mdot
.77021 .18786 Mdot
.77026 .18752 Mdot
.77031 .18718 Mdot
.77035 .18684 Mdot
.7704 .1865 Mdot
.77045 .18616 Mdot
.7705 .18582 Mdot
.77054 .18548 Mdot
.77059 .18514 Mdot
.77064 .1848 Mdot
.77069 .18446 Mdot
.77073 .18412 Mdot
.77078 .18378 Mdot
.77083 .18344 Mdot
.77088 .1831 Mdot
.77093 .18276 Mdot
.77097 .18242 Mdot
.77102 .18209 Mdot
.77107 .18175 Mdot
.77112 .18141 Mdot
.77116 .18107 Mdot
.77121 .18073 Mdot
.77126 .1804 Mdot
.77131 .18006 Mdot
.77135 .17972 Mdot
.7714 .17938 Mdot
.77145 .17905 Mdot
.7715 .17871 Mdot
.77154 .17837 Mdot
.77159 .17804 Mdot
.77164 .1777 Mdot
.77169 .17736 Mdot
.77173 .17703 Mdot
.77178 .17669 Mdot
.77183 .17636 Mdot
.77188 .17602 Mdot
.77193 .17568 Mdot
.77197 .17535 Mdot
.77202 .17501 Mdot
.77207 .17468 Mdot
.77212 .17434 Mdot
.77216 .17401 Mdot
.77221 .17368 Mdot
.77226 .17334 Mdot
.77231 .17301 Mdot
.77235 .17267 Mdot
.7724 .17234 Mdot
.77245 .17201 Mdot
.7725 .17167 Mdot
.77254 .17134 Mdot
.77259 .17101 Mdot
.77264 .17068 Mdot
.77269 .17034 Mdot
.77273 .17001 Mdot
.77278 .16968 Mdot
.77283 .16935 Mdot
.77288 .16902 Mdot
.77293 .16868 Mdot
.77297 .16835 Mdot
.77302 .16802 Mdot
.77307 .16769 Mdot
.77312 .16736 Mdot
.77316 .16703 Mdot
.77321 .1667 Mdot
.77326 .16637 Mdot
.77331 .16604 Mdot
.77335 .16571 Mdot
.7734 .16538 Mdot
.77345 .16505 Mdot
.7735 .16472 Mdot
.77354 .16439 Mdot
.77359 .16407 Mdot
.77364 .16374 Mdot
.77369 .16341 Mdot
.77373 .16308 Mdot
.77378 .16275 Mdot
.77383 .16243 Mdot
.77388 .1621 Mdot
.77392 .16177 Mdot
.77397 .16144 Mdot
.77402 .16112 Mdot
.77407 .16079 Mdot
.77412 .16047 Mdot
.77416 .16014 Mdot
.77421 .15981 Mdot
.77426 .15949 Mdot
.77431 .15916 Mdot
.77435 .15884 Mdot
.7744 .15851 Mdot
.77445 .15819 Mdot
.7745 .15786 Mdot
.77454 .15754 Mdot
.77459 .15721 Mdot
.77464 .15689 Mdot
.77469 .15657 Mdot
.77473 .15624 Mdot
.77478 .15592 Mdot
.77483 .1556 Mdot
.77488 .15527 Mdot
.77492 .15495 Mdot
.77497 .15463 Mdot
.77502 .15431 Mdot
.77507 .15399 Mdot
.77512 .15366 Mdot
.77516 .15334 Mdot
.77521 .15302 Mdot
.77526 .1527 Mdot
.77531 .15238 Mdot
.77535 .15206 Mdot
.7754 .15174 Mdot
.77545 .15142 Mdot
.7755 .1511 Mdot
.77554 .15078 Mdot
.77559 .15046 Mdot
.77564 .15014 Mdot
.77569 .14982 Mdot
.77573 .1495 Mdot
.77578 .14918 Mdot
.77583 .14887 Mdot
.77588 .14855 Mdot
.77592 .14823 Mdot
.77597 .14791 Mdot
.77602 .14759 Mdot
.77607 .14728 Mdot
.77612 .14696 Mdot
.77616 .14664 Mdot
.77621 .14633 Mdot
.77626 .14601 Mdot
.77631 .1457 Mdot
.77635 .14538 Mdot
.7764 .14507 Mdot
.77645 .14475 Mdot
.7765 .14443 Mdot
.77654 .14412 Mdot
.77659 .14381 Mdot
.77664 .14349 Mdot
.77669 .14318 Mdot
.77673 .14286 Mdot
.77678 .14255 Mdot
.77683 .14224 Mdot
.77688 .14192 Mdot
.77692 .14161 Mdot
.77697 .1413 Mdot
.77702 .14099 Mdot
.77707 .14067 Mdot
.77712 .14036 Mdot
.77716 .14005 Mdot
.77721 .13974 Mdot
.77726 .13943 Mdot
.77731 .13912 Mdot
.77735 .13881 Mdot
.7774 .1385 Mdot
.77745 .13819 Mdot
.7775 .13788 Mdot
.77754 .13757 Mdot
.77759 .13726 Mdot
.77764 .13695 Mdot
.77769 .13664 Mdot
.77773 .13633 Mdot
.77778 .13602 Mdot
.77783 .13572 Mdot
.77788 .13541 Mdot
.77792 .1351 Mdot
.77797 .13479 Mdot
.77802 .13449 Mdot
.77807 .13418 Mdot
.77812 .13387 Mdot
.77816 .13357 Mdot
.77821 .13326 Mdot
.77826 .13296 Mdot
.77831 .13265 Mdot
.77835 .13234 Mdot
.7784 .13204 Mdot
.77845 .13174 Mdot
.7785 .13143 Mdot
.77854 .13113 Mdot
.77859 .13082 Mdot
.77864 .13052 Mdot
.77869 .13022 Mdot
.77873 .12991 Mdot
.77878 .12961 Mdot
.77883 .12931 Mdot
.77888 .12901 Mdot
.77892 .1287 Mdot
.77897 .1284 Mdot
.77902 .1281 Mdot
.77907 .1278 Mdot
.77911 .1275 Mdot
.77916 .1272 Mdot
.77921 .1269 Mdot
.77926 .1266 Mdot
.77931 .1263 Mdot
.77935 .126 Mdot
.7794 .1257 Mdot
.77945 .1254 Mdot
.7795 .1251 Mdot
.77954 .1248 Mdot
.77959 .12451 Mdot
.77964 .12421 Mdot
.77969 .12391 Mdot
.77973 .12361 Mdot
.77978 .12332 Mdot
.77983 .12302 Mdot
.77988 .12273 Mdot
.77992 .12243 Mdot
.77997 .12213 Mdot
.78002 .12184 Mdot
.78007 .12154 Mdot
.78011 .12125 Mdot
.78016 .12095 Mdot
.78021 .12066 Mdot
.78026 .12037 Mdot
.78031 .12007 Mdot
.78035 .11978 Mdot
.7804 .11949 Mdot
.78045 .11919 Mdot
.7805 .1189 Mdot
.78054 .11861 Mdot
.78059 .11832 Mdot
.78064 .11802 Mdot
.78069 .11773 Mdot
.78073 .11744 Mdot
.78078 .11715 Mdot
.78083 .11686 Mdot
.78088 .11657 Mdot
.78092 .11628 Mdot
.78097 .11599 Mdot
.78102 .1157 Mdot
.78107 .11541 Mdot
.78111 .11513 Mdot
.78116 .11484 Mdot
.78121 .11455 Mdot
.78126 .11426 Mdot
.78131 .11397 Mdot
.78135 .11369 Mdot
.7814 .1134 Mdot
.78145 .11311 Mdot
.7815 .11283 Mdot
.78154 .11254 Mdot
.78159 .11226 Mdot
.78164 .11197 Mdot
.78169 .11169 Mdot
.78173 .1114 Mdot
.78178 .11112 Mdot
.78183 .11083 Mdot
.78188 .11055 Mdot
.78192 .11027 Mdot
.78197 .10998 Mdot
.78202 .1097 Mdot
.78207 .10942 Mdot
.78211 .10914 Mdot
.78216 .10886 Mdot
.78221 .10857 Mdot
.78226 .10829 Mdot
.78231 .10801 Mdot
.78235 .10773 Mdot
.7824 .10745 Mdot
.78245 .10717 Mdot
.7825 .10689 Mdot
.78254 .10661 Mdot
.78259 .10633 Mdot
.78264 .10605 Mdot
.78269 .10578 Mdot
.78273 .1055 Mdot
.78278 .10522 Mdot
.78283 .10494 Mdot
.78288 .10467 Mdot
.78292 .10439 Mdot
.78297 .10411 Mdot
.78302 .10384 Mdot
.78307 .10356 Mdot
.78311 .10329 Mdot
.78316 .10301 Mdot
.78321 .10274 Mdot
.78326 .10246 Mdot
.78331 .10219 Mdot
.78335 .10192 Mdot
.7834 .10164 Mdot
.78345 .10137 Mdot
.7835 .1011 Mdot
.78354 .10082 Mdot
.78359 .10055 Mdot
.78364 .10028 Mdot
.78369 .10001 Mdot
.78373 .09974 Mdot
.78378 .09947 Mdot
.78383 .0992 Mdot
.78388 .09893 Mdot
.78392 .09866 Mdot
.78397 .09839 Mdot
.78402 .09812 Mdot
.78407 .09785 Mdot
.78411 .09758 Mdot
.78416 .09731 Mdot
.78421 .09705 Mdot
.78426 .09678 Mdot
.7843 .09651 Mdot
.78435 .09625 Mdot
.7844 .09598 Mdot
.78445 .09571 Mdot
.7845 .09545 Mdot
.78454 .09518 Mdot
.78459 .09492 Mdot
.78464 .09465 Mdot
.78469 .09439 Mdot
.78473 .09413 Mdot
.78478 .09386 Mdot
.78483 .0936 Mdot
.78488 .09334 Mdot
.78492 .09308 Mdot
.78497 .09281 Mdot
.78502 .09255 Mdot
.78507 .09229 Mdot
.78511 .09203 Mdot
.78516 .09177 Mdot
.78521 .09151 Mdot
.78526 .09125 Mdot
.7853 .09099 Mdot
.78535 .09073 Mdot
.7854 .09047 Mdot
.78545 .09021 Mdot
.7855 .08996 Mdot
.78554 .0897 Mdot
.78559 .08944 Mdot
.78564 .08918 Mdot
.78569 .08893 Mdot
.78573 .08867 Mdot
.78578 .08842 Mdot
.78583 .08816 Mdot
.78588 .08791 Mdot
.78592 .08765 Mdot
.78597 .0874 Mdot
.78602 .08714 Mdot
.78607 .08689 Mdot
.78611 .08664 Mdot
.78616 .08638 Mdot
.78621 .08613 Mdot
.78626 .08588 Mdot
.7863 .08563 Mdot
.78635 .08537 Mdot
.7864 .08512 Mdot
.78645 .08487 Mdot
.7865 .08462 Mdot
.78654 .08437 Mdot
.78659 .08412 Mdot
.78664 .08387 Mdot
.78669 .08362 Mdot
.78673 .08338 Mdot
.78678 .08313 Mdot
.78683 .08288 Mdot
.78688 .08263 Mdot
.78692 .08239 Mdot
.78697 .08214 Mdot
.78702 .08189 Mdot
.78707 .08165 Mdot
.78711 .0814 Mdot
.78716 .08116 Mdot
.78721 .08091 Mdot
.78726 .08067 Mdot
.7873 .08043 Mdot
.78735 .08018 Mdot
.7874 .07994 Mdot
.78745 .0797 Mdot
.7875 .07945 Mdot
.78754 .07921 Mdot
.78759 .07897 Mdot
.78764 .07873 Mdot
.78769 .07849 Mdot
.78773 .07825 Mdot
.78778 .07801 Mdot
.78783 .07777 Mdot
.78788 .07753 Mdot
.78792 .07729 Mdot
.78797 .07705 Mdot
.78802 .07682 Mdot
.78807 .07658 Mdot
.78811 .07634 Mdot
.78816 .0761 Mdot
.78821 .07587 Mdot
.78826 .07563 Mdot
.7883 .0754 Mdot
.78835 .07516 Mdot
.7884 .07493 Mdot
.78845 .07469 Mdot
.78849 .07446 Mdot
.78854 .07422 Mdot
.78859 .07399 Mdot
.78864 .07376 Mdot
.78869 .07352 Mdot
.78873 .07329 Mdot
.78878 .07306 Mdot
.78883 .07283 Mdot
.78888 .0726 Mdot
.78892 .07237 Mdot
.78897 .07214 Mdot
.78902 .07191 Mdot
.78907 .07168 Mdot
.78911 .07145 Mdot
.78916 .07122 Mdot
.78921 .07099 Mdot
.78926 .07077 Mdot
.7893 .07054 Mdot
.78935 .07031 Mdot
.7894 .07008 Mdot
.78945 .06986 Mdot
.78949 .06963 Mdot
.78954 .06941 Mdot
.78959 .06918 Mdot
.78964 .06896 Mdot
.78969 .06873 Mdot
.78973 .06851 Mdot
.78978 .06829 Mdot
.78983 .06806 Mdot
.78988 .06784 Mdot
.78992 .06762 Mdot
.78997 .0674 Mdot
.79002 .06718 Mdot
.79007 .06695 Mdot
.79011 .06673 Mdot
.79016 .06651 Mdot
.79021 .06629 Mdot
.79026 .06608 Mdot
.7903 .06586 Mdot
.79035 .06564 Mdot
.7904 .06542 Mdot
.79045 .0652 Mdot
.79049 .06498 Mdot
.79054 .06477 Mdot
.79059 .06455 Mdot
.79064 .06434 Mdot
.79069 .06412 Mdot
.79073 .0639 Mdot
.79078 .06369 Mdot
.79083 .06348 Mdot
.79088 .06326 Mdot
.79092 .06305 Mdot
.79097 .06283 Mdot
.79102 .06262 Mdot
.79107 .06241 Mdot
.79111 .0622 Mdot
.79116 .06199 Mdot
.79121 .06178 Mdot
.79126 .06157 Mdot
.7913 .06135 Mdot
.79135 .06115 Mdot
.7914 .06094 Mdot
.79145 .06073 Mdot
.79149 .06052 Mdot
.79154 .06031 Mdot
.79159 .0601 Mdot
.79164 .0599 Mdot
.79169 .05969 Mdot
.79173 .05948 Mdot
.79178 .05928 Mdot
.79183 .05907 Mdot
.79188 .05887 Mdot
.79192 .05866 Mdot
.79197 .05846 Mdot
.79202 .05825 Mdot
.79207 .05805 Mdot
.79211 .05785 Mdot
.79216 .05765 Mdot
.79221 .05744 Mdot
.79226 .05724 Mdot
.7923 .05704 Mdot
.79235 .05684 Mdot
.7924 .05664 Mdot
.79245 .05644 Mdot
.79249 .05624 Mdot
.79254 .05604 Mdot
.79259 .05584 Mdot
.79264 .05565 Mdot
.79269 .05545 Mdot
.79273 .05525 Mdot
.79278 .05506 Mdot
.79283 .05486 Mdot
.79288 .05466 Mdot
.79292 .05447 Mdot
.79297 .05427 Mdot
.79302 .05408 Mdot
.79307 .05388 Mdot
.79311 .05369 Mdot
.79316 .0535 Mdot
.79321 .0533 Mdot
.79326 .05311 Mdot
.7933 .05292 Mdot
.79335 .05273 Mdot
.7934 .05254 Mdot
.79345 .05235 Mdot
.79349 .05216 Mdot
.79354 .05197 Mdot
.79359 .05178 Mdot
.79364 .05159 Mdot
.79368 .0514 Mdot
.79373 .05121 Mdot
.79378 .05102 Mdot
.79383 .05084 Mdot
.79388 .05065 Mdot
.79392 .05046 Mdot
.79397 .05028 Mdot
.79402 .05009 Mdot
.79407 .04991 Mdot
.79411 .04972 Mdot
.79416 .04954 Mdot
.79421 .04935 Mdot
.79426 .04917 Mdot
.7943 .04899 Mdot
.79435 .04881 Mdot
.7944 .04862 Mdot
.79445 .04844 Mdot
.79449 .04826 Mdot
.79454 .04808 Mdot
.79459 .0479 Mdot
.79464 .04772 Mdot
.79468 .04754 Mdot
.79473 .04736 Mdot
.79478 .04718 Mdot
.79483 .04701 Mdot
.79488 .04683 Mdot
.79492 .04665 Mdot
.79497 .04648 Mdot
.79502 .0463 Mdot
.79507 .04612 Mdot
.79511 .04595 Mdot
.79516 .04577 Mdot
.79521 .0456 Mdot
.79526 .04543 Mdot
.7953 .04525 Mdot
.79535 .04508 Mdot
.7954 .04491 Mdot
.79545 .04474 Mdot
.79549 .04457 Mdot
.79554 .04439 Mdot
.79559 .04422 Mdot
.79564 .04405 Mdot
.79568 .04388 Mdot
.79573 .04372 Mdot
.79578 .04355 Mdot
.79583 .04338 Mdot
.79588 .04321 Mdot
.79592 .04304 Mdot
.79597 .04288 Mdot
.79602 .04271 Mdot
.79607 .04254 Mdot
.79611 .04238 Mdot
.79616 .04221 Mdot
.79621 .04205 Mdot
.79626 .04189 Mdot
.7963 .04172 Mdot
.79635 .04156 Mdot
.7964 .0414 Mdot
.79645 .04123 Mdot
.79649 .04107 Mdot
.79654 .04091 Mdot
.79659 .04075 Mdot
.79664 .04059 Mdot
.79668 .04043 Mdot
.79673 .04027 Mdot
.79678 .04011 Mdot
.79683 .03995 Mdot
.79688 .0398 Mdot
.79692 .03964 Mdot
.79697 .03948 Mdot
.79702 .03932 Mdot
.79707 .03917 Mdot
.79711 .03901 Mdot
.79716 .03886 Mdot
.79721 .0387 Mdot
.79726 .03855 Mdot
.7973 .03839 Mdot
.79735 .03824 Mdot
.7974 .03809 Mdot
.79745 .03793 Mdot
.79749 .03778 Mdot
.79754 .03763 Mdot
.79759 .03748 Mdot
.79764 .03733 Mdot
.79768 .03718 Mdot
.79773 .03703 Mdot
.79778 .03688 Mdot
.79783 .03673 Mdot
.79787 .03658 Mdot
.79792 .03643 Mdot
.79797 .03629 Mdot
.79802 .03614 Mdot
.79807 .03599 Mdot
.79811 .03585 Mdot
.79816 .0357 Mdot
.79821 .03556 Mdot
.79826 .03541 Mdot
.7983 .03527 Mdot
.79835 .03512 Mdot
.7984 .03498 Mdot
.79845 .03484 Mdot
.79849 .0347 Mdot
.79854 .03455 Mdot
.79859 .03441 Mdot
.79864 .03427 Mdot
.79868 .03413 Mdot
.79873 .03399 Mdot
.79878 .03385 Mdot
.79883 .03371 Mdot
.79887 .03358 Mdot
.79892 .03344 Mdot
.79897 .0333 Mdot
.79902 .03316 Mdot
.79907 .03303 Mdot
.79911 .03289 Mdot
.79916 .03276 Mdot
.79921 .03262 Mdot
.79926 .03249 Mdot
.7993 .03235 Mdot
.79935 .03222 Mdot
.7994 .03209 Mdot
.79945 .03195 Mdot
.79949 .03182 Mdot
.79954 .03169 Mdot
.79959 .03156 Mdot
.79964 .03143 Mdot
.79968 .0313 Mdot
.79973 .03117 Mdot
.79978 .03104 Mdot
.79983 .03091 Mdot
.79987 .03078 Mdot
.79992 .03066 Mdot
.79997 .03053 Mdot
.80002 .0304 Mdot
.80007 .03028 Mdot
.80011 .03015 Mdot
.80016 .03003 Mdot
.80021 .0299 Mdot
.80026 .02978 Mdot
.8003 .02965 Mdot
.80035 .02953 Mdot
.8004 .02941 Mdot
.80045 .02928 Mdot
.80049 .02916 Mdot
.80054 .02904 Mdot
.80059 .02892 Mdot
.80064 .0288 Mdot
.80068 .02868 Mdot
.80073 .02856 Mdot
.80078 .02844 Mdot
.80083 .02832 Mdot
.80087 .0282 Mdot
.80092 .02809 Mdot
.80097 .02797 Mdot
.80102 .02785 Mdot
.80107 .02774 Mdot
.80111 .02762 Mdot
.80116 .02751 Mdot
.80121 .02739 Mdot
.80126 .02728 Mdot
.8013 .02716 Mdot
.80135 .02705 Mdot
.8014 .02694 Mdot
.80145 .02683 Mdot
.80149 .02672 Mdot
.80154 .02661 Mdot
.80159 .02649 Mdot
.80164 .02638 Mdot
.80168 .02628 Mdot
.80173 .02617 Mdot
.80178 .02606 Mdot
.80183 .02595 Mdot
.80187 .02584 Mdot
.80192 .02574 Mdot
.80197 .02563 Mdot
.80202 .02552 Mdot
.80207 .02542 Mdot
.80211 .02531 Mdot
.80216 .02521 Mdot
.80221 .0251 Mdot
.80226 .025 Mdot
.8023 .0249 Mdot
.80235 .0248 Mdot
.8024 .02469 Mdot
.80245 .02459 Mdot
.80249 .02449 Mdot
.80254 .02439 Mdot
.80259 .02429 Mdot
.80264 .02419 Mdot
.80268 .02409 Mdot
.80273 .02399 Mdot
.80278 .0239 Mdot
.80283 .0238 Mdot
.80287 .0237 Mdot
.80292 .0236 Mdot
.80297 .02351 Mdot
.80302 .02341 Mdot
.80306 .02332 Mdot
.80311 .02322 Mdot
.80316 .02313 Mdot
.80321 .02304 Mdot
.80326 .02294 Mdot
.8033 .02285 Mdot
.80335 .02276 Mdot
.8034 .02267 Mdot
.80345 .02258 Mdot
.80349 .02249 Mdot
.80354 .0224 Mdot
.80359 .02231 Mdot
.80364 .02222 Mdot
.80368 .02213 Mdot
.80373 .02204 Mdot
.80378 .02196 Mdot
.80383 .02187 Mdot
.80387 .02178 Mdot
.80392 .0217 Mdot
.80397 .02161 Mdot
.80402 .02153 Mdot
.80406 .02144 Mdot
.80411 .02136 Mdot
.80416 .02128 Mdot
.80421 .02119 Mdot
.80426 .02111 Mdot
.8043 .02103 Mdot
.80435 .02095 Mdot
.8044 .02087 Mdot
.80445 .02079 Mdot
.80449 .02071 Mdot
.80454 .02063 Mdot
.80459 .02055 Mdot
.80464 .02047 Mdot
.80468 .0204 Mdot
.80473 .02032 Mdot
.80478 .02024 Mdot
.80483 .02017 Mdot
.80487 .02009 Mdot
.80492 .02002 Mdot
.80497 .01994 Mdot
.80502 .01987 Mdot
.80506 .0198 Mdot
.80511 .01972 Mdot
.80516 .01965 Mdot
.80521 .01958 Mdot
.80526 .01951 Mdot
.8053 .01944 Mdot
.80535 .01937 Mdot
.8054 .0193 Mdot
.80545 .01923 Mdot
.80549 .01916 Mdot
.80554 .01909 Mdot
.80559 .01902 Mdot
.80564 .01896 Mdot
.80568 .01889 Mdot
.80573 .01882 Mdot
.80578 .01876 Mdot
.80583 .01869 Mdot
.80587 .01863 Mdot
.80592 .01856 Mdot
.80597 .0185 Mdot
.80602 .01844 Mdot
.80606 .01837 Mdot
.80611 .01831 Mdot
.80616 .01825 Mdot
.80621 .01819 Mdot
.80626 .01813 Mdot
.8063 .01807 Mdot
.80635 .01801 Mdot
.8064 .01795 Mdot
.80645 .01789 Mdot
.80649 .01784 Mdot
.80654 .01778 Mdot
.80659 .01772 Mdot
.80664 .01767 Mdot
.80668 .01761 Mdot
.80673 .01755 Mdot
.80678 .0175 Mdot
.80683 .01745 Mdot
.80687 .01739 Mdot
.80692 .01734 Mdot
.80697 .01729 Mdot
.80702 .01724 Mdot
.80706 .01718 Mdot
.80711 .01713 Mdot
.80716 .01708 Mdot
.80721 .01703 Mdot
.80725 .01698 Mdot
.8073 .01693 Mdot
.80735 .01689 Mdot
.8074 .01684 Mdot
.80745 .01679 Mdot
.80749 .01674 Mdot
.80754 .0167 Mdot
.80759 .01665 Mdot
.80764 .01661 Mdot
.80768 .01656 Mdot
.80773 .01652 Mdot
.80778 .01648 Mdot
.80783 .01643 Mdot
.80787 .01639 Mdot
.80792 .01635 Mdot
.80797 .01631 Mdot
.80802 .01627 Mdot
.80806 .01623 Mdot
.80811 .01619 Mdot
.80816 .01615 Mdot
.80821 .01611 Mdot
.80825 .01607 Mdot
.8083 .01603 Mdot
.80835 .016 Mdot
.8084 .01596 Mdot
.80845 .01592 Mdot
.80849 .01589 Mdot
.80854 .01585 Mdot
.80859 .01582 Mdot
.80864 .01578 Mdot
.80868 .01575 Mdot
.80873 .01572 Mdot
.80878 .01569 Mdot
.80883 .01565 Mdot
.80887 .01562 Mdot
.80892 .01559 Mdot
.80897 .01556 Mdot
.80902 .01553 Mdot
.80906 .0155 Mdot
.80911 .01547 Mdot
.80916 .01545 Mdot
.80921 .01542 Mdot
.80925 .01539 Mdot
.8093 .01536 Mdot
.80935 .01534 Mdot
.8094 .01531 Mdot
.80945 .01529 Mdot
.80949 .01526 Mdot
.80954 .01524 Mdot
.80959 .01522 Mdot
.80964 .01519 Mdot
.80968 .01517 Mdot
.80973 .01515 Mdot
.80978 .01513 Mdot
.80983 .01511 Mdot
.80987 .01509 Mdot
.80992 .01507 Mdot
.80997 .01505 Mdot
.81002 .01503 Mdot
.81006 .01501 Mdot
.81011 .01499 Mdot
.81016 .01498 Mdot
.81021 .01496 Mdot
.81025 .01495 Mdot
.8103 .01493 Mdot
.81035 .01492 Mdot
.8104 .0149 Mdot
.81045 .01489 Mdot
.81049 .01487 Mdot
.81054 .01486 Mdot
.81059 .01485 Mdot
.81064 .01484 Mdot
.81068 .01483 Mdot
.81073 .01481 Mdot
.81078 .0148 Mdot
.81083 .01479 Mdot
.81087 .01479 Mdot
.81092 .01478 Mdot
.81097 .01477 Mdot
.81102 .01476 Mdot
.81106 .01476 Mdot
.81111 .01475 Mdot
.81116 .01474 Mdot
.81121 .01474 Mdot
.81125 .01473 Mdot
.8113 .01473 Mdot
.81135 .01473 Mdot
.8114 .01472 Mdot
.81145 .01472 Mdot
.81149 .01472 Mdot
.81154 .01472 Mdot
.81159 .01472 Mdot
.81164 .01472 Mdot
.81168 .01472 Mdot
.81173 .01472 Mdot
.81178 .01472 Mdot
.81183 .01472 Mdot
.81187 .01472 Mdot
.81192 .01472 Mdot
.81197 .01473 Mdot
.81202 .01473 Mdot
.81206 .01474 Mdot
.81211 .01474 Mdot
.81216 .01475 Mdot
.81221 .01475 Mdot
.81225 .01476 Mdot
.8123 .01477 Mdot
.81235 .01477 Mdot
.8124 .01478 Mdot
.81244 .01479 Mdot
.81249 .0148 Mdot
.81254 .01481 Mdot
.81259 .01482 Mdot
.81264 .01483 Mdot
.81268 .01484 Mdot
.81273 .01485 Mdot
.81278 .01486 Mdot
.81283 .01488 Mdot
.81287 .01489 Mdot
.81292 .0149 Mdot
.81297 .01492 Mdot
.81302 .01493 Mdot
.81306 .01495 Mdot
.81311 .01497 Mdot
.81316 .01498 Mdot
.81321 .015 Mdot
.81325 .01502 Mdot
.8133 .01503 Mdot
.81335 .01505 Mdot
.8134 .01507 Mdot
.81344 .01509 Mdot
.81349 .01511 Mdot
.81354 .01513 Mdot
.81359 .01515 Mdot
.81364 .01518 Mdot
.81368 .0152 Mdot
.81373 .01522 Mdot
.81378 .01525 Mdot
.81383 .01527 Mdot
.81387 .01529 Mdot
.81392 .01532 Mdot
.81397 .01534 Mdot
.81402 .01537 Mdot
.81406 .0154 Mdot
.81411 .01543 Mdot
.81416 .01545 Mdot
.81421 .01548 Mdot
.81425 .01551 Mdot
.8143 .01554 Mdot
.81435 .01557 Mdot
.8144 .0156 Mdot
.81444 .01563 Mdot
.81449 .01566 Mdot
.81454 .01569 Mdot
.81459 .01573 Mdot
.81464 .01576 Mdot
.81468 .01579 Mdot
.81473 .01583 Mdot
.81478 .01586 Mdot
.81483 .0159 Mdot
.81487 .01593 Mdot
.81492 .01597 Mdot
.81497 .01601 Mdot
.81502 .01604 Mdot
.81506 .01608 Mdot
.81511 .01612 Mdot
.81516 .01616 Mdot
.81521 .0162 Mdot
.81525 .01624 Mdot
.8153 .01628 Mdot
.81535 .01632 Mdot
.8154 .01636 Mdot
.81544 .0164 Mdot
.81549 .01645 Mdot
.81554 .01649 Mdot
.81559 .01653 Mdot
.81564 .01658 Mdot
.81568 .01662 Mdot
.81573 .01667 Mdot
.81578 .01671 Mdot
.81583 .01676 Mdot
.81587 .01681 Mdot
.81592 .01685 Mdot
.81597 .0169 Mdot
.81602 .01695 Mdot
.81606 .017 Mdot
.81611 .01705 Mdot
.81616 .0171 Mdot
.81621 .01715 Mdot
.81625 .0172 Mdot
.8163 .01725 Mdot
.81635 .01731 Mdot
.8164 .01736 Mdot
.81644 .01741 Mdot
.81649 .01747 Mdot
.81654 .01752 Mdot
.81659 .01758 Mdot
.81664 .01763 Mdot
.81668 .01769 Mdot
.81673 .01775 Mdot
.81678 .0178 Mdot
.81683 .01786 Mdot
.81687 .01792 Mdot
.81692 .01798 Mdot
.81697 .01804 Mdot
.81702 .0181 Mdot
.81706 .01816 Mdot
.81711 .01822 Mdot
.81716 .01828 Mdot
.81721 .01834 Mdot
.81725 .0184 Mdot
.8173 .01847 Mdot
.81735 .01853 Mdot
.8174 .0186 Mdot
.81744 .01866 Mdot
.81749 .01873 Mdot
.81754 .01879 Mdot
.81759 .01886 Mdot
.81763 .01892 Mdot
.81768 .01899 Mdot
.81773 .01906 Mdot
.81778 .01913 Mdot
.81783 .0192 Mdot
.81787 .01927 Mdot
.81792 .01934 Mdot
.81797 .01941 Mdot
.81802 .01948 Mdot
.81806 .01955 Mdot
.81811 .01962 Mdot
.81816 .0197 Mdot
.81821 .01977 Mdot
.81825 .01984 Mdot
.8183 .01992 Mdot
.81835 .01999 Mdot
.8184 .02007 Mdot
.81844 .02014 Mdot
.81849 .02022 Mdot
.81854 .0203 Mdot
.81859 .02037 Mdot
.81863 .02045 Mdot
.81868 .02053 Mdot
.81873 .02061 Mdot
.81878 .02069 Mdot
.81883 .02077 Mdot
.81887 .02085 Mdot
.81892 .02093 Mdot
.81897 .02101 Mdot
.81902 .0211 Mdot
.81906 .02118 Mdot
.81911 .02126 Mdot
.81916 .02135 Mdot
.81921 .02143 Mdot
.81925 .02151 Mdot
.8193 .0216 Mdot
.81935 .02169 Mdot
.8194 .02177 Mdot
.81944 .02186 Mdot
.81949 .02195 Mdot
.81954 .02204 Mdot
.81959 .02212 Mdot
.81963 .02221 Mdot
.81968 .0223 Mdot
.81973 .02239 Mdot
.81978 .02248 Mdot
.81983 .02257 Mdot
.81987 .02267 Mdot
.81992 .02276 Mdot
.81997 .02285 Mdot
.82002 .02294 Mdot
.82006 .02304 Mdot
.82011 .02313 Mdot
.82016 .02323 Mdot
.82021 .02332 Mdot
.82025 .02342 Mdot
.8203 .02352 Mdot
.82035 .02361 Mdot
.8204 .02371 Mdot
.82044 .02381 Mdot
.82049 .02391 Mdot
.82054 .02401 Mdot
.82059 .02411 Mdot
.82063 .02421 Mdot
.82068 .02431 Mdot
.82073 .02441 Mdot
.82078 .02451 Mdot
.82083 .02461 Mdot
.82087 .02471 Mdot
.82092 .02482 Mdot
.82097 .02492 Mdot
.82102 .02502 Mdot
.82106 .02513 Mdot
.82111 .02523 Mdot
.82116 .02534 Mdot
.82121 .02545 Mdot
.82125 .02555 Mdot
.8213 .02566 Mdot
.82135 .02577 Mdot
.8214 .02588 Mdot
.82144 .02599 Mdot
.82149 .0261 Mdot
.82154 .02621 Mdot
.82159 .02632 Mdot
.82163 .02643 Mdot
.82168 .02654 Mdot
.82173 .02665 Mdot
.82178 .02676 Mdot
.82182 .02688 Mdot
.82187 .02699 Mdot
.82192 .02711 Mdot
.82197 .02722 Mdot
.82202 .02734 Mdot
.82206 .02745 Mdot
.82211 .02757 Mdot
.82216 .02769 Mdot
.82221 .0278 Mdot
.82225 .02792 Mdot
.8223 .02804 Mdot
.82235 .02816 Mdot
.8224 .02828 Mdot
.82244 .0284 Mdot
.82249 .02852 Mdot
.82254 .02864 Mdot
.82259 .02876 Mdot
.82263 .02888 Mdot
.82268 .02901 Mdot
.82273 .02913 Mdot
.82278 .02925 Mdot
.82282 .02938 Mdot
.82287 .0295 Mdot
.82292 .02963 Mdot
.82297 .02975 Mdot
.82302 .02988 Mdot
.82306 .03001 Mdot
.82311 .03013 Mdot
.82316 .03026 Mdot
.82321 .03039 Mdot
.82325 .03052 Mdot
.8233 .03065 Mdot
.82335 .03078 Mdot
.8234 .03091 Mdot
.82344 .03104 Mdot
.82349 .03117 Mdot
.82354 .0313 Mdot
.82359 .03143 Mdot
.82363 .03157 Mdot
.82368 .0317 Mdot
.82373 .03183 Mdot
.82378 .03197 Mdot
.82382 .0321 Mdot
.82387 .03224 Mdot
.82392 .03238 Mdot
.82397 .03251 Mdot
.82402 .03265 Mdot
.82406 .03279 Mdot
.82411 .03292 Mdot
.82416 .03306 Mdot
.82421 .0332 Mdot
.82425 .03334 Mdot
.8243 .03348 Mdot
.82435 .03362 Mdot
.8244 .03376 Mdot
.82444 .03391 Mdot
.82449 .03405 Mdot
.82454 .03419 Mdot
.82459 .03433 Mdot
.82463 .03448 Mdot
.82468 .03462 Mdot
.82473 .03477 Mdot
.82478 .03491 Mdot
.82482 .03506 Mdot
.82487 .0352 Mdot
.82492 .03535 Mdot
.82497 .0355 Mdot
.82502 .03564 Mdot
.82506 .03579 Mdot
.82511 .03594 Mdot
.82516 .03609 Mdot
.82521 .03624 Mdot
.82525 .03639 Mdot
.8253 .03654 Mdot
.82535 .03669 Mdot
.8254 .03684 Mdot
.82544 .037 Mdot
.82549 .03715 Mdot
.82554 .0373 Mdot
.82559 .03746 Mdot
.82563 .03761 Mdot
.82568 .03777 Mdot
.82573 .03792 Mdot
.82578 .03808 Mdot
.82582 .03823 Mdot
.82587 .03839 Mdot
.82592 .03855 Mdot
.82597 .0387 Mdot
.82602 .03886 Mdot
.82606 .03902 Mdot
.82611 .03918 Mdot
.82616 .03934 Mdot
.82621 .0395 Mdot
.82625 .03966 Mdot
.8263 .03982 Mdot
.82635 .03999 Mdot
.8264 .04015 Mdot
.82644 .04031 Mdot
.82649 .04048 Mdot
.82654 .04064 Mdot
.82659 .0408 Mdot
.82663 .04097 Mdot
.82668 .04113 Mdot
.82673 .0413 Mdot
.82678 .04147 Mdot
.82682 .04163 Mdot
.82687 .0418 Mdot
.82692 .04197 Mdot
.82697 .04214 Mdot
.82701 .04231 Mdot
.82706 .04248 Mdot
.82711 .04265 Mdot
.82716 .04282 Mdot
.82721 .04299 Mdot
.82725 .04316 Mdot
.8273 .04333 Mdot
.82735 .0435 Mdot
.8274 .04368 Mdot
.82744 .04385 Mdot
.82749 .04402 Mdot
.82754 .0442 Mdot
.82759 .04437 Mdot
.82763 .04455 Mdot
.82768 .04473 Mdot
.82773 .0449 Mdot
.82778 .04508 Mdot
.82782 .04526 Mdot
.82787 .04543 Mdot
.82792 .04561 Mdot
.82797 .04579 Mdot
.82801 .04597 Mdot
.82806 .04615 Mdot
.82811 .04633 Mdot
.82816 .04651 Mdot
.82821 .04669 Mdot
.82825 .04688 Mdot
.8283 .04706 Mdot
.82835 .04724 Mdot
.8284 .04742 Mdot
.82844 .04761 Mdot
.82849 .04779 Mdot
.82854 .04798 Mdot
.82859 .04816 Mdot
.82863 .04835 Mdot
.82868 .04854 Mdot
.82873 .04872 Mdot
.82878 .04891 Mdot
.82882 .0491 Mdot
.82887 .04929 Mdot
.82892 .04947 Mdot
.82897 .04966 Mdot
.82901 .04985 Mdot
.82906 .05004 Mdot
.82911 .05023 Mdot
.82916 .05043 Mdot
.82921 .05062 Mdot
.82925 .05081 Mdot
.8293 .051 Mdot
.82935 .05119 Mdot
.8294 .05139 Mdot
.82944 .05158 Mdot
.82949 .05178 Mdot
.82954 .05197 Mdot
.82959 .05217 Mdot
.82963 .05236 Mdot
.82968 .05256 Mdot
.82973 .05276 Mdot
.82978 .05295 Mdot
.82982 .05315 Mdot
.82987 .05335 Mdot
.82992 .05355 Mdot
.82997 .05375 Mdot
.83001 .05395 Mdot
.83006 .05415 Mdot
.83011 .05435 Mdot
.83016 .05455 Mdot
.83021 .05475 Mdot
.83025 .05495 Mdot
.8303 .05516 Mdot
.83035 .05536 Mdot
.8304 .05556 Mdot
.83044 .05577 Mdot
.83049 .05597 Mdot
.83054 .05617 Mdot
.83059 .05638 Mdot
.83063 .05659 Mdot
.83068 .05679 Mdot
.83073 .057 Mdot
.83078 .05721 Mdot
.83082 .05741 Mdot
.83087 .05762 Mdot
.83092 .05783 Mdot
.83097 .05804 Mdot
.83101 .05825 Mdot
.83106 .05846 Mdot
.83111 .05867 Mdot
.83116 .05888 Mdot
.8312 .05909 Mdot
.83125 .05931 Mdot
.8313 .05952 Mdot
.83135 .05973 Mdot
.8314 .05994 Mdot
.83144 .06016 Mdot
.83149 .06037 Mdot
.83154 .06059 Mdot
.83159 .0608 Mdot
.83163 .06102 Mdot
.83168 .06123 Mdot
.83173 .06145 Mdot
.83178 .06167 Mdot
.83182 .06189 Mdot
.83187 .0621 Mdot
.83192 .06232 Mdot
.83197 .06254 Mdot
.83201 .06276 Mdot
.83206 .06298 Mdot
.83211 .0632 Mdot
.83216 .06342 Mdot
.8322 .06364 Mdot
.83225 .06386 Mdot
.8323 .06409 Mdot
.83235 .06431 Mdot
.8324 .06453 Mdot
.83244 .06476 Mdot
.83249 .06498 Mdot
.83254 .06521 Mdot
.83259 .06543 Mdot
.83263 .06566 Mdot
.83268 .06588 Mdot
.83273 .06611 Mdot
.83278 .06634 Mdot
.83282 .06656 Mdot
.83287 .06679 Mdot
.83292 .06702 Mdot
.83297 .06725 Mdot
.83301 .06748 Mdot
.83306 .06771 Mdot
.83311 .06794 Mdot
.83316 .06817 Mdot
.8332 .0684 Mdot
.83325 .06863 Mdot
.8333 .06886 Mdot
.83335 .0691 Mdot
.8334 .06933 Mdot
.83344 .06956 Mdot
.83349 .0698 Mdot
.83354 .07003 Mdot
.83359 .07026 Mdot
.83363 .0705 Mdot
.83368 .07074 Mdot
.83373 .07097 Mdot
.83378 .07121 Mdot
.83382 .07145 Mdot
.83387 .07168 Mdot
.83392 .07192 Mdot
.83397 .07216 Mdot
.83401 .0724 Mdot
.83406 .07264 Mdot
.83411 .07288 Mdot
.83416 .07312 Mdot
.8342 .07336 Mdot
.83425 .0736 Mdot
.8343 .07384 Mdot
.83435 .07408 Mdot
.8344 .07432 Mdot
.83444 .07457 Mdot
.83449 .07481 Mdot
.83454 .07505 Mdot
.83459 .0753 Mdot
.83463 .07554 Mdot
.83468 .07579 Mdot
.83473 .07603 Mdot
.83478 .07628 Mdot
.83482 .07652 Mdot
.83487 .07677 Mdot
.83492 .07702 Mdot
.83497 .07726 Mdot
.83501 .07751 Mdot
.83506 .07776 Mdot
.83511 .07801 Mdot
.83516 .07826 Mdot
.8352 .07851 Mdot
.83525 .07876 Mdot
.8353 .07901 Mdot
.83535 .07926 Mdot
.8354 .07951 Mdot
.83544 .07976 Mdot
.83549 .08002 Mdot
.83554 .08027 Mdot
.83559 .08052 Mdot
.83563 .08078 Mdot
.83568 .08103 Mdot
.83573 .08128 Mdot
.83578 .08154 Mdot
.83582 .08179 Mdot
.83587 .08205 Mdot
.83592 .08231 Mdot
.83597 .08256 Mdot
.83601 .08282 Mdot
.83606 .08308 Mdot
.83611 .08334 Mdot
.83616 .08359 Mdot
.8362 .08385 Mdot
.83625 .08411 Mdot
.8363 .08437 Mdot
.83635 .08463 Mdot
.83639 .08489 Mdot
.83644 .08515 Mdot
.83649 .08541 Mdot
.83654 .08568 Mdot
.83659 .08594 Mdot
.83663 .0862 Mdot
.83668 .08646 Mdot
.83673 .08673 Mdot
.83678 .08699 Mdot
.83682 .08725 Mdot
.83687 .08752 Mdot
.83692 .08778 Mdot
.83697 .08805 Mdot
.83701 .08832 Mdot
.83706 .08858 Mdot
.83711 .08885 Mdot
.83716 .08912 Mdot
.8372 .08938 Mdot
.83725 .08965 Mdot
.8373 .08992 Mdot
.83735 .09019 Mdot
.83739 .09046 Mdot
.83744 .09073 Mdot
.83749 .091 Mdot
.83754 .09127 Mdot
.83759 .09154 Mdot
.83763 .09181 Mdot
.83768 .09208 Mdot
.83773 .09236 Mdot
.83778 .09263 Mdot
.83782 .0929 Mdot
.83787 .09317 Mdot
.83792 .09345 Mdot
.83797 .09372 Mdot
.83801 .094 Mdot
.83806 .09427 Mdot
.83811 .09455 Mdot
.83816 .09482 Mdot
.8382 .0951 Mdot
.83825 .09538 Mdot
.8383 .09565 Mdot
.83835 .09593 Mdot
.83839 .09621 Mdot
.83844 .09649 Mdot
.83849 .09677 Mdot
.83854 .09705 Mdot
.83859 .09733 Mdot
.83863 .09761 Mdot
.83868 .09789 Mdot
.83873 .09817 Mdot
.83878 .09845 Mdot
.83882 .09873 Mdot
.83887 .09901 Mdot
.83892 .0993 Mdot
.83897 .09958 Mdot
.83901 .09986 Mdot
.83906 .10015 Mdot
.83911 .10043 Mdot
.83916 .10072 Mdot
.8392 .101 Mdot
.83925 .10129 Mdot
.8393 .10157 Mdot
.83935 .10186 Mdot
.83939 .10214 Mdot
.83944 .10243 Mdot
.83949 .10272 Mdot
.83954 .10301 Mdot
.83959 .10329 Mdot
.83963 .10358 Mdot
.83968 .10387 Mdot
.83973 .10416 Mdot
.83978 .10445 Mdot
.83982 .10474 Mdot
.83987 .10503 Mdot
.83992 .10532 Mdot
.83997 .10562 Mdot
.84001 .10591 Mdot
.84006 .1062 Mdot
.84011 .10649 Mdot
.84016 .10679 Mdot
.8402 .10708 Mdot
.84025 .10737 Mdot
.8403 .10767 Mdot
.84035 .10796 Mdot
.84039 .10826 Mdot
.84044 .10855 Mdot
.84049 .10885 Mdot
.84054 .10914 Mdot
.84058 .10944 Mdot
.84063 .10974 Mdot
.84068 .11004 Mdot
.84073 .11033 Mdot
.84078 .11063 Mdot
.84082 .11093 Mdot
.84087 .11123 Mdot
.84092 .11153 Mdot
.84097 .11183 Mdot
.84101 .11213 Mdot
.84106 .11243 Mdot
.84111 .11273 Mdot
.84116 .11303 Mdot
.8412 .11333 Mdot
.84125 .11363 Mdot
.8413 .11394 Mdot
.84135 .11424 Mdot
.84139 .11454 Mdot
.84144 .11484 Mdot
.84149 .11515 Mdot
.84154 .11545 Mdot
.84158 .11576 Mdot
.84163 .11606 Mdot
.84168 .11637 Mdot
.84173 .11667 Mdot
.84178 .11698 Mdot
.84182 .11729 Mdot
.84187 .11759 Mdot
.84192 .1179 Mdot
.84197 .11821 Mdot
.84201 .11851 Mdot
.84206 .11882 Mdot
.84211 .11913 Mdot
.84216 .11944 Mdot
.8422 .11975 Mdot
.84225 .12006 Mdot
.8423 .12037 Mdot
.84235 .12068 Mdot
.84239 .12099 Mdot
.84244 .1213 Mdot
.84249 .12161 Mdot
.84254 .12192 Mdot
.84258 .12224 Mdot
.84263 .12255 Mdot
.84268 .12286 Mdot
.84273 .12317 Mdot
.84278 .12349 Mdot
.84282 .1238 Mdot
.84287 .12412 Mdot
.84292 .12443 Mdot
.84297 .12475 Mdot
.84301 .12506 Mdot
.84306 .12538 Mdot
.84311 .12569 Mdot
.84316 .12601 Mdot
.8432 .12633 Mdot
.84325 .12664 Mdot
.8433 .12696 Mdot
.84335 .12728 Mdot
.84339 .1276 Mdot
.84344 .12792 Mdot
.84349 .12824 Mdot
.84354 .12855 Mdot
.84358 .12887 Mdot
.84363 .12919 Mdot
.84368 .12951 Mdot
.84373 .12984 Mdot
.84378 .13016 Mdot
.84382 .13048 Mdot
.84387 .1308 Mdot
.84392 .13112 Mdot
.84397 .13144 Mdot
.84401 .13177 Mdot
.84406 .13209 Mdot
.84411 .13241 Mdot
.84416 .13274 Mdot
.8442 .13306 Mdot
.84425 .13338 Mdot
.8443 .13371 Mdot
.84435 .13403 Mdot
.84439 .13436 Mdot
.84444 .13469 Mdot
.84449 .13501 Mdot
.84454 .13534 Mdot
.84458 .13566 Mdot
.84463 .13599 Mdot
.84468 .13632 Mdot
.84473 .13665 Mdot
.84478 .13697 Mdot
.84482 .1373 Mdot
.84487 .13763 Mdot
.84492 .13796 Mdot
.84497 .13829 Mdot
.84501 .13862 Mdot
.84506 .13895 Mdot
.84511 .13928 Mdot
.84516 .13961 Mdot
.8452 .13994 Mdot
.84525 .14027 Mdot
.8453 .1406 Mdot
.84535 .14094 Mdot
.84539 .14127 Mdot
.84544 .1416 Mdot
.84549 .14193 Mdot
.84554 .14227 Mdot
.84558 .1426 Mdot
.84563 .14293 Mdot
.84568 .14327 Mdot
.84573 .1436 Mdot
.84577 .14394 Mdot
.84582 .14427 Mdot
.84587 .14461 Mdot
.84592 .14494 Mdot
.84597 .14528 Mdot
.84601 .14562 Mdot
.84606 .14595 Mdot
.84611 .14629 Mdot
.84616 .14663 Mdot
.8462 .14696 Mdot
.84625 .1473 Mdot
.8463 .14764 Mdot
.84635 .14798 Mdot
.84639 .14832 Mdot
.84644 .14866 Mdot
.84649 .149 Mdot
.84654 .14934 Mdot
.84658 .14968 Mdot
.84663 .15002 Mdot
.84668 .15036 Mdot
.84673 .1507 Mdot
.84677 .15104 Mdot
.84682 .15138 Mdot
.84687 .15172 Mdot
.84692 .15207 Mdot
.84697 .15241 Mdot
.84701 .15275 Mdot
.84706 .1531 Mdot
.84711 .15344 Mdot
.84716 .15378 Mdot
.8472 .15413 Mdot
.84725 .15447 Mdot
.8473 .15482 Mdot
.84735 .15516 Mdot
.84739 .15551 Mdot
.84744 .15585 Mdot
.84749 .1562 Mdot
.84754 .15655 Mdot
.84758 .15689 Mdot
.84763 .15724 Mdot
.84768 .15759 Mdot
.84773 .15793 Mdot
.84777 .15828 Mdot
.84782 .15863 Mdot
.84787 .15898 Mdot
.84792 .15933 Mdot
.84797 .15968 Mdot
.84801 .16003 Mdot
.84806 .16037 Mdot
.84811 .16072 Mdot
.84816 .16107 Mdot
.8482 .16142 Mdot
.84825 .16178 Mdot
.8483 .16213 Mdot
.84835 .16248 Mdot
.84839 .16283 Mdot
.84844 .16318 Mdot
.84849 .16353 Mdot
.84854 .16389 Mdot
.84858 .16424 Mdot
.84863 .16459 Mdot
.84868 .16494 Mdot
.84873 .1653 Mdot
.84877 .16565 Mdot
.84882 .16601 Mdot
.84887 .16636 Mdot
.84892 .16671 Mdot
.84897 .16707 Mdot
.84901 .16743 Mdot
.84906 .16778 Mdot
.84911 .16814 Mdot
.84916 .16849 Mdot
.8492 .16885 Mdot
.84925 .16921 Mdot
.8493 .16956 Mdot
.84935 .16992 Mdot
.84939 .17028 Mdot
.84944 .17064 Mdot
.84949 .17099 Mdot
.84954 .17135 Mdot
.84958 .17171 Mdot
.84963 .17207 Mdot
.84968 .17243 Mdot
.84973 .17279 Mdot
.84977 .17315 Mdot
.84982 .17351 Mdot
.84987 .17387 Mdot
.84992 .17423 Mdot
.84997 .17459 Mdot
.85001 .17495 Mdot
.85006 .17531 Mdot
.85011 .17567 Mdot
.85016 .17603 Mdot
.8502 .1764 Mdot
.85025 .17676 Mdot
.8503 .17712 Mdot
.85035 .17748 Mdot
.85039 .17785 Mdot
.85044 .17821 Mdot
.85049 .17857 Mdot
.85054 .17894 Mdot
.85058 .1793 Mdot
.85063 .17967 Mdot
.85068 .18003 Mdot
.85073 .1804 Mdot
.85077 .18076 Mdot
.85082 .18113 Mdot
.85087 .18149 Mdot
.85092 .18186 Mdot
.85096 .18222 Mdot
.85101 .18259 Mdot
.85106 .18296 Mdot
.85111 .18332 Mdot
.85116 .18369 Mdot
.8512 .18406 Mdot
.85125 .18443 Mdot
.8513 .18479 Mdot
.85135 .18516 Mdot
.85139 .18553 Mdot
.85144 .1859 Mdot
.85149 .18627 Mdot
.85154 .18664 Mdot
.85158 .18701 Mdot
.85163 .18738 Mdot
.85168 .18775 Mdot
.85173 .18812 Mdot
.85177 .18849 Mdot
.85182 .18886 Mdot
.85187 .18923 Mdot
.85192 .1896 Mdot
.85196 .18997 Mdot
.85201 .19034 Mdot
.85206 .19071 Mdot
.85211 .19108 Mdot
.85216 .19146 Mdot
.8522 .19183 Mdot
.85225 .1922 Mdot
.8523 .19257 Mdot
.85235 .19295 Mdot
.85239 .19332 Mdot
.85244 .19369 Mdot
.85249 .19407 Mdot
.85254 .19444 Mdot
.85258 .19482 Mdot
.85263 .19519 Mdot
.85268 .19556 Mdot
.85273 .19594 Mdot
.85277 .19631 Mdot
.85282 .19669 Mdot
.85287 .19707 Mdot
.85292 .19744 Mdot
.85296 .19782 Mdot
.85301 .19819 Mdot
.85306 .19857 Mdot
.85311 .19895 Mdot
.85316 .19932 Mdot
.8532 .1997 Mdot
.85325 .20008 Mdot
.8533 .20045 Mdot
.85335 .20083 Mdot
.85339 .20121 Mdot
.85344 .20159 Mdot
.85349 .20197 Mdot
.85354 .20234 Mdot
.85358 .20272 Mdot
.85363 .2031 Mdot
.85368 .20348 Mdot
.85373 .20386 Mdot
.85377 .20424 Mdot
.85382 .20462 Mdot
.85387 .205 Mdot
.85392 .20538 Mdot
.85396 .20576 Mdot
.85401 .20614 Mdot
.85406 .20652 Mdot
.85411 .2069 Mdot
.85416 .20728 Mdot
.8542 .20766 Mdot
.85425 .20805 Mdot
.8543 .20843 Mdot
.85435 .20881 Mdot
.85439 .20919 Mdot
.85444 .20957 Mdot
.85449 .20996 Mdot
.85454 .21034 Mdot
.85458 .21072 Mdot
.85463 .21111 Mdot
.85468 .21149 Mdot
.85473 .21187 Mdot
.85477 .21226 Mdot
.85482 .21264 Mdot
.85487 .21302 Mdot
.85492 .21341 Mdot
.85496 .21379 Mdot
.85501 .21418 Mdot
.85506 .21456 Mdot
.85511 .21495 Mdot
.85515 .21533 Mdot
.8552 .21572 Mdot
.85525 .21611 Mdot
.8553 .21649 Mdot
.85535 .21688 Mdot
.85539 .21726 Mdot
.85544 .21765 Mdot
.85549 .21804 Mdot
.85554 .21842 Mdot
.85558 .21881 Mdot
.85563 .2192 Mdot
.85568 .21958 Mdot
.85573 .21997 Mdot
.85577 .22036 Mdot
.85582 .22075 Mdot
.85587 .22114 Mdot
.85592 .22152 Mdot
.85596 .22191 Mdot
.85601 .2223 Mdot
.85606 .22269 Mdot
.85611 .22308 Mdot
.85615 .22347 Mdot
.8562 .22386 Mdot
.85625 .22425 Mdot
.8563 .22463 Mdot
.85635 .22502 Mdot
.85639 .22541 Mdot
.85644 .2258 Mdot
.85649 .22619 Mdot
.85654 .22658 Mdot
.85658 .22698 Mdot
.85663 .22737 Mdot
.85668 .22776 Mdot
.85673 .22815 Mdot
.85677 .22854 Mdot
.85682 .22893 Mdot
.85687 .22932 Mdot
.85692 .22971 Mdot
.85696 .2301 Mdot
.85701 .2305 Mdot
.85706 .23089 Mdot
.85711 .23128 Mdot
.85715 .23167 Mdot
.8572 .23207 Mdot
.85725 .23246 Mdot
.8573 .23285 Mdot
.85735 .23324 Mdot
.85739 .23364 Mdot
.85744 .23403 Mdot
.85749 .23442 Mdot
.85754 .23482 Mdot
.85758 .23521 Mdot
.85763 .23561 Mdot
.85768 .236 Mdot
.85773 .23639 Mdot
.85777 .23679 Mdot
.85782 .23718 Mdot
.85787 .23758 Mdot
.85792 .23797 Mdot
.85796 .23837 Mdot
.85801 .23876 Mdot
.85806 .23916 Mdot
.85811 .23955 Mdot
.85815 .23995 Mdot
.8582 .24035 Mdot
.85825 .24074 Mdot
.8583 .24114 Mdot
.85835 .24153 Mdot
.85839 .24193 Mdot
.85844 .24233 Mdot
.85849 .24272 Mdot
.85854 .24312 Mdot
.85858 .24352 Mdot
.85863 .24391 Mdot
.85868 .24431 Mdot
.85873 .24471 Mdot
.85877 .24511 Mdot
.85882 .2455 Mdot
.85887 .2459 Mdot
.85892 .2463 Mdot
.85896 .2467 Mdot
.85901 .2471 Mdot
.85906 .2475 Mdot
.85911 .24789 Mdot
.85915 .24829 Mdot
.8592 .24869 Mdot
.85925 .24909 Mdot
.8593 .24949 Mdot
.85935 .24989 Mdot
.85939 .25029 Mdot
.85944 .25069 Mdot
.85949 .25109 Mdot
.85954 .25149 Mdot
.85958 .25189 Mdot
.85963 .25229 Mdot
.85968 .25269 Mdot
.85973 .25309 Mdot
.85977 .25349 Mdot
.85982 .25389 Mdot
.85987 .25429 Mdot
.85992 .25469 Mdot
.85996 .25509 Mdot
.86001 .25549 Mdot
.86006 .25589 Mdot
.86011 .25629 Mdot
.86015 .25669 Mdot
.8602 .25709 Mdot
.86025 .2575 Mdot
.8603 .2579 Mdot
.86034 .2583 Mdot
.86039 .2587 Mdot
.86044 .2591 Mdot
.86049 .2595 Mdot
.86054 .25991 Mdot
.86058 .26031 Mdot
.86063 .26071 Mdot
.86068 .26111 Mdot
.86073 .26152 Mdot
.86077 .26192 Mdot
.86082 .26232 Mdot
.86087 .26272 Mdot
.86092 .26313 Mdot
.86096 .26353 Mdot
.86101 .26393 Mdot
.86106 .26434 Mdot
.86111 .26474 Mdot
.86115 .26514 Mdot
.8612 .26555 Mdot
.86125 .26595 Mdot
.8613 .26635 Mdot
.86134 .26676 Mdot
.86139 .26716 Mdot
.86144 .26756 Mdot
.86149 .26797 Mdot
.86154 .26837 Mdot
.86158 .26878 Mdot
.86163 .26918 Mdot
.86168 .26958 Mdot
.86173 .26999 Mdot
.86177 .27039 Mdot
.86182 .2708 Mdot
.86187 .2712 Mdot
.86192 .27161 Mdot
.86196 .27201 Mdot
.86201 .27242 Mdot
.86206 .27282 Mdot
.86211 .27323 Mdot
.86215 .27363 Mdot
.8622 .27404 Mdot
.86225 .27444 Mdot
.8623 .27485 Mdot
.86234 .27525 Mdot
.86239 .27566 Mdot
.86244 .27606 Mdot
.86249 .27647 Mdot
.86254 .27687 Mdot
.86258 .27728 Mdot
.86263 .27769 Mdot
.86268 .27809 Mdot
.86273 .2785 Mdot
.86277 .2789 Mdot
.86282 .27931 Mdot
.86287 .27972 Mdot
.86292 .28012 Mdot
.86296 .28053 Mdot
.86301 .28093 Mdot
.86306 .28134 Mdot
.86311 .28175 Mdot
.86315 .28215 Mdot
.8632 .28256 Mdot
.86325 .28297 Mdot
.8633 .28337 Mdot
.86334 .28378 Mdot
.86339 .28419 Mdot
.86344 .28459 Mdot
.86349 .285 Mdot
.86354 .28541 Mdot
.86358 .28582 Mdot
.86363 .28622 Mdot
.86368 .28663 Mdot
.86373 .28704 Mdot
.86377 .28744 Mdot
.86382 .28785 Mdot
.86387 .28826 Mdot
.86392 .28867 Mdot
.86396 .28908 Mdot
.86401 .28948 Mdot
.86406 .28989 Mdot
.86411 .2903 Mdot
.86415 .29071 Mdot
.8642 .29111 Mdot
.86425 .29152 Mdot
.8643 .29193 Mdot
.86434 .29234 Mdot
.86439 .29274 Mdot
.86444 .29315 Mdot
.86449 .29356 Mdot
.86453 .29397 Mdot
.86458 .29438 Mdot
.86463 .29478 Mdot
.86468 .29519 Mdot
.86473 .2956 Mdot
.86477 .29601 Mdot
.86482 .29642 Mdot
.86487 .29682 Mdot
.86492 .29723 Mdot
.86496 .29764 Mdot
.86501 .29805 Mdot
.86506 .29846 Mdot
.86511 .29886 Mdot
.86515 .29927 Mdot
.8652 .29968 Mdot
.86525 .30009 Mdot
.8653 .3005 Mdot
.86534 .30091 Mdot
.86539 .30131 Mdot
.86544 .30172 Mdot
.86549 .30213 Mdot
.86553 .30254 Mdot
.86558 .30295 Mdot
.86563 .30336 Mdot
.86568 .30376 Mdot
.86573 .30417 Mdot
.86577 .30458 Mdot
.86582 .30499 Mdot
.86587 .3054 Mdot
.86592 .30581 Mdot
.86596 .30622 Mdot
.86601 .30662 Mdot
.86606 .30703 Mdot
.86611 .30744 Mdot
.86615 .30785 Mdot
.8662 .30826 Mdot
.86625 .30867 Mdot
.8663 .30908 Mdot
.86634 .30948 Mdot
.86639 .30989 Mdot
.86644 .3103 Mdot
.86649 .31071 Mdot
.86653 .31112 Mdot
.86658 .31153 Mdot
.86663 .31194 Mdot
.86668 .31234 Mdot
.86673 .31275 Mdot
.86677 .31316 Mdot
.86682 .31357 Mdot
.86687 .31398 Mdot
.86692 .31439 Mdot
.86696 .3148 Mdot
.86701 .3152 Mdot
.86706 .31561 Mdot
.86711 .31602 Mdot
.86715 .31643 Mdot
.8672 .31684 Mdot
.86725 .31725 Mdot
.8673 .31766 Mdot
.86734 .31806 Mdot
.86739 .31847 Mdot
.86744 .31888 Mdot
.86749 .31929 Mdot
.86753 .3197 Mdot
.86758 .32011 Mdot
.86763 .32051 Mdot
.86768 .32092 Mdot
.86773 .32133 Mdot
.86777 .32174 Mdot
.86782 .32215 Mdot
.86787 .32256 Mdot
.86792 .32296 Mdot
.86796 .32337 Mdot
.86801 .32378 Mdot
.86806 .32419 Mdot
.86811 .3246 Mdot
.86815 .32501 Mdot
.8682 .32541 Mdot
.86825 .32582 Mdot
.8683 .32623 Mdot
.86834 .32664 Mdot
.86839 .32705 Mdot
.86844 .32745 Mdot
.86849 .32786 Mdot
.86853 .32827 Mdot
.86858 .32868 Mdot
.86863 .32909 Mdot
.86868 .32949 Mdot
.86873 .3299 Mdot
.86877 .33031 Mdot
.86882 .33072 Mdot
.86887 .33113 Mdot
.86892 .33153 Mdot
.86896 .33194 Mdot
.86901 .33235 Mdot
.86906 .33276 Mdot
.86911 .33317 Mdot
.86915 .33357 Mdot
.8692 .33398 Mdot
.86925 .33439 Mdot
.8693 .3348 Mdot
.86934 .3352 Mdot
.86939 .33561 Mdot
.86944 .33602 Mdot
.86949 .33643 Mdot
.86953 .33683 Mdot
.86958 .33724 Mdot
.86963 .33765 Mdot
.86968 .33805 Mdot
.86972 .33846 Mdot
.86977 .33887 Mdot
.86982 .33928 Mdot
.86987 .33968 Mdot
.86992 .34009 Mdot
.86996 .3405 Mdot
.87001 .3409 Mdot
.87006 .34131 Mdot
.87011 .34172 Mdot
.87015 .34212 Mdot
.8702 .34253 Mdot
.87025 .34293 Mdot
.8703 .34334 Mdot
.87034 .34375 Mdot
.87039 .34415 Mdot
.87044 .34456 Mdot
.87049 .34497 Mdot
.87053 .34537 Mdot
.87058 .34578 Mdot
.87063 .34618 Mdot
.87068 .34659 Mdot
.87072 .347 Mdot
.87077 .3474 Mdot
.87082 .34781 Mdot
.87087 .34821 Mdot
.87092 .34862 Mdot
.87096 .34902 Mdot
.87101 .34943 Mdot
.87106 .34983 Mdot
.87111 .35024 Mdot
.87115 .35065 Mdot
.8712 .35105 Mdot
.87125 .35146 Mdot
.8713 .35186 Mdot
.87134 .35227 Mdot
.87139 .35267 Mdot
.87144 .35308 Mdot
.87149 .35348 Mdot
.87153 .35388 Mdot
.87158 .35429 Mdot
.87163 .35469 Mdot
.87168 .3551 Mdot
.87172 .3555 Mdot
.87177 .35591 Mdot
.87182 .35631 Mdot
.87187 .35672 Mdot
.87192 .35712 Mdot
.87196 .35752 Mdot
.87201 .35793 Mdot
.87206 .35833 Mdot
.87211 .35873 Mdot
.87215 .35914 Mdot
.8722 .35954 Mdot
.87225 .35994 Mdot
.8723 .36035 Mdot
.87234 .36075 Mdot
.87239 .36115 Mdot
.87244 .36156 Mdot
.87249 .36196 Mdot
.87253 .36236 Mdot
.87258 .36277 Mdot
.87263 .36317 Mdot
.87268 .36357 Mdot
.87272 .36397 Mdot
.87277 .36438 Mdot
.87282 .36478 Mdot
.87287 .36518 Mdot
.87292 .36558 Mdot
.87296 .36598 Mdot
.87301 .36639 Mdot
.87306 .36679 Mdot
.87311 .36719 Mdot
.87315 .36759 Mdot
.8732 .36799 Mdot
.87325 .3684 Mdot
.8733 .3688 Mdot
.87334 .3692 Mdot
.87339 .3696 Mdot
.87344 .37 Mdot
.87349 .3704 Mdot
.87353 .3708 Mdot
.87358 .3712 Mdot
.87363 .3716 Mdot
.87368 .372 Mdot
.87372 .37241 Mdot
.87377 .37281 Mdot
.87382 .37321 Mdot
.87387 .37361 Mdot
.87391 .37401 Mdot
.87396 .37441 Mdot
.87401 .37481 Mdot
.87406 .37521 Mdot
.87411 .3756 Mdot
.87415 .376 Mdot
.8742 .3764 Mdot
.87425 .3768 Mdot
.8743 .3772 Mdot
.87434 .3776 Mdot
.87439 .378 Mdot
.87444 .3784 Mdot
.87449 .3788 Mdot
.87453 .37919 Mdot
.87458 .37959 Mdot
.87463 .37999 Mdot
.87468 .38039 Mdot
.87472 .38079 Mdot
.87477 .38118 Mdot
.87482 .38158 Mdot
.87487 .38198 Mdot
.87491 .38238 Mdot
.87496 .38277 Mdot
.87501 .38317 Mdot
.87506 .38357 Mdot
.87511 .38396 Mdot
.87515 .38436 Mdot
.8752 .38476 Mdot
.87525 .38515 Mdot
.8753 .38555 Mdot
.87534 .38595 Mdot
.87539 .38634 Mdot
.87544 .38674 Mdot
.87549 .38713 Mdot
.87553 .38753 Mdot
.87558 .38792 Mdot
.87563 .38832 Mdot
.87568 .38871 Mdot
.87572 .38911 Mdot
.87577 .3895 Mdot
.87582 .3899 Mdot
.87587 .39029 Mdot
.87591 .39069 Mdot
.87596 .39108 Mdot
.87601 .39148 Mdot
.87606 .39187 Mdot
.87611 .39226 Mdot
.87615 .39266 Mdot
.8762 .39305 Mdot
.87625 .39344 Mdot
.8763 .39384 Mdot
.87634 .39423 Mdot
.87639 .39462 Mdot
.87644 .39502 Mdot
.87649 .39541 Mdot
.87653 .3958 Mdot
.87658 .39619 Mdot
.87663 .39659 Mdot
.87668 .39698 Mdot
.87672 .39737 Mdot
.87677 .39776 Mdot
.87682 .39815 Mdot
.87687 .39854 Mdot
.87691 .39893 Mdot
.87696 .39933 Mdot
.87701 .39972 Mdot
.87706 .40011 Mdot
.87711 .4005 Mdot
.87715 .40089 Mdot
.8772 .40128 Mdot
.87725 .40167 Mdot
.8773 .40206 Mdot
.87734 .40245 Mdot
.87739 .40284 Mdot
.87744 .40322 Mdot
.87749 .40361 Mdot
.87753 .404 Mdot
.87758 .40439 Mdot
.87763 .40478 Mdot
.87768 .40517 Mdot
.87772 .40556 Mdot
.87777 .40594 Mdot
.87782 .40633 Mdot
.87787 .40672 Mdot
.87791 .40711 Mdot
.87796 .40749 Mdot
.87801 .40788 Mdot
.87806 .40827 Mdot
.87811 .40865 Mdot
.87815 .40904 Mdot
.8782 .40943 Mdot
.87825 .40981 Mdot
.8783 .4102 Mdot
.87834 .41059 Mdot
.87839 .41097 Mdot
.87844 .41136 Mdot
.87849 .41174 Mdot
.87853 .41213 Mdot
.87858 .41251 Mdot
.87863 .4129 Mdot
.87868 .41328 Mdot
.87872 .41366 Mdot
.87877 .41405 Mdot
.87882 .41443 Mdot
.87887 .41482 Mdot
.87891 .4152 Mdot
.87896 .41558 Mdot
.87901 .41596 Mdot
.87906 .41635 Mdot
.8791 .41673 Mdot
.87915 .41711 Mdot
.8792 .41749 Mdot
.87925 .41788 Mdot
.8793 .41826 Mdot
.87934 .41864 Mdot
.87939 .41902 Mdot
.87944 .4194 Mdot
.87949 .41978 Mdot
.87953 .42016 Mdot
.87958 .42054 Mdot
.87963 .42092 Mdot
.87968 .4213 Mdot
.87972 .42168 Mdot
.87977 .42206 Mdot
.87982 .42244 Mdot
.87987 .42282 Mdot
.87991 .4232 Mdot
.87996 .42358 Mdot
.88001 .42396 Mdot
.88006 .42433 Mdot
.8801 .42471 Mdot
.88015 .42509 Mdot
.8802 .42547 Mdot
.88025 .42585 Mdot
.8803 .42622 Mdot
.88034 .4266 Mdot
.88039 .42698 Mdot
.88044 .42735 Mdot
.88049 .42773 Mdot
.88053 .42811 Mdot
.88058 .42848 Mdot
.88063 .42886 Mdot
.88068 .42923 Mdot
.88072 .42961 Mdot
.88077 .42998 Mdot
.88082 .43036 Mdot
.88087 .43073 Mdot
.88091 .43111 Mdot
.88096 .43148 Mdot
.88101 .43185 Mdot
.88106 .43223 Mdot
.8811 .4326 Mdot
.88115 .43297 Mdot
.8812 .43335 Mdot
.88125 .43372 Mdot
.8813 .43409 Mdot
.88134 .43446 Mdot
.88139 .43484 Mdot
.88144 .43521 Mdot
.88149 .43558 Mdot
.88153 .43595 Mdot
.88158 .43632 Mdot
.88163 .43669 Mdot
.88168 .43706 Mdot
.88172 .43743 Mdot
.88177 .4378 Mdot
.88182 .43817 Mdot
.88187 .43854 Mdot
.88191 .43891 Mdot
.88196 .43928 Mdot
.88201 .43965 Mdot
.88206 .44002 Mdot
.8821 .44038 Mdot
.88215 .44075 Mdot
.8822 .44112 Mdot
.88225 .44149 Mdot
.8823 .44185 Mdot
.88234 .44222 Mdot
.88239 .44259 Mdot
.88244 .44295 Mdot
.88249 .44332 Mdot
.88253 .44369 Mdot
.88258 .44405 Mdot
.88263 .44442 Mdot
.88268 .44478 Mdot
.88272 .44515 Mdot
.88277 .44551 Mdot
.88282 .44588 Mdot
.88287 .44624 Mdot
.88291 .4466 Mdot
.88296 .44697 Mdot
.88301 .44733 Mdot
.88306 .44769 Mdot
.8831 .44806 Mdot
.88315 .44842 Mdot
.8832 .44878 Mdot
.88325 .44914 Mdot
.8833 .4495 Mdot
.88334 .44986 Mdot
.88339 .45023 Mdot
.88344 .45059 Mdot
.88349 .45095 Mdot
.88353 .45131 Mdot
.88358 .45167 Mdot
.88363 .45203 Mdot
.88368 .45239 Mdot
.88372 .45274 Mdot
.88377 .4531 Mdot
.88382 .45346 Mdot
.88387 .45382 Mdot
.88391 .45418 Mdot
.88396 .45454 Mdot
.88401 .45489 Mdot
.88406 .45525 Mdot
.8841 .45561 Mdot
.88415 .45596 Mdot
.8842 .45632 Mdot
.88425 .45668 Mdot
.88429 .45703 Mdot
.88434 .45739 Mdot
.88439 .45774 Mdot
.88444 .4581 Mdot
.88449 .45845 Mdot
.88453 .45881 Mdot
.88458 .45916 Mdot
.88463 .45952 Mdot
.88468 .45987 Mdot
.88472 .46022 Mdot
.88477 .46058 Mdot
.88482 .46093 Mdot
.88487 .46128 Mdot
.88491 .46163 Mdot
.88496 .46199 Mdot
.88501 .46234 Mdot
.88506 .46269 Mdot
.8851 .46304 Mdot
.88515 .46339 Mdot
.8852 .46374 Mdot
.88525 .46409 Mdot
.88529 .46444 Mdot
.88534 .46479 Mdot
.88539 .46514 Mdot
.88544 .46549 Mdot
.88549 .46584 Mdot
.88553 .46619 Mdot
.88558 .46653 Mdot
.88563 .46688 Mdot
.88568 .46723 Mdot
.88572 .46758 Mdot
.88577 .46792 Mdot
.88582 .46827 Mdot
.88587 .46862 Mdot
.88591 .46896 Mdot
.88596 .46931 Mdot
.88601 .46965 Mdot
.88606 .47 Mdot
.8861 .47034 Mdot
.88615 .47069 Mdot
.8862 .47103 Mdot
.88625 .47138 Mdot
.88629 .47172 Mdot
.88634 .47206 Mdot
.88639 .47241 Mdot
.88644 .47275 Mdot
.88649 .47309 Mdot
.88653 .47343 Mdot
.88658 .47378 Mdot
.88663 .47412 Mdot
.88668 .47446 Mdot
.88672 .4748 Mdot
.88677 .47514 Mdot
.88682 .47548 Mdot
.88687 .47582 Mdot
.88691 .47616 Mdot
.88696 .4765 Mdot
.88701 .47684 Mdot
.88706 .47718 Mdot
.8871 .47752 Mdot
.88715 .47785 Mdot
.8872 .47819 Mdot
.88725 .47853 Mdot
.88729 .47887 Mdot
.88734 .4792 Mdot
.88739 .47954 Mdot
.88744 .47987 Mdot
.88749 .48021 Mdot
.88753 .48055 Mdot
.88758 .48088 Mdot
.88763 .48122 Mdot
.88768 .48155 Mdot
.88772 .48188 Mdot
.88777 .48222 Mdot
.88782 .48255 Mdot
.88787 .48288 Mdot
.88791 .48322 Mdot
.88796 .48355 Mdot
.88801 .48388 Mdot
.88806 .48421 Mdot
.8881 .48454 Mdot
.88815 .48487 Mdot
.8882 .4852 Mdot
.88825 .48553 Mdot
.88829 .48586 Mdot
.88834 .48619 Mdot
.88839 .48652 Mdot
.88844 .48685 Mdot
.88848 .48718 Mdot
.88853 .48751 Mdot
.88858 .48784 Mdot
.88863 .48816 Mdot
.88868 .48849 Mdot
.88872 .48882 Mdot
.88877 .48915 Mdot
.88882 .48947 Mdot
.88887 .4898 Mdot
.88891 .49012 Mdot
.88896 .49045 Mdot
.88901 .49077 Mdot
.88906 .4911 Mdot
.8891 .49142 Mdot
.88915 .49175 Mdot
.8892 .49207 Mdot
.88925 .49239 Mdot
.88929 .49272 Mdot
.88934 .49304 Mdot
.88939 .49336 Mdot
.88944 .49368 Mdot
.88948 .494 Mdot
.88953 .49432 Mdot
.88958 .49465 Mdot
.88963 .49497 Mdot
.88968 .49529 Mdot
.88972 .49561 Mdot
.88977 .49592 Mdot
.88982 .49624 Mdot
.88987 .49656 Mdot
.88991 .49688 Mdot
.88996 .4972 Mdot
.89001 .49752 Mdot
.89006 .49783 Mdot
.8901 .49815 Mdot
.89015 .49847 Mdot
.8902 .49878 Mdot
.89025 .4991 Mdot
.89029 .49941 Mdot
.89034 .49973 Mdot
.89039 .50004 Mdot
.89044 .50036 Mdot
.89048 .50067 Mdot
.89053 .50099 Mdot
.89058 .5013 Mdot
.89063 .50161 Mdot
.89068 .50192 Mdot
.89072 .50224 Mdot
.89077 .50255 Mdot
.89082 .50286 Mdot
.89087 .50317 Mdot
.89091 .50348 Mdot
.89096 .50379 Mdot
.89101 .5041 Mdot
.89106 .50441 Mdot
.8911 .50472 Mdot
.89115 .50503 Mdot
.8912 .50534 Mdot
.89125 .50565 Mdot
.89129 .50595 Mdot
.89134 .50626 Mdot
.89139 .50657 Mdot
.89144 .50687 Mdot
.89148 .50718 Mdot
.89153 .50749 Mdot
.89158 .50779 Mdot
.89163 .5081 Mdot
.89168 .5084 Mdot
.89172 .50871 Mdot
.89177 .50901 Mdot
.89182 .50931 Mdot
.89187 .50962 Mdot
.89191 .50992 Mdot
.89196 .51022 Mdot
.89201 .51052 Mdot
.89206 .51083 Mdot
.8921 .51113 Mdot
.89215 .51143 Mdot
.8922 .51173 Mdot
.89225 .51203 Mdot
.89229 .51233 Mdot
.89234 .51263 Mdot
.89239 .51292 Mdot
.89244 .51322 Mdot
.89248 .51352 Mdot
.89253 .51382 Mdot
.89258 .51412 Mdot
.89263 .51441 Mdot
.89268 .51471 Mdot
.89272 .51501 Mdot
.89277 .5153 Mdot
.89282 .5156 Mdot
.89287 .51589 Mdot
.89291 .51619 Mdot
.89296 .51648 Mdot
.89301 .51677 Mdot
.89306 .51707 Mdot
.8931 .51736 Mdot
.89315 .51765 Mdot
.8932 .51794 Mdot
.89325 .51824 Mdot
.89329 .51853 Mdot
.89334 .51882 Mdot
.89339 .51911 Mdot
.89344 .5194 Mdot
.89348 .51969 Mdot
.89353 .51998 Mdot
.89358 .52026 Mdot
.89363 .52055 Mdot
.89367 .52084 Mdot
.89372 .52113 Mdot
.89377 .52142 Mdot
.89382 .5217 Mdot
.89387 .52199 Mdot
.89391 .52227 Mdot
.89396 .52256 Mdot
.89401 .52285 Mdot
.89406 .52313 Mdot
.8941 .52341 Mdot
.89415 .5237 Mdot
.8942 .52398 Mdot
.89425 .52426 Mdot
.89429 .52455 Mdot
.89434 .52483 Mdot
.89439 .52511 Mdot
.89444 .52539 Mdot
.89448 .52567 Mdot
.89453 .52595 Mdot
.89458 .52623 Mdot
.89463 .52651 Mdot
.89467 .52679 Mdot
.89472 .52707 Mdot
.89477 .52735 Mdot
.89482 .52763 Mdot
.89487 .5279 Mdot
.89491 .52818 Mdot
.89496 .52846 Mdot
.89501 .52873 Mdot
.89506 .52901 Mdot
.8951 .52929 Mdot
.89515 .52956 Mdot
.8952 .52983 Mdot
.89525 .53011 Mdot
.89529 .53038 Mdot
.89534 .53066 Mdot
.89539 .53093 Mdot
.89544 .5312 Mdot
.89548 .53147 Mdot
.89553 .53174 Mdot
.89558 .53201 Mdot
.89563 .53229 Mdot
.89567 .53256 Mdot
.89572 .53283 Mdot
.89577 .53309 Mdot
.89582 .53336 Mdot
.89587 .53363 Mdot
.89591 .5339 Mdot
.89596 .53417 Mdot
.89601 .53443 Mdot
.89606 .5347 Mdot
.8961 .53497 Mdot
.89615 .53523 Mdot
.8962 .5355 Mdot
.89625 .53576 Mdot
.89629 .53603 Mdot
.89634 .53629 Mdot
.89639 .53656 Mdot
.89644 .53682 Mdot
.89648 .53708 Mdot
.89653 .53734 Mdot
.89658 .53761 Mdot
.89663 .53787 Mdot
.89667 .53813 Mdot
.89672 .53839 Mdot
.89677 .53865 Mdot
.89682 .53891 Mdot
.89687 .53917 Mdot
.89691 .53943 Mdot
.89696 .53969 Mdot
.89701 .53994 Mdot
.89706 .5402 Mdot
.8971 .54046 Mdot
.89715 .54071 Mdot
.8972 .54097 Mdot
.89725 .54123 Mdot
.89729 .54148 Mdot
.89734 .54174 Mdot
.89739 .54199 Mdot
.89744 .54224 Mdot
.89748 .5425 Mdot
.89753 .54275 Mdot
.89758 .543 Mdot
.89763 .54326 Mdot
.89767 .54351 Mdot
.89772 .54376 Mdot
.89777 .54401 Mdot
.89782 .54426 Mdot
.89786 .54451 Mdot
.89791 .54476 Mdot
.89796 .54501 Mdot
.89801 .54526 Mdot
.89806 .5455 Mdot
.8981 .54575 Mdot
.89815 .546 Mdot
.8982 .54624 Mdot
.89825 .54649 Mdot
.89829 .54674 Mdot
.89834 .54698 Mdot
.89839 .54723 Mdot
.89844 .54747 Mdot
.89848 .54771 Mdot
.89853 .54796 Mdot
.89858 .5482 Mdot
.89863 .54844 Mdot
.89867 .54868 Mdot
.89872 .54893 Mdot
.89877 .54917 Mdot
.89882 .54941 Mdot
.89886 .54965 Mdot
.89891 .54989 Mdot
.89896 .55013 Mdot
.89901 .55036 Mdot
.89906 .5506 Mdot
.8991 .55084 Mdot
.89915 .55108 Mdot
.8992 .55131 Mdot
.89925 .55155 Mdot
.89929 .55179 Mdot
.89934 .55202 Mdot
.89939 .55226 Mdot
.89944 .55249 Mdot
.89948 .55272 Mdot
.89953 .55296 Mdot
.89958 .55319 Mdot
.89963 .55342 Mdot
.89967 .55365 Mdot
.89972 .55388 Mdot
.89977 .55412 Mdot
.89982 .55435 Mdot
.89986 .55458 Mdot
.89991 .55481 Mdot
.89996 .55503 Mdot
.90001 .55526 Mdot
.90006 .55549 Mdot
.9001 .55572 Mdot
.90015 .55594 Mdot
.9002 .55617 Mdot
.90025 .5564 Mdot
.90029 .55662 Mdot
.90034 .55685 Mdot
.90039 .55707 Mdot
.90044 .5573 Mdot
.90048 .55752 Mdot
.90053 .55774 Mdot
.90058 .55797 Mdot
.90063 .55819 Mdot
.90067 .55841 Mdot
.90072 .55863 Mdot
.90077 .55885 Mdot
.90082 .55907 Mdot
.90086 .55929 Mdot
.90091 .55951 Mdot
.90096 .55973 Mdot
.90101 .55995 Mdot
.90106 .56016 Mdot
.9011 .56038 Mdot
.90115 .5606 Mdot
.9012 .56081 Mdot
.90125 .56103 Mdot
.90129 .56125 Mdot
.90134 .56146 Mdot
.90139 .56167 Mdot
.90144 .56189 Mdot
.90148 .5621 Mdot
.90153 .56231 Mdot
.90158 .56253 Mdot
.90163 .56274 Mdot
.90167 .56295 Mdot
.90172 .56316 Mdot
.90177 .56337 Mdot
.90182 .56358 Mdot
.90186 .56379 Mdot
.90191 .564 Mdot
.90196 .5642 Mdot
.90201 .56441 Mdot
.90206 .56462 Mdot
.9021 .56483 Mdot
.90215 .56503 Mdot
.9022 .56524 Mdot
.90225 .56544 Mdot
.90229 .56565 Mdot
.90234 .56585 Mdot
.90239 .56606 Mdot
.90244 .56626 Mdot
.90248 .56646 Mdot
.90253 .56666 Mdot
.90258 .56686 Mdot
.90263 .56707 Mdot
.90267 .56727 Mdot
.90272 .56747 Mdot
.90277 .56767 Mdot
.90282 .56787 Mdot
.90286 .56806 Mdot
.90291 .56826 Mdot
.90296 .56846 Mdot
.90301 .56866 Mdot
.90305 .56885 Mdot
.9031 .56905 Mdot
.90315 .56924 Mdot
.9032 .56944 Mdot
.90325 .56963 Mdot
.90329 .56983 Mdot
.90334 .57002 Mdot
.90339 .57021 Mdot
.90344 .5704 Mdot
.90348 .5706 Mdot
.90353 .57079 Mdot
.90358 .57098 Mdot
.90363 .57117 Mdot
.90367 .57136 Mdot
.90372 .57154 Mdot
.90377 .57173 Mdot
.90382 .57192 Mdot
.90386 .57211 Mdot
.90391 .5723 Mdot
.90396 .57248 Mdot
.90401 .57267 Mdot
.90405 .57285 Mdot
.9041 .57304 Mdot
.90415 .57322 Mdot
.9042 .5734 Mdot
.90425 .57359 Mdot
.90429 .57377 Mdot
.90434 .57395 Mdot
.90439 .57413 Mdot
.90444 .57431 Mdot
.90448 .5745 Mdot
.90453 .57468 Mdot
.90458 .57485 Mdot
.90463 .57503 Mdot
.90467 .57521 Mdot
.90472 .57539 Mdot
.90477 .57557 Mdot
.90482 .57574 Mdot
.90486 .57592 Mdot
.90491 .5761 Mdot
.90496 .57627 Mdot
.90501 .57645 Mdot
.90505 .57662 Mdot
.9051 .57679 Mdot
.90515 .57697 Mdot
.9052 .57714 Mdot
.90525 .57731 Mdot
.90529 .57748 Mdot
.90534 .57765 Mdot
.90539 .57782 Mdot
.90544 .57799 Mdot
.90548 .57816 Mdot
.90553 .57833 Mdot
.90558 .5785 Mdot
.90563 .57867 Mdot
.90567 .57884 Mdot
.90572 .579 Mdot
.90577 .57917 Mdot
.90582 .57934 Mdot
.90586 .5795 Mdot
.90591 .57967 Mdot
.90596 .57983 Mdot
.90601 .57999 Mdot
.90605 .58016 Mdot
.9061 .58032 Mdot
.90615 .58048 Mdot
.9062 .58064 Mdot
.90625 .5808 Mdot
.90629 .58096 Mdot
.90634 .58112 Mdot
.90639 .58128 Mdot
.90644 .58144 Mdot
.90648 .5816 Mdot
.90653 .58176 Mdot
.90658 .58191 Mdot
.90663 .58207 Mdot
.90667 .58223 Mdot
.90672 .58238 Mdot
.90677 .58254 Mdot
.90682 .58269 Mdot
.90686 .58284 Mdot
.90691 .583 Mdot
.90696 .58315 Mdot
.90701 .5833 Mdot
.90705 .58345 Mdot
.9071 .58361 Mdot
.90715 .58376 Mdot
.9072 .58391 Mdot
.90724 .58406 Mdot
.90729 .5842 Mdot
.90734 .58435 Mdot
.90739 .5845 Mdot
.90744 .58465 Mdot
.90748 .58479 Mdot
.90753 .58494 Mdot
.90758 .58509 Mdot
.90763 .58523 Mdot
.90767 .58538 Mdot
.90772 .58552 Mdot
.90777 .58566 Mdot
.90782 .58581 Mdot
.90786 .58595 Mdot
.90791 .58609 Mdot
.90796 .58623 Mdot
.90801 .58637 Mdot
.90805 .58651 Mdot
.9081 .58665 Mdot
.90815 .58679 Mdot
.9082 .58693 Mdot
.90824 .58707 Mdot
.90829 .5872 Mdot
.90834 .58734 Mdot
.90839 .58748 Mdot
.90844 .58761 Mdot
.90848 .58775 Mdot
.90853 .58788 Mdot
.90858 .58801 Mdot
.90863 .58815 Mdot
.90867 .58828 Mdot
.90872 .58841 Mdot
.90877 .58854 Mdot
.90882 .58867 Mdot
.90886 .5888 Mdot
.90891 .58893 Mdot
.90896 .58906 Mdot
.90901 .58919 Mdot
.90905 .58932 Mdot
.9091 .58945 Mdot
.90915 .58957 Mdot
.9092 .5897 Mdot
.90924 .58983 Mdot
.90929 .58995 Mdot
.90934 .59008 Mdot
.90939 .5902 Mdot
.90944 .59032 Mdot
.90948 .59045 Mdot
.90953 .59057 Mdot
.90958 .59069 Mdot
.90963 .59081 Mdot
.90967 .59093 Mdot
.90972 .59105 Mdot
.90977 .59117 Mdot
.90982 .59129 Mdot
.90986 .59141 Mdot
.90991 .59153 Mdot
.90996 .59165 Mdot
.91001 .59176 Mdot
.91005 .59188 Mdot
.9101 .592 Mdot
.91015 .59211 Mdot
.9102 .59222 Mdot
.91024 .59234 Mdot
.91029 .59245 Mdot
.91034 .59257 Mdot
.91039 .59268 Mdot
.91044 .59279 Mdot
.91048 .5929 Mdot
.91053 .59301 Mdot
.91058 .59312 Mdot
.91063 .59323 Mdot
.91067 .59334 Mdot
.91072 .59345 Mdot
.91077 .59356 Mdot
.91082 .59366 Mdot
.91086 .59377 Mdot
.91091 .59388 Mdot
.91096 .59398 Mdot
.91101 .59409 Mdot
.91105 .59419 Mdot
.9111 .59429 Mdot
.91115 .5944 Mdot
.9112 .5945 Mdot
.91124 .5946 Mdot
.91129 .5947 Mdot
.91134 .5948 Mdot
.91139 .5949 Mdot
.91144 .595 Mdot
.91148 .5951 Mdot
.91153 .5952 Mdot
.91158 .5953 Mdot
.91163 .5954 Mdot
.91167 .59549 Mdot
.91172 .59559 Mdot
.91177 .59569 Mdot
.91182 .59578 Mdot
.91186 .59588 Mdot
.91191 .59597 Mdot
.91196 .59606 Mdot
.91201 .59615 Mdot
.91205 .59625 Mdot
.9121 .59634 Mdot
.91215 .59643 Mdot
.9122 .59652 Mdot
.91224 .59661 Mdot
.91229 .5967 Mdot
.91234 .59679 Mdot
.91239 .59687 Mdot
.91243 .59696 Mdot
.91248 .59705 Mdot
.91253 .59713 Mdot
.91258 .59722 Mdot
.91263 .5973 Mdot
.91267 .59739 Mdot
.91272 .59747 Mdot
.91277 .59755 Mdot
.91282 .59764 Mdot
.91286 .59772 Mdot
.91291 .5978 Mdot
.91296 .59788 Mdot
.91301 .59796 Mdot
.91305 .59804 Mdot
.9131 .59812 Mdot
.91315 .5982 Mdot
.9132 .59828 Mdot
.91324 .59835 Mdot
.91329 .59843 Mdot
.91334 .59851 Mdot
.91339 .59858 Mdot
.91343 .59866 Mdot
.91348 .59873 Mdot
.91353 .5988 Mdot
.91358 .59888 Mdot
.91363 .59895 Mdot
.91367 .59902 Mdot
.91372 .59909 Mdot
.91377 .59916 Mdot
.91382 .59923 Mdot
.91386 .5993 Mdot
.91391 .59937 Mdot
.91396 .59944 Mdot
.91401 .59951 Mdot
.91405 .59957 Mdot
.9141 .59964 Mdot
.91415 .59971 Mdot
.9142 .59977 Mdot
.91424 .59984 Mdot
.91429 .5999 Mdot
.91434 .59997 Mdot
.91439 .60003 Mdot
.91443 .60009 Mdot
.91448 .60015 Mdot
.91453 .60021 Mdot
.91458 .60027 Mdot
.91463 .60033 Mdot
.91467 .60039 Mdot
.91472 .60045 Mdot
.91477 .60051 Mdot
.91482 .60057 Mdot
.91486 .60063 Mdot
.91491 .60068 Mdot
.91496 .60074 Mdot
.91501 .60079 Mdot
.91505 .60085 Mdot
.9151 .6009 Mdot
.91515 .60096 Mdot
.9152 .60101 Mdot
.91524 .60106 Mdot
.91529 .60111 Mdot
.91534 .60116 Mdot
.91539 .60121 Mdot
.91543 .60126 Mdot
.91548 .60131 Mdot
.91553 .60136 Mdot
.91558 .60141 Mdot
.91563 .60146 Mdot
.91567 .6015 Mdot
.91572 .60155 Mdot
.91577 .6016 Mdot
.91582 .60164 Mdot
.91586 .60169 Mdot
.91591 .60173 Mdot
.91596 .60177 Mdot
.91601 .60182 Mdot
.91605 .60186 Mdot
.9161 .6019 Mdot
.91615 .60194 Mdot
.9162 .60198 Mdot
.91624 .60202 Mdot
.91629 .60206 Mdot
.91634 .6021 Mdot
.91639 .60214 Mdot
.91643 .60217 Mdot
.91648 .60221 Mdot
.91653 .60225 Mdot
.91658 .60228 Mdot
.91663 .60232 Mdot
.91667 .60235 Mdot
.91672 .60239 Mdot
.91677 .60242 Mdot
.91682 .60245 Mdot
.91686 .60248 Mdot
.91691 .60252 Mdot
.91696 .60255 Mdot
.91701 .60258 Mdot
.91705 .60261 Mdot
.9171 .60264 Mdot
.91715 .60266 Mdot
.9172 .60269 Mdot
.91724 .60272 Mdot
.91729 .60275 Mdot
.91734 .60277 Mdot
.91739 .6028 Mdot
.91743 .60282 Mdot
.91748 .60285 Mdot
.91753 .60287 Mdot
.91758 .60289 Mdot
.91762 .60291 Mdot
.91767 .60294 Mdot
.91772 .60296 Mdot
.91777 .60298 Mdot
.91782 .603 Mdot
.91786 .60302 Mdot
.91791 .60304 Mdot
.91796 .60305 Mdot
.91801 .60307 Mdot
.91805 .60309 Mdot
.9181 .6031 Mdot
.91815 .60312 Mdot
.9182 .60313 Mdot
.91824 .60315 Mdot
.91829 .60316 Mdot
.91834 .60318 Mdot
.91839 .60319 Mdot
.91843 .6032 Mdot
.91848 .60321 Mdot
.91853 .60322 Mdot
.91858 .60323 Mdot
.91862 .60324 Mdot
.91867 .60325 Mdot
.91872 .60326 Mdot
.91877 .60327 Mdot
.91882 .60328 Mdot
.91886 .60328 Mdot
.91891 .60329 Mdot
.91896 .6033 Mdot
.91901 .6033 Mdot
.91905 .6033 Mdot
.9191 .60331 Mdot
.91915 .60331 Mdot
.9192 .60331 Mdot
.91924 .60332 Mdot
.91929 .60332 Mdot
.91934 .60332 Mdot
.91939 .60332 Mdot
.91943 .60332 Mdot
.91948 .60332 Mdot
.91953 .60332 Mdot
.91958 .60331 Mdot
.91962 .60331 Mdot
.91967 .60331 Mdot
.91972 .6033 Mdot
.91977 .6033 Mdot
.91982 .60329 Mdot
.91986 .60329 Mdot
.91991 .60328 Mdot
.91996 .60327 Mdot
.92001 .60327 Mdot
.92005 .60326 Mdot
.9201 .60325 Mdot
.92015 .60324 Mdot
.9202 .60323 Mdot
.92024 .60322 Mdot
.92029 .60321 Mdot
.92034 .6032 Mdot
.92039 .60318 Mdot
.92043 .60317 Mdot
.92048 .60316 Mdot
.92053 .60314 Mdot
.92058 .60313 Mdot
.92062 .60311 Mdot
.92067 .6031 Mdot
.92072 .60308 Mdot
.92077 .60306 Mdot
.92082 .60304 Mdot
.92086 .60303 Mdot
.92091 .60301 Mdot
.92096 .60299 Mdot
.92101 .60297 Mdot
.92105 .60295 Mdot
.9211 .60293 Mdot
.92115 .6029 Mdot
.9212 .60288 Mdot
.92124 .60286 Mdot
.92129 .60283 Mdot
.92134 .60281 Mdot
.92139 .60278 Mdot
.92143 .60276 Mdot
.92148 .60273 Mdot
.92153 .60271 Mdot
.92158 .60268 Mdot
.92162 .60265 Mdot
.92167 .60262 Mdot
.92172 .60259 Mdot
.92177 .60256 Mdot
.92181 .60253 Mdot
.92186 .6025 Mdot
.92191 .60247 Mdot
.92196 .60244 Mdot
.92201 .6024 Mdot
.92205 .60237 Mdot
.9221 .60234 Mdot
.92215 .6023 Mdot
.9222 .60227 Mdot
.92224 .60223 Mdot
.92229 .60219 Mdot
.92234 .60216 Mdot
.92239 .60212 Mdot
.92243 .60208 Mdot
.92248 .60204 Mdot
.92253 .602 Mdot
.92258 .60196 Mdot
.92262 .60192 Mdot
.92267 .60188 Mdot
.92272 .60184 Mdot
.92277 .6018 Mdot
.92281 .60175 Mdot
.92286 .60171 Mdot
.92291 .60167 Mdot
.92296 .60162 Mdot
.92301 .60157 Mdot
.92305 .60153 Mdot
.9231 .60148 Mdot
.92315 .60143 Mdot
.9232 .60139 Mdot
.92324 .60134 Mdot
.92329 .60129 Mdot
.92334 .60124 Mdot
.92339 .60119 Mdot
.92343 .60114 Mdot
.92348 .60109 Mdot
.92353 .60103 Mdot
.92358 .60098 Mdot
.92362 .60093 Mdot
.92367 .60087 Mdot
.92372 .60082 Mdot
.92377 .60076 Mdot
.92381 .60071 Mdot
.92386 .60065 Mdot
.92391 .60059 Mdot
.92396 .60054 Mdot
.92401 .60048 Mdot
.92405 .60042 Mdot
.9241 .60036 Mdot
.92415 .6003 Mdot
.9242 .60024 Mdot
.92424 .60018 Mdot
.92429 .60012 Mdot
.92434 .60005 Mdot
.92439 .59999 Mdot
.92443 .59993 Mdot
.92448 .59986 Mdot
.92453 .5998 Mdot
.92458 .59973 Mdot
.92462 .59967 Mdot
.92467 .5996 Mdot
.92472 .59953 Mdot
.92477 .59946 Mdot
.92481 .5994 Mdot
.92486 .59933 Mdot
.92491 .59926 Mdot
.92496 .59919 Mdot
.92501 .59912 Mdot
.92505 .59904 Mdot
.9251 .59897 Mdot
.92515 .5989 Mdot
.9252 .59883 Mdot
.92524 .59875 Mdot
.92529 .59868 Mdot
.92534 .5986 Mdot
.92539 .59853 Mdot
.92543 .59845 Mdot
.92548 .59837 Mdot
.92553 .5983 Mdot
.92558 .59822 Mdot
.92562 .59814 Mdot
.92567 .59806 Mdot
.92572 .59798 Mdot
.92577 .5979 Mdot
.92581 .59782 Mdot
.92586 .59774 Mdot
.92591 .59765 Mdot
.92596 .59757 Mdot
.92601 .59749 Mdot
.92605 .5974 Mdot
.9261 .59732 Mdot
.92615 .59723 Mdot
.9262 .59715 Mdot
.92624 .59706 Mdot
.92629 .59697 Mdot
.92634 .59688 Mdot
.92639 .5968 Mdot
.92643 .59671 Mdot
.92648 .59662 Mdot
.92653 .59653 Mdot
.92658 .59644 Mdot
.92662 .59634 Mdot
.92667 .59625 Mdot
.92672 .59616 Mdot
.92677 .59607 Mdot
.92681 .59597 Mdot
.92686 .59588 Mdot
.92691 .59578 Mdot
.92696 .59569 Mdot
.927 .59559 Mdot
.92705 .59549 Mdot
.9271 .5954 Mdot
.92715 .5953 Mdot
.9272 .5952 Mdot
.92724 .5951 Mdot
.92729 .595 Mdot
.92734 .5949 Mdot
.92739 .5948 Mdot
.92743 .5947 Mdot
.92748 .5946 Mdot
.92753 .59449 Mdot
.92758 .59439 Mdot
.92762 .59429 Mdot
.92767 .59418 Mdot
.92772 .59408 Mdot
.92777 .59397 Mdot
.92781 .59386 Mdot
.92786 .59376 Mdot
.92791 .59365 Mdot
.92796 .59354 Mdot
.928 .59343 Mdot
.92805 .59332 Mdot
.9281 .59321 Mdot
.92815 .5931 Mdot
.9282 .59299 Mdot
.92824 .59288 Mdot
.92829 .59277 Mdot
.92834 .59265 Mdot
.92839 .59254 Mdot
.92843 .59243 Mdot
.92848 .59231 Mdot
.92853 .5922 Mdot
.92858 .59208 Mdot
.92862 .59197 Mdot
.92867 .59185 Mdot
.92872 .59173 Mdot
.92877 .59161 Mdot
.92881 .59149 Mdot
.92886 .59137 Mdot
.92891 .59125 Mdot
.92896 .59113 Mdot
.929 .59101 Mdot
.92905 .59089 Mdot
.9291 .59077 Mdot
.92915 .59065 Mdot
.9292 .59052 Mdot
.92924 .5904 Mdot
.92929 .59027 Mdot
.92934 .59015 Mdot
.92939 .59002 Mdot
.92943 .5899 Mdot
.92948 .58977 Mdot
.92953 .58964 Mdot
.92958 .58951 Mdot
.92962 .58938 Mdot
.92967 .58925 Mdot
.92972 .58912 Mdot
.92977 .58899 Mdot
.92981 .58886 Mdot
.92986 .58873 Mdot
.92991 .5886 Mdot
.92996 .58847 Mdot
.93 .58833 Mdot
.93005 .5882 Mdot
.9301 .58806 Mdot
.93015 .58793 Mdot
.9302 .58779 Mdot
.93024 .58766 Mdot
.93029 .58752 Mdot
.93034 .58738 Mdot
.93039 .58724 Mdot
.93043 .5871 Mdot
.93048 .58696 Mdot
.93053 .58682 Mdot
.93058 .58668 Mdot
.93062 .58654 Mdot
.93067 .5864 Mdot
.93072 .58626 Mdot
.93077 .58612 Mdot
.93081 .58597 Mdot
.93086 .58583 Mdot
.93091 .58568 Mdot
.93096 .58554 Mdot
.931 .58539 Mdot
.93105 .58525 Mdot
.9311 .5851 Mdot
.93115 .58495 Mdot
.93119 .5848 Mdot
.93124 .58466 Mdot
.93129 .58451 Mdot
.93134 .58436 Mdot
.93139 .58421 Mdot
.93143 .58405 Mdot
.93148 .5839 Mdot
.93153 .58375 Mdot
.93158 .5836 Mdot
.93162 .58345 Mdot
.93167 .58329 Mdot
.93172 .58314 Mdot
.93177 .58298 Mdot
.93181 .58283 Mdot
.93186 .58267 Mdot
.93191 .58251 Mdot
.93196 .58236 Mdot
.932 .5822 Mdot
.93205 .58204 Mdot
.9321 .58188 Mdot
.93215 .58172 Mdot
.93219 .58156 Mdot
.93224 .5814 Mdot
.93229 .58124 Mdot
.93234 .58108 Mdot
.93239 .58091 Mdot
.93243 .58075 Mdot
.93248 .58059 Mdot
.93253 .58042 Mdot
.93258 .58026 Mdot
.93262 .58009 Mdot
.93267 .57993 Mdot
.93272 .57976 Mdot
.93277 .57959 Mdot
.93281 .57942 Mdot
.93286 .57926 Mdot
.93291 .57909 Mdot
.93296 .57892 Mdot
.933 .57875 Mdot
.93305 .57858 Mdot
.9331 .57841 Mdot
.93315 .57823 Mdot
.93319 .57806 Mdot
.93324 .57789 Mdot
.93329 .57772 Mdot
.93334 .57754 Mdot
.93339 .57737 Mdot
.93343 .57719 Mdot
.93348 .57702 Mdot
.93353 .57684 Mdot
.93358 .57666 Mdot
.93362 .57649 Mdot
.93367 .57631 Mdot
.93372 .57613 Mdot
.93377 .57595 Mdot
.93381 .57577 Mdot
.93386 .57559 Mdot
.93391 .57541 Mdot
.93396 .57523 Mdot
.934 .57505 Mdot
.93405 .57486 Mdot
.9341 .57468 Mdot
.93415 .5745 Mdot
.93419 .57431 Mdot
.93424 .57413 Mdot
.93429 .57394 Mdot
.93434 .57376 Mdot
.93439 .57357 Mdot
.93443 .57338 Mdot
.93448 .57319 Mdot
.93453 .57301 Mdot
.93458 .57282 Mdot
.93462 .57263 Mdot
.93467 .57244 Mdot
.93472 .57225 Mdot
.93477 .57206 Mdot
.93481 .57187 Mdot
.93486 .57167 Mdot
.93491 .57148 Mdot
.93496 .57129 Mdot
.935 .57109 Mdot
.93505 .5709 Mdot
.9351 .5707 Mdot
.93515 .57051 Mdot
.93519 .57031 Mdot
.93524 .57012 Mdot
.93529 .56992 Mdot
.93534 .56972 Mdot
.93539 .56952 Mdot
.93543 .56932 Mdot
.93548 .56912 Mdot
.93553 .56892 Mdot
.93558 .56872 Mdot
.93562 .56852 Mdot
.93567 .56832 Mdot
.93572 .56812 Mdot
.93577 .56792 Mdot
.93581 .56771 Mdot
.93586 .56751 Mdot
.93591 .5673 Mdot
.93596 .5671 Mdot
.936 .56689 Mdot
.93605 .56669 Mdot
.9361 .56648 Mdot
.93615 .56627 Mdot
.93619 .56606 Mdot
.93624 .56586 Mdot
.93629 .56565 Mdot
.93634 .56544 Mdot
.93638 .56523 Mdot
.93643 .56502 Mdot
.93648 .56481 Mdot
.93653 .56459 Mdot
.93658 .56438 Mdot
.93662 .56417 Mdot
.93667 .56396 Mdot
.93672 .56374 Mdot
.93677 .56353 Mdot
.93681 .56331 Mdot
.93686 .5631 Mdot
.93691 .56288 Mdot
.93696 .56267 Mdot
.937 .56245 Mdot
.93705 .56223 Mdot
.9371 .56201 Mdot
.93715 .56179 Mdot
.93719 .56157 Mdot
.93724 .56135 Mdot
.93729 .56113 Mdot
.93734 .56091 Mdot
.93738 .56069 Mdot
.93743 .56047 Mdot
.93748 .56025 Mdot
.93753 .56002 Mdot
.93758 .5598 Mdot
.93762 .55958 Mdot
.93767 .55935 Mdot
.93772 .55913 Mdot
.93777 .5589 Mdot
.93781 .55867 Mdot
.93786 .55845 Mdot
.93791 .55822 Mdot
.93796 .55799 Mdot
.938 .55776 Mdot
.93805 .55753 Mdot
.9381 .5573 Mdot
.93815 .55707 Mdot
.93819 .55684 Mdot
.93824 .55661 Mdot
.93829 .55638 Mdot
.93834 .55615 Mdot
.93838 .55591 Mdot
.93843 .55568 Mdot
.93848 .55545 Mdot
.93853 .55521 Mdot
.93858 .55498 Mdot
.93862 .55474 Mdot
.93867 .5545 Mdot
.93872 .55427 Mdot
.93877 .55403 Mdot
.93881 .55379 Mdot
.93886 .55355 Mdot
.93891 .55331 Mdot
.93896 .55308 Mdot
.939 .55284 Mdot
.93905 .55259 Mdot
.9391 .55235 Mdot
.93915 .55211 Mdot
.93919 .55187 Mdot
.93924 .55163 Mdot
.93929 .55138 Mdot
.93934 .55114 Mdot
.93938 .5509 Mdot
.93943 .55065 Mdot
.93948 .55041 Mdot
.93953 .55016 Mdot
.93958 .54991 Mdot
.93962 .54967 Mdot
.93967 .54942 Mdot
.93972 .54917 Mdot
.93977 .54892 Mdot
.93981 .54867 Mdot
.93986 .54843 Mdot
.93991 .54818 Mdot
.93996 .54792 Mdot
.94 .54767 Mdot
.94005 .54742 Mdot
.9401 .54717 Mdot
.94015 .54692 Mdot
.94019 .54666 Mdot
.94024 .54641 Mdot
.94029 .54616 Mdot
.94034 .5459 Mdot
.94038 .54565 Mdot
.94043 .54539 Mdot
.94048 .54513 Mdot
.94053 .54488 Mdot
.94057 .54462 Mdot
.94062 .54436 Mdot
.94067 .5441 Mdot
.94072 .54385 Mdot
.94077 .54359 Mdot
.94081 .54333 Mdot
.94086 .54307 Mdot
.94091 .54281 Mdot
.94096 .54254 Mdot
.941 .54228 Mdot
.94105 .54202 Mdot
.9411 .54176 Mdot
.94115 .54149 Mdot
.94119 .54123 Mdot
.94124 .54097 Mdot
.94129 .5407 Mdot
.94134 .54044 Mdot
.94138 .54017 Mdot
.94143 .5399 Mdot
.94148 .53964 Mdot
.94153 .53937 Mdot
.94157 .5391 Mdot
.94162 .53883 Mdot
.94167 .53856 Mdot
.94172 .53829 Mdot
.94177 .53802 Mdot
.94181 .53775 Mdot
.94186 .53748 Mdot
.94191 .53721 Mdot
.94196 .53694 Mdot
.942 .53667 Mdot
.94205 .53639 Mdot
.9421 .53612 Mdot
.94215 .53585 Mdot
.94219 .53557 Mdot
.94224 .5353 Mdot
.94229 .53502 Mdot
.94234 .53475 Mdot
.94238 .53447 Mdot
.94243 .53419 Mdot
.94248 .53391 Mdot
.94253 .53364 Mdot
.94257 .53336 Mdot
.94262 .53308 Mdot
.94267 .5328 Mdot
.94272 .53252 Mdot
.94277 .53224 Mdot
.94281 .53196 Mdot
.94286 .53168 Mdot
.94291 .53139 Mdot
.94296 .53111 Mdot
.943 .53083 Mdot
.94305 .53054 Mdot
.9431 .53026 Mdot
.94315 .52998 Mdot
.94319 .52969 Mdot
.94324 .52941 Mdot
.94329 .52912 Mdot
.94334 .52883 Mdot
.94338 .52855 Mdot
.94343 .52826 Mdot
.94348 .52797 Mdot
.94353 .52768 Mdot
.94357 .52739 Mdot
.94362 .5271 Mdot
.94367 .52681 Mdot
.94372 .52652 Mdot
.94377 .52623 Mdot
.94381 .52594 Mdot
.94386 .52565 Mdot
.94391 .52536 Mdot
.94396 .52506 Mdot
.944 .52477 Mdot
.94405 .52448 Mdot
.9441 .52418 Mdot
.94415 .52389 Mdot
.94419 .52359 Mdot
.94424 .5233 Mdot
.94429 .523 Mdot
.94434 .5227 Mdot
.94438 .52241 Mdot
.94443 .52211 Mdot
.94448 .52181 Mdot
.94453 .52151 Mdot
.94457 .52121 Mdot
.94462 .52091 Mdot
.94467 .52061 Mdot
.94472 .52031 Mdot
.94477 .52001 Mdot
.94481 .51971 Mdot
.94486 .51941 Mdot
.94491 .51911 Mdot
.94496 .5188 Mdot
.945 .5185 Mdot
.94505 .5182 Mdot
.9451 .51789 Mdot
.94515 .51759 Mdot
.94519 .51728 Mdot
.94524 .51698 Mdot
.94529 .51667 Mdot
.94534 .51636 Mdot
.94538 .51606 Mdot
.94543 .51575 Mdot
.94548 .51544 Mdot
.94553 .51513 Mdot
.94557 .51482 Mdot
.94562 .51451 Mdot
.94567 .5142 Mdot
.94572 .51389 Mdot
.94576 .51358 Mdot
.94581 .51327 Mdot
.94586 .51296 Mdot
.94591 .51265 Mdot
.94596 .51234 Mdot
.946 .51202 Mdot
.94605 .51171 Mdot
.9461 .5114 Mdot
.94615 .51108 Mdot
.94619 .51077 Mdot
.94624 .51045 Mdot
.94629 .51013 Mdot
.94634 .50982 Mdot
.94638 .5095 Mdot
.94643 .50918 Mdot
.94648 .50887 Mdot
.94653 .50855 Mdot
.94657 .50823 Mdot
.94662 .50791 Mdot
.94667 .50759 Mdot
.94672 .50727 Mdot
.94676 .50695 Mdot
.94681 .50663 Mdot
.94686 .50631 Mdot
.94691 .50599 Mdot
.94696 .50566 Mdot
.947 .50534 Mdot
.94705 .50502 Mdot
.9471 .5047 Mdot
.94715 .50437 Mdot
.94719 .50405 Mdot
.94724 .50372 Mdot
.94729 .5034 Mdot
.94734 .50307 Mdot
.94738 .50274 Mdot
.94743 .50242 Mdot
.94748 .50209 Mdot
.94753 .50176 Mdot
.94757 .50144 Mdot
.94762 .50111 Mdot
.94767 .50078 Mdot
.94772 .50045 Mdot
.94776 .50012 Mdot
.94781 .49979 Mdot
.94786 .49946 Mdot
.94791 .49913 Mdot
.94796 .4988 Mdot
.948 .49846 Mdot
.94805 .49813 Mdot
.9481 .4978 Mdot
.94815 .49747 Mdot
.94819 .49713 Mdot
.94824 .4968 Mdot
.94829 .49646 Mdot
.94834 .49613 Mdot
.94838 .49579 Mdot
.94843 .49546 Mdot
.94848 .49512 Mdot
.94853 .49479 Mdot
.94857 .49445 Mdot
.94862 .49411 Mdot
.94867 .49377 Mdot
.94872 .49344 Mdot
.94876 .4931 Mdot
.94881 .49276 Mdot
.94886 .49242 Mdot
.94891 .49208 Mdot
.94896 .49174 Mdot
.949 .4914 Mdot
.94905 .49106 Mdot
.9491 .49072 Mdot
.94915 .49037 Mdot
.94919 .49003 Mdot
.94924 .48969 Mdot
.94929 .48935 Mdot
.94934 .489 Mdot
.94938 .48866 Mdot
.94943 .48831 Mdot
.94948 .48797 Mdot
.94953 .48762 Mdot
.94957 .48728 Mdot
.94962 .48693 Mdot
.94967 .48658 Mdot
.94972 .48624 Mdot
.94976 .48589 Mdot
.94981 .48554 Mdot
.94986 .48519 Mdot
.94991 .48484 Mdot
.94996 .48449 Mdot
.95 .48415 Mdot
.95005 .4838 Mdot
.9501 .48344 Mdot
.95015 .48309 Mdot
.95019 .48274 Mdot
.95024 .48239 Mdot
.95029 .48204 Mdot
.95034 .48169 Mdot
.95038 .48133 Mdot
.95043 .48098 Mdot
.95048 .48063 Mdot
.95053 .48027 Mdot
.95057 .47992 Mdot
.95062 .47956 Mdot
.95067 .47921 Mdot
.95072 .47885 Mdot
.95076 .4785 Mdot
.95081 .47814 Mdot
.95086 .47779 Mdot
.95091 .47743 Mdot
.95095 .47707 Mdot
.951 .47671 Mdot
.95105 .47636 Mdot
.9511 .476 Mdot
.95115 .47564 Mdot
.95119 .47528 Mdot
.95124 .47492 Mdot
.95129 .47456 Mdot
.95134 .4742 Mdot
.95138 .47384 Mdot
.95143 .47348 Mdot
.95148 .47312 Mdot
.95153 .47275 Mdot
.95157 .47239 Mdot
.95162 .47203 Mdot
.95167 .47167 Mdot
.95172 .4713 Mdot
.95176 .47094 Mdot
.95181 .47058 Mdot
.95186 .47021 Mdot
.95191 .46985 Mdot
.95195 .46948 Mdot
.952 .46911 Mdot
.95205 .46875 Mdot
.9521 .46838 Mdot
.95215 .46802 Mdot
.95219 .46765 Mdot
.95224 .46728 Mdot
.95229 .46691 Mdot
.95234 .46654 Mdot
.95238 .46618 Mdot
.95243 .46581 Mdot
.95248 .46544 Mdot
.95253 .46507 Mdot
.95257 .4647 Mdot
.95262 .46433 Mdot
.95267 .46396 Mdot
.95272 .46358 Mdot
.95276 .46321 Mdot
.95281 .46284 Mdot
.95286 .46247 Mdot
.95291 .4621 Mdot
.95295 .46172 Mdot
.953 .46135 Mdot
.95305 .46098 Mdot
.9531 .4606 Mdot
.95315 .46023 Mdot
.95319 .45985 Mdot
.95324 .45948 Mdot
.95329 .4591 Mdot
.95334 .45873 Mdot
.95338 .45835 Mdot
.95343 .45797 Mdot
.95348 .4576 Mdot
.95353 .45722 Mdot
.95357 .45684 Mdot
.95362 .45646 Mdot
.95367 .45608 Mdot
.95372 .4557 Mdot
.95376 .45533 Mdot
.95381 .45495 Mdot
.95386 .45457 Mdot
.95391 .45419 Mdot
.95395 .4538 Mdot
.954 .45342 Mdot
.95405 .45304 Mdot
.9541 .45266 Mdot
.95415 .45228 Mdot
.95419 .4519 Mdot
.95424 .45151 Mdot
.95429 .45113 Mdot
.95434 .45075 Mdot
.95438 .45036 Mdot
.95443 .44998 Mdot
.95448 .44959 Mdot
.95453 .44921 Mdot
.95457 .44882 Mdot
.95462 .44844 Mdot
.95467 .44805 Mdot
.95472 .44767 Mdot
.95476 .44728 Mdot
.95481 .44689 Mdot
.95486 .4465 Mdot
.95491 .44612 Mdot
.95495 .44573 Mdot
.955 .44534 Mdot
.95505 .44495 Mdot
.9551 .44456 Mdot
.95514 .44417 Mdot
.95519 .44378 Mdot
.95524 .44339 Mdot
.95529 .443 Mdot
.95534 .44261 Mdot
.95538 .44222 Mdot
.95543 .44183 Mdot
.95548 .44144 Mdot
.95553 .44105 Mdot
.95557 .44065 Mdot
.95562 .44026 Mdot
.95567 .43987 Mdot
.95572 .43947 Mdot
.95576 .43908 Mdot
.95581 .43869 Mdot
.95586 .43829 Mdot
.95591 .4379 Mdot
.95595 .4375 Mdot
.956 .43711 Mdot
.95605 .43671 Mdot
.9561 .43632 Mdot
.95614 .43592 Mdot
.95619 .43552 Mdot
.95624 .43513 Mdot
.95629 .43473 Mdot
.95634 .43433 Mdot
.95638 .43394 Mdot
.95643 .43354 Mdot
.95648 .43314 Mdot
.95653 .43274 Mdot
.95657 .43234 Mdot
.95662 .43194 Mdot
.95667 .43154 Mdot
.95672 .43114 Mdot
.95676 .43074 Mdot
.95681 .43034 Mdot
.95686 .42994 Mdot
.95691 .42954 Mdot
.95695 .42914 Mdot
.957 .42874 Mdot
.95705 .42834 Mdot
.9571 .42793 Mdot
.95714 .42753 Mdot
.95719 .42713 Mdot
.95724 .42672 Mdot
.95729 .42632 Mdot
.95734 .42592 Mdot
.95738 .42551 Mdot
.95743 .42511 Mdot
.95748 .4247 Mdot
.95753 .4243 Mdot
.95757 .42389 Mdot
.95762 .42349 Mdot
.95767 .42308 Mdot
.95772 .42268 Mdot
.95776 .42227 Mdot
.95781 .42186 Mdot
.95786 .42145 Mdot
.95791 .42105 Mdot
.95795 .42064 Mdot
.958 .42023 Mdot
.95805 .41982 Mdot
.9581 .41942 Mdot
.95814 .41901 Mdot
.95819 .4186 Mdot
.95824 .41819 Mdot
.95829 .41778 Mdot
.95834 .41737 Mdot
.95838 .41696 Mdot
.95843 .41655 Mdot
.95848 .41614 Mdot
.95853 .41573 Mdot
.95857 .41532 Mdot
.95862 .4149 Mdot
.95867 .41449 Mdot
.95872 .41408 Mdot
.95876 .41367 Mdot
.95881 .41326 Mdot
.95886 .41284 Mdot
.95891 .41243 Mdot
.95895 .41202 Mdot
.959 .4116 Mdot
.95905 .41119 Mdot
.9591 .41077 Mdot
.95914 .41036 Mdot
.95919 .40995 Mdot
.95924 .40953 Mdot
.95929 .40912 Mdot
.95934 .4087 Mdot
.95938 .40828 Mdot
.95943 .40787 Mdot
.95948 .40745 Mdot
.95953 .40704 Mdot
.95957 .40662 Mdot
.95962 .4062 Mdot
.95967 .40578 Mdot
.95972 .40537 Mdot
.95976 .40495 Mdot
.95981 .40453 Mdot
.95986 .40411 Mdot
.95991 .40369 Mdot
.95995 .40328 Mdot
.96 .40286 Mdot
.96005 .40244 Mdot
.9601 .40202 Mdot
.96014 .4016 Mdot
.96019 .40118 Mdot
.96024 .40076 Mdot
.96029 .40034 Mdot
.96033 .39992 Mdot
.96038 .39949 Mdot
.96043 .39907 Mdot
.96048 .39865 Mdot
.96053 .39823 Mdot
.96057 .39781 Mdot
.96062 .39739 Mdot
.96067 .39696 Mdot
.96072 .39654 Mdot
.96076 .39612 Mdot
.96081 .39569 Mdot
.96086 .39527 Mdot
.96091 .39485 Mdot
.96095 .39442 Mdot
.961 .394 Mdot
.96105 .39357 Mdot
.9611 .39315 Mdot
.96114 .39272 Mdot
.96119 .3923 Mdot
.96124 .39187 Mdot
.96129 .39145 Mdot
.96133 .39102 Mdot
.96138 .3906 Mdot
.96143 .39017 Mdot
.96148 .38974 Mdot
.96153 .38932 Mdot
.96157 .38889 Mdot
.96162 .38846 Mdot
.96167 .38804 Mdot
.96172 .38761 Mdot
.96176 .38718 Mdot
.96181 .38675 Mdot
.96186 .38632 Mdot
.96191 .3859 Mdot
.96195 .38547 Mdot
.962 .38504 Mdot
.96205 .38461 Mdot
.9621 .38418 Mdot
.96214 .38375 Mdot
.96219 .38332 Mdot
.96224 .38289 Mdot
.96229 .38246 Mdot
.96233 .38203 Mdot
.96238 .3816 Mdot
.96243 .38117 Mdot
.96248 .38074 Mdot
.96253 .38031 Mdot
.96257 .37987 Mdot
.96262 .37944 Mdot
.96267 .37901 Mdot
.96272 .37858 Mdot
.96276 .37815 Mdot
.96281 .37771 Mdot
.96286 .37728 Mdot
.96291 .37685 Mdot
.96295 .37641 Mdot
.963 .37598 Mdot
.96305 .37555 Mdot
.9631 .37511 Mdot
.96314 .37468 Mdot
.96319 .37424 Mdot
.96324 .37381 Mdot
.96329 .37338 Mdot
.96333 .37294 Mdot
.96338 .37251 Mdot
.96343 .37207 Mdot
.96348 .37163 Mdot
.96353 .3712 Mdot
.96357 .37076 Mdot
.96362 .37033 Mdot
.96367 .36989 Mdot
.96372 .36945 Mdot
.96376 .36902 Mdot
.96381 .36858 Mdot
.96386 .36814 Mdot
.96391 .36771 Mdot
.96395 .36727 Mdot
.964 .36683 Mdot
.96405 .36639 Mdot
.9641 .36596 Mdot
.96414 .36552 Mdot
.96419 .36508 Mdot
.96424 .36464 Mdot
.96429 .3642 Mdot
.96433 .36376 Mdot
.96438 .36332 Mdot
.96443 .36289 Mdot
.96448 .36245 Mdot
.96452 .36201 Mdot
.96457 .36157 Mdot
.96462 .36113 Mdot
.96467 .36069 Mdot
.96472 .36025 Mdot
.96476 .35981 Mdot
.96481 .35937 Mdot
.96486 .35892 Mdot
.96491 .35848 Mdot
.96495 .35804 Mdot
.965 .3576 Mdot
.96505 .35716 Mdot
.9651 .35672 Mdot
.96514 .35628 Mdot
.96519 .35583 Mdot
.96524 .35539 Mdot
.96529 .35495 Mdot
.96533 .35451 Mdot
.96538 .35407 Mdot
.96543 .35362 Mdot
.96548 .35318 Mdot
.96552 .35274 Mdot
.96557 .35229 Mdot
.96562 .35185 Mdot
.96567 .35141 Mdot
.96572 .35096 Mdot
.96576 .35052 Mdot
.96581 .35008 Mdot
.96586 .34963 Mdot
.96591 .34919 Mdot
.96595 .34874 Mdot
.966 .3483 Mdot
.96605 .34785 Mdot
.9661 .34741 Mdot
.96614 .34696 Mdot
.96619 .34652 Mdot
.96624 .34607 Mdot
.96629 .34563 Mdot
.96633 .34518 Mdot
.96638 .34474 Mdot
.96643 .34429 Mdot
.96648 .34384 Mdot
.96652 .3434 Mdot
.96657 .34295 Mdot
.96662 .3425 Mdot
.96667 .34206 Mdot
.96672 .34161 Mdot
.96676 .34116 Mdot
.96681 .34072 Mdot
.96686 .34027 Mdot
.96691 .33982 Mdot
.96695 .33938 Mdot
.967 .33893 Mdot
.96705 .33848 Mdot
.9671 .33803 Mdot
.96714 .33758 Mdot
.96719 .33714 Mdot
.96724 .33669 Mdot
.96729 .33624 Mdot
.96733 .33579 Mdot
.96738 .33534 Mdot
.96743 .33489 Mdot
.96748 .33445 Mdot
.96752 .334 Mdot
.96757 .33355 Mdot
.96762 .3331 Mdot
.96767 .33265 Mdot
.96772 .3322 Mdot
.96776 .33175 Mdot
.96781 .3313 Mdot
.96786 .33085 Mdot
.96791 .3304 Mdot
.96795 .32995 Mdot
.968 .3295 Mdot
.96805 .32905 Mdot
.9681 .3286 Mdot
.96814 .32815 Mdot
.96819 .3277 Mdot
.96824 .32725 Mdot
.96829 .3268 Mdot
.96833 .32635 Mdot
.96838 .32589 Mdot
.96843 .32544 Mdot
.96848 .32499 Mdot
.96852 .32454 Mdot
.96857 .32409 Mdot
.96862 .32364 Mdot
.96867 .32319 Mdot
.96872 .32273 Mdot
.96876 .32228 Mdot
.96881 .32183 Mdot
.96886 .32138 Mdot
.96891 .32093 Mdot
.96895 .32047 Mdot
.969 .32002 Mdot
.96905 .31957 Mdot
.9691 .31912 Mdot
.96914 .31866 Mdot
.96919 .31821 Mdot
.96924 .31776 Mdot
.96929 .3173 Mdot
.96933 .31685 Mdot
.96938 .3164 Mdot
.96943 .31594 Mdot
.96948 .31549 Mdot
.96952 .31504 Mdot
.96957 .31458 Mdot
.96962 .31413 Mdot
.96967 .31368 Mdot
.96971 .31322 Mdot
.96976 .31277 Mdot
.96981 .31231 Mdot
.96986 .31186 Mdot
.96991 .3114 Mdot
.96995 .31095 Mdot
.97 .3105 Mdot
.97005 .31004 Mdot
.9701 .30959 Mdot
.97014 .30913 Mdot
.97019 .30868 Mdot
.97024 .30822 Mdot
.97029 .30777 Mdot
.97033 .30731 Mdot
.97038 .30686 Mdot
.97043 .3064 Mdot
.97048 .30595 Mdot
.97052 .30549 Mdot
.97057 .30504 Mdot
.97062 .30458 Mdot
.97067 .30413 Mdot
.97071 .30367 Mdot
.97076 .30322 Mdot
.97081 .30276 Mdot
.97086 .30231 Mdot
.97091 .30185 Mdot
.97095 .30139 Mdot
.971 .30094 Mdot
.97105 .30048 Mdot
.9711 .30003 Mdot
.97114 .29957 Mdot
.97119 .29911 Mdot
.97124 .29866 Mdot
.97129 .2982 Mdot
.97133 .29775 Mdot
.97138 .29729 Mdot
.97143 .29683 Mdot
.97148 .29638 Mdot
.97152 .29592 Mdot
.97157 .29546 Mdot
.97162 .29501 Mdot
.97167 .29455 Mdot
.97171 .2941 Mdot
.97176 .29364 Mdot
.97181 .29318 Mdot
.97186 .29273 Mdot
.97191 .29227 Mdot
.97195 .29181 Mdot
.972 .29136 Mdot
.97205 .2909 Mdot
.9721 .29044 Mdot
.97214 .28998 Mdot
.97219 .28953 Mdot
.97224 .28907 Mdot
.97229 .28861 Mdot
.97233 .28816 Mdot
.97238 .2877 Mdot
.97243 .28724 Mdot
.97248 .28678 Mdot
.97252 .28633 Mdot
.97257 .28587 Mdot
.97262 .28541 Mdot
.97267 .28496 Mdot
.97271 .2845 Mdot
.97276 .28404 Mdot
.97281 .28358 Mdot
.97286 .28313 Mdot
.97291 .28267 Mdot
.97295 .28221 Mdot
.973 .28175 Mdot
.97305 .2813 Mdot
.9731 .28084 Mdot
.97314 .28038 Mdot
.97319 .27992 Mdot
.97324 .27947 Mdot
.97329 .27901 Mdot
.97333 .27855 Mdot
.97338 .27809 Mdot
.97343 .27764 Mdot
.97348 .27718 Mdot
.97352 .27672 Mdot
.97357 .27626 Mdot
.97362 .27581 Mdot
.97367 .27535 Mdot
.97371 .27489 Mdot
.97376 .27443 Mdot
.97381 .27398 Mdot
.97386 .27352 Mdot
.9739 .27306 Mdot
.97395 .2726 Mdot
.974 .27215 Mdot
.97405 .27169 Mdot
.9741 .27123 Mdot
.97414 .27077 Mdot
.97419 .27032 Mdot
.97424 .26986 Mdot
.97429 .2694 Mdot
.97433 .26894 Mdot
.97438 .26849 Mdot
.97443 .26803 Mdot
.97448 .26757 Mdot
.97452 .26711 Mdot
.97457 .26666 Mdot
.97462 .2662 Mdot
.97467 .26574 Mdot
.97471 .26528 Mdot
.97476 .26483 Mdot
.97481 .26437 Mdot
.97486 .26391 Mdot
.9749 .26345 Mdot
.97495 .263 Mdot
.975 .26254 Mdot
.97505 .26208 Mdot
.9751 .26162 Mdot
.97514 .26117 Mdot
.97519 .26071 Mdot
.97524 .26025 Mdot
.97529 .25979 Mdot
.97533 .25934 Mdot
.97538 .25888 Mdot
.97543 .25842 Mdot
.97548 .25797 Mdot
.97552 .25751 Mdot
.97557 .25705 Mdot
.97562 .25659 Mdot
.97567 .25614 Mdot
.97571 .25568 Mdot
.97576 .25522 Mdot
.97581 .25477 Mdot
.97586 .25431 Mdot
.9759 .25385 Mdot
.97595 .25339 Mdot
.976 .25294 Mdot
.97605 .25248 Mdot
.9761 .25202 Mdot
.97614 .25157 Mdot
.97619 .25111 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oo
nfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oo
oo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX0017ooo]Z1Ol0
07l9oookJPGo0000oooonf[ooookJQkooo]Z000@oookJPOo001o2?oonfX5o`000?oooo]ZoooonfXN
oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[ooookJQkooo]Z0003oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfZUoookJPKo0000L_oonfX000?ooo]Z
2_l007l8oookJP?o001o1ooonfX7o`000?oooo]ZX_oonfX8o`00077ooo]Z000EoookJP?o001o1ooo
nfX5o`000?oooo]ZXooonfX:o`00073ooo]Z000CoookJPCo001o2?oonfX5o`000?oooo]ZX_oonfX<
o`0006oooo]Z000CoookJP?o001o2OoonfX5o`000?oooo]ZX_oonfX5o`0000;ooo]Z1Ol0001_oook
JP005OoonfX2o`00O`Sooo]Z1Ol0003ooookJZ7ooo]Z1Ol00004oookJPGo0000K_oonfX000oooo]Z
0ol007l3oookJP?o001o1ooonfX5o`000?oooo]ZXOoonfX5o`0000Cooo]Z1Ol0001^oookJP003ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfZPoookJPGo00001_oonfX5o`0006gooo]Z000@
oookJPOo001o2?oonfX5o`000?oooo]ZX?oonfX5o`0000Kooo]Z1Ol0001]oookJP004OoonfX5o`00
O`Wooo]Z1Ol0003ooookJZ3ooo]Z1?l00008oookJPCo0000KOoonfX001oooo]Z1Ol0003ooookJYoo
oo]Z1Ol00008oookJPGo0000K?oonfX001oooo]Z1Ol0003ooookJYoooo]Z1Ol00008oookJPGo0000
K?oonfX001oooo]Z1Ol0003ooookJYoooo]Z1?l0000:oookJPCo0000K?oonfX001oooo]Z1Ol0003o
oookJYkooo]Z1Ol0000:oookJPGo0000JooonfX001oooo]Z1Ol0003ooookJYkooo]Z1Ol0000:oook
JPGo0000JooonfX001oooo]Z1Ol0003ooookJYkooo]Z1?l0000<oookJPCo0000JooonfX001oooo]Z
1Ol0003ooookJYgooo]Z1Ol0000<oookJPGo0000J_oonfX001oooo]Z1Ol0003ooookJYgooo]Z1Ol0
000<oookJPGo0000J_oonfX001oooo]Z1Ol0003ooookJYgooo]Z1?l0000>oookJPCo0000J_oonfX0
01oooo]Z1Ol0003ooookJYgooo]Z1?l0000>oookJPCo0000J_oonfX001oooo]Z1Ol0003ooookJYco
oo]Z1Ol0000>oookJPGo0000JOoonfX001oooo]Z1Ol0003ooookJYcooo]Z1Ol0000>oookJPGo0000
JOoonfX001oooo]Z1Ol0003ooookJYcooo]Z1?l0000@oookJPCo0000JOoonfX001oooo]Z1Ol0003o
oookJYcooo]Z1?l0000@oookJPCo0000JOoonfX001oooo]Z1Ol0003ooookJY_ooo]Z1Ol0000@oook
JPGo0000J?oonfX001oooo]Z1Ol0003ooookJY_ooo]Z1Ol0000@oookJPGo0000J?oonfX001oooo]Z
1Ol0003ooookJY_ooo]Z1?l0000BoookJPCo0000J?oonfX001oooo]Z1Ol0003ooookJY_ooo]Z1?l0
000BoookJPCo0000J?oonfX001oooo]Z1Ol0003ooookJY_ooo]Z1?l0000BoookJPCo0000J?oonfX0
01oooo]Z1Ol0003ooookJY[ooo]Z1Ol0000BoookJPGo0000IooonfX001oooo]Z1Ol0003ooookJY[o
oo]Z1?l0000CoookJPGo0000IooonfX001oooo]Z1Ol0003ooookJY[ooo]Z1?l0000DoookJPCo0000
IooonfX001oooo]Z1Ol0003ooookJY[ooo]Z1?l0000DoookJPCo0000IooonfX001oooo]Z1Ol0003o
oookJYWooo]Z1Ol0000DoookJPCo0000IooonfX001oooo]Z1Ol0003ooookJYWooo]Z1Ol0000Doook
JPGo0000I_oonfX001oooo]Z1Ol0003ooookJS;ooo]Z0ol0001ToookJPCo00005OoonfX5o`0006Ko
oo]Z000OoookJPGo0000oooonfX`oookJPOo0000H_oonfX4o`0001Kooo]Z1?l0001VoookJP007ooo
nfX5o`000?oooo]Z;ooonfX9o`00067ooo]Z1?l0000FoookJPCo0000I_oonfX001oooo]Z1Ol0003o
oookJRkooo]Z2ol0001OoookJPGo00005_oonfX4o`0006Kooo]Z000OoookJPGo0000oooonfX]oook
JPgo0000G_oonfX5o`0001Kooo]Z1Ol0001UoookJP007ooonfX5o`000?oooo]Z;?oonfX6o`0000?o
oo]Z1Ol0001NoookJPCo00005ooonfX5o`0006Gooo]Z000OoookJPGo0000oooonfX/oookJPGo0000
1OoonfX5o`0005gooo]Z1?l0000HoookJPCo0000IOoonfX001oooo]Z1Ol0003ooookJR_ooo]Z1Ol0
0006oookJPGo0000GOoonfX4o`0001Sooo]Z1?l0001UoookJP007ooonfX5o`000?oooo]Z:ooonfX5
o`0000Oooo]Z1Ol0001LoookJPCo00006?oonfX4o`0006Gooo]Z000OoookJPGo0000oooonfXZoook
JPGo00002?oonfX5o`0005_ooo]Z1Ol0000HoookJPCo0000IOoonfX001oooo]Z1Ol0003ooookJR[o
oo]Z1Ol00009oookJPGo0000F_oonfX5o`0001Sooo]Z1Ol0001ToookJP007ooonfX5o`000?oooo]Z
:OoonfX5o`0000[ooo]Z1Ol0001JoookJPCo00006OoonfX5o`0006Cooo]Z000?oookJPWo001o1ooo
nfX5o`000?oooo]Z:OoonfX5o`0000_ooo]Z1?l0001JoookJPCo00006_oonfX4o`0006Cooo]Z000?
oookJPWo001o1ooonfX5o`000?oooo]Z:OoonfX4o`0000cooo]Z1Ol0001IoookJPCo00006_oonfX4
o`0006Cooo]Z000?oookJPCo001o3?oonfX5o`000?oooo]Z:?oonfX5o`0000cooo]Z1Ol0001Hoook
JPGo00006_oonfX4o`0006Cooo]Z0003oookJP[o001o0ooonfX4o`00O`_ooo]Z1Ol0003ooookJRSo
oo]Z1?l0000>oookJPGo0000EooonfX5o`0001[ooo]Z1?l0001ToookJP000ooonfX:o`00O`Cooo]Z
1Ol007l9oookJPOo0000oooonfXUoookJPGo00003_oonfX5o`0005Oooo]Z1?l0000KoookJPGo0000
HooonfX001?ooo]Z1?l007l8oookJPGo0000oooonfXWoookJPGo00003ooonfX4o`0005Oooo]Z1?l0
000KoookJPGo0000HooonfX001Cooo]Z0ol007l8oookJPGo0000oooonfXWoookJPCo00004?oonfX4
o`0005Oooo]Z1?l0000LoookJPCo0000HooonfX001Gooo]Z0ol007l7oookJPGo0000oooonfXVoook
JPGo00004?oonfX5o`0005Kooo]Z1?l0000LoookJPCo0000HooonfX000oooo]Z0ol007l3oookJP?o
001o1ooonfX5o`000?oooo]Z9_oonfX5o`00013ooo]Z1Ol0001EoookJPGo00007?oonfX4o`0006?o
oo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJRKooo]Z1?l0000BoookJPCo0000
EOoonfX5o`0001cooo]Z1?l0001SoookJP003ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000oooo
nfXVoookJPCo00004_oonfX5o`0005Cooo]Z1?l0000MoookJPGo0000H_oonfX0013ooo]Z1ol007l8
oookJPGo0000oooonfXUoookJPGo00004_oonfX5o`0005Cooo]Z1?l0000MoookJPGo0000H_oonfX0
017ooo]Z1Ol007l9oookJPGo0000oooonfXUoookJPGo00004ooonfX4o`0005Cooo]Z1?l0000Noook
JPCo0000H_oonfX001oooo]Z1Ol0003ooookJRGooo]Z1?l0000DoookJPCo0000E?oonfX4o`0001ko
oo]Z1?l0001RoookJP007ooonfX5o`000?oooo]Z9?oonfX5o`0001Cooo]Z1Ol0001CoookJPCo0000
7_oonfX4o`0006;ooo]Z000OoookJPGo0000oooonfXToookJPGo00005?oonfX5o`0005;ooo]Z1Ol0
000NoookJPCo0000H_oonfX001oooo]Z1Ol0003ooookJRCooo]Z1?l0000FoookJPCo0000D_oonfX4
o`0001oooo]Z1?l0001RoookJP007ooonfX5o`000?oooo]Z9?oonfX4o`0001Kooo]Z1?l0001Boook
JPCo00007ooonfX5o`00067ooo]Z000OoookJPGo0000oooonfXSoookJPGo00005_oonfX5o`00057o
oo]Z1?l0000OoookJPGo0000HOoonfX001oooo]Z1Ol0003ooookJR?ooo]Z1Ol0000FoookJPGo0000
DOoonfX4o`00023ooo]Z1?l0001QoookJP007ooonfX5o`000?oooo]Z8ooonfX4o`0001Sooo]Z1?l0
001AoookJPCo00008?oonfX4o`00067ooo]Z000OoookJPGo0000oooonfXSoookJPCo00006?oonfX4
o`00053ooo]Z1Ol0000PoookJPCo0000HOoonfX001oooo]Z1Ol0002ioookJPKo0000H_oonfX5o`00
01Sooo]Z1Ol0001?oookJPGo00008?oonfX4o`00067ooo]Z000OoookJPGo0000]ooonfX9o`00067o
oo]Z1Ol0000HoookJPGo0000CooonfX4o`00027ooo]Z1?l0001QoookJP007ooonfX5o`000;Kooo]Z
2ol0001PoookJPCo00006_oonfX4o`0004oooo]Z1?l0000QoookJPGo0000H?oonfX001oooo]Z1Ol0
002eoookJPgo0000GooonfX4o`0001[ooo]Z1?l0001?oookJPCo00008OoonfX5o`00063ooo]Z000O
oookJPGo0000]?oonfX7o`0000;ooo]Z1_l0001MoookJPGo00006_oonfX4o`0004oooo]Z1?l0000R
oookJPCo0000H?oonfX001oooo]Z1Ol0002coookJPKo00001OoonfX6o`0005cooo]Z1Ol0000Joook
JPGo0000C_oonfX4o`0002;ooo]Z1?l0001PoookJP007ooonfX5o`000;?ooo]Z1Ol00007oookJPKo
0000FooonfX4o`0001cooo]Z1?l0001=oookJPGo00008_oonfX4o`00063ooo]Z000OoookJPGo0000
/_oonfX5o`0000Wooo]Z1Ol0001KoookJPCo00007?oonfX4o`0004gooo]Z1Ol0000RoookJPCo0000
H?oonfX001oooo]Z1Ol0002aoookJPKo00002_oonfX5o`0005[ooo]Z1?l0000LoookJPCo0000COoo
nfX4o`0002?ooo]Z1?l0001PoookJP007ooonfX5o`000;7ooo]Z1Ol0000;oookJPGo0000FOoonfX5
o`0001cooo]Z1Ol0001<oookJPCo00008ooonfX5o`0005oooo]Z000OoookJPGo0000/?oonfX5o`00
00gooo]Z1Ol0001HoookJPGo00007?oonfX5o`0004cooo]Z1?l0000SoookJPGo0000GooonfX001oo
oo]Z1Ol0002`oookJPGo00003OoonfX5o`0005Sooo]Z1?l0000NoookJPCo0000C?oonfX4o`0002Co
oo]Z1?l0001OoookJP007ooonfX5o`000:oooo]Z1Ol0000?oookJPGo0000EooonfX4o`0001kooo]Z
1?l0001<oookJPCo00009?oonfX4o`0005oooo]Z000OoookJPGo0000[ooonfX5o`0000oooo]Z1Ol0
001GoookJPCo00007_oonfX4o`0004_ooo]Z1Ol0000ToookJPCo0000GooonfX001oooo]Z1Ol0002^
oookJPGo00004OoonfX5o`0005Gooo]Z1Ol0000NoookJPGo0000B_oonfX4o`0002Gooo]Z1?l0001O
oookJP007ooonfX5o`000:kooo]Z1Ol0000AoookJPGo0000EOoonfX4o`0001oooo]Z1Ol0001:oook
JPCo00009OoonfX4o`0005oooo]Z000OoookJPGo0000[OoonfX5o`0001?ooo]Z1?l0001EoookJPCo
00008?oonfX4o`0004[ooo]Z1?l0000UoookJPGo0000G_oonfX001oooo]Z1Ol0002]oookJPGo0000
4ooonfX5o`0005Cooo]Z1?l0000PoookJPCo0000B_oonfX4o`0002Gooo]Z1Ol0001NoookJP007ooo
nfX5o`000:gooo]Z1?l0000EoookJPCo0000DooonfX5o`00023ooo]Z1?l0001:oookJPCo00009_oo
nfX4o`0005kooo]Z000OoookJPGo0000[?oonfX5o`0001Gooo]Z1Ol0001BoookJPGo00008?oonfX4
o`0004Wooo]Z1Ol0000VoookJPCo0000G_oonfX001oooo]Z1Ol0002/oookJPGo00005OoonfX5o`00
05;ooo]Z1?l0000QoookJPGo0000B?oonfX5o`0002Kooo]Z1?l0001NoookJP007ooonfX5o`000:_o
oo]Z1Ol0000GoookJPCo0000D_oonfX4o`0002;ooo]Z1?l00018oookJPCo00009ooonfX4o`0005ko
oo]Z000OoookJPGo0000ZooonfX5o`0001Oooo]Z1Ol0001AoookJPCo00008_oonfX4o`0004Sooo]Z
1?l0000WoookJPCo0000G_oonfX001oooo]Z1Ol0002[oookJPCo00006?oonfX5o`00053ooo]Z1Ol0
000RoookJPCo0000B?oonfX4o`0002Oooo]Z1?l0001NoookJP007ooonfX5o`000:[ooo]Z1Ol0000I
oookJPCo0000D?oonfX5o`0002;ooo]Z1?l00018oookJPCo00009ooonfX5o`0005gooo]Z000Ooook
JPGo0000Z_oonfX5o`0001Wooo]Z1Ol0001?oookJPCo00008ooonfX5o`0004Oooo]Z1?l0000Woook
JPGo0000GOoonfX001oooo]Z1Ol0000koookJPWo0000I_oonfX4o`0001[ooo]Z1Ol0001?oookJPCo
00008ooonfX5o`0004Oooo]Z1?l0000XoookJPCo0000GOoonfX001oooo]Z1Ol0000ioookJPgo0000
HooonfX5o`0001_ooo]Z1?l0001?oookJPCo00009?oonfX4o`0004Kooo]Z1Ol0000XoookJPCo0000
GOoonfX001?ooo]Z0ol007l9oookJPGo0000>?oonfX?o`0006;ooo]Z1Ol0000KoookJPGo0000C_oo
nfX4o`0002Cooo]Z1?l00016oookJPGo0000:?oonfX4o`0005gooo]Z000CoookJP?o001o2OoonfX5
o`0003Oooo]Z4Ol0001QoookJPCo00007?oonfX5o`0004gooo]Z1Ol0000ToookJPCo0000A_oonfX4
o`0002Wooo]Z1?l0001MoookJP004ooonfX3o`00O`Wooo]Z1Ol0000foookJPOo00001_oonfX6o`00
05oooo]Z1Ol0000MoookJPCo0000COoonfX4o`0002Gooo]Z1?l00016oookJPCo0000:OoonfX4o`00
05gooo]Z0003oookJP[o001o1_oonfX3o`00O`Wooo]Z1Ol0000eoookJPKo00002OoonfX6o`0005ko
oo]Z1Ol0000MoookJPCo0000COoonfX4o`0002Gooo]Z1Ol00015oookJPCo0000:OoonfX4o`0005go
oo]Z0003oookJP[o001o1_oonfX3o`00O`Wooo]Z1ol0000boookJPKo00002ooonfX6o`0005gooo]Z
1?l0000NoookJPGo0000C?oonfX4o`0002Kooo]Z1?l00015oookJPCo0000:OoonfX5o`0005cooo]Z
000CoookJP?o001o2OoonfX5o`0003?ooo]Z1_l0000=oookJPKo0000FooonfX5o`0001oooo]Z1?l0
001<oookJPCo00009_oonfX4o`0004Gooo]Z1?l0000YoookJPGo0000G?oonfX001?ooo]Z0ol007l9
oookJPGo0000<_oonfX6o`0000oooo]Z1_l0001JoookJPGo00007ooonfX4o`0004_ooo]Z1Ol0000V
oookJPCo0000A?oonfX5o`0002[ooo]Z1?l0001LoookJP004ooonfX3o`00O`Wooo]Z1Ol0000boook
JPGo00004OoonfX5o`0005[ooo]Z1?l0000PoookJPGo0000B_oonfX5o`0002Kooo]Z1?l00014oook
JPGo0000:_oonfX4o`0005cooo]Z000CoookJP?o001o2OoonfX5o`00037ooo]Z1Ol0000CoookJPGo
0000F?oonfX5o`00023ooo]Z1Ol0001:oookJPCo00009ooonfX5o`0004?ooo]Z1?l0000[oookJPCo
0000G?oonfX0013ooo]Z1_l007l9oookJPGo0000<?oonfX6o`0001?ooo]Z1_l0001GoookJPGo0000
8OoonfX4o`0004[ooo]Z1?l0000WoookJPGo0000@ooonfX4o`0002_ooo]Z1?l0001LoookJP004?oo
nfX6o`00O`Wooo]Z1Ol0000`oookJPGo00005OoonfX5o`0005Oooo]Z1?l0000RoookJPCo0000B_oo
nfX4o`0002Sooo]Z1?l00013oookJPCo0000:ooonfX4o`0005cooo]Z000BoookJPCo001o2OoonfX5
o`0002oooo]Z1Ol0000GoookJPGo0000E_oonfX4o`0002;ooo]Z1Ol00018oookJPGo0000:?oonfX4
o`0004?ooo]Z1?l0000[oookJPCo0000G?oonfX001?ooo]Z0ol007l9oookJPGo0000;_oonfX6o`00
01Oooo]Z1Ol0001EoookJPGo00008_oonfX5o`0004Sooo]Z1Ol0000XoookJPCo0000@ooonfX4o`00
02_ooo]Z1Ol0001KoookJP007ooonfX5o`0002kooo]Z1Ol0000IoookJPGo0000E?oonfX5o`0002?o
oo]Z1?l00018oookJPCo0000:OoonfX4o`0004;ooo]Z1Ol0000/oookJPCo0000FooonfX001oooo]Z
1Ol0000]oookJPGo00006_oonfX5o`0005Cooo]Z1?l0000ToookJPGo0000AooonfX4o`0002Wooo]Z
1Ol00011oookJPGo0000;?oonfX4o`0005_ooo]Z000OoookJPGo0000;OoonfX5o`0001_ooo]Z1Ol0
001BoookJPGo00009?oonfX5o`0004Oooo]Z1?l0000YoookJPGo0000@OoonfX4o`0002gooo]Z1?l0
001KoookJP007ooonfX5o`0002cooo]Z1Ol0000LoookJPGo0000D_oonfX5o`0002Gooo]Z1?l00016
oookJPGo0000:_oonfX4o`00047ooo]Z1?l0000]oookJPCo0000FooonfX001oooo]Z1Ol0000/oook
JPGo00007OoonfX5o`00057ooo]Z1?l0000VoookJPCo0000A_oonfX5o`0002[ooo]Z1?l00011oook
JPCo0000;OoonfX4o`0005_ooo]Z000OoookJPGo0000:ooonfX5o`0001kooo]Z1Ol0001AoookJPCo
00009_oonfX5o`0004Gooo]Z1?l0000[oookJPCo0000@OoonfX4o`0002gooo]Z1?l0001KoookJP00
7ooonfX5o`0002_ooo]Z1Ol0000OoookJPGo0000CooonfX5o`0002Kooo]Z1Ol00015oookJPCo0000
:ooonfX4o`00047ooo]Z1?l0000]oookJPCo0000FooonfX001oooo]Z1Ol0000ZoookJPGo00008?oo
nfX5o`0004oooo]Z1Ol0000WoookJPCo0000AOoonfX4o`0002_ooo]Z1Ol00010oookJPCo0000;Ooo
nfX5o`0005[ooo]Z000OoookJPGo0000:_oonfX5o`00027ooo]Z1Ol0001>oookJPCo0000:?oonfX4
o`0004Gooo]Z1?l0000[oookJPGo0000?ooonfX5o`0002gooo]Z1Ol0001JoookJP007ooonfX5o`00
02Wooo]Z1Ol0000RoookJPGo0000COoonfX5o`0002Sooo]Z1?l00014oookJPGo0000;?oonfX4o`00
03oooo]Z1?l0000_oookJPCo0000F_oonfX001oooo]Z1Ol0000YoookJPGo00008ooonfX4o`0004go
oo]Z1Ol0000XoookJPGo0000@ooonfX5o`0002cooo]Z1?l0000ooookJPCo0000;ooonfX4o`0005[o
oo]Z000OoookJPGo0000:?oonfX5o`0002Cooo]Z1Ol0001<oookJPCo0000:_oonfX4o`0004?ooo]Z
1?l0000]oookJPCo0000?ooonfX4o`0002oooo]Z1?l0001JoookJP007ooonfX5o`0002Sooo]Z1Ol0
000UoookJPCo0000C?oonfX4o`0002[ooo]Z1?l00013oookJPCo0000;OoonfX4o`0003oooo]Z1?l0
000_oookJPCo0000F_oonfX001oooo]Z1Ol0000WoookJPGo00009_oonfX5o`0004[ooo]Z1Ol0000Z
oookJPCo0000@ooonfX4o`0002gooo]Z1Ol0000noookJPCo0000;ooonfX4o`0005[ooo]Z000Ooook
JPGo00009ooonfX5o`0002Kooo]Z1Ol0001:oookJPGo0000:_oonfX5o`0004;ooo]Z1?l0000]oook
JPGo0000?_oonfX4o`0002oooo]Z1?l0001JoookJP007ooonfX5o`0002Oooo]Z1?l0000XoookJPGo
0000BOoonfX4o`0002_ooo]Z1Ol00011oookJPGo0000;_oonfX4o`0003gooo]Z1Ol0000_oookJPGo
0000FOoonfX001oooo]Z1Ol0000VoookJPGo0000:?oonfX5o`0004Wooo]Z1?l0000/oookJPCo0000
@OoonfX4o`0002oooo]Z1?l0000moookJPGo0000;ooonfX5o`0005Wooo]Z000OoookJPGo00009_oo
nfX5o`0002Wooo]Z1?l00018oookJPGo0000;?oonfX4o`00047ooo]Z1?l0000_oookJPCo0000?Ooo
nfX4o`00037ooo]Z1?l0000loookJP;o00006ooonfX001oooo]Z1Ol0000UoookJPGo0000:_oonfX5
o`0004Oooo]Z1?l0000]oookJPGo0000@?oonfX4o`0002oooo]Z1?l0000moookJPCo0000<OoonfX4
o`0003_ooo]Z1?l0000JoookJP007ooonfX5o`0002Gooo]Z1Ol0000ZoookJPGo0000AooonfX4o`00
02gooo]Z1Ol00010oookJPCo0000;ooonfX4o`0003gooo]Z1?l0000aoookJPCo0000>ooonfX4o`00
01[ooo]Z000OoookJPGo00009?oonfX5o`0002cooo]Z1?l0000CoookJPGo001o1OoonfX5o`00O`Go
oo]Z1Ol007l5oookJPGo001o4?oonfX5o`0002kooo]Z1?l0000CoookJP?o001o1OoonfX5o`00O`Go
oo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`03oookJ_l0003o000000?o0000;ooonfX5o`0001co
oo]Z0ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z1?l007l4o`0000;ooo]Z1Ol007lZoookJPCo
00008ooonfX9o`00O`?ooo]Z1Ol007l5oookJP;o001o1?l00004oookJPGo001o1OoonfX5o`00O`Oo
oo]Z000OoookJPGo00009?oonfX5o`0002cooo]Z1Ol0000AoookJPOo001o0ooonfX7o`00O`?ooo]Z
1ol007l3oookJPOo001o3ooonfX5o`0002kooo]Z1?l0000CoookJP?o001o1?oonfX7o`00O`?ooo]Z
1ol007l3oookJPOo001o0ooonfX7o`00O`Go0000;ooonfX5o`0001cooo]Z0ol007l4oookJPOo001o
0ooonfX7o`00O`?ooo]Z1Ol007l4o`000003oookJ_l007oo001o00Go001o:OoonfX4o`0002?ooo]Z
2Ol007l2oookJPOo001o0ooonfX3o`00O`Co00000ooonfX7o`00O`?ooo]Z1ol007l6oookJP007ooo
nfX5o`0002Cooo]Z1?l0000]oookJPGo00004?oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`oooo]Z1?l0000_oookJPGo00004_oonfX3o`00O`Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4o`00037ooo]Z1?l0000Loook
JP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00?ooo]Zo`00Ool000000ol000001Ooonf[o001oo`00Ool007oooo]Z00?o001o
:OoonfX4o`0002?ooo]Z1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Co
00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6
oookJP007ooonfX5o`0002?ooo]Z1Ol0000^oookJPGo00003ooonfX3o`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l>oookJPCo0000;ooonfX5o`0001;ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`Co0000<OoonfX4o`0001cooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l2oookJPGo00000ol007l3oookJP?o001o:?oonfX4o`0002Cooo]Z1?l007l5oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Go000000?o001ooookJ_l007l00_l007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000OoookJPGo00008ooonfX5o`0002ko
oo]Z1Ol0000EoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o3OoonfX5o`00033ooo]Z1?l0
000BoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0_l007l4o`00
037ooo]Z1?l0000LoookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l2oookJPGo00000ol007l3oookJP?o001o:?oonfX5o`0002Cooo]Z1Ol0
07l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Co00000_l007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000OoookJPGo
00008_oonfX5o`00033ooo]Z1?l0000EoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o3Ooo
nfX5o`00033ooo]Z1?l0000BoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0_l007l4o`00037ooo]Z1?l0000LoookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo000000Cooo]Zo`00Ool007oo001o
0ooonfX3o`00ObWooo]Z1?l0000VoookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l4o`0000;o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l5oookJP007ooonfX5o`0002;ooo]Z1Ol0000`oookJPGo00003ooonfX2o`00
O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l=oookJPCo0000<OoonfX4o`0001;ooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX00ol007oo0000o`000003
o`00037ooo]Z1Ol0000KoookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`000004oookJ_l007oo001oo`00O`?o
oo]Z0ol007lYoookJPCo00009ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o1?l00002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1OoonfX001oooo]Z1Ol0000QoookJPGo0000<OoonfX5o`0000oooo]Z1ol007l2
oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o3OoonfX4o`00037ooo]Z1Ol0000AoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z00?o001oo`000?l000000ol0000aoookJPGo00006ooonfX3
o`00O`Cooo]Z1ol007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l0
00001?oonf[o001oo`00Ool007l3oookJP?o001o:OoonfX4o`0002Sooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1?l00002o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX001oooo]Z1Ol0000Q
oookJPGo0000<_oonfX4o`0000oooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o3?oonfX5o`00037ooo]Z
1Ol0000AoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z00?o001o
o`000?l000000_l0000coookJPCo00006ooonfX3o`00O`Cooo]Z1_l007l3oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l000001?oonf[o001oo`00Ool007l3oookJP?o001o
:OoonfX4o`0002;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Co00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000OoookJPGo00008OoonfX4o`0003?ooo]Z1Ol0000>
oookJP;o001o1ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`cooo]Z1Ol0000boookJPCo00003_oonfX6o`00O`?ooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP03o`00Ool0003o000000;o0000<ooonfX4
o`0001Sooo]Z1_l007l4oookJP;o001o1ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l2oookJPCo000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00ObWooo]Z1?l0000RoookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4o`00
00;o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP007ooonfX5o`00023ooo]Z1Ol0000coookJPGo00003_oonfX2o`00O`Sooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`gooo]Z1?l0000coookJPCo00003_oonfX6o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`04o`0003?ooo]Z1?l0000HoookJPKo001o1?oo
nfX2o`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1Ol00002oookJP?o001o
00Cooo]Zo`00Ool007oo001o:_oonfX4o`0002;ooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0_l007l4o`000004o`00Oooonf[ooo]ZoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000OoookJPGo00008?oo
nfX5o`0003Cooo]Z1?l0000?oookJPOo001o0_oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o3Ooo
nfX4o`0003?ooo]Z1Ol0000?oookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooo
nfX5o`00O`Go0000<ooonfX4o`0001[ooo]Z1?l007l5oookJPOo001o0_oonfX7o`00O`?ooo]Z0ol0
07l5o`0000;ooo]Z1ol007lZoookJPCo00008ooonfX7o`00O`?ooo]Z1ol007l3oookJP;o001o1?l0
00001?l007oooo]ZoookJ_oonfX7o`00O`?ooo]Z1ol007l6oookJP007ooonfX5o`0001oooo]Z1Ol0
000eoookJPGo00003_oonfX7o`00O`?ooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`gooo]Z1Ol0
000coookJPGo00004?oonfX3o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z1?l0
07l5o`0003?ooo]Z1?l0000KoookJP?o001o1OoonfX7o`00O`?ooo]Z1Ol007l5oookJP;o001o1?l0
0004oookJPGo001o:ooonfX5o`0002?ooo]Z1Ol007l5oookJPGo001o1OoonfX5o`0000Gooo]Z1Ol0
07l5oookJPGo001o1ooonfX001oooo]Z1Ol0000OoookJPGo0000=OoonfX5o`0003kooo]Z1?l0000e
oookJPCo0000>_oonfX4o`0003Cooo]Z1Ol0000hoookJPCo0000=?oonfX5o`0003Oooo]Z1Ol0000K
oookJP007ooonfX5o`0001oooo]Z1?l0000goookJPCo0000?_oonfX4o`0003Gooo]Z1?l0000joook
JPCo0000=?oonfX5o`0003Sooo]Z1?l0000eoookJPCo0000=ooonfX4o`0001cooo]Z000OoookJPGo
00007_oonfX5o`0003Oooo]Z1Ol0000loookJPGo0000=OoonfX4o`0003[ooo]Z1?l0000eoookJPCo
0000>?oonfX4o`0003Gooo]Z1?l0000goookJPCo00007?oonfX001oooo]Z1Ol0000NoookJPGo0000
=ooonfX5o`0003cooo]Z1Ol0000eoookJPGo0000>OoonfX4o`0003Gooo]Z1?l0000hoookJPCo0000
=OoonfX4o`0003Oooo]Z1?l0000LoookJP007ooonfX5o`0001gooo]Z1Ol0000ioookJPCo0000??oo
nfX4o`0003Kooo]Z1Ol0000hoookJPGo0000=OoonfX4o`0003Sooo]Z1?l0000eoookJPCo0000=ooo
nfX4o`0001cooo]Z000OoookJPGo00007OoonfX5o`0003Wooo]Z1Ol0000koookJPCo0000=ooonfX4
o`0003Sooo]Z1Ol0000eoookJPCo0000=ooonfX5o`0003Gooo]Z1?l0000goookJPCo00007?oonfX0
01;ooo]Zool0003oo`0002?o00003OoonfX001;ooo]Zool0003oo`0002?o00003OoonfX001;ooo]Z
ool0003oo`0002?o00003OoonfX001;ooo]Zool0003oo`0002?o00003OoonfX001;ooo]Zool0003o
o`0002?o00003OoonfX001oooo]Z1Ol0000KoookJPCo0000?_oonfX5o`0001cooo]Z00?o0000oook
J_oonfX06?oonfX5o`0003Wooo]Z1?l0000SoookJP03o`000?oonf[ooo]Z013ooo]Z1?l0000hoook
JPCo0000;_oonfX00ol0003ooo]ZoookJP05oookJPCo0000=ooonfX4o`0003Gooo]Z1Ol0000Loook
JP007ooonfX5o`0001[ooo]Z1Ol0000noookJPGo0000=ooonfX4o`0003[ooo]Z1Ol0000eoookJPCo
0000>?oonfX4o`0003Gooo]Z1Ol0000goookJPCo0000=OoonfX4o`0001gooo]Z000OoookJPGo0000
6_oonfX5o`0003oooo]Z1?l0000foookJPGo0000>_oonfX5o`0003Gooo]Z1?l0000hoookJPGo0000
=?oonfX5o`0003Oooo]Z1?l0000eoookJPCo00007OoonfX001oooo]Z1Ol0000IoookJPGo0000@?oo
nfX5o`0003Gooo]Z1Ol0000koookJPCo0000=OoonfX4o`0003Sooo]Z1Ol0000doookJPCo0000>?oo
nfX4o`0003Gooo]Z1?l0000MoookJP007ooonfX5o`0001Wooo]Z1Ol00010oookJPGo0000=OoonfX4
o`0003cooo]Z1?l0000doookJPGo0000>OoonfX4o`0003Cooo]Z1?l0000hoookJPCo0000=OoonfX4
o`0001gooo]Z000OoookJPGo00006?oonfX5o`0004;ooo]Z1?l0000eoookJPCo0000??oonfX4o`00
03Cooo]Z1Ol0000ioookJPCo0000=?oonfX4o`0003Sooo]Z1Ol0000doookJPCo00007OoonfX001oo
oo]Z1Ol0000HoookJPGo0000@_oonfX5o`0003?ooo]Z1Ol0000loookJPGo0000<ooonfX4o`0003[o
oo]Z1?l0000doookJPCo0000>?oonfX5o`0003Cooo]Z1?l0000MoookJP007ooonfX5o`0001Sooo]Z
1?l00013oookJPGo0000<ooonfX5o`0003cooo]Z1Ol0000coookJPCo0000>_oonfX4o`0003Cooo]Z
1?l0000ioookJPCo0000<ooonfX5o`0001gooo]Z000OoookJPGo00005ooonfX5o`0004Cooo]Z1?l0
000coookJPCo0000?_oonfX4o`0003?ooo]Z1?l0000joookJPGo0000<ooonfX4o`0003Wooo]Z1?l0
000coookJPGo00007OoonfX001oooo]Z1Ol0000GoookJPGo0000A?oonfX5o`0003;ooo]Z1?l0000n
oookJPCo0000<ooonfX4o`0003[ooo]Z1Ol0000boookJPGo0000>OoonfX4o`0003?ooo]Z1?l0000N
oookJP007ooonfX5o`0001Kooo]Z1Ol00015oookJPGo0000<OoonfX5o`0003kooo]Z1Ol0000aoook
JPGo0000>ooonfX4o`0003;ooo]Z1Ol0000ioookJPCo0000<ooonfX4o`0001kooo]Z000OoookJPGo
00005_oonfX5o`0004Kooo]Z1?l0000aoookJPGo0000?_oonfX5o`00037ooo]Z1Ol0000koookJPCo
0000<_oonfX4o`0003[ooo]Z1?l0000coookJPCo00007_oonfX001oooo]Z1Ol0000EoookJPGo0000
AooonfX5o`00033ooo]Z1?l00010oookJPCo0000<OoonfX4o`0003cooo]Z1?l0000boookJPCo0000
>_oonfX4o`0003?ooo]Z1?l0000NoookJP007ooonfX5o`0001Gooo]Z1Ol00017oookJPGo0000;ooo
nfX5o`00043ooo]Z1?l0000aoookJPCo0000??oonfX4o`0003;ooo]Z1?l0000joookJPCo0000<ooo
nfX4o`0001kooo]Z000OoookJPGo00005OoonfX4o`0004Wooo]Z1?l0000_oookJPGo0000@?oonfX4
o`00037ooo]Z1?l0000loookJPCo0000<_oonfX4o`0003[ooo]Z1Ol0000boookJPCo00007_oonfX0
01oooo]Z1Ol0000DoookJPGo0000BOoonfX5o`0002kooo]Z1?l00011oookJPGo0000;ooonfX5o`00
03cooo]Z1Ol0000aoookJPCo0000>_oonfX5o`0003;ooo]Z1?l0000NoookJP007ooonfX5o`0001Co
oo]Z1Ol00019oookJPGo0000;_oonfX4o`00047ooo]Z1Ol0000_oookJPGo0000??oonfX5o`00033o
oo]Z1Ol0000koookJPCo0000<_oonfX4o`0001kooo]Z000OoookJPGo00004ooonfX5o`0004_ooo]Z
1?l0000]oookJPGo0000@_oonfX4o`0002oooo]Z1?l0000noookJPCo0000<?oonfX5o`0003_ooo]Z
1?l0000aoookJPGo00007_oonfX001oooo]Z1Ol0000CoookJPGo0000BooonfX5o`0002cooo]Z1Ol0
0012oookJPCo0000;ooonfX4o`0003kooo]Z1?l0000`oookJPCo0000??oonfX4o`00037ooo]Z1?l0
000OoookJP007ooonfX5o`0001;ooo]Z1Ol0001<oookJPGo0000;?oonfX4o`0004?ooo]Z1?l0000_
oookJPCo0000?_oonfX4o`00033ooo]Z1?l0000loookJPCo0000<OoonfX4o`0001oooo]Z000Ooook
JPGo00004_oonfX5o`0004gooo]Z1?l0000[oookJPGo0000@ooonfX5o`0002gooo]Z1Ol0000noook
JPCo0000<?oonfX4o`0003cooo]Z1?l0000aoookJPCo00007ooonfX001oooo]Z1Ol0000AoookJPGo
0000C_oonfX5o`0002[ooo]Z1Ol00013oookJPGo0000;OoonfX5o`0003kooo]Z1Ol0000_oookJPCo
0000??oonfX4o`00037ooo]Z1?l0000OoookJP007ooonfX5o`00017ooo]Z1Ol0001>oookJPGo0000
:_oonfX4o`0004Gooo]Z1?l0000]oookJPCo0000?ooonfX5o`0002oooo]Z1?l0000loookJPGo0000
<?oonfX4o`0001oooo]Z000OoookJPGo00004?oonfX5o`00053ooo]Z1Ol0000XoookJPGo0000AOoo
nfX4o`0002gooo]Z1?l00010oookJPCo0000;ooonfX4o`0003cooo]Z1Ol0000`oookJPCo00007ooo
nfX001oooo]Z1Ol0000@oookJPGo0000D?oonfX5o`0002Sooo]Z1Ol00015oookJPGo0000;?oonfX4
o`00043ooo]Z1?l0000^oookJPGo0000?OoonfX4o`00033ooo]Z1?l0000OoookJP007ooonfX5o`00
00oooo]Z1Ol0001BoookJPCo0000:?oonfX4o`0004Kooo]Z1Ol0000/oookJPCo0000@?oonfX4o`00
02kooo]Z1?l0000noookJPCo0000<?oonfX4o`0001oooo]Z000OoookJPGo00003ooonfX5o`0005;o
oo]Z1Ol0000WoookJPCo0000AooonfX4o`0002_ooo]Z1Ol00010oookJPCo0000;_oonfX4o`0003ko
oo]Z1?l0000_oookJPGo00007ooonfX001oooo]Z1Ol0000>oookJPGo0000DooonfX5o`0002Kooo]Z
1Ol00017oookJPCo0000:ooonfX5o`00043ooo]Z1?l0000^oookJPCo0000?_oonfX4o`0002oooo]Z
1Ol0000OoookJP007ooonfX5o`0000kooo]Z1Ol0001DoookJPCo00009_oonfX4o`0004Sooo]Z1?l0
000[oookJPCo0000@OoonfX5o`0002gooo]Z1?l0000noookJPCo0000;ooonfX4o`00023ooo]Z000O
oookJPGo00003OoonfX5o`0005Gooo]Z1Ol0000UoookJPCo0000B?oonfX5o`0002[ooo]Z1?l00011
oookJPGo0000;OoonfX4o`0003kooo]Z1?l0000_oookJPCo00008?oonfX001oooo]Z1Ol0000=oook
JPGo0000EOoonfX5o`0002Cooo]Z1Ol00018oookJPGo0000:_oonfX4o`0004;ooo]Z1?l0000]oook
JPCo0000?_oonfX4o`0002oooo]Z1?l0000PoookJP007ooonfX5o`0000cooo]Z1Ol0001GoookJPCo
00009?oonfX5o`0004Wooo]Z1?l0000YoookJPGo0000@_oonfX4o`0002cooo]Z1Ol0000noookJPGo
0000;_oonfX4o`00023ooo]Z000OoookJPGo00003?oonfX5o`0005Oooo]Z1Ol0000SoookJPCo0000
B_oonfX4o`0002Wooo]Z1Ol00012oookJPCo0000;?oonfX5o`0003kooo]Z1Ol0000^oookJPCo0000
8?oonfX001oooo]Z1Ol0000;oookJPGo0000F?oonfX5o`0002;ooo]Z1Ol0001:oookJPGo0000:?oo
nfX4o`0004?ooo]Z1?l0000/oookJPCo0000@?oonfX4o`0002kooo]Z1?l0000PoookJP007ooonfX5
o`0000[ooo]Z1Ol0001JoookJPGo00008OoonfX5o`0004[ooo]Z1Ol0000XoookJPCo0000@ooonfX5
o`0002_ooo]Z1?l00010oookJPCo0000;_oonfX4o`00023ooo]Z000OoookJPGo00002_oonfX5o`00
05[ooo]Z1Ol0000QoookJPCo0000C?oonfX4o`0002Sooo]Z1?l00013oookJPGo0000:ooonfX4o`00
043ooo]Z1?l0000]oookJPGo00008?oonfX001oooo]Z1Ol00009oookJPGo0000G?oonfX4o`00023o
oo]Z1Ol0001<oookJPCo00009ooonfX5o`0004Cooo]Z1?l0000[oookJPCo0000@?oonfX4o`0002go
oo]Z1Ol0000PoookJP007ooonfX5o`0000Sooo]Z1_l0001LoookJPGo00007ooonfX4o`0004gooo]Z
1?l0000WoookJPGo0000A?oonfX4o`0002_ooo]Z1?l00010oookJPCo0000;OoonfX4o`00027ooo]Z
000OoookJPGo00001ooonfX6o`0005gooo]Z1Ol0000NoookJPGo0000COoonfX5o`0002Kooo]Z1?l0
0015oookJPCo0000:_oonfX5o`00043ooo]Z1?l0000]oookJPCo00008OoonfX001oooo]Z1Ol00007
oookJPGo0000GooonfX5o`0001gooo]Z1Ol0001=oookJPGo00009_oonfX4o`0004Gooo]Z1?l0000Z
oookJPGo0000@?oonfX5o`0002cooo]Z1?l0000QoookJP007ooonfX5o`0000Kooo]Z1Ol0001Poook
JPGo00007OoonfX4o`0004oooo]Z1?l0000VoookJPCo0000AOoonfX4o`0002[ooo]Z1?l00011oook
JPGo0000;?oonfX4o`00027ooo]Z000OoookJPGo00001OoonfX6o`00067ooo]Z1?l0000LoookJPGo
0000CooonfX4o`0002Gooo]Z1Ol00015oookJPGo0000:OoonfX4o`0004;ooo]Z1?l0000/oookJPCo
00008OoonfX001?ooo]Z0ol007l9oookJPGo00000ooonfX7o`0006;ooo]Z1Ol0000KoookJPGo0000
CooonfX5o`0002Cooo]Z1Ol00015oookJPGo0000:OoonfX4o`0004;ooo]Z1?l0000/oookJPCo0000
8OoonfX001?ooo]Z0ol007l9oookJPGo00000_oonfX7o`0006?ooo]Z1Ol0000JoookJPGo0000D?oo
nfX5o`0002Cooo]Z1?l00017oookJPCo0000:OoonfX4o`0004;ooo]Z1?l0000/oookJPCo00008Ooo
nfX001?ooo]Z0ol007l9oookJPgo0000IOoonfX5o`0001Wooo]Z1Ol0001AoookJPCo00009?oonfX4
o`0004Oooo]Z1?l0000YoookJPCo0000@_oonfX4o`0002cooo]Z1?l0000QoookJP004ooonfX3o`00
O`Wooo]Z3?l0001VoookJPGo00006OoonfX4o`0005;ooo]Z1?l0000SoookJPGo0000AooonfX4o`00
02Sooo]Z1Ol00012oookJPCo0000:ooonfX5o`00027ooo]Z000CoookJP?o001o2OoonfX:o`0006Wo
oo]Z1Ol0000GoookJPGo0000D_oonfX5o`0002;ooo]Z1Ol00017oookJPCo0000:?oonfX5o`0004;o
oo]Z1?l0000[oookJPCo00008_oonfX001?ooo]Z0ol007l9oookJPWo0000J_oonfX5o`0001Oooo]Z
1Ol0001BoookJPGo00008_oonfX4o`0004Sooo]Z1Ol0000WoookJPCo0000@ooonfX4o`0002_ooo]Z
1?l0000RoookJP004ooonfX3o`00O`Wooo]Z1ol0001]oookJPGo00005OoonfX5o`0005Cooo]Z1?l0
000RoookJPCo0000B?oonfX5o`0002Oooo]Z1?l00013oookJPGo0000:_oonfX4o`0002;ooo]Z000C
oookJP?o001o2OoonfX5o`0006oooo]Z1Ol0000EoookJPGo0000E?oonfX4o`0002;ooo]Z1?l00019
oookJPCo00009ooonfX4o`0004Cooo]Z1?l0000ZoookJPCo00008_oonfX001?ooo]Z0ol007l9oook
JPGo0000L?oonfX5o`0001?ooo]Z1Ol0001EoookJPGo00008?oonfX5o`0004Wooo]Z1?l0000Woook
JPCo0000A?oonfX4o`0002[ooo]Z1?l0000RoookJP004?oonfX6o`00O`Wooo]Z1Ol0001`oookJPGo
00004ooonfX5o`0005Gooo]Z1Ol0000PoookJPGo0000BOoonfX4o`0002Oooo]Z1?l00014oookJPCo
0000:_oonfX4o`0002;ooo]Z000@oookJPKo001o2OoonfX5o`00077ooo]Z1Ol0000AoookJPGo0000
EooonfX4o`00023ooo]Z1?l0001:oookJPCo00009_oonfX5o`0004Cooo]Z1?l0000ZoookJPCo0000
8_oonfX001;ooo]Z1?l007l9oookJPGo0000LOoonfX5o`00017ooo]Z1Ol0001GoookJPCo00008?oo
nfX4o`0004[ooo]Z1Ol0000UoookJPCo0000AOoonfX4o`0002[ooo]Z1?l0000RoookJP004ooonfX3
o`00O`Wooo]Z1Ol0001boookJPGo00003ooonfX5o`0005Sooo]Z1Ol0000NoookJPGo0000B_oonfX5
o`0002Gooo]Z1?l00015oookJPCo0000:OoonfX5o`0002;ooo]Z000OoookJPGo0000L_oonfX6o`00
00gooo]Z1_l0001HoookJPGo00007_oonfX5o`0004_ooo]Z1?l0000UoookJPCo0000AOoonfX4o`00
02Wooo]Z1?l0000SoookJP007ooonfX5o`0007?ooo]Z1_l0000<oookJPGo0000F_oonfX4o`0001ko
oo]Z1?l0001<oookJPCo00009OoonfX4o`0004Gooo]Z1Ol0000XoookJPCo00008ooonfX001oooo]Z
1Ol0001doookJPGo00002ooonfX5o`0005_ooo]Z1?l0000NoookJPCo0000C?oonfX4o`0002Gooo]Z
1?l00015oookJPGo0000:?oonfX4o`0002?ooo]Z000OoookJPGo0000MOoonfX5o`0000Wooo]Z1_l0
001KoookJPGo00007OoonfX4o`0004cooo]Z1?l0000ToookJPGo0000A_oonfX4o`0002Sooo]Z1?l0
000SoookJP007ooonfX5o`0007Gooo]Z1ol00006oookJPKo0000G?oonfX5o`0001cooo]Z1Ol0001<
oookJPGo00008ooonfX5o`0004Kooo]Z1?l0000XoookJPCo00008ooonfX001oooo]Z1Ol0001foook
JPSo00000_oonfX7o`0005kooo]Z1?l0000LoookJPGo0000C?oonfX5o`0002?ooo]Z1?l00017oook
JPCo0000:?oonfX4o`0002?ooo]Z000OoookJPGo0000MooonfX?o`0005oooo]Z1?l0000LoookJPCo
0000C_oonfX4o`0002?ooo]Z1?l00017oookJPCo0000:?oonfX4o`0002?ooo]Z000OoookJPGo0000
N?oonfX=o`00063ooo]Z1Ol0000KoookJPCo0000C_oonfX4o`0002?ooo]Z1?l00017oookJPCo0000
9ooonfX5o`0002?ooo]Z000OoookJPGo0000N_oonfX:o`00067ooo]Z1Ol0000JoookJPGo0000C_oo
nfX4o`0002?ooo]Z1?l00017oookJPCo00009ooonfX5o`0002?ooo]Z000OoookJPGo0000O?oonfX6
o`0006Cooo]Z1?l0000JoookJPGo0000C_oonfX4o`0002;ooo]Z1Ol00017oookJPGo00009_oonfX4
o`0002Cooo]Z000OoookJPGo0000i_oonfX4o`0001[ooo]Z1?l0001?oookJPGo00008OoonfX5o`00
04Oooo]Z1Ol0000VoookJPCo00009?oonfX001oooo]Z1Ol0003VoookJPGo00006?oonfX5o`0004oo
oo]Z1Ol0000QoookJPCo0000BOoonfX4o`0002Kooo]Z1?l0000ToookJP007ooonfX5o`000>Oooo]Z
1?l0000HoookJPGo0000D?oonfX4o`00027ooo]Z1?l00019oookJPCo00009_oonfX4o`0002Cooo]Z
000OoookJPGo0000iooonfX4o`0001Sooo]Z1?l0001AoookJPCo00008OoonfX4o`0004Wooo]Z1?l0
000VoookJPCo00009?oonfX001oooo]Z1Ol0003WoookJPGo00005ooonfX4o`00057ooo]Z1?l0000Q
oookJPCo0000BOoonfX4o`0002Kooo]Z1?l0000ToookJP007ooonfX5o`000>Oooo]Z1Ol0000Foook
JPGo0000DOoonfX4o`00023ooo]Z1Ol00019oookJPCo00009_oonfX4o`0002Cooo]Z000OoookJPGo
0000j?oonfX4o`0001Kooo]Z1Ol0001AoookJPGo00007ooonfX5o`0004Wooo]Z1?l0000UoookJPGo
00009?oonfX001oooo]Z1Ol0003XoookJPGo00005OoonfX4o`0005;ooo]Z1Ol0000OoookJPCo0000
B_oonfX5o`0002Cooo]Z1Ol0000ToookJP007ooonfX5o`000>Sooo]Z1Ol0000DoookJPGo0000Dooo
nfX4o`0001oooo]Z1?l0001:oookJPGo00009?oonfX4o`0002Gooo]Z000OoookJPGo0000jOoonfX4
o`0001Cooo]Z1Ol0001CoookJPCo00007ooonfX4o`0004_ooo]Z1?l0000ToookJPCo00009OoonfX0
01oooo]Z1Ol0003YoookJPGo00004ooonfX4o`0005Cooo]Z1?l0000OoookJPCo0000BooonfX4o`00
02Cooo]Z1?l0000UoookJP007ooonfX5o`000>Wooo]Z1Ol0000BoookJPGo0000E?oonfX5o`0001go
oo]Z1Ol0001;oookJPCo00009?oonfX4o`0002Gooo]Z000OoookJPGo0000j_oonfX4o`0001;ooo]Z
1Ol0001DoookJPGo00007OoonfX5o`0004_ooo]Z1?l0000ToookJPCo00009OoonfX001oooo]Z1Ol0
003ZoookJPGo00004OoonfX4o`0005Kooo]Z1?l0000MoookJPCo0000C?oonfX4o`0002Cooo]Z1?l0
000UoookJP007ooonfX5o`000>[ooo]Z1Ol0000@oookJPGo0000E_oonfX4o`0001gooo]Z1?l0001<
oookJPCo00008ooonfX5o`0002Gooo]Z000OoookJPGo0000jooonfX5o`0000oooo]Z1Ol0001Foook
JPCo00007OoonfX4o`0004cooo]Z1Ol0000RoookJPGo00009OoonfX001oooo]Z1Ol0003[oookJPGo
00003ooonfX4o`0005Oooo]Z1?l0000MoookJPCo0000C?oonfX5o`0002;ooo]Z1?l0000VoookJP00
7ooonfX5o`000>cooo]Z1?l0000>oookJPGo0000EooonfX5o`0001_ooo]Z1Ol0001=oookJPCo0000
8_oonfX4o`0002Kooo]Z000OoookJPGo0000k?oonfX5o`0000gooo]Z1Ol0001HoookJPCo00006ooo
nfX5o`0004gooo]Z1?l0000RoookJPCo00009_oonfX001oooo]Z1Ol0003/oookJPGo00003?oonfX5
o`0005Wooo]Z1?l0000KoookJPCo0000C_oonfX4o`0002;ooo]Z1?l0000VoookJP007ooonfX5o`00
0>gooo]Z1Ol0000;oookJPGo0000FOoonfX4o`0001_ooo]Z1?l0001>oookJPCo00008_oonfX4o`00
02Kooo]Z000OoookJPGo0000kOoonfX5o`0000[ooo]Z1Ol0001JoookJPCo00006ooonfX4o`0004ko
oo]Z1?l0000RoookJPCo00009_oonfX001oooo]Z1Ol0003^oookJPGo00002OoonfX5o`0005[ooo]Z
1Ol0000IoookJPGo0000C_oonfX5o`00023ooo]Z1Ol0000VoookJP007ooonfX5o`000>kooo]Z1_l0
0007oookJPGo0000FooonfX5o`0001Wooo]Z1Ol0001>oookJPGo00008?oonfX5o`0002Kooo]Z000O
oookJPGo0000kooonfX5o`0000Oooo]Z1Ol0001LoookJPCo00006OoonfX4o`00053ooo]Z1?l0000P
oookJPCo00009ooonfX001oooo]Z1Ol0003`oookJPGo00001OoonfX5o`0005gooo]Z1?l0000Ioook
JPCo0000D?oonfX4o`00023ooo]Z1?l0000WoookJP007ooonfX5o`000?3ooo]Z1_l00002oookJPKo
0000G_oonfX4o`0001Wooo]Z1?l0001@oookJPCo00008?oonfX4o`0002Oooo]Z000?oookJPWo001o
1ooonfX5o`000?7ooo]Z3Ol0001NoookJPGo00005ooonfX5o`00053ooo]Z1?l0000PoookJPCo0000
9ooonfX000oooo]Z2Ol007l7oookJPGo0000l_oonfX;o`00063ooo]Z1?l0000GoookJPGo0000D?oo
nfX4o`00023ooo]Z1?l0000WoookJP003ooonfX4o`00O`cooo]Z1Ol0003coookJPWo0000HOoonfX4
o`0001Oooo]Z1?l0001AoookJPGo00007ooonfX4o`0002Oooo]Z000@oookJPCo001o2ooonfX5o`00
0?Cooo]Z1_l0001SoookJPCo00005ooonfX4o`00057ooo]Z1Ol0000NoookJPGo00009ooonfX0017o
oo]Z1Ol007l9oookJPOo0000oooonfYLoookJPGo00005_oonfX4o`0005;ooo]Z1?l0000NoookJPGo
00009ooonfX001?ooo]Z1?l007l8oookJPGo0000oooonfYNoookJPGo00005OoonfX5o`0005;ooo]Z
1?l0000NoookJPCo0000:?oonfX001Cooo]Z0ol007l8oookJPGo0000oooonfYOoookJPCo00005Ooo
nfX5o`0005;ooo]Z1?l0000NoookJPCo0000:?oonfX001Gooo]Z0ol007l7oookJPGo0000oooonfYO
oookJPCo00005OoonfX4o`0005?ooo]Z1?l0000NoookJPCo0000:?oonfX000oooo]Z0ol007l3oook
JP?o001o1ooonfX5o`000?oooo]ZGooonfX5o`0001Cooo]Z1?l0001CoookJPCo00007_oonfX4o`00
02Sooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJUoooo]Z1Ol0000DoookJPCo
0000DooonfX4o`0001kooo]Z1?l0000XoookJP003ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000
oooonfYPoookJPCo00004ooonfX5o`0005?ooo]Z1Ol0000LoookJPGo0000:?oonfX0013ooo]Z1ol0
07l8oookJPGo0000oooonfYPoookJPCo00004ooonfX5o`0005Cooo]Z1?l0000LoookJPGo0000:?oo
nfX0017ooo]Z1Ol007l9oookJPGo0000oooonfYPoookJPCo00004ooonfX4o`0005Gooo]Z1?l0000L
oookJPCo0000:OoonfX001oooo]Z1Ol0003ooookJV3ooo]Z1Ol0000BoookJPCo0000EOoonfX4o`00
01cooo]Z1?l0000YoookJP007ooonfX5o`000?oooo]ZHOoonfX4o`00017ooo]Z1Ol0001EoookJPCo
00007?oonfX4o`0002Wooo]Z000OoookJPGo0000oooonfYQoookJPCo00004OoonfX5o`0005Gooo]Z
1?l0000LoookJPCo0000:OoonfX001oooo]Z1Ol0003ooookJV7ooo]Z1Ol0000@oookJPCo0000E_oo
nfX5o`0001_ooo]Z1?l0000YoookJP007ooonfX5o`000?oooo]ZHOoonfX5o`00013ooo]Z1?l0001F
oookJPGo00006_oonfX5o`0002Wooo]Z000OoookJPGo0000oooonfYRoookJPCo00003ooonfX5o`00
05Oooo]Z1?l0000JoookJPGo0000:OoonfX001oooo]Z1Ol0003ooookJV;ooo]Z1?l0000?oookJPGo
0000EooonfX4o`0001[ooo]Z1?l0000ZoookJP007ooonfX5o`000?oooo]ZH_oonfX5o`0000kooo]Z
1?l0001HoookJPCo00006_oonfX4o`0002[ooo]Z000OoookJPGo0000oooonfYRoookJPGo00003Ooo
nfX5o`0005Sooo]Z1?l0000JoookJPCo0000:_oonfX001oooo]Z1Ol0003ooookJV?ooo]Z1?l0000=
oookJPGo0000F?oonfX4o`0001[ooo]Z1?l0000ZoookJP007ooonfX5o`000?oooo]ZHooonfX5o`00
00cooo]Z1?l0001IoookJPGo00006OoonfX4o`0002[ooo]Z000OoookJPGo0000oooonfYSoookJPGo
00002ooonfX5o`0005Wooo]Z1Ol0000HoookJPGo0000:_oonfX001oooo]Z1Ol0003ooookJVCooo]Z
1?l0000;oookJPGo0000F_oonfX4o`0001Sooo]Z1Ol0000ZoookJP007ooonfX5o`000?oooo]ZI?oo
nfX5o`0000[ooo]Z1?l0001KoookJPCo00006?oonfX4o`0002_ooo]Z000OoookJPGo0000oooonfYT
oookJPGo00002OoonfX5o`0005_ooo]Z1?l0000HoookJPCo0000:ooonfX001oooo]Z1Ol0003ooook
JVGooo]Z1Ol00008oookJPGo0000FooonfX4o`0001Sooo]Z1?l0000[oookJP007ooonfX5o`000?oo
oo]ZIOoonfX5o`0000Oooo]Z1Ol0001LoookJPGo00005ooonfX4o`0002_ooo]Z000OoookJPGo0000
oooonfYVoookJPGo00001_oonfX5o`0005cooo]Z1Ol0000FoookJPGo0000:ooonfX001oooo]Z1Ol0
003ooookJVKooo]Z1Ol00005oookJPGo0000G_oonfX4o`0001Kooo]Z1Ol0000[oookJP007ooonfX5
o`000?oooo]ZIooonfX5o`0000Cooo]Z1Ol0001NoookJPCo00005_oonfX4o`0002cooo]Z000Ooook
JPGo0000oooonfYWoookJPKo00000_oonfX5o`0005oooo]Z1?l0000FoookJPCo0000;?oonfX001oo
oo]Z1Ol0003ooookJVSooo]Z3?l0001OoookJPCo00005_oonfX4o`0002cooo]Z000OoookJPGo0000
oooonfYYoookJP[o0000H?oonfX5o`0001Gooo]Z1?l0000/oookJP007ooonfX5o`000?oooo]ZJ_oo
nfX8o`00067ooo]Z1Ol0000DoookJPGo0000;?oonfX001oooo]Z1Ol0003ooookJV_ooo]Z1_l0001S
oookJPCo00005?oonfX5o`0002cooo]Z000OoookJPGo0000oooonf[DoookJPCo00005?oonfX4o`00
02gooo]Z000OoookJPGo0000oooonf[DoookJPCo00005?oonfX4o`0002gooo]Z000OoookJPGo0000
oooonf[DoookJPGo00004ooonfX4o`0002gooo]Z000OoookJPGo0000oooonf[DoookJPGo00004ooo
nfX4o`0002gooo]Z000OoookJPGo0000oooonf[EoookJPCo00004_oonfX5o`0002gooo]Z000Ooook
JPGo0000oooonf[EoookJPCo00004_oonfX5o`0002gooo]Z000OoookJPGo0000oooonf[EoookJPCo
00004_oonfX4o`0002kooo]Z000OoookJPGo0000oooonf[EoookJPGo00004OoonfX4o`0002kooo]Z
000OoookJPGo0000oooonf[EoookJPGo00004OoonfX4o`0002kooo]Z000OoookJPGo0000oooonf[F
oookJPCo00004?oonfX5o`0002kooo]Z000OoookJPGo0000oooonf[FoookJPCo00004?oonfX5o`00
02kooo]Z000OoookJPGo0000oooonf[FoookJPCo00004?oonfX4o`0002oooo]Z000AoookJPGo001o
2OoonfX5o`000?oooo]Ze_oonfX5o`0000oooo]Z1?l0000_oookJP004?oonfX7o`00O`Sooo]Z1Ol0
003ooookJ]Kooo]Z1Ol0000?oookJPCo0000;ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX5
o`000?oooo]ZeooonfX4o`0000kooo]Z1Ol0000_oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[GoookJPCo00003_oonfX5o`0002oooo]Z000EoookJP?o001o1ooonfX7o`000?oo
oo]ZeOoonfX5o`0000gooo]Z1?l0000`oookJP005OoonfX3o`00O`Oooo]Z1Ol0003ooookJ]Oooo]Z
1Ol0000=oookJPCo0000<?oonfX001?ooo]Z1?l007l8oookJPGo0000oooonf[HoookJPCo00003?oo
nfX5o`00033ooo]Z000CoookJP?o001o2OoonfX5o`000?oooo]Zf?oonfX4o`0000cooo]Z1Ol0000`
oookJP005OoonfX2o`00O`Sooo]Z1Ol0003ooookJ]Sooo]Z1Ol0000;oookJPCo0000<OoonfX000oo
oo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]Zf?oonfX5o`0000_ooo]Z1?l0000aoookJP00
3ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[IoookJPCo00002_oonfX5o`00037ooo]Z
000@oookJPOo001o2?oonfX5o`000?oooo]ZfOoonfX4o`0000[ooo]Z1Ol0000aoookJP004OoonfX5
o`00O`Wooo]Z1Ol0003ooookJ]Wooo]Z1Ol00009oookJPCo0000<_oonfX001oooo]Z1Ol0003ooook
J]Wooo]Z1Ol00008oookJPGo0000<_oonfX001oooo]Z1Ol0003ooookJ][ooo]Z1?l00008oookJPGo
0000<_oonfX001oooo]Z1Ol0003ooookJ][ooo]Z1Ol00007oookJPCo0000<ooonfX001oooo]Z1Ol0
003ooookJ][ooo]Z1Ol00006oookJPGo0000<ooonfX001oooo]Z1Ol0003ooookJ]_ooo]Z1Ol00005
oookJPGo0000<ooonfX001oooo]Z1Ol0003ooookJ]_ooo]Z1Ol00004oookJPGo0000=?oonfX001oo
oo]Z1Ol0003ooookJ]cooo]Z1Ol00003oookJPGo0000=?oonfX001oooo]Z1Ol0003ooookJ]cooo]Z
1Ol00002oookJPGo0000=OoonfX001oooo]Z1Ol0003ooookJ]gooo]Z2ol0000eoookJP007ooonfX5
o`000?oooo]ZgOoonfX:o`0003Kooo]Z000OoookJPGo0000oooonf[NoookJPSo0000=ooonfX001oo
oo]Z1Ol0003ooookJ]oooo]Z1_l0000hoookJP007ooonfX5o`000?oooo]ZhOoonfX3o`0003Wooo]Z
000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000Ooook
JPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000
oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[o
oookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1310.15, -3.37762, 38.8875, \
0.0200909}},
  CellTags->"mmtag:23:noise__periodic_bias"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:23:noise__periodic_bias"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.308685 294856 [
[.26188 .29618 -22 -20 ]
[.26188 .29618 22 0 ]
[.49995 .29618 -27 -20 ]
[.49995 .29618 27 0 ]
[.73802 .29618 -27 -20 ]
[.73802 .29618 27 0 ]
[.9761 .29618 -27 -20 ]
[.9761 .29618 27 0 ]
[.01131 .01383 -80.4375 -11.9688 ]
[.01131 .01383 0 11.9688 ]
[.01131 .16126 -80.4375 -11.875 ]
[.01131 .16126 0 11.875 ]
[.01131 .45611 -67.5 -11.875 ]
[.01131 .45611 0 11.875 ]
[.01131 .60354 -67.5 -11.9688 ]
[.01131 .60354 0 11.9688 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .30868 m
.26188 .31493 L
s
gsave
.26188 .29618 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .30868 m
.49995 .31493 L
s
gsave
.49995 .29618 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .30868 m
.73802 .31493 L
s
gsave
.73802 .29618 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .30868 m
.9761 .31493 L
s
gsave
.9761 .29618 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .30868 m
.07142 .31243 L
s
.11904 .30868 m
.11904 .31243 L
s
.16665 .30868 m
.16665 .31243 L
s
.21427 .30868 m
.21427 .31243 L
s
.3095 .30868 m
.3095 .31243 L
s
.35711 .30868 m
.35711 .31243 L
s
.40472 .30868 m
.40472 .31243 L
s
.45234 .30868 m
.45234 .31243 L
s
.54757 .30868 m
.54757 .31243 L
s
.59518 .30868 m
.59518 .31243 L
s
.6428 .30868 m
.6428 .31243 L
s
.69041 .30868 m
.69041 .31243 L
s
.78564 .30868 m
.78564 .31243 L
s
.83325 .30868 m
.83325 .31243 L
s
.88087 .30868 m
.88087 .31243 L
s
.92848 .30868 m
.92848 .31243 L
s
.01 w
0 .30868 m
1 .30868 L
s
.25 Mabswid
.02381 .01383 m
.03006 .01383 L
s
gsave
.01131 .01383 -141.438 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 22.938 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
88.438 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
102.438 22.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
122.438 14.312 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
131.188 14.312 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.02381 .16126 m
.03006 .16126 L
s
gsave
.01131 .16126 -141.438 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 22.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
88.438 22.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
102.438 22.750 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
122.438 14.125 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
131.188 14.125 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.02381 .45611 m
.03006 .45611 L
s
gsave
.01131 .45611 -128.5 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
75.500 22.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
89.500 22.750 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
109.500 14.125 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
118.250 14.125 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.02381 .60354 m
.03006 .60354 L
s
gsave
.01131 .60354 -128.5 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 22.938 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
75.500 22.938 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(\\264) show
89.500 22.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
109.500 14.312 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
118.250 14.312 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 12.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04331 m
.02756 .04331 L
s
.02381 .0728 m
.02756 .0728 L
s
.02381 .10229 m
.02756 .10229 L
s
.02381 .13177 m
.02756 .13177 L
s
.02381 .19074 m
.02756 .19074 L
s
.02381 .22023 m
.02756 .22023 L
s
.02381 .24971 m
.02756 .24971 L
s
.02381 .2792 m
.02756 .2792 L
s
.02381 .33817 m
.02756 .33817 L
s
.02381 .36766 m
.02756 .36766 L
s
.02381 .39714 m
.02756 .39714 L
s
.02381 .42663 m
.02756 .42663 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51508 m
.02756 .51508 L
s
.02381 .54457 m
.02756 .54457 L
s
.02381 .57406 m
.02756 .57406 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .30868 Mdot
.0239 .30868 Mdot
.02395 .47554 Mdot
.024 .59222 Mdot
.02405 .59966 Mdot
.0241 .51913 Mdot
.02414 .55814 Mdot
.02419 .35111 Mdot
.02424 .40533 Mdot
.02429 .33471 Mdot
.02433 .3674 Mdot
.02438 .3814 Mdot
.02443 .54007 Mdot
.02448 .56523 Mdot
.02452 .32186 Mdot
.02457 .30941 Mdot
.02462 .57016 Mdot
.02467 .35354 Mdot
.02471 .58264 Mdot
.02476 .38596 Mdot
.02481 .58307 Mdot
.02486 .50493 Mdot
.0249 .39604 Mdot
.02495 .41656 Mdot
.025 .32521 Mdot
.02505 .43714 Mdot
.0251 .52401 Mdot
.02514 .42785 Mdot
.02519 .32907 Mdot
.02524 .52152 Mdot
.02529 .56937 Mdot
.02533 .38538 Mdot
.02538 .52723 Mdot
.02543 .49545 Mdot
.02548 .51061 Mdot
.02552 .31261 Mdot
.02557 .59065 Mdot
.02562 .5337 Mdot
.02567 .49736 Mdot
.02571 .31181 Mdot
.02576 .32909 Mdot
.02581 .48875 Mdot
.02586 .51817 Mdot
.0259 .52929 Mdot
.02595 .34945 Mdot
.026 .58725 Mdot
.02605 .4307 Mdot
.0261 .42128 Mdot
.02614 .33279 Mdot
.02619 .45866 Mdot
.02624 .51008 Mdot
.02629 .59682 Mdot
.02633 .31224 Mdot
.02638 .5405 Mdot
.02643 .54406 Mdot
.02648 .51992 Mdot
.02652 .38834 Mdot
.02657 .35352 Mdot
.02662 .34191 Mdot
.02667 .51576 Mdot
.02671 .40098 Mdot
.02676 .4231 Mdot
.02681 .44781 Mdot
.02686 .51235 Mdot
.0269 .38027 Mdot
.02695 .53757 Mdot
.027 .53286 Mdot
.02705 .58626 Mdot
.02709 .33915 Mdot
.02714 .55349 Mdot
.02719 .41046 Mdot
.02724 .47327 Mdot
.02729 .31463 Mdot
.02733 .40309 Mdot
.02738 .50348 Mdot
.02743 .47953 Mdot
.02748 .3106 Mdot
.02752 .46564 Mdot
.02757 .56245 Mdot
.02762 .56263 Mdot
.02767 .52527 Mdot
.02771 .42025 Mdot
.02776 .52865 Mdot
.02781 .35496 Mdot
.02786 .43236 Mdot
.0279 .60006 Mdot
.02795 .38887 Mdot
.028 .44549 Mdot
.02805 .36009 Mdot
.02809 .37046 Mdot
.02814 .45883 Mdot
.02819 .46202 Mdot
.02824 .32886 Mdot
.02829 .41973 Mdot
.02833 .35625 Mdot
.02838 .59146 Mdot
.02843 .32206 Mdot
.02848 .32444 Mdot
.02852 .45541 Mdot
.02857 .41969 Mdot
.02862 .31919 Mdot
.02867 .46138 Mdot
.02871 .49552 Mdot
.02876 .45959 Mdot
.02881 .39643 Mdot
.02886 .34876 Mdot
.0289 .56933 Mdot
.02895 .41221 Mdot
.029 .56648 Mdot
.02905 .35108 Mdot
.02909 .48796 Mdot
.02914 .56905 Mdot
.02919 .51383 Mdot
.02924 .58289 Mdot
.02929 .33652 Mdot
.02933 .4144 Mdot
.02938 .49232 Mdot
.02943 .47048 Mdot
.02948 .58242 Mdot
.02952 .42505 Mdot
.02957 .47749 Mdot
.02962 .45323 Mdot
.02967 .43417 Mdot
.02971 .3125 Mdot
.02976 .46541 Mdot
.02981 .59379 Mdot
.02986 .54056 Mdot
.0299 .45478 Mdot
.02995 .37596 Mdot
.03 .55199 Mdot
.03005 .57302 Mdot
.03009 .34947 Mdot
.03014 .41121 Mdot
.03019 .50774 Mdot
.03024 .39186 Mdot
.03029 .38204 Mdot
.03033 .49896 Mdot
.03038 .5264 Mdot
.03043 .362 Mdot
.03048 .56913 Mdot
.03052 .31324 Mdot
.03057 .36248 Mdot
.03062 .38096 Mdot
.03067 .45057 Mdot
.03071 .43707 Mdot
.03076 .51053 Mdot
.03081 .54803 Mdot
.03086 .44442 Mdot
.0309 .57283 Mdot
.03095 .51787 Mdot
.031 .31371 Mdot
.03105 .5907 Mdot
.03109 .50303 Mdot
.03114 .56687 Mdot
.03119 .34164 Mdot
.03124 .54728 Mdot
.03128 .39783 Mdot
.03133 .3651 Mdot
.03138 .55058 Mdot
.03143 .47114 Mdot
.03148 .49958 Mdot
.03152 .43937 Mdot
.03157 .49435 Mdot
.03162 .5026 Mdot
.03167 .49203 Mdot
.03171 .38254 Mdot
.03176 .419 Mdot
.03181 .3576 Mdot
.03186 .36049 Mdot
.0319 .47235 Mdot
.03195 .47126 Mdot
.032 .51343 Mdot
.03205 .38787 Mdot
.03209 .55465 Mdot
.03214 .46282 Mdot
.03219 .52281 Mdot
.03224 .48487 Mdot
.03228 .58777 Mdot
.03233 .42626 Mdot
.03238 .57542 Mdot
.03243 .39204 Mdot
.03248 .52762 Mdot
.03252 .47545 Mdot
.03257 .40914 Mdot
.03262 .49213 Mdot
.03267 .39302 Mdot
.03271 .58067 Mdot
.03276 .50607 Mdot
.03281 .30472 Mdot
.03286 .31505 Mdot
.0329 .4662 Mdot
.03295 .45295 Mdot
.033 .54352 Mdot
.03305 .44194 Mdot
.03309 .59413 Mdot
.03314 .53866 Mdot
.03319 .45988 Mdot
.03324 .48633 Mdot
.03328 .43544 Mdot
.03333 .31994 Mdot
.03338 .57389 Mdot
.03343 .4974 Mdot
.03348 .31311 Mdot
.03352 .34325 Mdot
.03357 .48568 Mdot
.03362 .5684 Mdot
.03367 .43624 Mdot
.03371 .53263 Mdot
.03376 .59202 Mdot
.03381 .47894 Mdot
.03386 .45393 Mdot
.0339 .33001 Mdot
.03395 .59069 Mdot
.034 .46723 Mdot
.03405 .58587 Mdot
.03409 .47514 Mdot
.03414 .35035 Mdot
.03419 .32841 Mdot
.03424 .58966 Mdot
.03428 .53434 Mdot
.03433 .48827 Mdot
.03438 .43983 Mdot
.03443 .45706 Mdot
.03448 .51719 Mdot
.03452 .51196 Mdot
.03457 .53995 Mdot
.03462 .44655 Mdot
.03467 .47649 Mdot
.03471 .32877 Mdot
.03476 .56884 Mdot
.03481 .31268 Mdot
.03486 .54103 Mdot
.0349 .33386 Mdot
.03495 .39208 Mdot
.035 .45574 Mdot
.03505 .51309 Mdot
.03509 .34003 Mdot
.03514 .52165 Mdot
.03519 .46661 Mdot
.03524 .33977 Mdot
.03528 .5863 Mdot
.03533 .49494 Mdot
.03538 .47344 Mdot
.03543 .40186 Mdot
.03548 .39953 Mdot
.03552 .35656 Mdot
.03557 .31777 Mdot
.03562 .48085 Mdot
.03567 .48369 Mdot
.03571 .41265 Mdot
.03576 .4672 Mdot
.03581 .30542 Mdot
.03586 .45591 Mdot
.0359 .4396 Mdot
.03595 .45538 Mdot
.036 .36005 Mdot
.03605 .42279 Mdot
.03609 .34818 Mdot
.03614 .30023 Mdot
.03619 .44234 Mdot
.03624 .38322 Mdot
.03628 .42178 Mdot
.03633 .4288 Mdot
.03638 .40282 Mdot
.03643 .39197 Mdot
.03647 .52182 Mdot
.03652 .55027 Mdot
.03657 .30095 Mdot
.03662 .5872 Mdot
.03667 .4651 Mdot
.03671 .53227 Mdot
.03676 .41466 Mdot
.03681 .40315 Mdot
.03686 .35201 Mdot
.0369 .36456 Mdot
.03695 .40865 Mdot
.037 .54144 Mdot
.03705 .50654 Mdot
.03709 .50324 Mdot
.03714 .34773 Mdot
.03719 .41771 Mdot
.03724 .45734 Mdot
.03728 .50191 Mdot
.03733 .49909 Mdot
.03738 .33325 Mdot
.03743 .33425 Mdot
.03747 .37172 Mdot
.03752 .3948 Mdot
.03757 .5346 Mdot
.03762 .40567 Mdot
.03767 .41462 Mdot
.03771 .39209 Mdot
.03776 .54041 Mdot
.03781 .53351 Mdot
.03786 .47521 Mdot
.0379 .57022 Mdot
.03795 .43511 Mdot
.038 .47927 Mdot
.03805 .40835 Mdot
.03809 .45918 Mdot
.03814 .48607 Mdot
.03819 .56504 Mdot
.03824 .49735 Mdot
.03828 .40875 Mdot
.03833 .36559 Mdot
.03838 .40484 Mdot
.03843 .58736 Mdot
.03847 .50151 Mdot
.03852 .32925 Mdot
.03857 .36742 Mdot
.03862 .51238 Mdot
.03867 .40337 Mdot
.03871 .38608 Mdot
.03876 .5531 Mdot
.03881 .39418 Mdot
.03886 .30761 Mdot
.0389 .43678 Mdot
.03895 .31576 Mdot
.039 .50991 Mdot
.03905 .32825 Mdot
.03909 .29758 Mdot
.03914 .42719 Mdot
.03919 .39732 Mdot
.03924 .45959 Mdot
.03928 .40195 Mdot
.03933 .4525 Mdot
.03938 .49023 Mdot
.03943 .34616 Mdot
.03947 .3316 Mdot
.03952 .34281 Mdot
.03957 .4928 Mdot
.03962 .43449 Mdot
.03967 .29725 Mdot
.03971 .56505 Mdot
.03976 .56999 Mdot
.03981 .32576 Mdot
.03986 .50057 Mdot
.0399 .30641 Mdot
.03995 .47018 Mdot
.04 .31242 Mdot
.04005 .35798 Mdot
.04009 .5796 Mdot
.04014 .54914 Mdot
.04019 .57295 Mdot
.04024 .35423 Mdot
.04028 .44616 Mdot
.04033 .44547 Mdot
.04038 .40692 Mdot
.04043 .5406 Mdot
.04047 .58189 Mdot
.04052 .54338 Mdot
.04057 .35395 Mdot
.04062 .50211 Mdot
.04066 .5321 Mdot
.04071 .34351 Mdot
.04076 .50714 Mdot
.04081 .4976 Mdot
.04086 .55454 Mdot
.0409 .36092 Mdot
.04095 .47384 Mdot
.041 .58425 Mdot
.04105 .5404 Mdot
.04109 .47777 Mdot
.04114 .4535 Mdot
.04119 .51826 Mdot
.04124 .54755 Mdot
.04128 .51528 Mdot
.04133 .4671 Mdot
.04138 .45563 Mdot
.04143 .3929 Mdot
.04147 .36122 Mdot
.04152 .3515 Mdot
.04157 .5011 Mdot
.04162 .39698 Mdot
.04166 .40371 Mdot
.04171 .58332 Mdot
.04176 .28981 Mdot
.04181 .45046 Mdot
.04186 .35083 Mdot
.0419 .36671 Mdot
.04195 .3775 Mdot
.042 .4811 Mdot
.04205 .57499 Mdot
.04209 .47785 Mdot
.04214 .37813 Mdot
.04219 .52548 Mdot
.04224 .38705 Mdot
.04228 .31408 Mdot
.04233 .44436 Mdot
.04238 .56232 Mdot
.04243 .45605 Mdot
.04247 .43116 Mdot
.04252 .5728 Mdot
.04257 .45854 Mdot
.04262 .38385 Mdot
.04266 .36858 Mdot
.04271 .36051 Mdot
.04276 .35027 Mdot
.04281 .5636 Mdot
.04286 .36861 Mdot
.0429 .35909 Mdot
.04295 .48296 Mdot
.043 .50095 Mdot
.04305 .28999 Mdot
.04309 .56443 Mdot
.04314 .28973 Mdot
.04319 .50858 Mdot
.04324 .39465 Mdot
.04328 .47386 Mdot
.04333 .34655 Mdot
.04338 .40887 Mdot
.04343 .3678 Mdot
.04347 .31663 Mdot
.04352 .36611 Mdot
.04357 .53459 Mdot
.04362 .5183 Mdot
.04366 .32538 Mdot
.04371 .48902 Mdot
.04376 .43723 Mdot
.04381 .4361 Mdot
.04386 .54599 Mdot
.0439 .4249 Mdot
.04395 .45453 Mdot
.044 .35342 Mdot
.04405 .47272 Mdot
.04409 .52251 Mdot
.04414 .53404 Mdot
.04419 .34892 Mdot
.04424 .48853 Mdot
.04428 .51805 Mdot
.04433 .31062 Mdot
.04438 .53418 Mdot
.04443 .29961 Mdot
.04447 .45632 Mdot
.04452 .48131 Mdot
.04457 .45097 Mdot
.04462 .56233 Mdot
.04466 .37458 Mdot
.04471 .52584 Mdot
.04476 .51167 Mdot
.04481 .52098 Mdot
.04486 .46434 Mdot
.0449 .37241 Mdot
.04495 .35927 Mdot
.045 .55342 Mdot
.04505 .3229 Mdot
.04509 .49608 Mdot
.04514 .28908 Mdot
.04519 .36381 Mdot
.04524 .37824 Mdot
.04528 .53978 Mdot
.04533 .51778 Mdot
.04538 .45279 Mdot
.04543 .43758 Mdot
.04547 .51158 Mdot
.04552 .56075 Mdot
.04557 .43536 Mdot
.04562 .55818 Mdot
.04566 .31221 Mdot
.04571 .39161 Mdot
.04576 .4496 Mdot
.04581 .46519 Mdot
.04585 .36271 Mdot
.0459 .45614 Mdot
.04595 .50471 Mdot
.046 .28196 Mdot
.04605 .56614 Mdot
.04609 .37775 Mdot
.04614 .5269 Mdot
.04619 .53455 Mdot
.04624 .35057 Mdot
.04628 .36906 Mdot
.04633 .44335 Mdot
.04638 .43646 Mdot
.04643 .38566 Mdot
.04647 .42605 Mdot
.04652 .5652 Mdot
.04657 .27853 Mdot
.04662 .44847 Mdot
.04666 .43956 Mdot
.04671 .40913 Mdot
.04676 .29437 Mdot
.04681 .4153 Mdot
.04685 .32687 Mdot
.0469 .53318 Mdot
.04695 .40271 Mdot
.047 .33114 Mdot
.04705 .444 Mdot
.04709 .30677 Mdot
.04714 .39892 Mdot
.04719 .3379 Mdot
.04724 .34417 Mdot
.04728 .35252 Mdot
.04733 .43689 Mdot
.04738 .55973 Mdot
.04743 .54738 Mdot
.04747 .48132 Mdot
.04752 .27759 Mdot
.04757 .4511 Mdot
.04762 .39824 Mdot
.04766 .48775 Mdot
.04771 .27571 Mdot
.04776 .27915 Mdot
.04781 .52992 Mdot
.04785 .35488 Mdot
.0479 .55233 Mdot
.04795 .43471 Mdot
.048 .47893 Mdot
.04805 .39231 Mdot
.04809 .42524 Mdot
.04814 .37905 Mdot
.04819 .31029 Mdot
.04824 .36076 Mdot
.04828 .30142 Mdot
.04833 .31612 Mdot
.04838 .53581 Mdot
.04843 .28294 Mdot
.04847 .43396 Mdot
.04852 .32568 Mdot
.04857 .5576 Mdot
.04862 .37066 Mdot
.04866 .43041 Mdot
.04871 .44335 Mdot
.04876 .43314 Mdot
.04881 .45141 Mdot
.04885 .42821 Mdot
.0489 .43758 Mdot
.04895 .47132 Mdot
.049 .36963 Mdot
.04905 .44372 Mdot
.04909 .27572 Mdot
.04914 .55995 Mdot
.04919 .54476 Mdot
.04924 .29092 Mdot
.04928 .46382 Mdot
.04933 .52183 Mdot
.04938 .45603 Mdot
.04943 .55625 Mdot
.04947 .41946 Mdot
.04952 .55249 Mdot
.04957 .44457 Mdot
.04962 .39365 Mdot
.04966 .36499 Mdot
.04971 .56083 Mdot
.04976 .34485 Mdot
.04981 .52889 Mdot
.04985 .48716 Mdot
.0499 .39821 Mdot
.04995 .45868 Mdot
.05 .37093 Mdot
.05004 .31968 Mdot
.05009 .49172 Mdot
.05014 .35888 Mdot
.05019 .49176 Mdot
.05024 .31352 Mdot
.05028 .49604 Mdot
.05033 .37825 Mdot
.05038 .46997 Mdot
.05043 .41354 Mdot
.05047 .53792 Mdot
.05052 .48579 Mdot
.05057 .47714 Mdot
.05062 .55736 Mdot
.05066 .54857 Mdot
.05071 .30937 Mdot
.05076 .3515 Mdot
.05081 .46023 Mdot
.05085 .55032 Mdot
.0509 .52695 Mdot
.05095 .3849 Mdot
.051 .53522 Mdot
.05104 .41925 Mdot
.05109 .33527 Mdot
.05114 .28083 Mdot
.05119 .48225 Mdot
.05124 .48897 Mdot
.05128 .53768 Mdot
.05133 .35022 Mdot
.05138 .43487 Mdot
.05143 .55378 Mdot
.05147 .42528 Mdot
.05152 .44081 Mdot
.05157 .28689 Mdot
.05162 .28128 Mdot
.05166 .49961 Mdot
.05171 .52365 Mdot
.05176 .28936 Mdot
.05181 .2924 Mdot
.05185 .45493 Mdot
.0519 .43669 Mdot
.05195 .38838 Mdot
.052 .30118 Mdot
.05204 .48693 Mdot
.05209 .31575 Mdot
.05214 .41182 Mdot
.05219 .44044 Mdot
.05224 .41516 Mdot
.05228 .29827 Mdot
.05233 .48763 Mdot
.05238 .50939 Mdot
.05243 .43525 Mdot
.05247 .50567 Mdot
.05252 .31537 Mdot
.05257 .51292 Mdot
.05262 .27229 Mdot
.05266 .32702 Mdot
.05271 .29049 Mdot
.05276 .49351 Mdot
.05281 .32924 Mdot
.05285 .35979 Mdot
.0529 .26254 Mdot
.05295 .46236 Mdot
.053 .43027 Mdot
.05304 .47891 Mdot
.05309 .42982 Mdot
.05314 .42183 Mdot
.05319 .4987 Mdot
.05324 .42351 Mdot
.05328 .2782 Mdot
.05333 .53629 Mdot
.05338 .34342 Mdot
.05343 .38498 Mdot
.05347 .34501 Mdot
.05352 .28634 Mdot
.05357 .4623 Mdot
.05362 .43328 Mdot
.05366 .28861 Mdot
.05371 .32708 Mdot
.05376 .44868 Mdot
.05381 .36477 Mdot
.05385 .25647 Mdot
.0539 .38663 Mdot
.05395 .37748 Mdot
.054 .26286 Mdot
.05404 .54652 Mdot
.05409 .4767 Mdot
.05414 .49948 Mdot
.05419 .33607 Mdot
.05424 .37381 Mdot
.05428 .31181 Mdot
.05433 .25758 Mdot
.05438 .46405 Mdot
.05443 .35209 Mdot
.05447 .3267 Mdot
.05452 .46518 Mdot
.05457 .33508 Mdot
.05462 .26293 Mdot
.05466 .29605 Mdot
.05471 .25841 Mdot
.05476 .45203 Mdot
.05481 .52439 Mdot
.05485 .51888 Mdot
.0549 .35948 Mdot
.05495 .342 Mdot
.055 .5225 Mdot
.05504 .38667 Mdot
.05509 .53112 Mdot
.05514 .33324 Mdot
.05519 .52477 Mdot
.05523 .45861 Mdot
.05528 .28526 Mdot
.05533 .25063 Mdot
.05538 .40426 Mdot
.05543 .39994 Mdot
.05547 .28066 Mdot
.05552 .33426 Mdot
.05557 .30483 Mdot
.05562 .32574 Mdot
.05566 .36268 Mdot
.05571 .25135 Mdot
.05576 .29391 Mdot
.05581 .28153 Mdot
.05585 .35596 Mdot
.0559 .3457 Mdot
.05595 .31573 Mdot
.056 .3087 Mdot
.05604 .54236 Mdot
.05609 .25456 Mdot
.05614 .3388 Mdot
.05619 .46743 Mdot
.05623 .26162 Mdot
.05628 .46639 Mdot
.05633 .35893 Mdot
.05638 .2587 Mdot
.05643 .52093 Mdot
.05647 .46531 Mdot
.05652 .49892 Mdot
.05657 .40284 Mdot
.05662 .48933 Mdot
.05666 .37995 Mdot
.05671 .44282 Mdot
.05676 .32566 Mdot
.05681 .37505 Mdot
.05685 .37684 Mdot
.0569 .39697 Mdot
.05695 .29203 Mdot
.057 .26683 Mdot
.05704 .27871 Mdot
.05709 .32864 Mdot
.05714 .52542 Mdot
.05719 .26639 Mdot
.05723 .27104 Mdot
.05728 .53142 Mdot
.05733 .30455 Mdot
.05738 .25116 Mdot
.05743 .34573 Mdot
.05747 .41855 Mdot
.05752 .29175 Mdot
.05757 .27081 Mdot
.05762 .42083 Mdot
.05766 .45987 Mdot
.05771 .42898 Mdot
.05776 .32138 Mdot
.05781 .28575 Mdot
.05785 .26176 Mdot
.0579 .34785 Mdot
.05795 .48556 Mdot
.058 .44797 Mdot
.05804 .40367 Mdot
.05809 .29967 Mdot
.05814 .46241 Mdot
.05819 .41278 Mdot
.05823 .31837 Mdot
.05828 .31228 Mdot
.05833 .43903 Mdot
.05838 .38457 Mdot
.05843 .32446 Mdot
.05847 .25021 Mdot
.05852 .43018 Mdot
.05857 .28098 Mdot
.05862 .44274 Mdot
.05866 .49512 Mdot
.05871 .40099 Mdot
.05876 .39646 Mdot
.05881 .519 Mdot
.05885 .30725 Mdot
.0589 .32054 Mdot
.05895 .35147 Mdot
.059 .49783 Mdot
.05904 .49467 Mdot
.05909 .37009 Mdot
.05914 .43843 Mdot
.05919 .33406 Mdot
.05923 .43472 Mdot
.05928 .44207 Mdot
.05933 .26502 Mdot
.05938 .25488 Mdot
.05943 .36146 Mdot
.05947 .24189 Mdot
.05952 .41398 Mdot
.05957 .46376 Mdot
.05962 .34956 Mdot
.05966 .34471 Mdot
.05971 .37097 Mdot
.05976 .25882 Mdot
.05981 .38691 Mdot
.05985 .47602 Mdot
.0599 .50663 Mdot
.05995 .27176 Mdot
.06 .31657 Mdot
.06004 .39221 Mdot
.06009 .39171 Mdot
.06014 .30516 Mdot
.06019 .35296 Mdot
.06023 .25815 Mdot
.06028 .48399 Mdot
.06033 .50163 Mdot
.06038 .44859 Mdot
.06042 .34625 Mdot
.06047 .45411 Mdot
.06052 .48171 Mdot
.06057 .32192 Mdot
.06062 .33896 Mdot
.06066 .27456 Mdot
.06071 .2522 Mdot
.06076 .50128 Mdot
.06081 .52299 Mdot
.06085 .43215 Mdot
.0609 .52176 Mdot
.06095 .34772 Mdot
.061 .28015 Mdot
.06104 .45337 Mdot
.06109 .48282 Mdot
.06114 .26377 Mdot
.06119 .41525 Mdot
.06123 .29393 Mdot
.06128 .40975 Mdot
.06133 .43758 Mdot
.06138 .38883 Mdot
.06142 .33634 Mdot
.06147 .43434 Mdot
.06152 .51503 Mdot
.06157 .27358 Mdot
.06162 .40791 Mdot
.06166 .47812 Mdot
.06171 .42357 Mdot
.06176 .45976 Mdot
.06181 .36345 Mdot
.06185 .45584 Mdot
.0619 .44689 Mdot
.06195 .46117 Mdot
.062 .45552 Mdot
.06204 .45811 Mdot
.06209 .32817 Mdot
.06214 .40984 Mdot
.06219 .23078 Mdot
.06223 .49861 Mdot
.06228 .29267 Mdot
.06233 .51754 Mdot
.06238 .45961 Mdot
.06242 .31658 Mdot
.06247 .37748 Mdot
.06252 .35606 Mdot
.06257 .35044 Mdot
.06262 .40408 Mdot
.06266 .3841 Mdot
.06271 .30909 Mdot
.06276 .46382 Mdot
.06281 .44706 Mdot
.06285 .48144 Mdot
.0629 .37007 Mdot
.06295 .32606 Mdot
.063 .51158 Mdot
.06304 .25988 Mdot
.06309 .42889 Mdot
.06314 .39035 Mdot
.06319 .27823 Mdot
.06323 .45114 Mdot
.06328 .24343 Mdot
.06333 .38378 Mdot
.06338 .2985 Mdot
.06342 .3823 Mdot
.06347 .2444 Mdot
.06352 .44248 Mdot
.06357 .50005 Mdot
.06362 .22791 Mdot
.06366 .40609 Mdot
.06371 .31475 Mdot
.06376 .3185 Mdot
.06381 .36101 Mdot
.06385 .31915 Mdot
.0639 .36775 Mdot
.06395 .38807 Mdot
.064 .39601 Mdot
.06404 .46534 Mdot
.06409 .2629 Mdot
.06414 .39237 Mdot
.06419 .35697 Mdot
.06423 .2571 Mdot
.06428 .38786 Mdot
.06433 .33441 Mdot
.06438 .42077 Mdot
.06442 .23356 Mdot
.06447 .22379 Mdot
.06452 .25543 Mdot
.06457 .25779 Mdot
.06461 .50315 Mdot
.06466 .29511 Mdot
.06471 .26899 Mdot
.06476 .24845 Mdot
.06481 .31544 Mdot
.06485 .4934 Mdot
.0649 .46335 Mdot
.06495 .4001 Mdot
.065 .21391 Mdot
.06504 .34308 Mdot
.06509 .29251 Mdot
.06514 .22114 Mdot
.06519 .26029 Mdot
.06523 .29685 Mdot
.06528 .41148 Mdot
.06533 .37531 Mdot
.06538 .21928 Mdot
.06542 .41975 Mdot
.06547 .29278 Mdot
.06552 .46492 Mdot
.06557 .49591 Mdot
.06561 .4111 Mdot
.06566 .2523 Mdot
.06571 .42188 Mdot
.06576 .50218 Mdot
.06581 .33036 Mdot
.06585 .49234 Mdot
.0659 .38742 Mdot
.06595 .40053 Mdot
.066 .34542 Mdot
.06604 .24241 Mdot
.06609 .49539 Mdot
.06614 .39965 Mdot
.06619 .21517 Mdot
.06623 .45739 Mdot
.06628 .4867 Mdot
.06633 .35162 Mdot
.06638 .42524 Mdot
.06642 .25778 Mdot
.06647 .32306 Mdot
.06652 .34381 Mdot
.06657 .21677 Mdot
.06661 .47095 Mdot
.06666 .36389 Mdot
.06671 .35346 Mdot
.06676 .31104 Mdot
.06681 .42897 Mdot
.06685 .44698 Mdot
.0669 .35607 Mdot
.06695 .48527 Mdot
.067 .44102 Mdot
.06704 .2689 Mdot
.06709 .45954 Mdot
.06714 .34881 Mdot
.06719 .40738 Mdot
.06723 .27693 Mdot
.06728 .26826 Mdot
.06733 .34182 Mdot
.06738 .45283 Mdot
.06742 .29288 Mdot
.06747 .41909 Mdot
.06752 .41883 Mdot
.06757 .40225 Mdot
.06761 .47168 Mdot
.06766 .28209 Mdot
.06771 .40867 Mdot
.06776 .43257 Mdot
.06781 .31401 Mdot
.06785 .42951 Mdot
.0679 .30346 Mdot
.06795 .20924 Mdot
.068 .36732 Mdot
.06804 .27868 Mdot
.06809 .31808 Mdot
.06814 .26792 Mdot
.06819 .30307 Mdot
.06823 .31845 Mdot
.06828 .46838 Mdot
.06833 .35945 Mdot
.06838 .22999 Mdot
.06842 .25385 Mdot
.06847 .33003 Mdot
.06852 .40475 Mdot
.06857 .43504 Mdot
.06861 .33249 Mdot
.06866 .40873 Mdot
.06871 .20498 Mdot
.06876 .4605 Mdot
.06881 .25248 Mdot
.06885 .20194 Mdot
.0689 .26896 Mdot
.06895 .34798 Mdot
.069 .31912 Mdot
.06904 .39444 Mdot
.06909 .26062 Mdot
.06914 .47621 Mdot
.06919 .24095 Mdot
.06923 .27666 Mdot
.06928 .48766 Mdot
.06933 .37305 Mdot
.06938 .41706 Mdot
.06942 .30264 Mdot
.06947 .32752 Mdot
.06952 .34217 Mdot
.06957 .36213 Mdot
.06961 .46618 Mdot
.06966 .41613 Mdot
.06971 .40029 Mdot
.06976 .22776 Mdot
.0698 .25537 Mdot
.06985 .40887 Mdot
.0699 .43216 Mdot
.06995 .46745 Mdot
.07 .25054 Mdot
.07004 .33683 Mdot
.07009 .2809 Mdot
.07014 .34484 Mdot
.07019 .34728 Mdot
.07023 .27232 Mdot
.07028 .29547 Mdot
.07033 .29961 Mdot
.07038 .26614 Mdot
.07042 .27483 Mdot
.07047 .41239 Mdot
.07052 .37232 Mdot
.07057 .45308 Mdot
.07061 .43669 Mdot
.07066 .26454 Mdot
.07071 .20431 Mdot
.07076 .47566 Mdot
.0708 .21427 Mdot
.07085 .35262 Mdot
.0709 .46472 Mdot
.07095 .41341 Mdot
.071 .29317 Mdot
.07104 .40802 Mdot
.07109 .18978 Mdot
.07114 .35517 Mdot
.07119 .4433 Mdot
.07123 .31902 Mdot
.07128 .3315 Mdot
.07133 .19939 Mdot
.07138 .36228 Mdot
.07142 .21465 Mdot
.07147 .22278 Mdot
.07152 .41879 Mdot
.07157 .27794 Mdot
.07161 .28741 Mdot
.07166 .33541 Mdot
.07171 .45046 Mdot
.07176 .32579 Mdot
.0718 .21236 Mdot
.07185 .32038 Mdot
.0719 .45874 Mdot
.07195 .3004 Mdot
.072 .34327 Mdot
.07204 .339 Mdot
.07209 .2336 Mdot
.07214 .19531 Mdot
.07219 .41798 Mdot
.07223 .33688 Mdot
.07228 .36075 Mdot
.07233 .23412 Mdot
.07238 .28601 Mdot
.07242 .19224 Mdot
.07247 .34802 Mdot
.07252 .35314 Mdot
.07257 .25761 Mdot
.07261 .45036 Mdot
.07266 .40992 Mdot
.07271 .26084 Mdot
.07276 .45048 Mdot
.0728 .30018 Mdot
.07285 .43934 Mdot
.0729 .41473 Mdot
.07295 .42275 Mdot
.073 .45907 Mdot
.07304 .45967 Mdot
.07309 .29834 Mdot
.07314 .26328 Mdot
.07319 .30368 Mdot
.07323 .40947 Mdot
.07328 .28623 Mdot
.07333 .32315 Mdot
.07338 .44444 Mdot
.07342 .23131 Mdot
.07347 .23449 Mdot
.07352 .21931 Mdot
.07357 .43417 Mdot
.07361 .35992 Mdot
.07366 .35777 Mdot
.07371 .43793 Mdot
.07376 .45983 Mdot
.0738 .42581 Mdot
.07385 .27768 Mdot
.0739 .46285 Mdot
.07395 .33999 Mdot
.07399 .46147 Mdot
.07404 .33774 Mdot
.07409 .21983 Mdot
.07414 .35531 Mdot
.07419 .18113 Mdot
.07423 .21853 Mdot
.07428 .43033 Mdot
.07433 .23034 Mdot
.07438 .24502 Mdot
.07442 .40546 Mdot
.07447 .28527 Mdot
.07452 .25865 Mdot
.07457 .1914 Mdot
.07461 .34845 Mdot
.07466 .24324 Mdot
.07471 .29641 Mdot
.07476 .30321 Mdot
.0748 .4622 Mdot
.07485 .27663 Mdot
.0749 .30769 Mdot
.07495 .3483 Mdot
.07499 .36036 Mdot
.07504 .28428 Mdot
.07509 .43799 Mdot
.07514 .35692 Mdot
.07519 .19764 Mdot
.07523 .23926 Mdot
.07528 .2573 Mdot
.07533 .3502 Mdot
.07538 .44818 Mdot
.07542 .2778 Mdot
.07547 .20075 Mdot
.07552 .27877 Mdot
.07557 .21611 Mdot
.07561 .46056 Mdot
.07566 .40993 Mdot
.07571 .26014 Mdot
.07576 .33508 Mdot
.0758 .38968 Mdot
.07585 .28568 Mdot
.0759 .42374 Mdot
.07595 .33948 Mdot
.07599 .28459 Mdot
.07604 .44418 Mdot
.07609 .24656 Mdot
.07614 .4449 Mdot
.07619 .17104 Mdot
.07623 .1767 Mdot
.07628 .35481 Mdot
.07633 .41736 Mdot
.07638 .39652 Mdot
.07642 .38395 Mdot
.07647 .1741 Mdot
.07652 .43332 Mdot
.07657 .2878 Mdot
.07661 .35207 Mdot
.07666 .35884 Mdot
.07671 .38567 Mdot
.07676 .29035 Mdot
.0768 .40503 Mdot
.07685 .26654 Mdot
.0769 .21822 Mdot
.07695 .36296 Mdot
.07699 .28658 Mdot
.07704 .30468 Mdot
.07709 .34041 Mdot
.07714 .24497 Mdot
.07719 .30366 Mdot
.07723 .22431 Mdot
.07728 .35635 Mdot
.07733 .23972 Mdot
.07738 .29254 Mdot
.07742 .32973 Mdot
.07747 .39901 Mdot
.07752 .30301 Mdot
.07757 .3682 Mdot
.07761 .32019 Mdot
.07766 .42489 Mdot
.07771 .17935 Mdot
.07776 .18006 Mdot
.0778 .41993 Mdot
.07785 .20274 Mdot
.0779 .34716 Mdot
.07795 .23299 Mdot
.07799 .31629 Mdot
.07804 .44207 Mdot
.07809 .44156 Mdot
.07814 .40356 Mdot
.07819 .17369 Mdot
.07823 .26354 Mdot
.07828 .35825 Mdot
.07833 .26136 Mdot
.07838 .40549 Mdot
.07842 .36309 Mdot
.07847 .27938 Mdot
.07852 .42432 Mdot
.07857 .23619 Mdot
.07861 .41917 Mdot
.07866 .43125 Mdot
.07871 .21594 Mdot
.07876 .37047 Mdot
.0788 .44853 Mdot
.07885 .4111 Mdot
.0789 .19487 Mdot
.07895 .40419 Mdot
.07899 .40437 Mdot
.07904 .22231 Mdot
.07909 .4149 Mdot
.07914 .24587 Mdot
.07918 .41491 Mdot
.07923 .23316 Mdot
.07928 .16869 Mdot
.07933 .22932 Mdot
.07938 .30831 Mdot
.07942 .3265 Mdot
.07947 .35871 Mdot
.07952 .27501 Mdot
.07957 .39618 Mdot
.07961 .20302 Mdot
.07966 .38494 Mdot
.07971 .19431 Mdot
.07976 .42716 Mdot
.0798 .22171 Mdot
.07985 .32388 Mdot
.0799 .27336 Mdot
.07995 .42795 Mdot
.07999 .25973 Mdot
.08004 .28307 Mdot
.08009 .31788 Mdot
.08014 .17723 Mdot
.08018 .19086 Mdot
.08023 .31625 Mdot
.08028 .22504 Mdot
.08033 .21 Mdot
.08038 .40517 Mdot
.08042 .29997 Mdot
.08047 .44278 Mdot
.08052 .34854 Mdot
.08057 .23047 Mdot
.08061 .38771 Mdot
.08066 .31916 Mdot
.08071 .3984 Mdot
.08076 .17843 Mdot
.0808 .15354 Mdot
.08085 .27542 Mdot
.0809 .41645 Mdot
.08095 .40172 Mdot
.08099 .27446 Mdot
.08104 .1518 Mdot
.08109 .43289 Mdot
.08114 .29132 Mdot
.08118 .43538 Mdot
.08123 .2777 Mdot
.08128 .40438 Mdot
.08133 .24897 Mdot
.08138 .26743 Mdot
.08142 .20076 Mdot
.08147 .34228 Mdot
.08152 .28635 Mdot
.08157 .4098 Mdot
.08161 .20012 Mdot
.08166 .43567 Mdot
.08171 .20275 Mdot
.08176 .16876 Mdot
.0818 .32228 Mdot
.08185 .18353 Mdot
.0819 .17038 Mdot
.08195 .16107 Mdot
.08199 .1925 Mdot
.08204 .20738 Mdot
.08209 .20875 Mdot
.08214 .3265 Mdot
.08218 .18553 Mdot
.08223 .21396 Mdot
.08228 .3567 Mdot
.08233 .33019 Mdot
.08238 .3467 Mdot
.08242 .24824 Mdot
.08247 .25133 Mdot
.08252 .20615 Mdot
.08257 .28913 Mdot
.08261 .3438 Mdot
.08266 .40262 Mdot
.08271 .23379 Mdot
.08276 .23139 Mdot
.0828 .34516 Mdot
.08285 .34184 Mdot
.0829 .20679 Mdot
.08295 .34553 Mdot
.08299 .30298 Mdot
.08304 .31261 Mdot
.08309 .18666 Mdot
.08314 .29377 Mdot
.08318 .23614 Mdot
.08323 .2442 Mdot
.08328 .29515 Mdot
.08333 .24816 Mdot
.08337 .16191 Mdot
.08342 .32187 Mdot
.08347 .39913 Mdot
.08352 .33543 Mdot
.08357 .34743 Mdot
.08361 .20925 Mdot
.08366 .33147 Mdot
.08371 .18459 Mdot
.08376 .14172 Mdot
.0838 .23938 Mdot
.08385 .23538 Mdot
.0839 .38554 Mdot
.08395 .2287 Mdot
.08399 .32948 Mdot
.08404 .16547 Mdot
.08409 .17669 Mdot
.08414 .35705 Mdot
.08418 .15314 Mdot
.08423 .40973 Mdot
.08428 .31365 Mdot
.08433 .25656 Mdot
.08437 .33925 Mdot
.08442 .24984 Mdot
.08447 .20054 Mdot
.08452 .22951 Mdot
.08457 .15203 Mdot
.08461 .28001 Mdot
.08466 .29421 Mdot
.08471 .31098 Mdot
.08476 .37147 Mdot
.0848 .37703 Mdot
.08485 .24305 Mdot
.0849 .30248 Mdot
.08495 .26513 Mdot
.08499 .27448 Mdot
.08504 .28499 Mdot
.08509 .20621 Mdot
.08514 .36273 Mdot
.08518 .24103 Mdot
.08523 .24012 Mdot
.08528 .27563 Mdot
.08533 .34101 Mdot
.08537 .25738 Mdot
.08542 .35234 Mdot
.08547 .14988 Mdot
.08552 .13236 Mdot
.08557 .13795 Mdot
.08561 .28201 Mdot
.08566 .34523 Mdot
.08571 .405 Mdot
.08576 .2824 Mdot
.0858 .41206 Mdot
.08585 .16345 Mdot
.0859 .16252 Mdot
.08595 .32902 Mdot
.08599 .2976 Mdot
.08604 .28422 Mdot
.08609 .32045 Mdot
.08614 .18254 Mdot
.08618 .14041 Mdot
.08623 .20562 Mdot
.08628 .37998 Mdot
.08633 .36356 Mdot
.08637 .32214 Mdot
.08642 .35164 Mdot
.08647 .16557 Mdot
.08652 .23258 Mdot
.08657 .39085 Mdot
.08661 .32776 Mdot
.08666 .159 Mdot
.08671 .22023 Mdot
.08676 .23424 Mdot
.0868 .40258 Mdot
.08685 .17386 Mdot
.0869 .35748 Mdot
.08695 .24164 Mdot
.08699 .36353 Mdot
.08704 .13553 Mdot
.08709 .15246 Mdot
.08714 .3627 Mdot
.08718 .20291 Mdot
.08723 .23334 Mdot
.08728 .38798 Mdot
.08733 .3453 Mdot
.08737 .1201 Mdot
.08742 .27083 Mdot
.08747 .14683 Mdot
.08752 .14537 Mdot
.08757 .18533 Mdot
.08761 .22708 Mdot
.08766 .33073 Mdot
.08771 .17079 Mdot
.08776 .27365 Mdot
.0878 .1891 Mdot
.08785 .23133 Mdot
.0879 .35203 Mdot
.08795 .28635 Mdot
.08799 .13547 Mdot
.08804 .28874 Mdot
.08809 .23023 Mdot
.08814 .33731 Mdot
.08818 .11938 Mdot
.08823 .25552 Mdot
.08828 .28144 Mdot
.08833 .25325 Mdot
.08837 .29955 Mdot
.08842 .28085 Mdot
.08847 .34926 Mdot
.08852 .25122 Mdot
.08856 .14658 Mdot
.08861 .25168 Mdot
.08866 .32136 Mdot
.08871 .18316 Mdot
.08876 .33144 Mdot
.0888 .33269 Mdot
.08885 .26726 Mdot
.0889 .32087 Mdot
.08895 .25863 Mdot
.08899 .21746 Mdot
.08904 .32598 Mdot
.08909 .15023 Mdot
.08914 .23867 Mdot
.08918 .33889 Mdot
.08923 .21087 Mdot
.08928 .22269 Mdot
.08933 .23401 Mdot
.08937 .19791 Mdot
.08942 .33863 Mdot
.08947 .37844 Mdot
.08952 .34327 Mdot
.08956 .32567 Mdot
.08961 .39778 Mdot
.08966 .24058 Mdot
.08971 .30986 Mdot
.08976 .18696 Mdot
.0898 .1892 Mdot
.08985 .17001 Mdot
.0899 .38567 Mdot
.08995 .26133 Mdot
.08999 .32881 Mdot
.09004 .25581 Mdot
.09009 .23865 Mdot
.09014 .1553 Mdot
.09018 .11405 Mdot
.09023 .21662 Mdot
.09028 .11083 Mdot
.09033 .22191 Mdot
.09037 .30849 Mdot
.09042 .39904 Mdot
.09047 .28174 Mdot
.09052 .13388 Mdot
.09056 .37441 Mdot
.09061 .13009 Mdot
.09066 .34263 Mdot
.09071 .21217 Mdot
.09076 .38039 Mdot
.0908 .29308 Mdot
.09085 .14129 Mdot
.0909 .13354 Mdot
.09095 .29933 Mdot
.09099 .23103 Mdot
.09104 .15824 Mdot
.09109 .27464 Mdot
.09114 .37276 Mdot
.09118 .37727 Mdot
.09123 .32144 Mdot
.09128 .22614 Mdot
.09133 .36532 Mdot
.09137 .26707 Mdot
.09142 .31683 Mdot
.09147 .11027 Mdot
.09152 .16267 Mdot
.09156 .26854 Mdot
.09161 .14056 Mdot
.09166 .37652 Mdot
.09171 .1882 Mdot
.09176 .24335 Mdot
.0918 .19749 Mdot
.09185 .26886 Mdot
.0919 .20699 Mdot
.09195 .34925 Mdot
.09199 .16014 Mdot
.09204 .23907 Mdot
.09209 .30608 Mdot
.09214 .2216 Mdot
.09218 .10509 Mdot
.09223 .36229 Mdot
.09228 .33099 Mdot
.09233 .24181 Mdot
.09237 .18094 Mdot
.09242 .23839 Mdot
.09247 .36258 Mdot
.09252 .37147 Mdot
.09256 .26064 Mdot
.09261 .22962 Mdot
.09266 .30121 Mdot
.09271 .20404 Mdot
.09276 .22101 Mdot
.0928 .2487 Mdot
.09285 .21356 Mdot
.0929 .35591 Mdot
.09295 .12369 Mdot
.09299 .37468 Mdot
.09304 .10637 Mdot
.09309 .10627 Mdot
.09314 .35783 Mdot
.09318 .23485 Mdot
.09323 .1942 Mdot
.09328 .2784 Mdot
.09333 .35142 Mdot
.09337 .26591 Mdot
.09342 .25637 Mdot
.09347 .13471 Mdot
.09352 .26842 Mdot
.09356 .12527 Mdot
.09361 .28621 Mdot
.09366 .15548 Mdot
.09371 .10497 Mdot
.09375 .28752 Mdot
.0938 .37668 Mdot
.09385 .34293 Mdot
.0939 .27527 Mdot
.09395 .13509 Mdot
.09399 .2592 Mdot
.09404 .37778 Mdot
.09409 .24729 Mdot
.09414 .15079 Mdot
.09418 .24818 Mdot
.09423 .36667 Mdot
.09428 .2793 Mdot
.09433 .30559 Mdot
.09437 .1486 Mdot
.09442 .1827 Mdot
.09447 .31698 Mdot
.09452 .13374 Mdot
.09456 .28096 Mdot
.09461 .14169 Mdot
.09466 .14208 Mdot
.09471 .1018 Mdot
.09475 .38275 Mdot
.0948 .37404 Mdot
.09485 .12989 Mdot
.0949 .20175 Mdot
.09495 .09849 Mdot
.09499 .12334 Mdot
.09504 .24153 Mdot
.09509 .15853 Mdot
.09514 .22583 Mdot
.09518 .13193 Mdot
.09523 .38042 Mdot
.09528 .09888 Mdot
.09533 .36348 Mdot
.09537 .1509 Mdot
.09542 .19173 Mdot
.09547 .17857 Mdot
.09552 .30513 Mdot
.09556 .35311 Mdot
.09561 .25949 Mdot
.09566 .13453 Mdot
.09571 .11369 Mdot
.09575 .30076 Mdot
.0958 .20658 Mdot
.09585 .12171 Mdot
.0959 .11461 Mdot
.09595 .31021 Mdot
.09599 .16514 Mdot
.09604 .30309 Mdot
.09609 .10421 Mdot
.09614 .27478 Mdot
.09618 .3062 Mdot
.09623 .23211 Mdot
.09628 .2606 Mdot
.09633 .23005 Mdot
.09637 .30765 Mdot
.09642 .22007 Mdot
.09647 .27865 Mdot
.09652 .16564 Mdot
.09656 .20223 Mdot
.09661 .12764 Mdot
.09666 .35433 Mdot
.09671 .19316 Mdot
.09675 .3232 Mdot
.0968 .37339 Mdot
.09685 .32589 Mdot
.0969 .27233 Mdot
.09695 .20152 Mdot
.09699 .3364 Mdot
.09704 .29583 Mdot
.09709 .34135 Mdot
.09714 .12058 Mdot
.09718 .11733 Mdot
.09723 .27547 Mdot
.09728 .15024 Mdot
.09733 .19273 Mdot
.09737 .26339 Mdot
.09742 .09801 Mdot
.09747 .29802 Mdot
.09752 .26273 Mdot
.09756 .12593 Mdot
.09761 .19666 Mdot
.09766 .21465 Mdot
.09771 .1426 Mdot
.09775 .08022 Mdot
.0978 .21894 Mdot
.09785 .10307 Mdot
.0979 .19566 Mdot
.09794 .08293 Mdot
.09799 .26897 Mdot
.09804 .20648 Mdot
.09809 .36971 Mdot
.09814 .12193 Mdot
.09818 .34837 Mdot
.09823 .24019 Mdot
.09828 .32916 Mdot
.09833 .08446 Mdot
.09837 .15258 Mdot
.09842 .16946 Mdot
.09847 .21577 Mdot
.09852 .1951 Mdot
.09856 .13358 Mdot
.09861 .24512 Mdot
.09866 .32655 Mdot
.09871 .14765 Mdot
.09875 .31009 Mdot
.0988 .10862 Mdot
.09885 .26193 Mdot
.0989 .14524 Mdot
.09894 .16878 Mdot
.09899 .08302 Mdot
.09904 .14357 Mdot
.09909 .13944 Mdot
.09914 .27163 Mdot
.09918 .24818 Mdot
.09923 .14534 Mdot
.09928 .09397 Mdot
.09933 .29441 Mdot
.09937 .08412 Mdot
.09942 .18699 Mdot
.09947 .08529 Mdot
.09952 .21744 Mdot
.09956 .28496 Mdot
.09961 .34135 Mdot
.09966 .26016 Mdot
.09971 .15881 Mdot
.09975 .11462 Mdot
.0998 .08941 Mdot
.09985 .18696 Mdot
.0999 .21786 Mdot
.09994 .08011 Mdot
.09999 .19628 Mdot
.10004 .1155 Mdot
.10009 .1227 Mdot
.10014 .07055 Mdot
.10018 .126 Mdot
.10023 .34404 Mdot
.10028 .21888 Mdot
.10033 .19001 Mdot
.10037 .34814 Mdot
.10042 .32254 Mdot
.10047 .29162 Mdot
.10052 .17803 Mdot
.10056 .23313 Mdot
.10061 .30906 Mdot
.10066 .14583 Mdot
.10071 .25941 Mdot
.10075 .25795 Mdot
.1008 .12005 Mdot
.10085 .35286 Mdot
.1009 .21562 Mdot
.10094 .23921 Mdot
.10099 .29845 Mdot
.10104 .20534 Mdot
.10109 .20569 Mdot
.10114 .11295 Mdot
.10118 .25281 Mdot
.10123 .15234 Mdot
.10128 .20468 Mdot
.10133 .35118 Mdot
.10137 .27283 Mdot
.10142 .29738 Mdot
.10147 .08356 Mdot
.10152 .07177 Mdot
.10156 .31372 Mdot
.10161 .07416 Mdot
.10166 .26863 Mdot
.10171 .20159 Mdot
.10175 .0726 Mdot
.1018 .29097 Mdot
.10185 .07684 Mdot
.1019 .30594 Mdot
.10194 .3147 Mdot
.10199 .3001 Mdot
.10204 .22305 Mdot
.10209 .13356 Mdot
.10214 .08291 Mdot
.10218 .16126 Mdot
.10223 .08371 Mdot
.10228 .0868 Mdot
.10233 .19099 Mdot
.10237 .07479 Mdot
.10242 .23961 Mdot
.10247 .09604 Mdot
.10252 .27843 Mdot
.10256 .13752 Mdot
.10261 .22115 Mdot
.10266 .08922 Mdot
.10271 .32435 Mdot
.10275 .12799 Mdot
.1028 .31184 Mdot
.10285 .2468 Mdot
.1029 .31591 Mdot
.10294 .19589 Mdot
.10299 .29886 Mdot
.10304 .29942 Mdot
.10309 .06476 Mdot
.10313 .25404 Mdot
.10318 .13905 Mdot
.10323 .22894 Mdot
.10328 .33963 Mdot
.10333 .15555 Mdot
.10337 .11796 Mdot
.10342 .20461 Mdot
.10347 .21096 Mdot
.10352 .14293 Mdot
.10356 .23522 Mdot
.10361 .17043 Mdot
.10366 .2891 Mdot
.10371 .06696 Mdot
.10375 .07548 Mdot
.1038 .14247 Mdot
.10385 .32071 Mdot
.1039 .29478 Mdot
.10394 .1193 Mdot
.10399 .25117 Mdot
.10404 .0653 Mdot
.10409 .15924 Mdot
.10413 .17549 Mdot
.10418 .30667 Mdot
.10423 .06044 Mdot
.10428 .25982 Mdot
.10433 .09605 Mdot
.10437 .13718 Mdot
.10442 .07497 Mdot
.10447 .16342 Mdot
.10452 .33195 Mdot
.10456 .28628 Mdot
.10461 .21759 Mdot
.10466 .07906 Mdot
.10471 .15515 Mdot
.10475 .17412 Mdot
.1048 .28147 Mdot
.10485 .07008 Mdot
.1049 .13749 Mdot
.10494 .08933 Mdot
.10499 .31315 Mdot
.10504 .12754 Mdot
.10509 .07544 Mdot
.10513 .19011 Mdot
.10518 .3048 Mdot
.10523 .31996 Mdot
.10528 .25147 Mdot
.10533 .23482 Mdot
.10537 .30073 Mdot
.10542 .11638 Mdot
.10547 .2115 Mdot
.10552 .15358 Mdot
.10556 .28156 Mdot
.10561 .30346 Mdot
.10566 .22992 Mdot
.10571 .21752 Mdot
.10575 .11919 Mdot
.1058 .27948 Mdot
.10585 .12971 Mdot
.1059 .0982 Mdot
.10594 .18723 Mdot
.10599 .26391 Mdot
.10604 .34144 Mdot
.10609 .06309 Mdot
.10613 .22302 Mdot
.10618 .19031 Mdot
.10623 .3198 Mdot
.10628 .2215 Mdot
.10633 .2666 Mdot
.10637 .21859 Mdot
.10642 .12157 Mdot
.10647 .33463 Mdot
.10652 .31368 Mdot
.10656 .15503 Mdot
.10661 .25761 Mdot
.10666 .23359 Mdot
.10671 .08453 Mdot
.10675 .19869 Mdot
.1068 .07982 Mdot
.10685 .06806 Mdot
.1069 .31204 Mdot
.10694 .26578 Mdot
.10699 .29654 Mdot
.10704 .31616 Mdot
.10709 .17611 Mdot
.10713 .05303 Mdot
.10718 .30099 Mdot
.10723 .30396 Mdot
.10728 .2987 Mdot
.10732 .2082 Mdot
.10737 .32653 Mdot
.10742 .13281 Mdot
.10747 .08232 Mdot
.10752 .33454 Mdot
.10756 .2549 Mdot
.10761 .14284 Mdot
.10766 .11317 Mdot
.10771 .22905 Mdot
.10775 .34155 Mdot
.1078 .25337 Mdot
.10785 .07777 Mdot
.1079 .07936 Mdot
.10794 .3106 Mdot
.10799 .23405 Mdot
.10804 .10919 Mdot
.10809 .1569 Mdot
.10813 .0624 Mdot
.10818 .26096 Mdot
.10823 .27601 Mdot
.10828 .15181 Mdot
.10832 .10408 Mdot
.10837 .29954 Mdot
.10842 .31971 Mdot
.10847 .28589 Mdot
.10852 .1197 Mdot
.10856 .21388 Mdot
.10861 .28441 Mdot
.10866 .2931 Mdot
.10871 .20643 Mdot
.10875 .11768 Mdot
.1088 .21775 Mdot
.10885 .11043 Mdot
.1089 .20598 Mdot
.10894 .20528 Mdot
.10899 .18597 Mdot
.10904 .07694 Mdot
.10909 .23597 Mdot
.10913 .3117 Mdot
.10918 .12226 Mdot
.10923 .26025 Mdot
.10928 .2188 Mdot
.10932 .09584 Mdot
.10937 .18609 Mdot
.10942 .15329 Mdot
.10947 .15944 Mdot
.10952 .13575 Mdot
.10956 .20571 Mdot
.10961 .2066 Mdot
.10966 .08395 Mdot
.10971 .26082 Mdot
.10975 .26012 Mdot
.1098 .2522 Mdot
.10985 .2161 Mdot
.1099 .18674 Mdot
.10994 .08584 Mdot
.10999 .18512 Mdot
.11004 .05334 Mdot
.11009 .31941 Mdot
.11013 .2377 Mdot
.11018 .15104 Mdot
.11023 .15496 Mdot
.11028 .05032 Mdot
.11032 .15793 Mdot
.11037 .22801 Mdot
.11042 .27326 Mdot
.11047 .29147 Mdot
.11052 .3087 Mdot
.11056 .11661 Mdot
.11061 .15559 Mdot
.11066 .19735 Mdot
.11071 .14452 Mdot
.11075 .24626 Mdot
.1108 .11292 Mdot
.11085 .27255 Mdot
.1109 .2203 Mdot
.11094 .32984 Mdot
.11099 .23248 Mdot
.11104 .1265 Mdot
.11109 .17503 Mdot
.11113 .18517 Mdot
.11118 .21947 Mdot
.11123 .14216 Mdot
.11128 .27228 Mdot
.11132 .07412 Mdot
.11137 .10437 Mdot
.11142 .13159 Mdot
.11147 .15398 Mdot
.11152 .18048 Mdot
.11156 .16536 Mdot
.11161 .17426 Mdot
.11166 .1793 Mdot
.11171 .10292 Mdot
.11175 .04871 Mdot
.1118 .31058 Mdot
.11185 .0735 Mdot
.1119 .19011 Mdot
.11194 .26913 Mdot
.11199 .0764 Mdot
.11204 .18631 Mdot
.11209 .19326 Mdot
.11213 .07468 Mdot
.11218 .28266 Mdot
.11223 .04908 Mdot
.11228 .04578 Mdot
.11232 .18764 Mdot
.11237 .17796 Mdot
.11242 .10901 Mdot
.11247 .30376 Mdot
.11251 .1204 Mdot
.11256 .0834 Mdot
.11261 .2868 Mdot
.11266 .16008 Mdot
.11271 .28658 Mdot
.11275 .24057 Mdot
.1128 .14396 Mdot
.11285 .09352 Mdot
.1129 .27412 Mdot
.11294 .26098 Mdot
.11299 .10649 Mdot
.11304 .23419 Mdot
.11309 .0408 Mdot
.11313 .22029 Mdot
.11318 .25064 Mdot
.11323 .07642 Mdot
.11328 .29637 Mdot
.11332 .26776 Mdot
.11337 .23673 Mdot
.11342 .0657 Mdot
.11347 .14368 Mdot
.11351 .12465 Mdot
.11356 .16247 Mdot
.11361 .09144 Mdot
.11366 .05782 Mdot
.11371 .07569 Mdot
.11375 .20485 Mdot
.1138 .26044 Mdot
.11385 .10022 Mdot
.1139 .16399 Mdot
.11394 .09481 Mdot
.11399 .20073 Mdot
.11404 .15466 Mdot
.11409 .23146 Mdot
.11413 .31666 Mdot
.11418 .2948 Mdot
.11423 .14715 Mdot
.11428 .04436 Mdot
.11432 .09911 Mdot
.11437 .25137 Mdot
.11442 .17853 Mdot
.11447 .10423 Mdot
.11451 .18992 Mdot
.11456 .21825 Mdot
.11461 .06733 Mdot
.11466 .30682 Mdot
.11471 .05974 Mdot
.11475 .15899 Mdot
.1148 .04159 Mdot
.11485 .26312 Mdot
.1149 .18163 Mdot
.11494 .22519 Mdot
.11499 .26792 Mdot
.11504 .13072 Mdot
.11509 .11832 Mdot
.11513 .05586 Mdot
.11518 .14456 Mdot
.11523 .22532 Mdot
.11528 .12761 Mdot
.11532 .08693 Mdot
.11537 .32318 Mdot
.11542 .21178 Mdot
.11547 .05922 Mdot
.11551 .16104 Mdot
.11556 .17518 Mdot
.11561 .13798 Mdot
.11566 .1945 Mdot
.11571 .26789 Mdot
.11575 .13801 Mdot
.1158 .15607 Mdot
.11585 .16473 Mdot
.1159 .13877 Mdot
.11594 .1262 Mdot
.11599 .2175 Mdot
.11604 .30755 Mdot
.11609 .23794 Mdot
.11613 .18254 Mdot
.11618 .1161 Mdot
.11623 .21846 Mdot
.11628 .21121 Mdot
.11632 .06703 Mdot
.11637 .21459 Mdot
.11642 .1197 Mdot
.11647 .15305 Mdot
.11651 .06739 Mdot
.11656 .0314 Mdot
.11661 .08898 Mdot
.11666 .31528 Mdot
.1167 .21539 Mdot
.11675 .21651 Mdot
.1168 .21748 Mdot
.11685 .07544 Mdot
.1169 .10535 Mdot
.11694 .08832 Mdot
.11699 .08055 Mdot
.11704 .25923 Mdot
.11709 .30163 Mdot
.11713 .19321 Mdot
.11718 .0953 Mdot
.11723 .04865 Mdot
.11728 .14636 Mdot
.11732 .1043 Mdot
.11737 .1988 Mdot
.11742 .15931 Mdot
.11747 .10626 Mdot
.11751 .21142 Mdot
.11756 .10586 Mdot
.11761 .03294 Mdot
.11766 .06547 Mdot
.1177 .20653 Mdot
.11775 .04331 Mdot
.1178 .03886 Mdot
.11785 .1712 Mdot
.1179 .31106 Mdot
.11794 .14678 Mdot
.11799 .28429 Mdot
.11804 .09179 Mdot
.11809 .24859 Mdot
.11813 .09201 Mdot
.11818 .05076 Mdot
.11823 .11063 Mdot
.11828 .08091 Mdot
.11832 .31702 Mdot
.11837 .02748 Mdot
.11842 .28442 Mdot
.11847 .29668 Mdot
.11851 .14334 Mdot
.11856 .18807 Mdot
.11861 .20313 Mdot
.11866 .11015 Mdot
.1187 .0623 Mdot
.11875 .17987 Mdot
.1188 .16232 Mdot
.11885 .22306 Mdot
.1189 .0435 Mdot
.11894 .16544 Mdot
.11899 .31033 Mdot
.11904 .23114 Mdot
.11909 .21577 Mdot
.11913 .20013 Mdot
.11918 .2426 Mdot
.11923 .30138 Mdot
.11928 .14767 Mdot
.11932 .1732 Mdot
.11937 .15573 Mdot
.11942 .24415 Mdot
.11947 .14911 Mdot
.11951 .16925 Mdot
.11956 .18963 Mdot
.11961 .26571 Mdot
.11966 .02908 Mdot
.1197 .29928 Mdot
.11975 .30452 Mdot
.1198 .17866 Mdot
.11985 .28466 Mdot
.1199 .14236 Mdot
.11994 .16508 Mdot
.11999 .27326 Mdot
.12004 .2639 Mdot
.12009 .29445 Mdot
.12013 .1722 Mdot
.12018 .06466 Mdot
.12023 .07059 Mdot
.12028 .11671 Mdot
.12032 .24678 Mdot
.12037 .08039 Mdot
.12042 .23997 Mdot
.12047 .26049 Mdot
.12051 .11311 Mdot
.12056 .15308 Mdot
.12061 .11277 Mdot
.12066 .11309 Mdot
.1207 .24012 Mdot
.12075 .20394 Mdot
.1208 .10534 Mdot
.12085 .13025 Mdot
.1209 .25197 Mdot
.12094 .04673 Mdot
.12099 .13693 Mdot
.12104 .30406 Mdot
.12109 .10815 Mdot
.12113 .08952 Mdot
.12118 .18901 Mdot
.12123 .03068 Mdot
.12128 .25181 Mdot
.12132 .04581 Mdot
.12137 .13929 Mdot
.12142 .22963 Mdot
.12147 .02577 Mdot
.12151 .28096 Mdot
.12156 .21481 Mdot
.12161 .28456 Mdot
.12166 .22803 Mdot
.1217 .14833 Mdot
.12175 .12242 Mdot
.1218 .1918 Mdot
.12185 .30302 Mdot
.12189 .25945 Mdot
.12194 .03722 Mdot
.12199 .08164 Mdot
.12204 .07107 Mdot
.12209 .23268 Mdot
.12213 .21505 Mdot
.12218 .09228 Mdot
.12223 .27757 Mdot
.12228 .1629 Mdot
.12232 .04572 Mdot
.12237 .08122 Mdot
.12242 .04533 Mdot
.12247 .1366 Mdot
.12251 .22073 Mdot
.12256 .16584 Mdot
.12261 .03889 Mdot
.12266 .16977 Mdot
.1227 .02515 Mdot
.12275 .19531 Mdot
.1228 .12484 Mdot
.12285 .0405 Mdot
.12289 .21659 Mdot
.12294 .02246 Mdot
.12299 .13557 Mdot
.12304 .09475 Mdot
.12309 .19817 Mdot
.12313 .25442 Mdot
.12318 .08319 Mdot
.12323 .17556 Mdot
.12328 .29656 Mdot
.12332 .18067 Mdot
.12337 .11896 Mdot
.12342 .0311 Mdot
.12347 .26922 Mdot
.12351 .11778 Mdot
.12356 .09191 Mdot
.12361 .20759 Mdot
.12366 .06667 Mdot
.1237 .26492 Mdot
.12375 .0711 Mdot
.1238 .05585 Mdot
.12385 .05951 Mdot
.12389 .08756 Mdot
.12394 .25901 Mdot
.12399 .03319 Mdot
.12404 .15557 Mdot
.12409 .08284 Mdot
.12413 .14113 Mdot
.12418 .25095 Mdot
.12423 .26986 Mdot
.12428 .14084 Mdot
.12432 .07546 Mdot
.12437 .09286 Mdot
.12442 .28558 Mdot
.12447 .2724 Mdot
.12451 .26869 Mdot
.12456 .07905 Mdot
.12461 .0336 Mdot
.12466 .17183 Mdot
.1247 .19394 Mdot
.12475 .18343 Mdot
.1248 .27886 Mdot
.12485 .21879 Mdot
.12489 .13983 Mdot
.12494 .14453 Mdot
.12499 .23625 Mdot
.12504 .14809 Mdot
.12509 .1925 Mdot
.12513 .12812 Mdot
.12518 .09742 Mdot
.12523 .08195 Mdot
.12528 .06803 Mdot
.12532 .18865 Mdot
.12537 .139 Mdot
.12542 .25251 Mdot
.12547 .30393 Mdot
.12551 .11225 Mdot
.12556 .1647 Mdot
.12561 .29135 Mdot
.12566 .05158 Mdot
.1257 .04952 Mdot
.12575 .14737 Mdot
.1258 .13576 Mdot
.12585 .1687 Mdot
.12589 .1771 Mdot
.12594 .1795 Mdot
.12599 .22792 Mdot
.12604 .04492 Mdot
.12609 .04859 Mdot
.12613 .25409 Mdot
.12618 .09578 Mdot
.12623 .16319 Mdot
.12628 .23121 Mdot
.12632 .17252 Mdot
.12637 .02964 Mdot
.12642 .11095 Mdot
.12647 .05831 Mdot
.12651 .04924 Mdot
.12656 .08767 Mdot
.12661 .11753 Mdot
.12666 .25653 Mdot
.1267 .19498 Mdot
.12675 .10673 Mdot
.1268 .08147 Mdot
.12685 .22251 Mdot
.12689 .06307 Mdot
.12694 .28125 Mdot
.12699 .22303 Mdot
.12704 .06078 Mdot
.12708 .19378 Mdot
.12713 .06865 Mdot
.12718 .1934 Mdot
.12723 .02745 Mdot
.12728 .24977 Mdot
.12732 .28293 Mdot
.12737 .04538 Mdot
.12742 .10624 Mdot
.12747 .09237 Mdot
.12751 .26838 Mdot
.12756 .24436 Mdot
.12761 .06297 Mdot
.12766 .05815 Mdot
.1277 .1957 Mdot
.12775 .14179 Mdot
.1278 .11623 Mdot
.12785 .17293 Mdot
.12789 .10386 Mdot
.12794 .07519 Mdot
.12799 .20342 Mdot
.12804 .12468 Mdot
.12808 .13226 Mdot
.12813 .16178 Mdot
.12818 .15738 Mdot
.12823 .24048 Mdot
.12828 .07831 Mdot
.12832 .27792 Mdot
.12837 .14459 Mdot
.12842 .30021 Mdot
.12847 .10486 Mdot
.12851 .24714 Mdot
.12856 .05292 Mdot
.12861 .22239 Mdot
.12866 .14587 Mdot
.1287 .0173 Mdot
.12875 .29931 Mdot
.1288 .17872 Mdot
.12885 .25948 Mdot
.12889 .1848 Mdot
.12894 .1975 Mdot
.12899 .02019 Mdot
.12904 .17 Mdot
.12908 .12398 Mdot
.12913 .30329 Mdot
.12918 .20471 Mdot
.12923 .05207 Mdot
.12928 .27136 Mdot
.12932 .1602 Mdot
.12937 .27335 Mdot
.12942 .28287 Mdot
.12947 .30253 Mdot
.12951 .02983 Mdot
.12956 .28221 Mdot
.12961 .19221 Mdot
.12966 .06957 Mdot
.1297 .28593 Mdot
.12975 .07398 Mdot
.1298 .06048 Mdot
.12985 .0664 Mdot
.12989 .2956 Mdot
.12994 .20422 Mdot
.12999 .10995 Mdot
.13004 .19053 Mdot
.13008 .11217 Mdot
.13013 .19809 Mdot
.13018 .24885 Mdot
.13023 .08058 Mdot
.13028 .11776 Mdot
.13032 .30225 Mdot
.13037 .21079 Mdot
.13042 .11808 Mdot
.13047 .26641 Mdot
.13051 .04288 Mdot
.13056 .23675 Mdot
.13061 .12438 Mdot
.13066 .25053 Mdot
.1307 .06947 Mdot
.13075 .05849 Mdot
.1308 .06874 Mdot
.13085 .27338 Mdot
.13089 .30427 Mdot
.13094 .30678 Mdot
.13099 .01625 Mdot
.13104 .28654 Mdot
.13108 .11395 Mdot
.13113 .21072 Mdot
.13118 .13447 Mdot
.13123 .18826 Mdot
.13127 .2246 Mdot
.13132 .2706 Mdot
.13137 .06776 Mdot
.13142 .08436 Mdot
.13147 .23107 Mdot
.13151 .07367 Mdot
.13156 .25839 Mdot
.13161 .12667 Mdot
.13166 .20205 Mdot
.1317 .14563 Mdot
.13175 .14787 Mdot
.1318 .18485 Mdot
.13185 .14642 Mdot
.13189 .10099 Mdot
.13194 .09298 Mdot
.13199 .22018 Mdot
.13204 .15086 Mdot
.13208 .10292 Mdot
.13213 .09058 Mdot
.13218 .24234 Mdot
.13223 .05076 Mdot
.13227 .20092 Mdot
.13232 .26483 Mdot
.13237 .06795 Mdot
.13242 .13488 Mdot
.13247 .23904 Mdot
.13251 .21094 Mdot
.13256 .29232 Mdot
.13261 .21255 Mdot
.13266 .17925 Mdot
.1327 .2613 Mdot
.13275 .17954 Mdot
.1328 .0244 Mdot
.13285 .04753 Mdot
.13289 .12734 Mdot
.13294 .30346 Mdot
.13299 .18675 Mdot
.13304 .25533 Mdot
.13308 .04829 Mdot
.13313 .09723 Mdot
.13318 .04984 Mdot
.13323 .16636 Mdot
.13327 .26653 Mdot
.13332 .16371 Mdot
.13337 .30791 Mdot
.13342 .27429 Mdot
.13347 .0157 Mdot
.13351 .10977 Mdot
.13356 .18705 Mdot
.13361 .04928 Mdot
.13366 .11365 Mdot
.1337 .12636 Mdot
.13375 .28342 Mdot
.1338 .17895 Mdot
.13385 .16129 Mdot
.13389 .25577 Mdot
.13394 .27313 Mdot
.13399 .14554 Mdot
.13404 .04809 Mdot
.13408 .2613 Mdot
.13413 .10053 Mdot
.13418 .19924 Mdot
.13423 .30883 Mdot
.13427 .17827 Mdot
.13432 .0649 Mdot
.13437 .0471 Mdot
.13442 .05654 Mdot
.13447 .02881 Mdot
.13451 .06611 Mdot
.13456 .08195 Mdot
.13461 .05513 Mdot
.13466 .22822 Mdot
.1347 .18825 Mdot
.13475 .04702 Mdot
.1348 .2507 Mdot
.13485 .11625 Mdot
.13489 .21409 Mdot
.13494 .17734 Mdot
.13499 .10385 Mdot
.13504 .16979 Mdot
.13508 .2503 Mdot
.13513 .0463 Mdot
.13518 .07028 Mdot
.13523 .21788 Mdot
.13527 .16432 Mdot
.13532 .15649 Mdot
.13537 .0709 Mdot
.13542 .05423 Mdot
.13547 .11406 Mdot
.13551 .12405 Mdot
.13556 .02904 Mdot
.13561 .04012 Mdot
.13566 .06267 Mdot
.1357 .05685 Mdot
.13575 .28353 Mdot
.1358 .12156 Mdot
.13585 .18409 Mdot
.13589 .02468 Mdot
.13594 .04769 Mdot
.13599 .0202 Mdot
.13604 .27976 Mdot
.13608 .15713 Mdot
.13613 .25366 Mdot
.13618 .16025 Mdot
.13623 .04448 Mdot
.13627 .12587 Mdot
.13632 .19845 Mdot
.13637 .25231 Mdot
.13642 .19013 Mdot
.13646 .27938 Mdot
.13651 .14273 Mdot
.13656 .21328 Mdot
.13661 .0913 Mdot
.13666 .17058 Mdot
.1367 .12897 Mdot
.13675 .18847 Mdot
.1368 .04397 Mdot
.13685 .1291 Mdot
.13689 .15569 Mdot
.13694 .08235 Mdot
.13699 .1702 Mdot
.13704 .11992 Mdot
.13708 .12352 Mdot
.13713 .07771 Mdot
.13718 .20088 Mdot
.13723 .27326 Mdot
.13727 .18037 Mdot
.13732 .228 Mdot
.13737 .17211 Mdot
.13742 .16314 Mdot
.13746 .29255 Mdot
.13751 .28636 Mdot
.13756 .29269 Mdot
.13761 .1945 Mdot
.13766 .16574 Mdot
.1377 .08903 Mdot
.13775 .21738 Mdot
.1378 .03995 Mdot
.13785 .05283 Mdot
.13789 .2115 Mdot
.13794 .18953 Mdot
.13799 .22187 Mdot
.13804 .20819 Mdot
.13808 .14539 Mdot
.13813 .03561 Mdot
.13818 .11826 Mdot
.13823 .10101 Mdot
.13827 .08406 Mdot
.13832 .14601 Mdot
.13837 .15632 Mdot
.13842 .232 Mdot
.13846 .16746 Mdot
.13851 .28533 Mdot
.13856 .30465 Mdot
.13861 .25097 Mdot
.13866 .19265 Mdot
.1387 .30424 Mdot
.13875 .12692 Mdot
.1388 .10205 Mdot
.13885 .12049 Mdot
.13889 .10376 Mdot
.13894 .10392 Mdot
.13899 .06621 Mdot
.13904 .22087 Mdot
.13908 .22616 Mdot
.13913 .19403 Mdot
.13918 .17003 Mdot
.13923 .09269 Mdot
.13927 .2078 Mdot
.13932 .09306 Mdot
.13937 .08636 Mdot
.13942 .026 Mdot
.13946 .07922 Mdot
.13951 .24907 Mdot
.13956 .16672 Mdot
.13961 .17096 Mdot
.13966 .10635 Mdot
.1397 .25693 Mdot
.13975 .22831 Mdot
.1398 .29091 Mdot
.13985 .11476 Mdot
.13989 .14785 Mdot
.13994 .14415 Mdot
.13999 .18836 Mdot
.14004 .02898 Mdot
.14008 .06196 Mdot
.14013 .09603 Mdot
.14018 .28047 Mdot
.14023 .11586 Mdot
.14027 .18101 Mdot
.14032 .23913 Mdot
.14037 .20612 Mdot
.14042 .22129 Mdot
.14046 .10639 Mdot
.14051 .17125 Mdot
.14056 .19865 Mdot
.14061 .16066 Mdot
.14065 .17081 Mdot
.1407 .02322 Mdot
.14075 .04643 Mdot
.1408 .07311 Mdot
.14085 .22759 Mdot
.14089 .10866 Mdot
.14094 .06933 Mdot
.14099 .27221 Mdot
.14104 .0988 Mdot
.14108 .27848 Mdot
.14113 .195 Mdot
.14118 .26246 Mdot
.14123 .05613 Mdot
.14127 .20179 Mdot
.14132 .22877 Mdot
.14137 .16605 Mdot
.14142 .18948 Mdot
.14146 .27708 Mdot
.14151 .04227 Mdot
.14156 .25929 Mdot
.14161 .10283 Mdot
.14165 .12562 Mdot
.1417 .15833 Mdot
.14175 .11853 Mdot
.1418 .24684 Mdot
.14185 .12243 Mdot
.14189 .13199 Mdot
.14194 .06557 Mdot
.14199 .03945 Mdot
.14204 .03402 Mdot
.14208 .08298 Mdot
.14213 .10859 Mdot
.14218 .25595 Mdot
.14223 .0709 Mdot
.14227 .2034 Mdot
.14232 .16162 Mdot
.14237 .2205 Mdot
.14242 .18471 Mdot
.14246 .2903 Mdot
.14251 .3113 Mdot
.14256 .05197 Mdot
.14261 .22349 Mdot
.14265 .26909 Mdot
.1427 .07315 Mdot
.14275 .26519 Mdot
.1428 .11912 Mdot
.14285 .13208 Mdot
.14289 .27086 Mdot
.14294 .03981 Mdot
.14299 .31307 Mdot
.14304 .31654 Mdot
.14308 .22694 Mdot
.14313 .31693 Mdot
.14318 .30083 Mdot
.14323 .25541 Mdot
.14327 .14026 Mdot
.14332 .08296 Mdot
.14337 .25198 Mdot
.14342 .07412 Mdot
.14346 .29569 Mdot
.14351 .17957 Mdot
.14356 .08959 Mdot
.14361 .10107 Mdot
.14365 .3017 Mdot
.1437 .15014 Mdot
.14375 .18356 Mdot
.1438 .1495 Mdot
.14385 .2513 Mdot
.14389 .20262 Mdot
.14394 .08732 Mdot
.14399 .04037 Mdot
.14404 .29832 Mdot
.14408 .1859 Mdot
.14413 .09227 Mdot
.14418 .04193 Mdot
.14423 .09469 Mdot
.14427 .18722 Mdot
.14432 .10976 Mdot
.14437 .10492 Mdot
.14442 .27289 Mdot
.14446 .12793 Mdot
.14451 .17639 Mdot
.14456 .05462 Mdot
.14461 .29596 Mdot
.14465 .26719 Mdot
.1447 .11085 Mdot
.14475 .27254 Mdot
.1448 .31332 Mdot
.14485 .14134 Mdot
.14489 .2465 Mdot
.14494 .14746 Mdot
.14499 .08653 Mdot
.14504 .25816 Mdot
.14508 .18385 Mdot
.14513 .13183 Mdot
.14518 .10788 Mdot
.14523 .09715 Mdot
.14527 .11655 Mdot
.14532 .11495 Mdot
.14537 .03832 Mdot
.14542 .23 Mdot
.14546 .03209 Mdot
.14551 .0354 Mdot
.14556 .08573 Mdot
.14561 .1276 Mdot
.14565 .17617 Mdot
.1457 .30133 Mdot
.14575 .1104 Mdot
.1458 .18111 Mdot
.14584 .09125 Mdot
.14589 .05481 Mdot
.14594 .11803 Mdot
.14599 .06595 Mdot
.14604 .16587 Mdot
.14608 .22854 Mdot
.14613 .05793 Mdot
.14618 .12916 Mdot
.14623 .30347 Mdot
.14627 .12339 Mdot
.14632 .27167 Mdot
.14637 .05886 Mdot
.14642 .21385 Mdot
.14646 .03546 Mdot
.14651 .26045 Mdot
.14656 .1509 Mdot
.14661 .20904 Mdot
.14665 .32228 Mdot
.1467 .20216 Mdot
.14675 .05083 Mdot
.1468 .06049 Mdot
.14684 .04865 Mdot
.14689 .11956 Mdot
.14694 .19246 Mdot
.14699 .29207 Mdot
.14704 .31676 Mdot
.14708 .32452 Mdot
.14713 .15474 Mdot
.14718 .15452 Mdot
.14723 .11663 Mdot
.14727 .29509 Mdot
.14732 .05417 Mdot
.14737 .17459 Mdot
.14742 .31686 Mdot
.14746 .05228 Mdot
.14751 .31912 Mdot
.14756 .28463 Mdot
.14761 .31053 Mdot
.14765 .11591 Mdot
.1477 .19754 Mdot
.14775 .105 Mdot
.1478 .31261 Mdot
.14784 .23819 Mdot
.14789 .17639 Mdot
.14794 .07429 Mdot
.14799 .29383 Mdot
.14804 .1486 Mdot
.14808 .30884 Mdot
.14813 .10723 Mdot
.14818 .30217 Mdot
.14823 .14927 Mdot
.14827 .18454 Mdot
.14832 .27809 Mdot
.14837 .21617 Mdot
.14842 .17976 Mdot
.14846 .16119 Mdot
.14851 .13442 Mdot
.14856 .22518 Mdot
.14861 .15859 Mdot
.14865 .16812 Mdot
.1487 .17594 Mdot
.14875 .2409 Mdot
.1488 .07418 Mdot
.14884 .29704 Mdot
.14889 .10263 Mdot
.14894 .25493 Mdot
.14899 .16273 Mdot
.14904 .15264 Mdot
.14908 .06043 Mdot
.14913 .28815 Mdot
.14918 .04641 Mdot
.14923 .17104 Mdot
.14927 .28054 Mdot
.14932 .31342 Mdot
.14937 .22468 Mdot
.14942 .31414 Mdot
.14946 .03533 Mdot
.14951 .13024 Mdot
.14956 .078 Mdot
.14961 .18615 Mdot
.14965 .22906 Mdot
.1497 .23331 Mdot
.14975 .24777 Mdot
.1498 .05162 Mdot
.14984 .08682 Mdot
.14989 .32108 Mdot
.14994 .2075 Mdot
.14999 .08346 Mdot
.15003 .31316 Mdot
.15008 .10036 Mdot
.15013 .07909 Mdot
.15018 .2601 Mdot
.15023 .28726 Mdot
.15027 .14171 Mdot
.15032 .06742 Mdot
.15037 .12392 Mdot
.15042 .04168 Mdot
.15046 .15822 Mdot
.15051 .17277 Mdot
.15056 .13991 Mdot
.15061 .04173 Mdot
.15065 .06347 Mdot
.1507 .13037 Mdot
.15075 .28433 Mdot
.1508 .14334 Mdot
.15084 .16094 Mdot
.15089 .21349 Mdot
.15094 .26884 Mdot
.15099 .09278 Mdot
.15103 .17108 Mdot
.15108 .04246 Mdot
.15113 .22197 Mdot
.15118 .11116 Mdot
.15123 .10751 Mdot
.15127 .29513 Mdot
.15132 .29374 Mdot
.15137 .15589 Mdot
.15142 .29789 Mdot
.15146 .26506 Mdot
.15151 .20728 Mdot
.15156 .15178 Mdot
.15161 .17737 Mdot
.15165 .13009 Mdot
.1517 .10529 Mdot
.15175 .14808 Mdot
.1518 .15203 Mdot
.15184 .33283 Mdot
.15189 .15418 Mdot
.15194 .04321 Mdot
.15199 .32455 Mdot
.15203 .15805 Mdot
.15208 .21902 Mdot
.15213 .28423 Mdot
.15218 .19252 Mdot
.15223 .15476 Mdot
.15227 .33119 Mdot
.15232 .21247 Mdot
.15237 .12452 Mdot
.15242 .19411 Mdot
.15246 .07719 Mdot
.15251 .09644 Mdot
.15256 .16147 Mdot
.15261 .264 Mdot
.15265 .20498 Mdot
.1527 .27985 Mdot
.15275 .31941 Mdot
.1528 .17448 Mdot
.15284 .14038 Mdot
.15289 .17257 Mdot
.15294 .20829 Mdot
.15299 .17755 Mdot
.15303 .32222 Mdot
.15308 .17064 Mdot
.15313 .22001 Mdot
.15318 .06101 Mdot
.15323 .14485 Mdot
.15327 .22303 Mdot
.15332 .06937 Mdot
.15337 .24311 Mdot
.15342 .15064 Mdot
.15346 .05281 Mdot
.15351 .28207 Mdot
.15356 .09149 Mdot
.15361 .11606 Mdot
.15365 .29396 Mdot
.1537 .16346 Mdot
.15375 .16532 Mdot
.1538 .24903 Mdot
.15384 .05733 Mdot
.15389 .18226 Mdot
.15394 .32917 Mdot
.15399 .15225 Mdot
.15403 .22334 Mdot
.15408 .31266 Mdot
.15413 .1956 Mdot
.15418 .16898 Mdot
.15423 .09691 Mdot
.15427 .137 Mdot
.15432 .17905 Mdot
.15437 .06872 Mdot
.15442 .21346 Mdot
.15446 .11248 Mdot
.15451 .27576 Mdot
.15456 .25804 Mdot
.15461 .20588 Mdot
.15465 .17062 Mdot
.1547 .22975 Mdot
.15475 .18759 Mdot
.1548 .25252 Mdot
.15484 .05302 Mdot
.15489 .11042 Mdot
.15494 .27954 Mdot
.15499 .24143 Mdot
.15503 .212 Mdot
.15508 .12261 Mdot
.15513 .17393 Mdot
.15518 .06486 Mdot
.15522 .24109 Mdot
.15527 .2689 Mdot
.15532 .05211 Mdot
.15537 .31009 Mdot
.15542 .15151 Mdot
.15546 .1374 Mdot
.15551 .32592 Mdot
.15556 .14444 Mdot
.15561 .08697 Mdot
.15565 .20456 Mdot
.1557 .11608 Mdot
.15575 .28175 Mdot
.1558 .25968 Mdot
.15584 .31827 Mdot
.15589 .27208 Mdot
.15594 .0781 Mdot
.15599 .25566 Mdot
.15603 .25698 Mdot
.15608 .33667 Mdot
.15613 .18093 Mdot
.15618 .09319 Mdot
.15622 .18404 Mdot
.15627 .21255 Mdot
.15632 .16601 Mdot
.15637 .19703 Mdot
.15642 .26021 Mdot
.15646 .21079 Mdot
.15651 .20126 Mdot
.15656 .09614 Mdot
.15661 .17356 Mdot
.15665 .23062 Mdot
.1567 .10785 Mdot
.15675 .06033 Mdot
.1568 .31516 Mdot
.15684 .16597 Mdot
.15689 .17253 Mdot
.15694 .14722 Mdot
.15699 .3436 Mdot
.15703 .24073 Mdot
.15708 .14656 Mdot
.15713 .23869 Mdot
.15718 .13902 Mdot
.15722 .25146 Mdot
.15727 .31317 Mdot
.15732 .19831 Mdot
.15737 .3028 Mdot
.15742 .09201 Mdot
.15746 .2004 Mdot
.15751 .34952 Mdot
.15756 .09612 Mdot
.15761 .22974 Mdot
.15765 .3478 Mdot
.1577 .30732 Mdot
.15775 .2715 Mdot
.1578 .34821 Mdot
.15784 .29431 Mdot
.15789 .30149 Mdot
.15794 .30584 Mdot
.15799 .23703 Mdot
.15803 .17671 Mdot
.15808 .20935 Mdot
.15813 .31232 Mdot
.15818 .34652 Mdot
.15822 .08566 Mdot
.15827 .32117 Mdot
.15832 .22909 Mdot
.15837 .151 Mdot
.15842 .12343 Mdot
.15846 .17909 Mdot
.15851 .27752 Mdot
.15856 .11551 Mdot
.15861 .27455 Mdot
.15865 .18123 Mdot
.1587 .23835 Mdot
.15875 .23772 Mdot
.1588 .27886 Mdot
.15884 .22616 Mdot
.15889 .31925 Mdot
.15894 .24205 Mdot
.15899 .33723 Mdot
.15903 .2775 Mdot
.15908 .07153 Mdot
.15913 .06328 Mdot
.15918 .21893 Mdot
.15922 .12671 Mdot
.15927 .11277 Mdot
.15932 .07048 Mdot
.15937 .19228 Mdot
.15942 .15956 Mdot
.15946 .23784 Mdot
.15951 .27379 Mdot
.15956 .12845 Mdot
.15961 .33508 Mdot
.15965 .31508 Mdot
.1597 .21833 Mdot
.15975 .20895 Mdot
.1598 .2142 Mdot
.15984 .13723 Mdot
.15989 .33612 Mdot
.15994 .28575 Mdot
.15999 .34385 Mdot
.16003 .17394 Mdot
.16008 .15533 Mdot
.16013 .30478 Mdot
.16018 .1279 Mdot
.16022 .16413 Mdot
.16027 .15391 Mdot
.16032 .14786 Mdot
.16037 .35821 Mdot
.16041 .11367 Mdot
.16046 .1459 Mdot
.16051 .31306 Mdot
.16056 .26143 Mdot
.16061 .23362 Mdot
.16065 .23006 Mdot
.1607 .24785 Mdot
.16075 .2846 Mdot
.1608 .27693 Mdot
.16084 .07542 Mdot
.16089 .10276 Mdot
.16094 .13441 Mdot
.16099 .20386 Mdot
.16103 .09848 Mdot
.16108 .17633 Mdot
.16113 .15005 Mdot
.16118 .0947 Mdot
.16122 .30294 Mdot
.16127 .2315 Mdot
.16132 .08739 Mdot
.16137 .29084 Mdot
.16141 .2146 Mdot
.16146 .14936 Mdot
.16151 .08991 Mdot
.16156 .2432 Mdot
.16161 .13489 Mdot
.16165 .1975 Mdot
.1617 .18984 Mdot
.16175 .07625 Mdot
.1618 .26651 Mdot
.16184 .31148 Mdot
.16189 .26724 Mdot
.16194 .16147 Mdot
.16199 .25854 Mdot
.16203 .27634 Mdot
.16208 .2006 Mdot
.16213 .3204 Mdot
.16218 .22816 Mdot
.16222 .16826 Mdot
.16227 .11897 Mdot
.16232 .29426 Mdot
.16237 .28881 Mdot
.16241 .30051 Mdot
.16246 .10063 Mdot
.16251 .07264 Mdot
.16256 .14358 Mdot
.16261 .22068 Mdot
.16265 .08041 Mdot
.1627 .19415 Mdot
.16275 .07872 Mdot
.1628 .09336 Mdot
.16284 .25576 Mdot
.16289 .1884 Mdot
.16294 .17773 Mdot
.16299 .14757 Mdot
.16303 .35437 Mdot
.16308 .09809 Mdot
.16313 .28536 Mdot
.16318 .23756 Mdot
.16322 .22541 Mdot
.16327 .14435 Mdot
.16332 .12918 Mdot
.16337 .14144 Mdot
.16341 .17875 Mdot
.16346 .21741 Mdot
.16351 .20786 Mdot
.16356 .20858 Mdot
.16361 .15108 Mdot
.16365 .21789 Mdot
.1637 .13756 Mdot
.16375 .35621 Mdot
.1638 .14429 Mdot
.16384 .09753 Mdot
.16389 .13279 Mdot
.16394 .33696 Mdot
.16399 .25767 Mdot
.16403 .27843 Mdot
.16408 .32453 Mdot
.16413 .26417 Mdot
.16418 .2731 Mdot
.16422 .25546 Mdot
.16427 .11445 Mdot
.16432 .10206 Mdot
.16437 .1233 Mdot
.16441 .18689 Mdot
.16446 .35608 Mdot
.16451 .3316 Mdot
.16456 .3157 Mdot
.1646 .34079 Mdot
.16465 .22485 Mdot
.1647 .19981 Mdot
.16475 .24158 Mdot
.1648 .20003 Mdot
.16484 .16459 Mdot
.16489 .21593 Mdot
.16494 .17493 Mdot
.16499 .18031 Mdot
.16503 .10977 Mdot
.16508 .25198 Mdot
.16513 .29044 Mdot
.16518 .27522 Mdot
.16522 .15875 Mdot
.16527 .36149 Mdot
.16532 .09634 Mdot
.16537 .09893 Mdot
.16541 .12364 Mdot
.16546 .33894 Mdot
.16551 .34758 Mdot
.16556 .28676 Mdot
.1656 .14245 Mdot
.16565 .08753 Mdot
.1657 .11225 Mdot
.16575 .32136 Mdot
.1658 .29317 Mdot
.16584 .26346 Mdot
.16589 .24658 Mdot
.16594 .20257 Mdot
.16599 .20999 Mdot
.16603 .12911 Mdot
.16608 .1534 Mdot
.16613 .10419 Mdot
.16618 .18232 Mdot
.16622 .25426 Mdot
.16627 .24027 Mdot
.16632 .20644 Mdot
.16637 .10636 Mdot
.16641 .2706 Mdot
.16646 .22707 Mdot
.16651 .19082 Mdot
.16656 .36106 Mdot
.1666 .31019 Mdot
.16665 .25819 Mdot
.1667 .28294 Mdot
.16675 .30281 Mdot
.1668 .30702 Mdot
.16684 .23048 Mdot
.16689 .34115 Mdot
.16694 .09454 Mdot
.16699 .12863 Mdot
.16703 .364 Mdot
.16708 .22401 Mdot
.16713 .26501 Mdot
.16718 .38016 Mdot
.16722 .29655 Mdot
.16727 .20596 Mdot
.16732 .169 Mdot
.16737 .21238 Mdot
.16741 .14295 Mdot
.16746 .38121 Mdot
.16751 .14966 Mdot
.16756 .32384 Mdot
.1676 .29811 Mdot
.16765 .27794 Mdot
.1677 .17118 Mdot
.16775 .10156 Mdot
.1678 .12802 Mdot
.16784 .37813 Mdot
.16789 .25168 Mdot
.16794 .17802 Mdot
.16799 .2812 Mdot
.16803 .12596 Mdot
.16808 .2463 Mdot
.16813 .13873 Mdot
.16818 .30158 Mdot
.16822 .28651 Mdot
.16827 .36603 Mdot
.16832 .14349 Mdot
.16837 .09527 Mdot
.16841 .17098 Mdot
.16846 .28764 Mdot
.16851 .31674 Mdot
.16856 .33815 Mdot
.1686 .17577 Mdot
.16865 .22931 Mdot
.1687 .37927 Mdot
.16875 .13172 Mdot
.1688 .28455 Mdot
.16884 .15018 Mdot
.16889 .36995 Mdot
.16894 .09612 Mdot
.16899 .29388 Mdot
.16903 .28614 Mdot
.16908 .2849 Mdot
.16913 .20292 Mdot
.16918 .26125 Mdot
.16922 .13335 Mdot
.16927 .23987 Mdot
.16932 .29007 Mdot
.16937 .36367 Mdot
.16941 .15641 Mdot
.16946 .19081 Mdot
.16951 .28941 Mdot
.16956 .28749 Mdot
.1696 .25861 Mdot
.16965 .26408 Mdot
.1697 .34147 Mdot
.16975 .20725 Mdot
.16979 .12502 Mdot
.16984 .27556 Mdot
.16989 .30583 Mdot
.16994 .31382 Mdot
.16999 .36615 Mdot
.17003 .29711 Mdot
.17008 .30653 Mdot
.17013 .11695 Mdot
.17018 .17721 Mdot
.17022 .10959 Mdot
.17027 .20118 Mdot
.17032 .2483 Mdot
.17037 .1418 Mdot
.17041 .2627 Mdot
.17046 .30427 Mdot
.17051 .27799 Mdot
.17056 .37892 Mdot
.1706 .17076 Mdot
.17065 .11391 Mdot
.1707 .3846 Mdot
.17075 .21974 Mdot
.17079 .30114 Mdot
.17084 .1671 Mdot
.17089 .27734 Mdot
.17094 .1949 Mdot
.17099 .12594 Mdot
.17103 .25667 Mdot
.17108 .35911 Mdot
.17113 .22453 Mdot
.17118 .2248 Mdot
.17122 .34629 Mdot
.17127 .34365 Mdot
.17132 .149 Mdot
.17137 .21708 Mdot
.17141 .24717 Mdot
.17146 .19759 Mdot
.17151 .10964 Mdot
.17156 .35186 Mdot
.1716 .34057 Mdot
.17165 .31745 Mdot
.1717 .12876 Mdot
.17175 .28448 Mdot
.17179 .33023 Mdot
.17184 .33147 Mdot
.17189 .30782 Mdot
.17194 .38233 Mdot
.17199 .26746 Mdot
.17203 .15865 Mdot
.17208 .21762 Mdot
.17213 .36128 Mdot
.17218 .11587 Mdot
.17222 .19967 Mdot
.17227 .39341 Mdot
.17232 .24213 Mdot
.17237 .17028 Mdot
.17241 .25692 Mdot
.17246 .35064 Mdot
.17251 .13147 Mdot
.17256 .32458 Mdot
.1726 .16613 Mdot
.17265 .34799 Mdot
.1727 .18165 Mdot
.17275 .38624 Mdot
.17279 .2511 Mdot
.17284 .32699 Mdot
.17289 .29998 Mdot
.17294 .16415 Mdot
.17299 .32283 Mdot
.17303 .1277 Mdot
.17308 .32123 Mdot
.17313 .30046 Mdot
.17318 .27328 Mdot
.17322 .31423 Mdot
.17327 .3643 Mdot
.17332 .29427 Mdot
.17337 .18349 Mdot
.17341 .32574 Mdot
.17346 .23243 Mdot
.17351 .23444 Mdot
.17356 .33207 Mdot
.1736 .3808 Mdot
.17365 .21199 Mdot
.1737 .31595 Mdot
.17375 .27736 Mdot
.17379 .14442 Mdot
.17384 .14215 Mdot
.17389 .33657 Mdot
.17394 .13846 Mdot
.17398 .22468 Mdot
.17403 .24961 Mdot
.17408 .2852 Mdot
.17413 .22346 Mdot
.17418 .21015 Mdot
.17422 .3366 Mdot
.17427 .39315 Mdot
.17432 .35879 Mdot
.17437 .30472 Mdot
.17441 .3813 Mdot
.17446 .21321 Mdot
.17451 .28983 Mdot
.17456 .38857 Mdot
.1746 .26379 Mdot
.17465 .38875 Mdot
.1747 .36793 Mdot
.17475 .12328 Mdot
.17479 .1675 Mdot
.17484 .1887 Mdot
.17489 .20667 Mdot
.17494 .39001 Mdot
.17498 .14184 Mdot
.17503 .26367 Mdot
.17508 .18509 Mdot
.17513 .28241 Mdot
.17518 .30436 Mdot
.17522 .3908 Mdot
.17527 .37415 Mdot
.17532 .19013 Mdot
.17537 .38068 Mdot
.17541 .41077 Mdot
.17546 .13382 Mdot
.17551 .29891 Mdot
.17556 .41309 Mdot
.1756 .3166 Mdot
.17565 .25809 Mdot
.1757 .32464 Mdot
.17575 .26894 Mdot
.17579 .34255 Mdot
.17584 .30504 Mdot
.17589 .32159 Mdot
.17594 .22187 Mdot
.17598 .27447 Mdot
.17603 .2192 Mdot
.17608 .34746 Mdot
.17613 .20124 Mdot
.17618 .13222 Mdot
.17622 .15573 Mdot
.17627 .18686 Mdot
.17632 .31375 Mdot
.17637 .15848 Mdot
.17641 .19884 Mdot
.17646 .41419 Mdot
.17651 .35073 Mdot
.17656 .16557 Mdot
.1766 .18823 Mdot
.17665 .23868 Mdot
.1767 .35609 Mdot
.17675 .26763 Mdot
.17679 .349 Mdot
.17684 .3331 Mdot
.17689 .21155 Mdot
.17694 .34454 Mdot
.17698 .16875 Mdot
.17703 .13651 Mdot
.17708 .40974 Mdot
.17713 .19546 Mdot
.17718 .37 Mdot
.17722 .2097 Mdot
.17727 .33449 Mdot
.17732 .18944 Mdot
.17737 .34067 Mdot
.17741 .14944 Mdot
.17746 .14754 Mdot
.17751 .15795 Mdot
.17756 .26903 Mdot
.1776 .1575 Mdot
.17765 .21926 Mdot
.1777 .41504 Mdot
.17775 .2088 Mdot
.17779 .34187 Mdot
.17784 .28643 Mdot
.17789 .27601 Mdot
.17794 .28346 Mdot
.17798 .13777 Mdot
.17803 .20408 Mdot
.17808 .35573 Mdot
.17813 .24431 Mdot
.17818 .42593 Mdot
.17822 .2192 Mdot
.17827 .29047 Mdot
.17832 .29957 Mdot
.17837 .34683 Mdot
.17841 .31038 Mdot
.17846 .23204 Mdot
.17851 .38497 Mdot
.17856 .32881 Mdot
.1786 .29446 Mdot
.17865 .20591 Mdot
.1787 .24797 Mdot
.17875 .30353 Mdot
.17879 .20763 Mdot
.17884 .21835 Mdot
.17889 .17199 Mdot
.17894 .38955 Mdot
.17898 .34929 Mdot
.17903 .37064 Mdot
.17908 .31703 Mdot
.17913 .38562 Mdot
.17917 .27925 Mdot
.17922 .14915 Mdot
.17927 .20716 Mdot
.17932 .38919 Mdot
.17937 .19489 Mdot
.17941 .28859 Mdot
.17946 .3377 Mdot
.17951 .17782 Mdot
.17956 .31503 Mdot
.1796 .19241 Mdot
.17965 .38365 Mdot
.1797 .28013 Mdot
.17975 .15703 Mdot
.17979 .41803 Mdot
.17984 .27256 Mdot
.17989 .40854 Mdot
.17994 .38155 Mdot
.17998 .33716 Mdot
.18003 .23826 Mdot
.18008 .15688 Mdot
.18013 .17035 Mdot
.18017 .39968 Mdot
.18022 .35459 Mdot
.18027 .20483 Mdot
.18032 .32487 Mdot
.18037 .38964 Mdot
.18041 .28674 Mdot
.18046 .25001 Mdot
.18051 .2697 Mdot
.18056 .24098 Mdot
.1806 .38403 Mdot
.18065 .21252 Mdot
.1807 .39007 Mdot
.18075 .18931 Mdot
.18079 .43618 Mdot
.18084 .36839 Mdot
.18089 .37439 Mdot
.18094 .20769 Mdot
.18098 .30538 Mdot
.18103 .39668 Mdot
.18108 .42986 Mdot
.18113 .30776 Mdot
.18117 .2097 Mdot
.18122 .38258 Mdot
.18127 .4025 Mdot
.18132 .34613 Mdot
.18137 .29336 Mdot
.18141 .32135 Mdot
.18146 .22143 Mdot
.18151 .39535 Mdot
.18156 .15083 Mdot
.1816 .21576 Mdot
.18165 .3912 Mdot
.1817 .2992 Mdot
.18175 .20669 Mdot
.18179 .44333 Mdot
.18184 .44143 Mdot
.18189 .25553 Mdot
.18194 .21122 Mdot
.18198 .22099 Mdot
.18203 .21331 Mdot
.18208 .1943 Mdot
.18213 .34737 Mdot
.18217 .26604 Mdot
.18222 .22537 Mdot
.18227 .32868 Mdot
.18232 .28516 Mdot
.18237 .32601 Mdot
.18241 .26563 Mdot
.18246 .42551 Mdot
.18251 .43496 Mdot
.18256 .15317 Mdot
.1826 .19292 Mdot
.18265 .17908 Mdot
.1827 .43325 Mdot
.18275 .38159 Mdot
.18279 .24611 Mdot
.18284 .32448 Mdot
.18289 .3765 Mdot
.18294 .38327 Mdot
.18298 .24989 Mdot
.18303 .21952 Mdot
.18308 .31605 Mdot
.18313 .31325 Mdot
.18317 .18776 Mdot
.18322 .1766 Mdot
.18327 .41513 Mdot
.18332 .199 Mdot
.18336 .40925 Mdot
.18341 .29499 Mdot
.18346 .28238 Mdot
.18351 .32047 Mdot
.18356 .29644 Mdot
.1836 .31736 Mdot
.18365 .29551 Mdot
.1837 .32074 Mdot
.18375 .25716 Mdot
.18379 .29213 Mdot
.18384 .31117 Mdot
.18389 .38827 Mdot
.18394 .16552 Mdot
.18398 .41718 Mdot
.18403 .3844 Mdot
.18408 .16009 Mdot
.18413 .36578 Mdot
.18417 .35315 Mdot
.18422 .22406 Mdot
.18427 .2976 Mdot
.18432 .33412 Mdot
.18436 .33287 Mdot
.18441 .26031 Mdot
.18446 .25532 Mdot
.18451 .37667 Mdot
.18456 .19502 Mdot
.1846 .43013 Mdot
.18465 .38726 Mdot
.1847 .23799 Mdot
.18475 .33047 Mdot
.18479 .29278 Mdot
.18484 .22489 Mdot
.18489 .43426 Mdot
.18494 .19713 Mdot
.18498 .43546 Mdot
.18503 .29068 Mdot
.18508 .42815 Mdot
.18513 .23442 Mdot
.18517 .21087 Mdot
.18522 .29061 Mdot
.18527 .2226 Mdot
.18532 .33656 Mdot
.18536 .44231 Mdot
.18541 .44872 Mdot
.18546 .34438 Mdot
.18551 .4598 Mdot
.18556 .34346 Mdot
.1856 .35506 Mdot
.18565 .42444 Mdot
.1857 .42686 Mdot
.18575 .37048 Mdot
.18579 .42515 Mdot
.18584 .34916 Mdot
.18589 .25929 Mdot
.18594 .2408 Mdot
.18598 .36357 Mdot
.18603 .37327 Mdot
.18608 .22589 Mdot
.18613 .26413 Mdot
.18617 .23703 Mdot
.18622 .40432 Mdot
.18627 .45087 Mdot
.18632 .21802 Mdot
.18636 .40623 Mdot
.18641 .34689 Mdot
.18646 .27969 Mdot
.18651 .23614 Mdot
.18656 .41816 Mdot
.1866 .46336 Mdot
.18665 .28094 Mdot
.1867 .35393 Mdot
.18675 .2297 Mdot
.18679 .20572 Mdot
.18684 .31595 Mdot
.18689 .44553 Mdot
.18694 .26684 Mdot
.18698 .31906 Mdot
.18703 .2245 Mdot
.18708 .37278 Mdot
.18713 .36637 Mdot
.18717 .4091 Mdot
.18722 .46213 Mdot
.18727 .27751 Mdot
.18732 .29841 Mdot
.18736 .17406 Mdot
.18741 .18074 Mdot
.18746 .22919 Mdot
.18751 .35693 Mdot
.18756 .29212 Mdot
.1876 .36621 Mdot
.18765 .45841 Mdot
.1877 .40435 Mdot
.18775 .29454 Mdot
.18779 .2564 Mdot
.18784 .27581 Mdot
.18789 .34619 Mdot
.18794 .26057 Mdot
.18798 .40725 Mdot
.18803 .29729 Mdot
.18808 .25171 Mdot
.18813 .40893 Mdot
.18817 .35553 Mdot
.18822 .39234 Mdot
.18827 .35338 Mdot
.18832 .46807 Mdot
.18836 .36185 Mdot
.18841 .28863 Mdot
.18846 .22897 Mdot
.18851 .46822 Mdot
.18855 .35552 Mdot
.1886 .23405 Mdot
.18865 .34171 Mdot
.1887 .35112 Mdot
.18875 .45939 Mdot
.18879 .24593 Mdot
.18884 .40786 Mdot
.18889 .23242 Mdot
.18894 .37905 Mdot
.18898 .44123 Mdot
.18903 .23813 Mdot
.18908 .44338 Mdot
.18913 .44352 Mdot
.18917 .32102 Mdot
.18922 .45855 Mdot
.18927 .21193 Mdot
.18932 .26568 Mdot
.18936 .40142 Mdot
.18941 .28327 Mdot
.18946 .21702 Mdot
.18951 .37719 Mdot
.18955 .2915 Mdot
.1896 .23322 Mdot
.18965 .22278 Mdot
.1897 .201 Mdot
.18975 .23698 Mdot
.18979 .3661 Mdot
.18984 .34645 Mdot
.18989 .2166 Mdot
.18994 .46624 Mdot
.18998 .43364 Mdot
.19003 .29478 Mdot
.19008 .31336 Mdot
.19013 .20617 Mdot
.19017 .37687 Mdot
.19022 .32783 Mdot
.19027 .34647 Mdot
.19032 .36199 Mdot
.19036 .39536 Mdot
.19041 .29828 Mdot
.19046 .26338 Mdot
.19051 .43821 Mdot
.19055 .29508 Mdot
.1906 .26446 Mdot
.19065 .36445 Mdot
.1907 .33031 Mdot
.19075 .24567 Mdot
.19079 .22569 Mdot
.19084 .34767 Mdot
.19089 .27775 Mdot
.19094 .35905 Mdot
.19098 .35892 Mdot
.19103 .3161 Mdot
.19108 .2916 Mdot
.19113 .4057 Mdot
.19117 .24977 Mdot
.19122 .48343 Mdot
.19127 .27147 Mdot
.19132 .21507 Mdot
.19136 .40324 Mdot
.19141 .3236 Mdot
.19146 .39119 Mdot
.19151 .30162 Mdot
.19155 .29221 Mdot
.1916 .24768 Mdot
.19165 .4355 Mdot
.1917 .19441 Mdot
.19175 .21582 Mdot
.19179 .36636 Mdot
.19184 .29366 Mdot
.19189 .43227 Mdot
.19194 .47386 Mdot
.19198 .20777 Mdot
.19203 .20518 Mdot
.19208 .2627 Mdot
.19213 .30463 Mdot
.19217 .37642 Mdot
.19222 .39853 Mdot
.19227 .34214 Mdot
.19232 .24536 Mdot
.19236 .37854 Mdot
.19241 .31796 Mdot
.19246 .31817 Mdot
.19251 .32827 Mdot
.19255 .24644 Mdot
.1926 .41333 Mdot
.19265 .20845 Mdot
.1927 .22817 Mdot
.19275 .48592 Mdot
.19279 .4652 Mdot
.19284 .20675 Mdot
.19289 .20526 Mdot
.19294 .31267 Mdot
.19298 .36485 Mdot
.19303 .26285 Mdot
.19308 .21996 Mdot
.19313 .29882 Mdot
.19317 .35378 Mdot
.19322 .48933 Mdot
.19327 .4047 Mdot
.19332 .41197 Mdot
.19336 .44502 Mdot
.19341 .3423 Mdot
.19346 .35466 Mdot
.19351 .22895 Mdot
.19355 .32278 Mdot
.1936 .22005 Mdot
.19365 .22251 Mdot
.1937 .47369 Mdot
.19374 .40082 Mdot
.19379 .20831 Mdot
.19384 .48611 Mdot
.19389 .47974 Mdot
.19394 .4278 Mdot
.19398 .49393 Mdot
.19403 .47857 Mdot
.19408 .36498 Mdot
.19413 .26106 Mdot
.19417 .42939 Mdot
.19422 .45712 Mdot
.19427 .26488 Mdot
.19432 .40104 Mdot
.19436 .43403 Mdot
.19441 .25173 Mdot
.19446 .34727 Mdot
.19451 .45057 Mdot
.19455 .29163 Mdot
.1946 .39202 Mdot
.19465 .31862 Mdot
.1947 .32829 Mdot
.19474 .27229 Mdot
.19479 .37041 Mdot
.19484 .34088 Mdot
.19489 .42362 Mdot
.19494 .26546 Mdot
.19498 .38085 Mdot
.19503 .35789 Mdot
.19508 .49277 Mdot
.19513 .26867 Mdot
.19517 .39961 Mdot
.19522 .49044 Mdot
.19527 .43458 Mdot
.19532 .33721 Mdot
.19536 .44062 Mdot
.19541 .42903 Mdot
.19546 .23721 Mdot
.19551 .4019 Mdot
.19555 .39295 Mdot
.1956 .28601 Mdot
.19565 .28595 Mdot
.1957 .31491 Mdot
.19574 .50063 Mdot
.19579 .46729 Mdot
.19584 .45775 Mdot
.19589 .24806 Mdot
.19594 .33584 Mdot
.19598 .33224 Mdot
.19603 .24015 Mdot
.19608 .48367 Mdot
.19613 .45627 Mdot
.19617 .47582 Mdot
.19622 .24905 Mdot
.19627 .422 Mdot
.19632 .26385 Mdot
.19636 .48763 Mdot
.19641 .31691 Mdot
.19646 .29258 Mdot
.19651 .32607 Mdot
.19655 .26678 Mdot
.1966 .28807 Mdot
.19665 .3941 Mdot
.1967 .43674 Mdot
.19674 .48458 Mdot
.19679 .50613 Mdot
.19684 .28853 Mdot
.19689 .44051 Mdot
.19694 .22702 Mdot
.19698 .25831 Mdot
.19703 .25059 Mdot
.19708 .31498 Mdot
.19713 .40015 Mdot
.19717 .22886 Mdot
.19722 .27267 Mdot
.19727 .36466 Mdot
.19732 .43048 Mdot
.19736 .48615 Mdot
.19741 .3572 Mdot
.19746 .31268 Mdot
.19751 .44976 Mdot
.19755 .38149 Mdot
.1976 .27706 Mdot
.19765 .4941 Mdot
.1977 .39581 Mdot
.19774 .30645 Mdot
.19779 .39103 Mdot
.19784 .27077 Mdot
.19789 .41968 Mdot
.19793 .30897 Mdot
.19798 .31648 Mdot
.19803 .33929 Mdot
.19808 .40703 Mdot
.19813 .26523 Mdot
.19817 .28064 Mdot
.19822 .23925 Mdot
.19827 .22202 Mdot
.19832 .2517 Mdot
.19836 .22349 Mdot
.19841 .38516 Mdot
.19846 .3023 Mdot
.19851 .2765 Mdot
.19855 .37743 Mdot
.1986 .28896 Mdot
.19865 .36407 Mdot
.1987 .40672 Mdot
.19874 .31742 Mdot
.19879 .30696 Mdot
.19884 .48054 Mdot
.19889 .31789 Mdot
.19893 .43905 Mdot
.19898 .25419 Mdot
.19903 .27905 Mdot
.19908 .22729 Mdot
.19913 .34114 Mdot
.19917 .42851 Mdot
.19922 .38582 Mdot
.19927 .47606 Mdot
.19932 .27982 Mdot
.19936 .40877 Mdot
.19941 .3835 Mdot
.19946 .44426 Mdot
.19951 .27641 Mdot
.19955 .24388 Mdot
.1996 .30166 Mdot
.19965 .3884 Mdot
.1997 .41468 Mdot
.19974 .4708 Mdot
.19979 .45366 Mdot
.19984 .49794 Mdot
.19989 .31885 Mdot
.19993 .38562 Mdot
.19998 .48994 Mdot
.20003 .4022 Mdot
.20008 .39699 Mdot
.20013 .35396 Mdot
.20017 .4336 Mdot
.20022 .39781 Mdot
.20027 .27894 Mdot
.20032 .44358 Mdot
.20036 .27125 Mdot
.20041 .44025 Mdot
.20046 .51781 Mdot
.20051 .25883 Mdot
.20055 .40681 Mdot
.2006 .51524 Mdot
.20065 .46597 Mdot
.2007 .23971 Mdot
.20074 .3301 Mdot
.20079 .35197 Mdot
.20084 .27661 Mdot
.20089 .28927 Mdot
.20093 .39698 Mdot
.20098 .37476 Mdot
.20103 .47868 Mdot
.20108 .42474 Mdot
.20113 .42833 Mdot
.20117 .49403 Mdot
.20122 .30849 Mdot
.20127 .29777 Mdot
.20132 .51675 Mdot
.20136 .32357 Mdot
.20141 .25708 Mdot
.20146 .37676 Mdot
.20151 .47341 Mdot
.20155 .40626 Mdot
.2016 .2624 Mdot
.20165 .34639 Mdot
.2017 .29524 Mdot
.20174 .41469 Mdot
.20179 .32029 Mdot
.20184 .33586 Mdot
.20189 .48936 Mdot
.20193 .29227 Mdot
.20198 .27341 Mdot
.20203 .27651 Mdot
.20208 .32248 Mdot
.20213 .44264 Mdot
.20217 .32004 Mdot
.20222 .37726 Mdot
.20227 .41982 Mdot
.20232 .47447 Mdot
.20236 .24274 Mdot
.20241 .31086 Mdot
.20246 .42948 Mdot
.20251 .38263 Mdot
.20255 .51242 Mdot
.2026 .46104 Mdot
.20265 .4832 Mdot
.2027 .50367 Mdot
.20274 .48265 Mdot
.20279 .34747 Mdot
.20284 .42095 Mdot
.20289 .32215 Mdot
.20293 .39571 Mdot
.20298 .24513 Mdot
.20303 .46015 Mdot
.20308 .26377 Mdot
.20312 .35637 Mdot
.20317 .49772 Mdot
.20322 .3721 Mdot
.20327 .35059 Mdot
.20332 .27111 Mdot
.20336 .35542 Mdot
.20341 .48227 Mdot
.20346 .40629 Mdot
.20351 .26386 Mdot
.20355 .28023 Mdot
.2036 .28864 Mdot
.20365 .25969 Mdot
.2037 .2825 Mdot
.20374 .35042 Mdot
.20379 .33686 Mdot
.20384 .28761 Mdot
.20389 .33162 Mdot
.20393 .5349 Mdot
.20398 .44803 Mdot
.20403 .49775 Mdot
.20408 .46839 Mdot
.20412 .52756 Mdot
.20417 .5207 Mdot
.20422 .47212 Mdot
.20427 .35034 Mdot
.20432 .26833 Mdot
.20436 .38727 Mdot
.20441 .36038 Mdot
.20446 .31825 Mdot
.20451 .44696 Mdot
.20455 .43923 Mdot
.2046 .48848 Mdot
.20465 .29411 Mdot
.2047 .40662 Mdot
.20474 .39065 Mdot
.20479 .46903 Mdot
.20484 .25202 Mdot
.20489 .29679 Mdot
.20493 .29456 Mdot
.20498 .42236 Mdot
.20503 .45636 Mdot
.20508 .29802 Mdot
.20512 .38284 Mdot
.20517 .46109 Mdot
.20522 .52463 Mdot
.20527 .30729 Mdot
.20532 .39914 Mdot
.20536 .52613 Mdot
.20541 .41677 Mdot
.20546 .28162 Mdot
.20551 .2547 Mdot
.20555 .40875 Mdot
.2056 .34169 Mdot
.20565 .37285 Mdot
.2057 .35385 Mdot
.20574 .45881 Mdot
.20579 .29144 Mdot
.20584 .50511 Mdot
.20589 .50224 Mdot
.20593 .529 Mdot
.20598 .28395 Mdot
.20603 .45303 Mdot
.20608 .45256 Mdot
.20612 .35169 Mdot
.20617 .36766 Mdot
.20622 .4004 Mdot
.20627 .31527 Mdot
.20632 .43118 Mdot
.20636 .38378 Mdot
.20641 .33917 Mdot
.20646 .45721 Mdot
.20651 .44629 Mdot
.20655 .50842 Mdot
.2066 .30428 Mdot
.20665 .4494 Mdot
.2067 .2846 Mdot
.20674 .41397 Mdot
.20679 .47368 Mdot
.20684 .34312 Mdot
.20689 .36838 Mdot
.20693 .37043 Mdot
.20698 .51149 Mdot
.20703 .38396 Mdot
.20708 .38264 Mdot
.20712 .33504 Mdot
.20717 .30718 Mdot
.20722 .47515 Mdot
.20727 .28001 Mdot
.20731 .51146 Mdot
.20736 .45103 Mdot
.20741 .40944 Mdot
.20746 .39341 Mdot
.20751 .37757 Mdot
.20755 .36192 Mdot
.2076 .4973 Mdot
.20765 .49235 Mdot
.2077 .41454 Mdot
.20774 .30834 Mdot
.20779 .29877 Mdot
.20784 .45878 Mdot
.20789 .54662 Mdot
.20793 .38088 Mdot
.20798 .50203 Mdot
.20803 .34208 Mdot
.20808 .42804 Mdot
.20812 .41626 Mdot
.20817 .37023 Mdot
.20822 .50663 Mdot
.20827 .34549 Mdot
.20831 .36173 Mdot
.20836 .44275 Mdot
.20841 .4796 Mdot
.20846 .38203 Mdot
.20851 .45886 Mdot
.20855 .28677 Mdot
.2086 .33981 Mdot
.20865 .25824 Mdot
.2087 .35088 Mdot
.20874 .33843 Mdot
.20879 .39658 Mdot
.20884 .39298 Mdot
.20889 .29712 Mdot
.20893 .2944 Mdot
.20898 .48756 Mdot
.20903 .39627 Mdot
.20908 .46632 Mdot
.20912 .3426 Mdot
.20917 .40101 Mdot
.20922 .51877 Mdot
.20927 .30591 Mdot
.20931 .52323 Mdot
.20936 .4454 Mdot
.20941 .4296 Mdot
.20946 .49551 Mdot
.20951 .33711 Mdot
.20955 .51745 Mdot
.2096 .30452 Mdot
.20965 .29376 Mdot
.2097 .3076 Mdot
.20974 .43506 Mdot
.20979 .30385 Mdot
.20984 .49547 Mdot
.20989 .52192 Mdot
.20993 .29652 Mdot
.20998 .46393 Mdot
.21003 .4567 Mdot
.21008 .48603 Mdot
.21012 .36248 Mdot
.21017 .32648 Mdot
.21022 .54421 Mdot
.21027 .40255 Mdot
.21031 .51561 Mdot
.21036 .36199 Mdot
.21041 .49788 Mdot
.21046 .43391 Mdot
.21051 .33009 Mdot
.21055 .48729 Mdot
.2106 .55742 Mdot
.21065 .35714 Mdot
.2107 .368 Mdot
.21074 .44342 Mdot
.21079 .52446 Mdot
.21084 .31049 Mdot
.21089 .4889 Mdot
.21093 .40082 Mdot
.21098 .2904 Mdot
.21103 .34499 Mdot
.21108 .45409 Mdot
.21112 .49361 Mdot
.21117 .39057 Mdot
.21122 .41599 Mdot
.21127 .35391 Mdot
.21131 .4296 Mdot
.21136 .40383 Mdot
.21141 .2762 Mdot
.21146 .39607 Mdot
.21151 .33067 Mdot
.21155 .46401 Mdot
.2116 .4005 Mdot
.21165 .32948 Mdot
.2117 .40189 Mdot
.21174 .46525 Mdot
.21179 .30731 Mdot
.21184 .52044 Mdot
.21189 .51757 Mdot
.21193 .50003 Mdot
.21198 .55621 Mdot
.21203 .29622 Mdot
.21208 .38158 Mdot
.21212 .47461 Mdot
.21217 .47634 Mdot
.21222 .40226 Mdot
.21227 .44824 Mdot
.21231 .34961 Mdot
.21236 .32606 Mdot
.21241 .3142 Mdot
.21246 .28463 Mdot
.2125 .50678 Mdot
.21255 .31614 Mdot
.2126 .47941 Mdot
.21265 .51539 Mdot
.2127 .30949 Mdot
.21274 .47736 Mdot
.21279 .41693 Mdot
.21284 .38065 Mdot
.21289 .40639 Mdot
.21293 .43748 Mdot
.21298 .45893 Mdot
.21303 .42566 Mdot
.21308 .46907 Mdot
.21312 .44413 Mdot
.21317 .43085 Mdot
.21322 .31237 Mdot
.21327 .55774 Mdot
.21331 .53122 Mdot
.21336 .29729 Mdot
.21341 .42784 Mdot
.21346 .47713 Mdot
.2135 .4743 Mdot
.21355 .54722 Mdot
.2136 .41262 Mdot
.21365 .53476 Mdot
.2137 .42784 Mdot
.21374 .33764 Mdot
.21379 .46205 Mdot
.21384 .49538 Mdot
.21389 .51559 Mdot
.21393 .48595 Mdot
.21398 .35192 Mdot
.21403 .35966 Mdot
.21408 .34891 Mdot
.21412 .29796 Mdot
.21417 .49219 Mdot
.21422 .45666 Mdot
.21427 .47098 Mdot
.21431 .43345 Mdot
.21436 .45145 Mdot
.21441 .46553 Mdot
.21446 .50651 Mdot
.2145 .40819 Mdot
.21455 .29578 Mdot
.2146 .55556 Mdot
.21465 .30465 Mdot
.2147 .42839 Mdot
.21474 .45072 Mdot
.21479 .29364 Mdot
.21484 .44464 Mdot
.21489 .36386 Mdot
.21493 .55677 Mdot
.21498 .36649 Mdot
.21503 .49742 Mdot
.21508 .44642 Mdot
.21512 .47863 Mdot
.21517 .28074 Mdot
.21522 .42255 Mdot
.21527 .42263 Mdot
.21531 .5556 Mdot
.21536 .39338 Mdot
.21541 .521 Mdot
.21546 .55874 Mdot
.2155 .37899 Mdot
.21555 .49767 Mdot
.2156 .28959 Mdot
.21565 .42578 Mdot
.2157 .35857 Mdot
.21574 .51245 Mdot
.21579 .55542 Mdot
.21584 .56799 Mdot
.21589 .47858 Mdot
.21593 .49482 Mdot
.21598 .38691 Mdot
.21603 .48039 Mdot
.21608 .49305 Mdot
.21612 .40485 Mdot
.21617 .461 Mdot
.21622 .31075 Mdot
.21627 .29133 Mdot
.21631 .40115 Mdot
.21636 .31561 Mdot
.21641 .46025 Mdot
.21646 .30799 Mdot
.2165 .28531 Mdot
.21655 .36713 Mdot
.2166 .47416 Mdot
.21665 .50178 Mdot
.21669 .36054 Mdot
.21674 .35571 Mdot
.21679 .32668 Mdot
.21684 .42163 Mdot
.21689 .42149 Mdot
.21693 .37382 Mdot
.21698 .33234 Mdot
.21703 .51682 Mdot
.21708 .50057 Mdot
.21712 .56092 Mdot
.21717 .42609 Mdot
.21722 .30318 Mdot
.21727 .37525 Mdot
.21731 .37958 Mdot
.21736 .39513 Mdot
.21741 .29176 Mdot
.21746 .54898 Mdot
.2175 .34412 Mdot
.21755 .51 Mdot
.2176 .55901 Mdot
.21765 .54418 Mdot
.21769 .55248 Mdot
.21774 .31658 Mdot
.21779 .3381 Mdot
.21784 .46463 Mdot
.21789 .47789 Mdot
.21793 .566 Mdot
.21798 .49268 Mdot
.21803 .32461 Mdot
.21808 .38566 Mdot
.21812 .51537 Mdot
.21817 .55254 Mdot
.21822 .40085 Mdot
.21827 .40166 Mdot
.21831 .37145 Mdot
.21836 .53165 Mdot
.21841 .30801 Mdot
.21846 .30461 Mdot
.2185 .55383 Mdot
.21855 .52267 Mdot
.2186 .33677 Mdot
.21865 .53834 Mdot
.21869 .32695 Mdot
.21874 .54175 Mdot
.21879 .37078 Mdot
.21884 .56418 Mdot
.21889 .29394 Mdot
.21893 .48734 Mdot
.21898 .48481 Mdot
.21903 .37021 Mdot
.21908 .30684 Mdot
.21912 .57366 Mdot
.21917 .44446 Mdot
.21922 .56378 Mdot
.21927 .37081 Mdot
.21931 .30573 Mdot
.21936 .32832 Mdot
.21941 .44695 Mdot
.21946 .57915 Mdot
.2195 .35398 Mdot
.21955 .30547 Mdot
.2196 .42761 Mdot
.21965 .3107 Mdot
.21969 .41166 Mdot
.21974 .54917 Mdot
.21979 .46984 Mdot
.21984 .56444 Mdot
.21989 .45071 Mdot
.21993 .46443 Mdot
.21998 .48668 Mdot
.22003 .55676 Mdot
.22008 .5446 Mdot
.22012 .56095 Mdot
.22017 .40306 Mdot
.22022 .53662 Mdot
.22027 .5526 Mdot
.22031 .40341 Mdot
.22036 .42116 Mdot
.22041 .45293 Mdot
.22046 .53411 Mdot
.2205 .36243 Mdot
.22055 .55651 Mdot
.2206 .45619 Mdot
.22065 .46779 Mdot
.22069 .34472 Mdot
.22074 .41677 Mdot
.22079 .43346 Mdot
.22084 .34421 Mdot
.22089 .3786 Mdot
.22093 .53007 Mdot
.22098 .45228 Mdot
.22103 .47686 Mdot
.22108 .49763 Mdot
.22112 .3321 Mdot
.22117 .47919 Mdot
.22122 .51603 Mdot
.22127 .52055 Mdot
.22131 .51302 Mdot
.22136 .52665 Mdot
.22141 .54761 Mdot
.22146 .40657 Mdot
.2215 .38139 Mdot
.22155 .36334 Mdot
.2216 .30323 Mdot
.22165 .33397 Mdot
.22169 .40966 Mdot
.22174 .49203 Mdot
.22179 .42043 Mdot
.22184 .57434 Mdot
.22188 .57808 Mdot
.22193 .349 Mdot
.22198 .36675 Mdot
.22203 .48637 Mdot
.22208 .33873 Mdot
.22212 .4824 Mdot
.22217 .47567 Mdot
.22222 .57461 Mdot
.22227 .29774 Mdot
.22231 .29442 Mdot
.22236 .54581 Mdot
.22241 .34547 Mdot
.22246 .37108 Mdot
.2225 .35423 Mdot
.22255 .58475 Mdot
.2226 .52555 Mdot
.22265 .57644 Mdot
.22269 .57773 Mdot
.22274 .5736 Mdot
.22279 .48375 Mdot
.22284 .45904 Mdot
.22288 .37805 Mdot
.22293 .44562 Mdot
.22298 .49681 Mdot
.22303 .46846 Mdot
.22308 .32179 Mdot
.22312 .3717 Mdot
.22317 .30337 Mdot
.22322 .42275 Mdot
.22327 .42736 Mdot
.22331 .48409 Mdot
.22336 .3169 Mdot
.22341 .41839 Mdot
.22346 .42641 Mdot
.2235 .5267 Mdot
.22355 .55994 Mdot
.2236 .34105 Mdot
.22365 .36601 Mdot
.22369 .53073 Mdot
.22374 .32841 Mdot
.22379 .35357 Mdot
.22384 .37733 Mdot
.22388 .54627 Mdot
.22393 .43388 Mdot
.22398 .48384 Mdot
.22403 .58868 Mdot
.22408 .39528 Mdot
.22412 .52664 Mdot
.22417 .31019 Mdot
.22422 .56178 Mdot
.22427 .31855 Mdot
.22431 .51834 Mdot
.22436 .47745 Mdot
.22441 .42967 Mdot
.22446 .42465 Mdot
.2245 .49685 Mdot
.22455 .35456 Mdot
.2246 .29884 Mdot
.22465 .48847 Mdot
.22469 .52752 Mdot
.22474 .30935 Mdot
.22479 .5236 Mdot
.22484 .5486 Mdot
.22488 .4952 Mdot
.22493 .5468 Mdot
.22498 .44252 Mdot
.22503 .29866 Mdot
.22508 .35773 Mdot
.22512 .35946 Mdot
.22517 .44527 Mdot
.22522 .4949 Mdot
.22527 .42268 Mdot
.22531 .34609 Mdot
.22536 .47525 Mdot
.22541 .47333 Mdot
.22546 .49626 Mdot
.2255 .46064 Mdot
.22555 .34281 Mdot
.2256 .34599 Mdot
.22565 .59164 Mdot
.22569 .40353 Mdot
.22574 .34151 Mdot
.22579 .44999 Mdot
.22584 .36182 Mdot
.22588 .39196 Mdot
.22593 .41061 Mdot
.22598 .49418 Mdot
.22603 .45949 Mdot
.22608 .43809 Mdot
.22612 .5611 Mdot
.22617 .49375 Mdot
.22622 .40007 Mdot
.22627 .37702 Mdot
.22631 .41429 Mdot
.22636 .59225 Mdot
.22641 .57085 Mdot
.22646 .32962 Mdot
.2265 .53266 Mdot
.22655 .41775 Mdot
.2266 .3735 Mdot
.22665 .46282 Mdot
.22669 .4889 Mdot
.22674 .37089 Mdot
.22679 .37591 Mdot
.22684 .35856 Mdot
.22688 .44674 Mdot
.22693 .51517 Mdot
.22698 .31357 Mdot
.22703 .56101 Mdot
.22707 .33576 Mdot
.22712 .32069 Mdot
.22717 .44872 Mdot
.22722 .42276 Mdot
.22727 .36943 Mdot
.22731 .42177 Mdot
.22736 .3487 Mdot
.22741 .34587 Mdot
.22746 .55018 Mdot
.2275 .42464 Mdot
.22755 .37304 Mdot
.2276 .31664 Mdot
.22765 .31799 Mdot
.22769 .30742 Mdot
.22774 .59499 Mdot
.22779 .44935 Mdot
.22784 .42467 Mdot
.22788 .53219 Mdot
.22793 .51995 Mdot
.22798 .39172 Mdot
.22803 .57378 Mdot
.22807 .31808 Mdot
.22812 .5075 Mdot
.22817 .42676 Mdot
.22822 .53927 Mdot
.22827 .59357 Mdot
.22831 .36017 Mdot
.22836 .30544 Mdot
.22841 .47135 Mdot
.22846 .47337 Mdot
.2285 .3131 Mdot
.22855 .55613 Mdot
.2286 .51779 Mdot
.22865 .35055 Mdot
.22869 .53681 Mdot
.22874 .54143 Mdot
.22879 .5018 Mdot
.22884 .3452 Mdot
.22888 .5388 Mdot
.22893 .39427 Mdot
.22898 .37938 Mdot
.22903 .41018 Mdot
.22907 .32122 Mdot
.22912 .30498 Mdot
.22917 .40295 Mdot
.22922 .39465 Mdot
.22927 .41118 Mdot
.22931 .47575 Mdot
.22936 .46126 Mdot
.22941 .39871 Mdot
.22946 .35385 Mdot
.2295 .4732 Mdot
.22955 .58771 Mdot
.2296 .52321 Mdot
.22965 .34382 Mdot
.22969 .51505 Mdot
.22974 .3731 Mdot
.22979 .47588 Mdot
.22984 .40516 Mdot
.22988 .57182 Mdot
.22993 .46955 Mdot
.22998 .43413 Mdot
.23003 .46472 Mdot
.23007 .4811 Mdot
.23012 .39378 Mdot
.23017 .32762 Mdot
.23022 .44722 Mdot
.23027 .47989 Mdot
.23031 .58951 Mdot
.23036 .53171 Mdot
.23041 .33996 Mdot
.23046 .30813 Mdot
.2305 .43229 Mdot
.23055 .43708 Mdot
.2306 .5851 Mdot
.23065 .43396 Mdot
.23069 .44367 Mdot
.23074 .51301 Mdot
.23079 .54561 Mdot
.23084 .51815 Mdot
.23088 .375 Mdot
.23093 .3416 Mdot
.23098 .44498 Mdot
.23103 .54577 Mdot
.23107 .50492 Mdot
.23112 .507 Mdot
.23117 .57984 Mdot
.23122 .36943 Mdot
.23126 .41596 Mdot
.23131 .48424 Mdot
.23136 .43753 Mdot
.23141 .48935 Mdot
.23146 .4263 Mdot
.2315 .55243 Mdot
.23155 .40266 Mdot
.2316 .48636 Mdot
.23165 .59404 Mdot
.23169 .42058 Mdot
.23174 .41769 Mdot
.23179 .35771 Mdot
.23184 .45573 Mdot
.23188 .50782 Mdot
.23193 .47237 Mdot
.23198 .4399 Mdot
.23203 .38626 Mdot
.23207 .47179 Mdot
.23212 .333 Mdot
.23217 .49464 Mdot
.23222 .48189 Mdot
.23226 .56538 Mdot
.23231 .35379 Mdot
.23236 .43102 Mdot
.23241 .37178 Mdot
.23246 .38704 Mdot
.2325 .51705 Mdot
.23255 .5425 Mdot
.2326 .54635 Mdot
.23265 .43551 Mdot
.23269 .42048 Mdot
.23274 .36226 Mdot
.23279 .55333 Mdot
.23284 .32114 Mdot
.23288 .30903 Mdot
.23293 .31083 Mdot
.23298 .40391 Mdot
.23303 .41452 Mdot
.23307 .4379 Mdot
.23312 .47222 Mdot
.23317 .32411 Mdot
.23322 .54408 Mdot
.23326 .41143 Mdot
.23331 .579 Mdot
.23336 .44368 Mdot
.23341 .58019 Mdot
.23346 .36431 Mdot
.2335 .45468 Mdot
.23355 .37863 Mdot
.2336 .49992 Mdot
.23365 .44892 Mdot
.23369 .51387 Mdot
.23374 .434 Mdot
.23379 .3713 Mdot
.23384 .33537 Mdot
.23388 .45857 Mdot
.23393 .48251 Mdot
.23398 .35718 Mdot
.23403 .33339 Mdot
.23407 .45481 Mdot
.23412 .3857 Mdot
.23417 .54465 Mdot
.23422 .49751 Mdot
.23426 .58465 Mdot
.23431 .36882 Mdot
.23436 .30782 Mdot
.23441 .39336 Mdot
.23446 .31296 Mdot
.2345 .52734 Mdot
.23455 .32986 Mdot
.2346 .33644 Mdot
.23465 .46056 Mdot
.23469 .45616 Mdot
.23474 .43227 Mdot
.23479 .48988 Mdot
.23484 .54907 Mdot
.23488 .32971 Mdot
.23493 .36855 Mdot
.23498 .46211 Mdot
.23503 .39812 Mdot
.23507 .44971 Mdot
.23512 .31905 Mdot
.23517 .43642 Mdot
.23522 .54589 Mdot
.23526 .37174 Mdot
.23531 .37702 Mdot
.23536 .54155 Mdot
.23541 .5639 Mdot
.23546 .31076 Mdot
.2355 .37705 Mdot
.23555 .45607 Mdot
.2356 .55884 Mdot
.23565 .38619 Mdot
.23569 .35513 Mdot
.23574 .42758 Mdot
.23579 .40626 Mdot
.23584 .53289 Mdot
.23588 .52573 Mdot
.23593 .5406 Mdot
.23598 .4601 Mdot
.23603 .51125 Mdot
.23607 .46527 Mdot
.23612 .3866 Mdot
.23617 .37011 Mdot
.23622 .36969 Mdot
.23626 .45438 Mdot
.23631 .55321 Mdot
.23636 .42727 Mdot
.23641 .60102 Mdot
.23645 .38559 Mdot
.2365 .3199 Mdot
.23655 .46648 Mdot
.2366 .59853 Mdot
.23665 .31683 Mdot
.23669 .46699 Mdot
.23674 .51082 Mdot
.23679 .52067 Mdot
.23684 .5649 Mdot
.23688 .34776 Mdot
.23693 .41293 Mdot
.23698 .59102 Mdot
.23703 .34757 Mdot
.23707 .41043 Mdot
.23712 .55611 Mdot
.23717 .3882 Mdot
.23722 .4856 Mdot
.23726 .33229 Mdot
.23731 .49446 Mdot
.23736 .32698 Mdot
.23741 .3397 Mdot
.23745 .38242 Mdot
.2375 .3757 Mdot
.23755 .32934 Mdot
.2376 .55749 Mdot
.23765 .37105 Mdot
.23769 .51261 Mdot
.23774 .33421 Mdot
.23779 .54922 Mdot
.23784 .50748 Mdot
.23788 .31036 Mdot
.23793 .41697 Mdot
.23798 .58776 Mdot
.23803 .46831 Mdot
.23807 .50088 Mdot
.23812 .42941 Mdot
.23817 .5488 Mdot
.23822 .3665 Mdot
.23826 .54825 Mdot
.23831 .34984 Mdot
.23836 .37183 Mdot
.23841 .34284 Mdot
.23845 .36242 Mdot
.2385 .3315 Mdot
.23855 .34077 Mdot
.2386 .56392 Mdot
.23865 .59023 Mdot
.23869 .31081 Mdot
.23874 .38678 Mdot
.23879 .50152 Mdot
.23884 .38628 Mdot
.23888 .58012 Mdot
.23893 .44108 Mdot
.23898 .59756 Mdot
.23903 .38458 Mdot
.23907 .47181 Mdot
.23912 .45684 Mdot
.23917 .43791 Mdot
.23922 .48722 Mdot
.23926 .35105 Mdot
.23931 .51156 Mdot
.23936 .38007 Mdot
.23941 .54247 Mdot
.23945 .30987 Mdot
.2395 .44838 Mdot
.23955 .34587 Mdot
.2396 .48869 Mdot
.23965 .58187 Mdot
.23969 .41625 Mdot
.23974 .38544 Mdot
.23979 .50195 Mdot
.23984 .57968 Mdot
.23988 .33809 Mdot
.23993 .48739 Mdot
.23998 .42427 Mdot
.24003 .60303 Mdot
.24007 .50047 Mdot
.24012 .49328 Mdot
.24017 .34828 Mdot
.24022 .4398 Mdot
.24026 .3522 Mdot
.24031 .36393 Mdot
.24036 .46448 Mdot
.24041 .39729 Mdot
.24045 .44404 Mdot
.2405 .58726 Mdot
.24055 .52538 Mdot
.2406 .39594 Mdot
.24064 .59902 Mdot
.24069 .54988 Mdot
.24074 .34517 Mdot
.24079 .4174 Mdot
.24084 .49123 Mdot
.24088 .4729 Mdot
.24093 .44653 Mdot
.24098 .441 Mdot
.24103 .46156 Mdot
.24107 .58878 Mdot
.24112 .33065 Mdot
.24117 .44122 Mdot
.24122 .56433 Mdot
.24126 .40386 Mdot
.24131 .58557 Mdot
.24136 .30975 Mdot
.24141 .52044 Mdot
.24145 .34823 Mdot
.2415 .42938 Mdot
.24155 .51558 Mdot
.2416 .38466 Mdot
.24164 .36407 Mdot
.24169 .50708 Mdot
.24174 .42785 Mdot
.24179 .38869 Mdot
.24184 .41722 Mdot
.24188 .47007 Mdot
.24193 .3186 Mdot
.24198 .50044 Mdot
.24203 .54729 Mdot
.24207 .33163 Mdot
.24212 .48053 Mdot
.24217 .34693 Mdot
.24222 .5614 Mdot
.24226 .309 Mdot
.24231 .34731 Mdot
.24236 .38544 Mdot
.24241 .4655 Mdot
.24245 .32622 Mdot
.2425 .34548 Mdot
.24255 .46775 Mdot
.2426 .42515 Mdot
.24264 .49955 Mdot
.24269 .43258 Mdot
.24274 .3909 Mdot
.24279 .36887 Mdot
.24284 .59509 Mdot
.24288 .31247 Mdot
.24293 .30993 Mdot
.24298 .5542 Mdot
.24303 .4327 Mdot
.24307 .59638 Mdot
.24312 .41197 Mdot
.24317 .31451 Mdot
.24322 .40864 Mdot
.24326 .42341 Mdot
.24331 .37256 Mdot
.24336 .35546 Mdot
.24341 .40711 Mdot
.24345 .38355 Mdot
.2435 .5894 Mdot
.24355 .49221 Mdot
.2436 .38826 Mdot
.24364 .34541 Mdot
.24369 .42896 Mdot
.24374 .37434 Mdot
.24379 .49082 Mdot
.24384 .51491 Mdot
.24388 .34526 Mdot
.24393 .31264 Mdot
.24398 .49772 Mdot
.24403 .50954 Mdot
.24407 .34241 Mdot
.24412 .36035 Mdot
.24417 .37204 Mdot
.24422 .51501 Mdot
.24426 .53226 Mdot
.24431 .35277 Mdot
.24436 .56516 Mdot
.24441 .39847 Mdot
.24445 .46653 Mdot
.2445 .59897 Mdot
.24455 .46481 Mdot
.2446 .32165 Mdot
.24464 .47869 Mdot
.24469 .41342 Mdot
.24474 .38319 Mdot
.24479 .5777 Mdot
.24484 .35629 Mdot
.24488 .34561 Mdot
.24493 .49372 Mdot
.24498 .36925 Mdot
.24503 .31746 Mdot
.24507 .33935 Mdot
.24512 .59721 Mdot
.24517 .46088 Mdot
.24522 .57617 Mdot
.24526 .5801 Mdot
.24531 .53137 Mdot
.24536 .54689 Mdot
.24541 .35004 Mdot
.24545 .53341 Mdot
.2455 .56712 Mdot
.24555 .45444 Mdot
.2456 .48434 Mdot
.24564 .53524 Mdot
.24569 .4082 Mdot
.24574 .43864 Mdot
.24579 .31146 Mdot
.24583 .42759 Mdot
.24588 .33075 Mdot
.24593 .46149 Mdot
.24598 .55568 Mdot
.24603 .38759 Mdot
.24607 .43745 Mdot
.24612 .39776 Mdot
.24617 .54371 Mdot
.24622 .35368 Mdot
.24626 .4405 Mdot
.24631 .5371 Mdot
.24636 .5677 Mdot
.24641 .37371 Mdot
.24645 .50921 Mdot
.2465 .59024 Mdot
.24655 .52279 Mdot
.2466 .44024 Mdot
.24664 .54199 Mdot
.24669 .4408 Mdot
.24674 .34341 Mdot
.24679 .50476 Mdot
.24683 .43865 Mdot
.24688 .30697 Mdot
.24693 .33671 Mdot
.24698 .38189 Mdot
.24703 .41258 Mdot
.24707 .44497 Mdot
.24712 .38046 Mdot
.24717 .59369 Mdot
.24722 .57447 Mdot
.24726 .35163 Mdot
.24731 .436 Mdot
.24736 .54434 Mdot
.24741 .43825 Mdot
.24745 .41363 Mdot
.2475 .46734 Mdot
.24755 .47477 Mdot
.2476 .52798 Mdot
.24764 .42228 Mdot
.24769 .54338 Mdot
.24774 .33846 Mdot
.24779 .58472 Mdot
.24783 .58016 Mdot
.24788 .50375 Mdot
.24793 .43227 Mdot
.24798 .44974 Mdot
.24803 .57679 Mdot
.24807 .4706 Mdot
.24812 .35388 Mdot
.24817 .34061 Mdot
.24822 .43522 Mdot
.24826 .39347 Mdot
.24831 .35834 Mdot
.24836 .36423 Mdot
.24841 .38676 Mdot
.24845 .55546 Mdot
.2485 .41191 Mdot
.24855 .52384 Mdot
.2486 .57094 Mdot
.24864 .39102 Mdot
.24869 .53484 Mdot
.24874 .5935 Mdot
.24879 .45139 Mdot
.24883 .44516 Mdot
.24888 .49898 Mdot
.24893 .31132 Mdot
.24898 .46858 Mdot
.24903 .5387 Mdot
.24907 .36908 Mdot
.24912 .45875 Mdot
.24917 .48889 Mdot
.24922 .37029 Mdot
.24926 .31733 Mdot
.24931 .42021 Mdot
.24936 .35568 Mdot
.24941 .57362 Mdot
.24945 .55573 Mdot
.2495 .3578 Mdot
.24955 .56553 Mdot
.2496 .31986 Mdot
.24964 .44545 Mdot
.24969 .43039 Mdot
.24974 .59095 Mdot
.24979 .52515 Mdot
.24983 .50685 Mdot
.24988 .43307 Mdot
.24993 .44082 Mdot
.24998 .38119 Mdot
.25002 .309 Mdot
.25007 .42281 Mdot
.25012 .56809 Mdot
.25017 .43827 Mdot
.25022 .53564 Mdot
.25026 .55971 Mdot
.25031 .37993 Mdot
.25036 .36865 Mdot
.25041 .51891 Mdot
.25045 .44003 Mdot
.2505 .32471 Mdot
.25055 .39028 Mdot
.2506 .55836 Mdot
.25064 .38248 Mdot
.25069 .35423 Mdot
.25074 .37054 Mdot
.25079 .41296 Mdot
.25083 .54693 Mdot
.25088 .35804 Mdot
.25093 .44009 Mdot
.25098 .50074 Mdot
.25102 .41356 Mdot
.25107 .51171 Mdot
.25112 .35846 Mdot
.25117 .49123 Mdot
.25122 .58503 Mdot
.25126 .53782 Mdot
.25131 .51432 Mdot
.25136 .54964 Mdot
.25141 .32445 Mdot
.25145 .45695 Mdot
.2515 .44465 Mdot
.25155 .32964 Mdot
.2516 .47811 Mdot
.25164 .431 Mdot
.25169 .35305 Mdot
.25174 .36475 Mdot
.25179 .39416 Mdot
.25183 .37523 Mdot
.25188 .57576 Mdot
.25193 .54495 Mdot
.25198 .44032 Mdot
.25202 .31534 Mdot
.25207 .43375 Mdot
.25212 .34222 Mdot
.25217 .32469 Mdot
.25222 .39634 Mdot
.25226 .37307 Mdot
.25231 .44355 Mdot
.25236 .33213 Mdot
.25241 .45091 Mdot
.25245 .45107 Mdot
.2525 .48614 Mdot
.25255 .30499 Mdot
.2526 .58604 Mdot
.25264 .30356 Mdot
.25269 .45357 Mdot
.25274 .41872 Mdot
.25279 .45195 Mdot
.25283 .54219 Mdot
.25288 .38556 Mdot
.25293 .32122 Mdot
.25298 .3733 Mdot
.25302 .55778 Mdot
.25307 .43188 Mdot
.25312 .47209 Mdot
.25317 .35421 Mdot
.25322 .4202 Mdot
.25326 .38574 Mdot
.25331 .4434 Mdot
.25336 .54865 Mdot
.25341 .34296 Mdot
.25345 .53279 Mdot
.2535 .40694 Mdot
.25355 .39332 Mdot
.2536 .48225 Mdot
.25364 .34206 Mdot
.25369 .39727 Mdot
.25374 .39738 Mdot
.25379 .47384 Mdot
.25383 .47842 Mdot
.25388 .56839 Mdot
.25393 .53518 Mdot
.25398 .52132 Mdot
.25402 .38758 Mdot
.25407 .54181 Mdot
.25412 .45643 Mdot
.25417 .55285 Mdot
.25422 .54493 Mdot
.25426 .364 Mdot
.25431 .39642 Mdot
.25436 .42676 Mdot
.25441 .4532 Mdot
.25445 .50938 Mdot
.2545 .43646 Mdot
.25455 .37754 Mdot
.2546 .50892 Mdot
.25464 .396 Mdot
.25469 .33661 Mdot
.25474 .48352 Mdot
.25479 .46015 Mdot
.25483 .29192 Mdot
.25488 .5272 Mdot
.25493 .3027 Mdot
.25498 .5695 Mdot
.25502 .31122 Mdot
.25507 .5796 Mdot
.25512 .36887 Mdot
.25517 .47447 Mdot
.25521 .35672 Mdot
.25526 .41553 Mdot
.25531 .40314 Mdot
.25536 .51657 Mdot
.25541 .57966 Mdot
.25545 .3111 Mdot
.2555 .56313 Mdot
.25555 .35516 Mdot
.2556 .36198 Mdot
.25564 .4611 Mdot
.25569 .4771 Mdot
.25574 .4325 Mdot
.25579 .55215 Mdot
.25583 .4157 Mdot
.25588 .57954 Mdot
.25593 .55823 Mdot
.25598 .55114 Mdot
.25602 .47418 Mdot
.25607 .56757 Mdot
.25612 .57421 Mdot
.25617 .53045 Mdot
.25621 .47986 Mdot
.25626 .48903 Mdot
.25631 .38997 Mdot
.25636 .46386 Mdot
.25641 .35436 Mdot
.25645 .37582 Mdot
.2565 .45808 Mdot
.25655 .46878 Mdot
.2566 .33288 Mdot
.25664 .39707 Mdot
.25669 .39235 Mdot
.25674 .39613 Mdot
.25679 .45586 Mdot
.25683 .50395 Mdot
.25688 .54372 Mdot
.25693 .42775 Mdot
.25698 .32897 Mdot
.25702 .50797 Mdot
.25707 .56894 Mdot
.25712 .45996 Mdot
.25717 .43804 Mdot
.25721 .52354 Mdot
.25726 .57777 Mdot
.25731 .51245 Mdot
.25736 .54102 Mdot
.25741 .32238 Mdot
.25745 .47557 Mdot
.2575 .33625 Mdot
.25755 .47421 Mdot
.2576 .52887 Mdot
.25764 .30483 Mdot
.25769 .44955 Mdot
.25774 .42846 Mdot
.25779 .41882 Mdot
.25783 .49425 Mdot
.25788 .34023 Mdot
.25793 .55415 Mdot
.25798 .49632 Mdot
.25802 .53187 Mdot
.25807 .49371 Mdot
.25812 .51144 Mdot
.25817 .56936 Mdot
.25821 .54383 Mdot
.25826 .31969 Mdot
.25831 .35922 Mdot
.25836 .33154 Mdot
.25841 .54651 Mdot
.25845 .38759 Mdot
.2585 .39844 Mdot
.25855 .29443 Mdot
.2586 .3561 Mdot
.25864 .33639 Mdot
.25869 .50402 Mdot
.25874 .34524 Mdot
.25879 .33599 Mdot
.25883 .4663 Mdot
.25888 .36005 Mdot
.25893 .50565 Mdot
.25898 .42086 Mdot
.25902 .41021 Mdot
.25907 .38479 Mdot
.25912 .29325 Mdot
.25917 .46766 Mdot
.25921 .49504 Mdot
.25926 .45179 Mdot
.25931 .3022 Mdot
.25936 .50203 Mdot
.25941 .45859 Mdot
.25945 .37569 Mdot
.2595 .54852 Mdot
.25955 .53326 Mdot
.2596 .35376 Mdot
.25964 .55476 Mdot
.25969 .53663 Mdot
.25974 .45957 Mdot
.25979 .29967 Mdot
.25983 .33292 Mdot
.25988 .47345 Mdot
.25993 .40553 Mdot
.25998 .41005 Mdot
.26002 .54943 Mdot
.26007 .54425 Mdot
.26012 .56099 Mdot
.26017 .28119 Mdot
.26021 .44587 Mdot
.26026 .53212 Mdot
.26031 .37433 Mdot
.26036 .36187 Mdot
.2604 .56969 Mdot
.26045 .51055 Mdot
.2605 .44766 Mdot
.26055 .47853 Mdot
.2606 .47427 Mdot
.26064 .53703 Mdot
.26069 .48928 Mdot
.26074 .40467 Mdot
.26079 .49415 Mdot
.26083 .28006 Mdot
.26088 .30925 Mdot
.26093 .38442 Mdot
.26098 .44052 Mdot
.26102 .38063 Mdot
.26107 .47762 Mdot
.26112 .54814 Mdot
.26117 .46474 Mdot
.26121 .4099 Mdot
.26126 .49003 Mdot
.26131 .54537 Mdot
.26136 .29716 Mdot
.2614 .45081 Mdot
.26145 .39374 Mdot
.2615 .46141 Mdot
.26155 .30012 Mdot
.2616 .51279 Mdot
.26164 .51848 Mdot
.26169 .55515 Mdot
.26174 .398 Mdot
.26179 .54777 Mdot
.26183 .30623 Mdot
.26188 .42738 Mdot
.26193 .47549 Mdot
.26198 .54436 Mdot
.26202 .56835 Mdot
.26207 .31936 Mdot
.26212 .31124 Mdot
.26217 .43987 Mdot
.26221 .36674 Mdot
.26226 .34195 Mdot
.26231 .4171 Mdot
.26236 .30558 Mdot
.2624 .44705 Mdot
.26245 .36679 Mdot
.2625 .39517 Mdot
.26255 .42472 Mdot
.2626 .32827 Mdot
.26264 .47507 Mdot
.26269 .36975 Mdot
.26274 .48136 Mdot
.26279 .37909 Mdot
.26283 .48908 Mdot
.26288 .54078 Mdot
.26293 .50249 Mdot
.26298 .34678 Mdot
.26302 .33547 Mdot
.26307 .33893 Mdot
.26312 .52649 Mdot
.26317 .34666 Mdot
.26321 .28936 Mdot
.26326 .3008 Mdot
.26331 .3596 Mdot
.26336 .54762 Mdot
.2634 .51498 Mdot
.26345 .45113 Mdot
.2635 .32645 Mdot
.26355 .37286 Mdot
.2636 .42035 Mdot
.26364 .32799 Mdot
.26369 .46848 Mdot
.26374 .31635 Mdot
.26379 .51176 Mdot
.26383 .52459 Mdot
.26388 .55332 Mdot
.26393 .50332 Mdot
.26398 .29376 Mdot
.26402 .5496 Mdot
.26407 .32164 Mdot
.26412 .42721 Mdot
.26417 .52366 Mdot
.26421 .48106 Mdot
.26426 .36025 Mdot
.26431 .35066 Mdot
.26436 .50427 Mdot
.2644 .45009 Mdot
.26445 .27034 Mdot
.2645 .36745 Mdot
.26455 .55356 Mdot
.26459 .26823 Mdot
.26464 .50787 Mdot
.26469 .55844 Mdot
.26474 .40206 Mdot
.26479 .50381 Mdot
.26483 .30796 Mdot
.26488 .51052 Mdot
.26493 .45345 Mdot
.26498 .54223 Mdot
.26502 .3175 Mdot
.26507 .27506 Mdot
.26512 .42741 Mdot
.26517 .55506 Mdot
.26521 .55815 Mdot
.26526 .40999 Mdot
.26531 .46575 Mdot
.26536 .341 Mdot
.2654 .46477 Mdot
.26545 .32605 Mdot
.2655 .52291 Mdot
.26555 .4522 Mdot
.26559 .46071 Mdot
.26564 .51959 Mdot
.26569 .5302 Mdot
.26574 .44982 Mdot
.26579 .5134 Mdot
.26583 .52157 Mdot
.26588 .39355 Mdot
.26593 .50613 Mdot
.26598 .47057 Mdot
.26602 .27603 Mdot
.26607 .49979 Mdot
.26612 .52344 Mdot
.26617 .41761 Mdot
.26621 .26536 Mdot
.26626 .33663 Mdot
.26631 .52734 Mdot
.26636 .41826 Mdot
.2664 .41402 Mdot
.26645 .42938 Mdot
.2665 .44984 Mdot
.26655 .51171 Mdot
.26659 .35118 Mdot
.26664 .46439 Mdot
.26669 .26056 Mdot
.26674 .31375 Mdot
.26679 .38906 Mdot
.26683 .4915 Mdot
.26688 .36791 Mdot
.26693 .35737 Mdot
.26698 .42435 Mdot
.26702 .35981 Mdot
.26707 .41835 Mdot
.26712 .44322 Mdot
.26717 .40974 Mdot
.26721 .41613 Mdot
.26726 .45087 Mdot
.26731 .28657 Mdot
.26736 .40518 Mdot
.2674 .34016 Mdot
.26745 .47888 Mdot
.2675 .42351 Mdot
.26755 .54621 Mdot
.26759 .46567 Mdot
.26764 .28893 Mdot
.26769 .4664 Mdot
.26774 .45461 Mdot
.26779 .26072 Mdot
.26783 .28765 Mdot
.26788 .41177 Mdot
.26793 .32452 Mdot
.26798 .32289 Mdot
.26802 .47326 Mdot
.26807 .31291 Mdot
.26812 .45338 Mdot
.26817 .51613 Mdot
.26821 .31295 Mdot
.26826 .42243 Mdot
.26831 .30137 Mdot
.26836 .35757 Mdot
.2684 .41436 Mdot
.26845 .39312 Mdot
.2685 .44815 Mdot
.26855 .27437 Mdot
.26859 .48712 Mdot
.26864 .5211 Mdot
.26869 .45328 Mdot
.26874 .35988 Mdot
.26879 .45436 Mdot
.26883 .3107 Mdot
.26888 .25452 Mdot
.26893 .35485 Mdot
.26898 .42224 Mdot
.26902 .44916 Mdot
.26907 .48007 Mdot
.26912 .28702 Mdot
.26917 .49874 Mdot
.26921 .391 Mdot
.26926 .28127 Mdot
.26931 .32017 Mdot
.26936 .44005 Mdot
.2694 .51753 Mdot
.26945 .5287 Mdot
.2695 .51123 Mdot
.26955 .27932 Mdot
.26959 .37787 Mdot
.26964 .33385 Mdot
.26969 .49001 Mdot
.26974 .34003 Mdot
.26978 .40444 Mdot
.26983 .42808 Mdot
.26988 .38262 Mdot
.26993 .43286 Mdot
.26998 .34591 Mdot
.27002 .42557 Mdot
.27007 .27962 Mdot
.27012 .2623 Mdot
.27017 .44312 Mdot
.27021 .49172 Mdot
.27026 .53865 Mdot
.27031 .30945 Mdot
.27036 .30299 Mdot
.2704 .46115 Mdot
.27045 .46902 Mdot
.2705 .41463 Mdot
.27055 .33054 Mdot
.27059 .47736 Mdot
.27064 .50253 Mdot
.27069 .38504 Mdot
.27074 .49709 Mdot
.27078 .3929 Mdot
.27083 .26175 Mdot
.27088 .29407 Mdot
.27093 .34154 Mdot
.27098 .50841 Mdot
.27102 .42255 Mdot
.27107 .40447 Mdot
.27112 .53872 Mdot
.27117 .3309 Mdot
.27121 .39083 Mdot
.27126 .3899 Mdot
.27131 .34317 Mdot
.27136 .38144 Mdot
.2714 .39426 Mdot
.27145 .32751 Mdot
.2715 .28707 Mdot
.27155 .46187 Mdot
.27159 .46666 Mdot
.27164 .45413 Mdot
.27169 .49761 Mdot
.27174 .52543 Mdot
.27178 .50487 Mdot
.27183 .31482 Mdot
.27188 .24608 Mdot
.27193 .37791 Mdot
.27198 .48834 Mdot
.27202 .26579 Mdot
.27207 .44427 Mdot
.27212 .40907 Mdot
.27217 .31032 Mdot
.27221 .40054 Mdot
.27226 .4446 Mdot
.27231 .32219 Mdot
.27236 .45821 Mdot
.2724 .25433 Mdot
.27245 .34495 Mdot
.2725 .47895 Mdot
.27255 .30712 Mdot
.27259 .46467 Mdot
.27264 .30071 Mdot
.27269 .25974 Mdot
.27274 .3778 Mdot
.27278 .25285 Mdot
.27283 .34009 Mdot
.27288 .27113 Mdot
.27293 .40959 Mdot
.27298 .47452 Mdot
.27302 .33547 Mdot
.27307 .42936 Mdot
.27312 .45721 Mdot
.27317 .44966 Mdot
.27321 .42682 Mdot
.27326 .26088 Mdot
.27331 .3873 Mdot
.27336 .28936 Mdot
.2734 .51714 Mdot
.27345 .47343 Mdot
.2735 .46367 Mdot
.27355 .27457 Mdot
.27359 .41156 Mdot
.27364 .52853 Mdot
.27369 .39557 Mdot
.27374 .3436 Mdot
.27378 .34952 Mdot
.27383 .50729 Mdot
.27388 .25608 Mdot
.27393 .32889 Mdot
.27397 .2474 Mdot
.27402 .47395 Mdot
.27407 .37897 Mdot
.27412 .38667 Mdot
.27417 .44405 Mdot
.27421 .28168 Mdot
.27426 .45353 Mdot
.27431 .4686 Mdot
.27436 .25379 Mdot
.2744 .25718 Mdot
.27445 .30243 Mdot
.2745 .41526 Mdot
.27455 .26736 Mdot
.27459 .31427 Mdot
.27464 .36911 Mdot
.27469 .376 Mdot
.27474 .38579 Mdot
.27478 .31556 Mdot
.27483 .50318 Mdot
.27488 .267 Mdot
.27493 .27069 Mdot
.27497 .33737 Mdot
.27502 .48116 Mdot
.27507 .46685 Mdot
.27512 .257 Mdot
.27517 .3918 Mdot
.27521 .33554 Mdot
.27526 .31335 Mdot
.27531 .3408 Mdot
.27536 .34293 Mdot
.2754 .4095 Mdot
.27545 .37206 Mdot
.2755 .31928 Mdot
.27555 .31784 Mdot
.27559 .33898 Mdot
.27564 .48339 Mdot
.27569 .28347 Mdot
.27574 .23493 Mdot
.27578 .49591 Mdot
.27583 .33838 Mdot
.27588 .42335 Mdot
.27593 .44487 Mdot
.27597 .51805 Mdot
.27602 .30166 Mdot
.27607 .38275 Mdot
.27612 .33742 Mdot
.27617 .26662 Mdot
.27621 .35921 Mdot
.27626 .35512 Mdot
.27631 .46966 Mdot
.27636 .45494 Mdot
.2764 .27467 Mdot
.27645 .24295 Mdot
.2765 .35518 Mdot
.27655 .27371 Mdot
.27659 .42555 Mdot
.27664 .44643 Mdot
.27669 .26506 Mdot
.27674 .45711 Mdot
.27678 .46437 Mdot
.27683 .39013 Mdot
.27688 .2571 Mdot
.27693 .48285 Mdot
.27697 .3526 Mdot
.27702 .48807 Mdot
.27707 .33333 Mdot
.27712 .48572 Mdot
.27717 .27682 Mdot
.27721 .331 Mdot
.27726 .51627 Mdot
.27731 .44442 Mdot
.27736 .4376 Mdot
.2774 .49569 Mdot
.27745 .27137 Mdot
.2775 .50891 Mdot
.27755 .38732 Mdot
.27759 .47695 Mdot
.27764 .43507 Mdot
.27769 .45904 Mdot
.27774 .48027 Mdot
.27778 .25397 Mdot
.27783 .39329 Mdot
.27788 .22501 Mdot
.27793 .23879 Mdot
.27797 .38141 Mdot
.27802 .35871 Mdot
.27807 .25935 Mdot
.27812 .4032 Mdot
.27817 .41016 Mdot
.27821 .24715 Mdot
.27826 .29008 Mdot
.27831 .34778 Mdot
.27836 .30037 Mdot
.2784 .24676 Mdot
.27845 .36135 Mdot
.2785 .42568 Mdot
.27855 .31999 Mdot
.27859 .49052 Mdot
.27864 .36738 Mdot
.27869 .25825 Mdot
.27874 .3576 Mdot
.27878 .27496 Mdot
.27883 .42252 Mdot
.27888 .29198 Mdot
.27893 .32258 Mdot
.27897 .39529 Mdot
.27902 .41608 Mdot
.27907 .27157 Mdot
.27912 .45421 Mdot
.27916 .25458 Mdot
.27921 .37454 Mdot
.27926 .38085 Mdot
.27931 .26148 Mdot
.27936 .22467 Mdot
.2794 .3015 Mdot
.27945 .24993 Mdot
.2795 .47264 Mdot
.27955 .48923 Mdot
.27959 .45129 Mdot
.27964 .3352 Mdot
.27969 .36855 Mdot
.27974 .21443 Mdot
.27978 .29943 Mdot
.27983 .29227 Mdot
.27988 .22608 Mdot
.27993 .44927 Mdot
.27997 .38652 Mdot
.28002 .21486 Mdot
.28007 .41273 Mdot
.28012 .26815 Mdot
.28016 .47928 Mdot
.28021 .45194 Mdot
.28026 .46698 Mdot
.28031 .22698 Mdot
.28036 .31796 Mdot
.2804 .28412 Mdot
.28045 .41833 Mdot
.2805 .21495 Mdot
.28055 .2289 Mdot
.28059 .24644 Mdot
.28064 .45261 Mdot
.28069 .23244 Mdot
.28074 .28414 Mdot
.28078 .41758 Mdot
.28083 .29534 Mdot
.28088 .2291 Mdot
.28093 .49046 Mdot
.28097 .33601 Mdot
.28102 .27977 Mdot
.28107 .28501 Mdot
.28112 .31407 Mdot
.28116 .33108 Mdot
.28121 .37163 Mdot
.28126 .2264 Mdot
.28131 .33899 Mdot
.28136 .38315 Mdot
.2814 .40846 Mdot
.28145 .20818 Mdot
.2815 .2296 Mdot
.28155 .3074 Mdot
.28159 .49316 Mdot
.28164 .49606 Mdot
.28169 .20848 Mdot
.28174 .26854 Mdot
.28178 .24795 Mdot
.28183 .47082 Mdot
.28188 .42621 Mdot
.28193 .35263 Mdot
.28197 .45408 Mdot
.28202 .44813 Mdot
.28207 .43682 Mdot
.28212 .22264 Mdot
.28216 .38013 Mdot
.28221 .36876 Mdot
.28226 .32818 Mdot
.28231 .39165 Mdot
.28236 .21355 Mdot
.2824 .3472 Mdot
.28245 .4887 Mdot
.2825 .21296 Mdot
.28255 .3042 Mdot
.28259 .34309 Mdot
.28264 .46296 Mdot
.28269 .40408 Mdot
.28274 .30936 Mdot
.28278 .34515 Mdot
.28283 .45755 Mdot
.28288 .33841 Mdot
.28293 .26409 Mdot
.28297 .37167 Mdot
.28302 .23362 Mdot
.28307 .48273 Mdot
.28312 .30676 Mdot
.28316 .42008 Mdot
.28321 .29315 Mdot
.28326 .46138 Mdot
.28331 .42258 Mdot
.28335 .25222 Mdot
.2834 .46053 Mdot
.28345 .27023 Mdot
.2835 .40933 Mdot
.28355 .39997 Mdot
.28359 .46659 Mdot
.28364 .25698 Mdot
.28369 .30463 Mdot
.28374 .2562 Mdot
.28378 .20274 Mdot
.28383 .34666 Mdot
.28388 .48884 Mdot
.28393 .40441 Mdot
.28397 .23837 Mdot
.28402 .20636 Mdot
.28407 .42267 Mdot
.28412 .23047 Mdot
.28416 .20226 Mdot
.28421 .21581 Mdot
.28426 .31303 Mdot
.28431 .30216 Mdot
.28435 .40068 Mdot
.2844 .2458 Mdot
.28445 .38163 Mdot
.2845 .24606 Mdot
.28455 .43093 Mdot
.28459 .46614 Mdot
.28464 .46267 Mdot
.28469 .33626 Mdot
.28474 .45431 Mdot
.28478 .40408 Mdot
.28483 .35275 Mdot
.28488 .27458 Mdot
.28493 .44588 Mdot
.28497 .25153 Mdot
.28502 .35268 Mdot
.28507 .35874 Mdot
.28512 .40103 Mdot
.28516 .23848 Mdot
.28521 .41798 Mdot
.28526 .32118 Mdot
.28531 .39148 Mdot
.28535 .21518 Mdot
.2854 .29726 Mdot
.28545 .21112 Mdot
.2855 .47756 Mdot
.28555 .45594 Mdot
.28559 .402 Mdot
.28564 .45122 Mdot
.28569 .23774 Mdot
.28574 .47555 Mdot
.28578 .42488 Mdot
.28583 .30545 Mdot
.28588 .26858 Mdot
.28593 .26156 Mdot
.28597 .26201 Mdot
.28602 .22055 Mdot
.28607 .30703 Mdot
.28612 .19931 Mdot
.28616 .39326 Mdot
.28621 .34555 Mdot
.28626 .38954 Mdot
.28631 .44415 Mdot
.28635 .45841 Mdot
.2864 .21244 Mdot
.28645 .18592 Mdot
.2865 .41663 Mdot
.28655 .3486 Mdot
.28659 .18857 Mdot
.28664 .19027 Mdot
.28669 .4424 Mdot
.28674 .42811 Mdot
.28678 .21866 Mdot
.28683 .43363 Mdot
.28688 .44775 Mdot
.28693 .18908 Mdot
.28697 .3937 Mdot
.28702 .35049 Mdot
.28707 .37142 Mdot
.28712 .40695 Mdot
.28716 .35797 Mdot
.28721 .22808 Mdot
.28726 .35653 Mdot
.28731 .1979 Mdot
.28735 .19643 Mdot
.2874 .31721 Mdot
.28745 .39084 Mdot
.2875 .21775 Mdot
.28755 .46204 Mdot
.28759 .31428 Mdot
.28764 .45185 Mdot
.28769 .34659 Mdot
.28774 .45585 Mdot
.28778 .30619 Mdot
.28783 .19143 Mdot
.28788 .3951 Mdot
.28793 .41877 Mdot
.28797 .34878 Mdot
.28802 .2197 Mdot
.28807 .38698 Mdot
.28812 .20582 Mdot
.28816 .17883 Mdot
.28821 .32348 Mdot
.28826 .45503 Mdot
.28831 .32264 Mdot
.28835 .42534 Mdot
.2884 .44132 Mdot
.28845 .43645 Mdot
.2885 .30533 Mdot
.28854 .28704 Mdot
.28859 .22919 Mdot
.28864 .3972 Mdot
.28869 .31644 Mdot
.28874 .44572 Mdot
.28878 .25009 Mdot
.28883 .2283 Mdot
.28888 .33293 Mdot
.28893 .3168 Mdot
.28897 .23573 Mdot
.28902 .30492 Mdot
.28907 .38568 Mdot
.28912 .43934 Mdot
.28916 .19229 Mdot
.28921 .38885 Mdot
.28926 .35571 Mdot
.28931 .43615 Mdot
.28935 .33911 Mdot
.2894 .40391 Mdot
.28945 .2081 Mdot
.2895 .18564 Mdot
.28954 .36726 Mdot
.28959 .43673 Mdot
.28964 .37183 Mdot
.28969 .36745 Mdot
.28974 .31186 Mdot
.28978 .21311 Mdot
.28983 .22877 Mdot
.28988 .38977 Mdot
.28993 .23475 Mdot
.28997 .45244 Mdot
.29002 .36327 Mdot
.29007 .24533 Mdot
.29012 .17117 Mdot
.29016 .31947 Mdot
.29021 .44419 Mdot
.29026 .27238 Mdot
.29031 .44507 Mdot
.29035 .3966 Mdot
.2904 .2594 Mdot
.29045 .3018 Mdot
.2905 .27647 Mdot
.29054 .45786 Mdot
.29059 .2214 Mdot
.29064 .28606 Mdot
.29069 .37376 Mdot
.29074 .19062 Mdot
.29078 .3137 Mdot
.29083 .38254 Mdot
.29088 .23077 Mdot
.29093 .44102 Mdot
.29097 .25339 Mdot
.29102 .45587 Mdot
.29107 .16407 Mdot
.29112 .45128 Mdot
.29116 .35261 Mdot
.29121 .37798 Mdot
.29126 .45498 Mdot
.29131 .29883 Mdot
.29135 .37009 Mdot
.2914 .27221 Mdot
.29145 .17631 Mdot
.2915 .36328 Mdot
.29154 .27669 Mdot
.29159 .43105 Mdot
.29164 .36027 Mdot
.29169 .36565 Mdot
.29174 .22045 Mdot
.29178 .30996 Mdot
.29183 .44612 Mdot
.29188 .33958 Mdot
.29193 .36595 Mdot
.29197 .38641 Mdot
.29202 .37928 Mdot
.29207 .35714 Mdot
.29212 .27608 Mdot
.29216 .38871 Mdot
.29221 .37832 Mdot
.29226 .36362 Mdot
.29231 .38103 Mdot
.29235 .17323 Mdot
.2924 .38048 Mdot
.29245 .22687 Mdot
.2925 .17281 Mdot
.29254 .35754 Mdot
.29259 .36564 Mdot
.29264 .3197 Mdot
.29269 .35203 Mdot
.29274 .38219 Mdot
.29278 .16601 Mdot
.29283 .40933 Mdot
.29288 .2918 Mdot
.29293 .23226 Mdot
.29297 .17456 Mdot
.29302 .22936 Mdot
.29307 .38011 Mdot
.29312 .2999 Mdot
.29316 .24913 Mdot
.29321 .32586 Mdot
.29326 .26261 Mdot
.29331 .36442 Mdot
.29335 .32384 Mdot
.2934 .41506 Mdot
.29345 .3342 Mdot
.2935 .34875 Mdot
.29354 .39556 Mdot
.29359 .34533 Mdot
.29364 .31833 Mdot
.29369 .44279 Mdot
.29373 .18645 Mdot
.29378 .18195 Mdot
.29383 .41727 Mdot
.29388 .2165 Mdot
.29393 .17614 Mdot
.29397 .22297 Mdot
.29402 .28076 Mdot
.29407 .43418 Mdot
.29412 .15646 Mdot
.29416 .44314 Mdot
.29421 .34997 Mdot
.29426 .28854 Mdot
.29431 .35624 Mdot
.29435 .27113 Mdot
.2944 .24101 Mdot
.29445 .37242 Mdot
.2945 .18563 Mdot
.29454 .30395 Mdot
.29459 .35449 Mdot
.29464 .17629 Mdot
.29469 .23733 Mdot
.29473 .40568 Mdot
.29478 .18816 Mdot
.29483 .18015 Mdot
.29488 .20247 Mdot
.29493 .37512 Mdot
.29497 .21692 Mdot
.29502 .40948 Mdot
.29507 .1771 Mdot
.29512 .30271 Mdot
.29516 .38138 Mdot
.29521 .42031 Mdot
.29526 .17059 Mdot
.29531 .30417 Mdot
.29535 .18094 Mdot
.2954 .2811 Mdot
.29545 .25834 Mdot
.2955 .18196 Mdot
.29554 .3835 Mdot
.29559 .35205 Mdot
.29564 .22102 Mdot
.29569 .32097 Mdot
.29573 .17691 Mdot
.29578 .32345 Mdot
.29583 .42603 Mdot
.29588 .35742 Mdot
.29593 .43069 Mdot
.29597 .29017 Mdot
.29602 .37023 Mdot
.29607 .42363 Mdot
.29612 .36002 Mdot
.29616 .32159 Mdot
.29621 .33898 Mdot
.29626 .26656 Mdot
.29631 .41894 Mdot
.29635 .34137 Mdot
.2964 .31342 Mdot
.29645 .40207 Mdot
.2965 .38262 Mdot
.29654 .20469 Mdot
.29659 .19929 Mdot
.29664 .36411 Mdot
.29669 .14292 Mdot
.29673 .2911 Mdot
.29678 .41652 Mdot
.29683 .18633 Mdot
.29688 .40385 Mdot
.29693 .40529 Mdot
.29697 .42793 Mdot
.29702 .26614 Mdot
.29707 .4102 Mdot
.29712 .25709 Mdot
.29716 .19946 Mdot
.29721 .27893 Mdot
.29726 .19153 Mdot
.29731 .3715 Mdot
.29735 .29629 Mdot
.2974 .15311 Mdot
.29745 .20798 Mdot
.2975 .17046 Mdot
.29754 .41786 Mdot
.29759 .18583 Mdot
.29764 .25994 Mdot
.29769 .40015 Mdot
.29773 .35788 Mdot
.29778 .25568 Mdot
.29783 .25592 Mdot
.29788 .24775 Mdot
.29792 .37472 Mdot
.29797 .20765 Mdot
.29802 .28502 Mdot
.29807 .27521 Mdot
.29812 .37934 Mdot
.29816 .37385 Mdot
.29821 .30697 Mdot
.29826 .1552 Mdot
.29831 .31675 Mdot
.29835 .23159 Mdot
.2984 .25191 Mdot
.29845 .21482 Mdot
.2985 .15653 Mdot
.29854 .21434 Mdot
.29859 .17959 Mdot
.29864 .17981 Mdot
.29869 .16878 Mdot
.29873 .16357 Mdot
.29878 .34935 Mdot
.29883 .20917 Mdot
.29888 .2402 Mdot
.29892 .33699 Mdot
.29897 .22747 Mdot
.29902 .39011 Mdot
.29907 .29397 Mdot
.29912 .26277 Mdot
.29916 .37054 Mdot
.29921 .24793 Mdot
.29926 .34232 Mdot
.29931 .31641 Mdot
.29935 .19599 Mdot
.2994 .22495 Mdot
.29945 .15758 Mdot
.2995 .21663 Mdot
.29954 .37056 Mdot
.29959 .14155 Mdot
.29964 .13227 Mdot
.29969 .1333 Mdot
.29973 .32178 Mdot
.29978 .3872 Mdot
.29983 .38875 Mdot
.29988 .39479 Mdot
.29992 .39729 Mdot
.29997 .30784 Mdot
.30002 .27815 Mdot
.30007 .18721 Mdot
.30012 .29902 Mdot
.30016 .34159 Mdot
.30021 .40784 Mdot
.30026 .34789 Mdot
.30031 .35174 Mdot
.30035 .22186 Mdot
.3004 .19352 Mdot
.30045 .15928 Mdot
.3005 .28334 Mdot
.30054 .1243 Mdot
.30059 .16313 Mdot
.30064 .36451 Mdot
.30069 .33444 Mdot
.30073 .40421 Mdot
.30078 .15726 Mdot
.30083 .3574 Mdot
.30088 .13865 Mdot
.30092 .1428 Mdot
.30097 .18896 Mdot
.30102 .38286 Mdot
.30107 .16142 Mdot
.30112 .25482 Mdot
.30116 .33046 Mdot
.30121 .32025 Mdot
.30126 .28165 Mdot
.30131 .33229 Mdot
.30135 .34148 Mdot
.3014 .39101 Mdot
.30145 .34837 Mdot
.3015 .23384 Mdot
.30154 .27117 Mdot
.30159 .35473 Mdot
.30164 .18784 Mdot
.30169 .23214 Mdot
.30173 .23044 Mdot
.30178 .4073 Mdot
.30183 .27027 Mdot
.30188 .24461 Mdot
.30192 .1948 Mdot
.30197 .17131 Mdot
.30202 .25283 Mdot
.30207 .22283 Mdot
.30212 .12666 Mdot
.30216 .20394 Mdot
.30221 .21184 Mdot
.30226 .38309 Mdot
.30231 .21109 Mdot
.30235 .29838 Mdot
.3024 .34468 Mdot
.30245 .17025 Mdot
.3025 .28371 Mdot
.30254 .32127 Mdot
.30259 .11516 Mdot
.30264 .34992 Mdot
.30269 .131 Mdot
.30273 .37965 Mdot
.30278 .34024 Mdot
.30283 .23564 Mdot
.30288 .31308 Mdot
.30292 .38469 Mdot
.30297 .18725 Mdot
.30302 .40297 Mdot
.30307 .23516 Mdot
.30311 .33006 Mdot
.30316 .34576 Mdot
.30321 .29643 Mdot
.30326 .2246 Mdot
.30331 .24202 Mdot
.30335 .24963 Mdot
.3034 .32371 Mdot
.30345 .12882 Mdot
.3035 .35362 Mdot
.30354 .31472 Mdot
.30359 .26819 Mdot
.30364 .2545 Mdot
.30369 .14668 Mdot
.30373 .3137 Mdot
.30378 .32708 Mdot
.30383 .23726 Mdot
.30388 .17544 Mdot
.30392 .38168 Mdot
.30397 .20461 Mdot
.30402 .33201 Mdot
.30407 .19839 Mdot
.30411 .30702 Mdot
.30416 .20889 Mdot
.30421 .20905 Mdot
.30426 .27519 Mdot
.30431 .36792 Mdot
.30435 .31893 Mdot
.3044 .39073 Mdot
.30445 .1444 Mdot
.3045 .22933 Mdot
.30454 .40092 Mdot
.30459 .37255 Mdot
.30464 .19609 Mdot
.30469 .31972 Mdot
.30473 .24279 Mdot
.30478 .22792 Mdot
.30483 .15909 Mdot
.30488 .11551 Mdot
.30492 .31987 Mdot
.30497 .39463 Mdot
.30502 .38742 Mdot
.30507 .1374 Mdot
.30511 .22379 Mdot
.30516 .17095 Mdot
.30521 .29717 Mdot
.30526 .23319 Mdot
.30531 .12266 Mdot
.30535 .36433 Mdot
.3054 .12935 Mdot
.30545 .26731 Mdot
.3055 .20559 Mdot
.30554 .37525 Mdot
.30559 .38642 Mdot
.30564 .1444 Mdot
.30569 .20575 Mdot
.30573 .10874 Mdot
.30578 .29618 Mdot
.30583 .22519 Mdot
.30588 .36328 Mdot
.30592 .28095 Mdot
.30597 .24217 Mdot
.30602 .21458 Mdot
.30607 .14811 Mdot
.30611 .28569 Mdot
.30616 .25394 Mdot
.30621 .18131 Mdot
.30626 .32313 Mdot
.30631 .2185 Mdot
.30635 .35519 Mdot
.3064 .34636 Mdot
.30645 .30365 Mdot
.3065 .25203 Mdot
.30654 .32864 Mdot
.30659 .18166 Mdot
.30664 .2005 Mdot
.30669 .27387 Mdot
.30673 .33913 Mdot
.30678 .13912 Mdot
.30683 .39128 Mdot
.30688 .26662 Mdot
.30692 .14425 Mdot
.30697 .3099 Mdot
.30702 .12892 Mdot
.30707 .38127 Mdot
.30711 .29748 Mdot
.30716 .19568 Mdot
.30721 .37584 Mdot
.30726 .19557 Mdot
.3073 .14335 Mdot
.30735 .11398 Mdot
.3074 .15214 Mdot
.30745 .37117 Mdot
.3075 .18207 Mdot
.30754 .16135 Mdot
.30759 .24203 Mdot
.30764 .21764 Mdot
.30769 .24659 Mdot
.30773 .37267 Mdot
.30778 .13947 Mdot
.30783 .33637 Mdot
.30788 .29989 Mdot
.30792 .33092 Mdot
.30797 .14024 Mdot
.30802 .16676 Mdot
.30807 .25246 Mdot
.30811 .11766 Mdot
.30816 .10777 Mdot
.30821 .17661 Mdot
.30826 .34592 Mdot
.3083 .31273 Mdot
.30835 .1225 Mdot
.3084 .37143 Mdot
.30845 .29792 Mdot
.3085 .29391 Mdot
.30854 .36019 Mdot
.30859 .09506 Mdot
.30864 .21046 Mdot
.30869 .22699 Mdot
.30873 .21241 Mdot
.30878 .26633 Mdot
.30883 .3526 Mdot
.30888 .24288 Mdot
.30892 .16645 Mdot
.30897 .31815 Mdot
.30902 .14586 Mdot
.30907 .29978 Mdot
.30911 .119 Mdot
.30916 .24399 Mdot
.30921 .28067 Mdot
.30926 .27435 Mdot
.3093 .10328 Mdot
.30935 .15925 Mdot
.3094 .3213 Mdot
.30945 .34799 Mdot
.3095 .36697 Mdot
.30954 .17382 Mdot
.30959 .11435 Mdot
.30964 .14486 Mdot
.30969 .09738 Mdot
.30973 .16919 Mdot
.30978 .28899 Mdot
.30983 .30278 Mdot
.30988 .26971 Mdot
.30992 .28741 Mdot
.30997 .32077 Mdot
.31002 .14925 Mdot
.31007 .19242 Mdot
.31011 .35311 Mdot
.31016 .26372 Mdot
.31021 .23296 Mdot
.31026 .16188 Mdot
.3103 .19739 Mdot
.31035 .36599 Mdot
.3104 .34137 Mdot
.31045 .14633 Mdot
.3105 .1257 Mdot
.31054 .13206 Mdot
.31059 .37544 Mdot
.31064 .16124 Mdot
.31069 .33358 Mdot
.31073 .10438 Mdot
.31078 .31707 Mdot
.31083 .15017 Mdot
.31088 .25052 Mdot
.31092 .1962 Mdot
.31097 .10006 Mdot
.31102 .26091 Mdot
.31107 .34339 Mdot
.31111 .25553 Mdot
.31116 .33074 Mdot
.31121 .15338 Mdot
.31126 .36986 Mdot
.3113 .37122 Mdot
.31135 .18216 Mdot
.3114 .37056 Mdot
.31145 .25649 Mdot
.3115 .08907 Mdot
.31154 .21931 Mdot
.31159 .30772 Mdot
.31164 .21411 Mdot
.31169 .33501 Mdot
.31173 .2217 Mdot
.31178 .22928 Mdot
.31183 .25801 Mdot
.31188 .31308 Mdot
.31192 .28176 Mdot
.31197 .16122 Mdot
.31202 .08941 Mdot
.31207 .19864 Mdot
.31211 .26328 Mdot
.31216 .27657 Mdot
.31221 .12211 Mdot
.31226 .31903 Mdot
.3123 .30828 Mdot
.31235 .2039 Mdot
.3124 .12765 Mdot
.31245 .32304 Mdot
.31249 .20632 Mdot
.31254 .20822 Mdot
.31259 .24587 Mdot
.31264 .31365 Mdot
.31269 .36138 Mdot
.31273 .2747 Mdot
.31278 .11093 Mdot
.31283 .35249 Mdot
.31288 .21851 Mdot
.31292 .12407 Mdot
.31297 .22626 Mdot
.31302 .11772 Mdot
.31307 .30976 Mdot
.31311 .33569 Mdot
.31316 .21465 Mdot
.31321 .29158 Mdot
.31326 .12395 Mdot
.3133 .13642 Mdot
.31335 .16968 Mdot
.3134 .34437 Mdot
.31345 .18732 Mdot
.31349 .304 Mdot
.31354 .11849 Mdot
.31359 .09762 Mdot
.31364 .35197 Mdot
.31369 .17173 Mdot
.31373 .24326 Mdot
.31378 .15444 Mdot
.31383 .36089 Mdot
.31388 .26717 Mdot
.31392 .20745 Mdot
.31397 .17176 Mdot
.31402 .21716 Mdot
.31407 .21771 Mdot
.31411 .35049 Mdot
.31416 .12831 Mdot
.31421 .27638 Mdot
.31426 .25083 Mdot
.3143 .20962 Mdot
.31435 .20521 Mdot
.3144 .22588 Mdot
.31445 .18769 Mdot
.31449 .11307 Mdot
.31454 .22866 Mdot
.31459 .11136 Mdot
.31464 .25117 Mdot
.31469 .36191 Mdot
.31473 .20334 Mdot
.31478 .12638 Mdot
.31483 .15141 Mdot
.31488 .19046 Mdot
.31492 .12054 Mdot
.31497 .13183 Mdot
.31502 .25042 Mdot
.31507 .34902 Mdot
.31511 .31463 Mdot
.31516 .28036 Mdot
.31521 .10337 Mdot
.31526 .06903 Mdot
.3153 .25666 Mdot
.31535 .07416 Mdot
.3154 .21742 Mdot
.31545 .22412 Mdot
.31549 .12114 Mdot
.31554 .21267 Mdot
.31559 .09911 Mdot
.31564 .18026 Mdot
.31569 .25639 Mdot
.31573 .1702 Mdot
.31578 .21152 Mdot
.31583 .18179 Mdot
.31588 .12147 Mdot
.31592 .11207 Mdot
.31597 .1282 Mdot
.31602 .35412 Mdot
.31607 .0687 Mdot
.31611 .34272 Mdot
.31616 .2401 Mdot
.31621 .0724 Mdot
.31626 .11607 Mdot
.3163 .12934 Mdot
.31635 .20354 Mdot
.3164 .07003 Mdot
.31645 .22078 Mdot
.31649 .12153 Mdot
.31654 .34717 Mdot
.31659 .2068 Mdot
.31664 .16551 Mdot
.31668 .26944 Mdot
.31673 .31362 Mdot
.31678 .09195 Mdot
.31683 .26923 Mdot
.31688 .16433 Mdot
.31692 .16704 Mdot
.31697 .2698 Mdot
.31702 .21239 Mdot
.31707 .11673 Mdot
.31711 .10316 Mdot
.31716 .2747 Mdot
.31721 .20769 Mdot
.31726 .13272 Mdot
.3173 .22162 Mdot
.31735 .26585 Mdot
.3174 .15501 Mdot
.31745 .06662 Mdot
.31749 .08116 Mdot
.31754 .25874 Mdot
.31759 .29187 Mdot
.31764 .30257 Mdot
.31768 .09132 Mdot
.31773 .11426 Mdot
.31778 .18852 Mdot
.31783 .09515 Mdot
.31788 .13441 Mdot
.31792 .08402 Mdot
.31797 .27571 Mdot
.31802 .28708 Mdot
.31807 .32348 Mdot
.31811 .17018 Mdot
.31816 .12427 Mdot
.31821 .23116 Mdot
.31826 .28098 Mdot
.3183 .25083 Mdot
.31835 .27179 Mdot
.3184 .15864 Mdot
.31845 .11942 Mdot
.31849 .33975 Mdot
.31854 .17653 Mdot
.31859 .15162 Mdot
.31864 .09771 Mdot
.31868 .14031 Mdot
.31873 .23868 Mdot
.31878 .20292 Mdot
.31883 .06526 Mdot
.31888 .08476 Mdot
.31892 .10873 Mdot
.31897 .16619 Mdot
.31902 .28397 Mdot
.31907 .05887 Mdot
.31911 .18586 Mdot
.31916 .23179 Mdot
.31921 .31303 Mdot
.31926 .24108 Mdot
.3193 .11897 Mdot
.31935 .05788 Mdot
.3194 .08915 Mdot
.31945 .34206 Mdot
.31949 .19885 Mdot
.31954 .25076 Mdot
.31959 .32111 Mdot
.31964 .05868 Mdot
.31968 .07854 Mdot
.31973 .15523 Mdot
.31978 .27933 Mdot
.31983 .26903 Mdot
.31988 .19036 Mdot
.31992 .30268 Mdot
.31997 .26944 Mdot
.32002 .23949 Mdot
.32007 .13672 Mdot
.32011 .19142 Mdot
.32016 .33512 Mdot
.32021 .23527 Mdot
.32026 .30023 Mdot
.3203 .30886 Mdot
.32035 .07632 Mdot
.3204 .34313 Mdot
.32045 .2352 Mdot
.32049 .30478 Mdot
.32054 .33569 Mdot
.32059 .0546 Mdot
.32064 .08973 Mdot
.32068 .10726 Mdot
.32073 .06769 Mdot
.32078 .34373 Mdot
.32083 .06402 Mdot
.32088 .29957 Mdot
.32092 .13575 Mdot
.32097 .12711 Mdot
.32102 .22077 Mdot
.32107 .34388 Mdot
.32111 .21316 Mdot
.32116 .23433 Mdot
.32121 .13577 Mdot
.32126 .20403 Mdot
.3213 .22434 Mdot
.32135 .05035 Mdot
.3214 .18157 Mdot
.32145 .24106 Mdot
.32149 .19891 Mdot
.32154 .05283 Mdot
.32159 .29184 Mdot
.32164 .28162 Mdot
.32168 .20842 Mdot
.32173 .04845 Mdot
.32178 .25219 Mdot
.32183 .2243 Mdot
.32187 .19054 Mdot
.32192 .04925 Mdot
.32197 .23771 Mdot
.32202 .26899 Mdot
.32207 .10406 Mdot
.32211 .26613 Mdot
.32216 .06594 Mdot
.32221 .26884 Mdot
.32226 .23449 Mdot
.3223 .08041 Mdot
.32235 .27349 Mdot
.3224 .11315 Mdot
.32245 .05836 Mdot
.32249 .07813 Mdot
.32254 .13987 Mdot
.32259 .21476 Mdot
.32264 .20199 Mdot
.32268 .07284 Mdot
.32273 .1903 Mdot
.32278 .27528 Mdot
.32283 .33558 Mdot
.32287 .07142 Mdot
.32292 .27986 Mdot
.32297 .09775 Mdot
.32302 .19167 Mdot
.32307 .06868 Mdot
.32311 .08853 Mdot
.32316 .16987 Mdot
.32321 .13373 Mdot
.32326 .1434 Mdot
.3233 .06846 Mdot
.32335 .24162 Mdot
.3234 .23971 Mdot
.32345 .10847 Mdot
.32349 .13518 Mdot
.32354 .1737 Mdot
.32359 .22645 Mdot
.32364 .07531 Mdot
.32368 .33502 Mdot
.32373 .29852 Mdot
.32378 .06906 Mdot
.32383 .04694 Mdot
.32387 .18906 Mdot
.32392 .06745 Mdot
.32397 .07243 Mdot
.32402 .31434 Mdot
.32407 .2479 Mdot
.32411 .30828 Mdot
.32416 .21922 Mdot
.32421 .28913 Mdot
.32426 .20271 Mdot
.3243 .18164 Mdot
.32435 .12859 Mdot
.3244 .18871 Mdot
.32445 .17711 Mdot
.32449 .27761 Mdot
.32454 .22635 Mdot
.32459 .12273 Mdot
.32464 .0843 Mdot
.32468 .14615 Mdot
.32473 .04202 Mdot
.32478 .08942 Mdot
.32483 .08602 Mdot
.32487 .18425 Mdot
.32492 .30946 Mdot
.32497 .084 Mdot
.32502 .23322 Mdot
.32507 .15808 Mdot
.32511 .27819 Mdot
.32516 .10556 Mdot
.32521 .3211 Mdot
.32526 .18546 Mdot
.3253 .09967 Mdot
.32535 .15185 Mdot
.3254 .15884 Mdot
.32545 .04415 Mdot
.32549 .30615 Mdot
.32554 .2981 Mdot
.32559 .31656 Mdot
.32564 .10127 Mdot
.32568 .11955 Mdot
.32573 .215 Mdot
.32578 .27178 Mdot
.32583 .28937 Mdot
.32587 .11681 Mdot
.32592 .16475 Mdot
.32597 .22482 Mdot
.32602 .14406 Mdot
.32607 .14103 Mdot
.32611 .11946 Mdot
.32616 .32505 Mdot
.32621 .31932 Mdot
.32626 .19606 Mdot
.3263 .05216 Mdot
.32635 .04209 Mdot
.3264 .17189 Mdot
.32645 .13431 Mdot
.32649 .23297 Mdot
.32654 .2158 Mdot
.32659 .16531 Mdot
.32664 .16047 Mdot
.32668 .26708 Mdot
.32673 .23133 Mdot
.32678 .10117 Mdot
.32683 .07794 Mdot
.32687 .08898 Mdot
.32692 .29121 Mdot
.32697 .14335 Mdot
.32702 .29256 Mdot
.32706 .25555 Mdot
.32711 .10275 Mdot
.32716 .03554 Mdot
.32721 .18767 Mdot
.32726 .17212 Mdot
.3273 .10848 Mdot
.32735 .0469 Mdot
.3274 .32218 Mdot
.32745 .15556 Mdot
.32749 .10188 Mdot
.32754 .20526 Mdot
.32759 .22315 Mdot
.32764 .25262 Mdot
.32768 .216 Mdot
.32773 .07491 Mdot
.32778 .09753 Mdot
.32783 .31515 Mdot
.32787 .31416 Mdot
.32792 .30312 Mdot
.32797 .05402 Mdot
.32802 .26049 Mdot
.32806 .05718 Mdot
.32811 .19389 Mdot
.32816 .09033 Mdot
.32821 .03885 Mdot
.32826 .28309 Mdot
.3283 .19205 Mdot
.32835 .23112 Mdot
.3284 .19508 Mdot
.32845 .20801 Mdot
.32849 .17844 Mdot
.32854 .23699 Mdot
.32859 .07261 Mdot
.32864 .13911 Mdot
.32868 .30093 Mdot
.32873 .04662 Mdot
.32878 .14753 Mdot
.32883 .25055 Mdot
.32887 .25851 Mdot
.32892 .27633 Mdot
.32897 .15952 Mdot
.32902 .26343 Mdot
.32906 .28232 Mdot
.32911 .25429 Mdot
.32916 .22577 Mdot
.32921 .23804 Mdot
.32926 .12012 Mdot
.3293 .19555 Mdot
.32935 .21842 Mdot
.3294 .2812 Mdot
.32945 .25423 Mdot
.32949 .29049 Mdot
.32954 .05444 Mdot
.32959 .1042 Mdot
.32964 .1067 Mdot
.32968 .08432 Mdot
.32973 .3074 Mdot
.32978 .29057 Mdot
.32983 .13116 Mdot
.32987 .06814 Mdot
.32992 .19021 Mdot
.32997 .07026 Mdot
.33002 .19766 Mdot
.33006 .11673 Mdot
.33011 .06065 Mdot
.33016 .13156 Mdot
.33021 .23997 Mdot
.33026 .18698 Mdot
.3303 .15932 Mdot
.33035 .21788 Mdot
.3304 .14925 Mdot
.33045 .3156 Mdot
.33049 .26499 Mdot
.33054 .26068 Mdot
.33059 .21892 Mdot
.33064 .05406 Mdot
.33068 .23941 Mdot
.33073 .18525 Mdot
.33078 .1409 Mdot
.33083 .29319 Mdot
.33087 .25537 Mdot
.33092 .21795 Mdot
.33097 .03807 Mdot
.33102 .25328 Mdot
.33106 .09331 Mdot
.33111 .17574 Mdot
.33116 .16323 Mdot
.33121 .16444 Mdot
.33125 .06045 Mdot
.3313 .07188 Mdot
.33135 .24574 Mdot
.3314 .29985 Mdot
.33145 .22343 Mdot
.33149 .17621 Mdot
.33154 .12376 Mdot
.33159 .30629 Mdot
.33164 .2804 Mdot
.33168 .23741 Mdot
.33173 .22663 Mdot
.33178 .27907 Mdot
.33183 .06775 Mdot
.33187 .07884 Mdot
.33192 .11232 Mdot
.33197 .30725 Mdot
.33202 .13366 Mdot
.33206 .18209 Mdot
.33211 .10052 Mdot
.33216 .08015 Mdot
.33221 .06645 Mdot
.33225 .03237 Mdot
.3323 .25808 Mdot
.33235 .23642 Mdot
.3324 .03177 Mdot
.33245 .28103 Mdot
.33249 .03794 Mdot
.33254 .25696 Mdot
.33259 .12865 Mdot
.33264 .13019 Mdot
.33268 .23433 Mdot
.33273 .27074 Mdot
.33278 .16824 Mdot
.33283 .21269 Mdot
.33287 .03267 Mdot
.33292 .31142 Mdot
.33297 .12531 Mdot
.33302 .15859 Mdot
.33306 .23986 Mdot
.33311 .02875 Mdot
.33316 .31101 Mdot
.33321 .29578 Mdot
.33325 .1637 Mdot
.3333 .26774 Mdot
.33335 .26876 Mdot
.3334 .28754 Mdot
.33345 .22453 Mdot
.33349 .0553 Mdot
.33354 .26089 Mdot
.33359 .03033 Mdot
.33364 .21034 Mdot
.33368 .11688 Mdot
.33373 .15585 Mdot
.33378 .21853 Mdot
.33383 .29433 Mdot
.33387 .16438 Mdot
.33392 .30578 Mdot
.33397 .02908 Mdot
.33402 .28483 Mdot
.33406 .17092 Mdot
.33411 .20349 Mdot
.33416 .1883 Mdot
.33421 .06785 Mdot
.33425 .16498 Mdot
.3343 .21007 Mdot
.33435 .21004 Mdot
.3344 .22161 Mdot
.33445 .21463 Mdot
.33449 .25863 Mdot
.33454 .23975 Mdot
.33459 .31426 Mdot
.33464 .18158 Mdot
.33468 .31478 Mdot
.33473 .23154 Mdot
.33478 .12597 Mdot
.33483 .08669 Mdot
.33487 .18084 Mdot
.33492 .03486 Mdot
.33497 .14828 Mdot
.33502 .23888 Mdot
.33506 .19157 Mdot
.33511 .02736 Mdot
.33516 .17983 Mdot
.33521 .08941 Mdot
.33525 .30432 Mdot
.3353 .15524 Mdot
.33535 .13324 Mdot
.3354 .24048 Mdot
.33545 .11538 Mdot
.33549 .26112 Mdot
.33554 .22748 Mdot
.33559 .04679 Mdot
.33564 .17249 Mdot
.33568 .04218 Mdot
.33573 .22883 Mdot
.33578 .18076 Mdot
.33583 .1732 Mdot
.33587 .12607 Mdot
.33592 .12336 Mdot
.33597 .11451 Mdot
.33602 .30759 Mdot
.33606 .11153 Mdot
.33611 .2902 Mdot
.33616 .19069 Mdot
.33621 .13617 Mdot
.33625 .10426 Mdot
.3363 .1304 Mdot
.33635 .12125 Mdot
.3364 .1466 Mdot
.33644 .26372 Mdot
.33649 .31181 Mdot
.33654 .19535 Mdot
.33659 .0509 Mdot
.33664 .02222 Mdot
.33668 .10389 Mdot
.33673 .16807 Mdot
.33678 .19272 Mdot
.33683 .29429 Mdot
.33687 .18925 Mdot
.33692 .30145 Mdot
.33697 .03875 Mdot
.33702 .18739 Mdot
.33706 .085 Mdot
.33711 .206 Mdot
.33716 .04502 Mdot
.33721 .09481 Mdot
.33725 .10856 Mdot
.3373 .03415 Mdot
.33735 .2225 Mdot
.3374 .30415 Mdot
.33744 .29171 Mdot
.33749 .2264 Mdot
.33754 .09448 Mdot
.33759 .05896 Mdot
.33764 .29324 Mdot
.33768 .04947 Mdot
.33773 .06196 Mdot
.33778 .05507 Mdot
.33783 .20763 Mdot
.33787 .19449 Mdot
.33792 .18229 Mdot
.33797 .07377 Mdot
.33802 .03646 Mdot
.33806 .20594 Mdot
.33811 .16152 Mdot
.33816 .19918 Mdot
.33821 .2642 Mdot
.33825 .01778 Mdot
.3383 .1343 Mdot
.33835 .12211 Mdot
.3384 .17334 Mdot
.33844 .29614 Mdot
.33849 .22426 Mdot
.33854 .13038 Mdot
.33859 .194 Mdot
.33864 .08721 Mdot
.33868 .1472 Mdot
.33873 .0888 Mdot
.33878 .21295 Mdot
.33883 .05503 Mdot
.33887 .10248 Mdot
.33892 .05093 Mdot
.33897 .02248 Mdot
.33902 .17251 Mdot
.33906 .23213 Mdot
.33911 .28904 Mdot
.33916 .29787 Mdot
.33921 .27837 Mdot
.33925 .08751 Mdot
.3393 .10672 Mdot
.33935 .05049 Mdot
.3394 .27737 Mdot
.33944 .2648 Mdot
.33949 .29616 Mdot
.33954 .18866 Mdot
.33959 .2927 Mdot
.33964 .05712 Mdot
.33968 .18232 Mdot
.33973 .30602 Mdot
.33978 .22195 Mdot
.33983 .2212 Mdot
.33987 .10991 Mdot
.33992 .10941 Mdot
.33997 .18323 Mdot
.34002 .13499 Mdot
.34006 .07522 Mdot
.34011 .10313 Mdot
.34016 .02688 Mdot
.34021 .21384 Mdot
.34025 .09713 Mdot
.3403 .11617 Mdot
.34035 .05939 Mdot
.3404 .14232 Mdot
.34044 .30121 Mdot
.34049 .0816 Mdot
.34054 .09276 Mdot
.34059 .18822 Mdot
.34063 .02086 Mdot
.34068 .20358 Mdot
.34073 .11066 Mdot
.34078 .14681 Mdot
.34083 .14908 Mdot
.34087 .20807 Mdot
.34092 .19918 Mdot
.34097 .23606 Mdot
.34102 .05472 Mdot
.34106 .11418 Mdot
.34111 .03144 Mdot
.34116 .11654 Mdot
.34121 .28979 Mdot
.34125 .02646 Mdot
.3413 .01993 Mdot
.34135 .2129 Mdot
.3414 .20798 Mdot
.34144 .22043 Mdot
.34149 .27066 Mdot
.34154 .08581 Mdot
.34159 .21682 Mdot
.34163 .154 Mdot
.34168 .19305 Mdot
.34173 .20756 Mdot
.34178 .21105 Mdot
.34183 .26034 Mdot
.34187 .09743 Mdot
.34192 .07576 Mdot
.34197 .07696 Mdot
.34202 .06723 Mdot
.34206 .20805 Mdot
.34211 .14948 Mdot
.34216 .03712 Mdot
.34221 .26277 Mdot
.34225 .19144 Mdot
.3423 .04776 Mdot
.34235 .05698 Mdot
.3424 .25108 Mdot
.34244 .18626 Mdot
.34249 .14444 Mdot
.34254 .15856 Mdot
.34259 .04533 Mdot
.34263 .22511 Mdot
.34268 .07327 Mdot
.34273 .25121 Mdot
.34278 .20079 Mdot
.34283 .04664 Mdot
.34287 .17512 Mdot
.34292 .0547 Mdot
.34297 .24982 Mdot
.34302 .25856 Mdot
.34306 .11383 Mdot
.34311 .28705 Mdot
.34316 .19702 Mdot
.34321 .06494 Mdot
.34325 .27362 Mdot
.3433 .26432 Mdot
.34335 .24348 Mdot
.3434 .1827 Mdot
.34344 .2402 Mdot
.34349 .22165 Mdot
.34354 .30155 Mdot
.34359 .30559 Mdot
.34363 .11002 Mdot
.34368 .07735 Mdot
.34373 .27046 Mdot
.34378 .0947 Mdot
.34383 .05096 Mdot
.34387 .13519 Mdot
.34392 .08386 Mdot
.34397 .06222 Mdot
.34402 .18485 Mdot
.34406 .09464 Mdot
.34411 .14303 Mdot
.34416 .11264 Mdot
.34421 .08513 Mdot
.34425 .11653 Mdot
.3443 .25494 Mdot
.34435 .06177 Mdot
.3444 .12042 Mdot
.34444 .16112 Mdot
.34449 .02551 Mdot
.34454 .18795 Mdot
.34459 .1891 Mdot
.34463 .24833 Mdot
.34468 .03281 Mdot
.34473 .19121 Mdot
.34478 .09306 Mdot
.34483 .18496 Mdot
.34487 .07116 Mdot
.34492 .11046 Mdot
.34497 .05605 Mdot
.34502 .06371 Mdot
.34506 .29609 Mdot
.34511 .06217 Mdot
.34516 .17997 Mdot
.34521 .27784 Mdot
.34525 .16697 Mdot
.3453 .25829 Mdot
.34535 .10874 Mdot
.3454 .1752 Mdot
.34544 .22077 Mdot
.34549 .21041 Mdot
.34554 .29705 Mdot
.34559 .02796 Mdot
.34563 .20914 Mdot
.34568 .03633 Mdot
.34573 .12182 Mdot
.34578 .08835 Mdot
.34582 .1902 Mdot
.34587 .15384 Mdot
.34592 .04262 Mdot
.34597 .2121 Mdot
.34602 .13289 Mdot
.34606 .05722 Mdot
.34611 .29528 Mdot
.34616 .16225 Mdot
.34621 .1455 Mdot
.34625 .30376 Mdot
.3463 .12916 Mdot
.34635 .19311 Mdot
.3464 .28723 Mdot
.34644 .05933 Mdot
.34649 .03428 Mdot
.34654 .03177 Mdot
.34659 .08032 Mdot
.34663 .15764 Mdot
.34668 .04595 Mdot
.34673 .01768 Mdot
.34678 .17991 Mdot
.34682 .13519 Mdot
.34687 .23286 Mdot
.34692 .23807 Mdot
.34697 .29846 Mdot
.34702 .2901 Mdot
.34706 .20415 Mdot
.34711 .03988 Mdot
.34716 .17948 Mdot
.34721 .24679 Mdot
.34725 .21764 Mdot
.3473 .18641 Mdot
.34735 .04792 Mdot
.3474 .25182 Mdot
.34744 .10243 Mdot
.34749 .30211 Mdot
.34754 .0695 Mdot
.34759 .20647 Mdot
.34763 .08213 Mdot
.34768 .28434 Mdot
.34773 .29804 Mdot
.34778 .06283 Mdot
.34782 .0502 Mdot
.34787 .28068 Mdot
.34792 .13217 Mdot
.34797 .23655 Mdot
.34802 .12626 Mdot
.34806 .05668 Mdot
.34811 .14265 Mdot
.34816 .2554 Mdot
.34821 .23107 Mdot
.34825 .03092 Mdot
.3483 .27215 Mdot
.34835 .02275 Mdot
.3484 .02758 Mdot
.34844 .15353 Mdot
.34849 .23842 Mdot
.34854 .07998 Mdot
.34859 .23422 Mdot
.34863 .1605 Mdot
.34868 .18315 Mdot
.34873 .18262 Mdot
.34878 .16636 Mdot
.34882 .1853 Mdot
.34887 .19427 Mdot
.34892 .13411 Mdot
.34897 .13049 Mdot
.34902 .21383 Mdot
.34906 .07647 Mdot
.34911 .2068 Mdot
.34916 .01864 Mdot
.34921 .17157 Mdot
.34925 .24312 Mdot
.3493 .26071 Mdot
.34935 .0969 Mdot
.3494 .15514 Mdot
.34944 .28034 Mdot
.34949 .2525 Mdot
.34954 .08387 Mdot
.34959 .01619 Mdot
.34963 .05652 Mdot
.34968 .18714 Mdot
.34973 .15914 Mdot
.34978 .1652 Mdot
.34982 .18291 Mdot
.34987 .01922 Mdot
.34992 .30237 Mdot
.34997 .2895 Mdot
.35001 .29826 Mdot
.35006 .19476 Mdot
.35011 .18669 Mdot
.35016 .09051 Mdot
.35021 .23665 Mdot
.35025 .2977 Mdot
.3503 .18297 Mdot
.35035 .22874 Mdot
.3504 .30335 Mdot
.35044 .05198 Mdot
.35049 .10108 Mdot
.35054 .08863 Mdot
.35059 .03808 Mdot
.35063 .10943 Mdot
.35068 .03233 Mdot
.35073 .08759 Mdot
.35078 .29159 Mdot
.35082 .23235 Mdot
.35087 .18327 Mdot
.35092 .2325 Mdot
.35097 .12397 Mdot
.35101 .22845 Mdot
.35106 .19111 Mdot
.35111 .25323 Mdot
.35116 .13596 Mdot
.35121 .04912 Mdot
.35125 .01987 Mdot
.3513 .17821 Mdot
.35135 .20969 Mdot
.3514 .06183 Mdot
.35144 .14735 Mdot
.35149 .25995 Mdot
.35154 .21684 Mdot
.35159 .02553 Mdot
.35163 .06198 Mdot
.35168 .18706 Mdot
.35173 .19455 Mdot
.35178 .22678 Mdot
.35182 .0455 Mdot
.35187 .11535 Mdot
.35192 .21373 Mdot
.35197 .30523 Mdot
.35201 .17307 Mdot
.35206 .19372 Mdot
.35211 .10582 Mdot
.35216 .09288 Mdot
.35221 .29295 Mdot
.35225 .25151 Mdot
.3523 .28091 Mdot
.35235 .05999 Mdot
.3524 .28934 Mdot
.35244 .0896 Mdot
.35249 .08757 Mdot
.35254 .3094 Mdot
.35259 .15842 Mdot
.35263 .14097 Mdot
.35268 .18208 Mdot
.35273 .30041 Mdot
.35278 .11302 Mdot
.35282 .26539 Mdot
.35287 .29905 Mdot
.35292 .09033 Mdot
.35297 .08426 Mdot
.35301 .16682 Mdot
.35306 .10214 Mdot
.35311 .09681 Mdot
.35316 .22295 Mdot
.35321 .2849 Mdot
.35325 .30816 Mdot
.3533 .02097 Mdot
.35335 .24193 Mdot
.3534 .05051 Mdot
.35344 .04441 Mdot
.35349 .27304 Mdot
.35354 .26469 Mdot
.35359 .27305 Mdot
.35363 .26903 Mdot
.35368 .27587 Mdot
.35373 .12369 Mdot
.35378 .14954 Mdot
.35382 .10446 Mdot
.35387 .28788 Mdot
.35392 .02828 Mdot
.35397 .19666 Mdot
.35401 .11796 Mdot
.35406 .2153 Mdot
.35411 .25667 Mdot
.35416 .04769 Mdot
.35421 .03371 Mdot
.35425 .13642 Mdot
.3543 .05171 Mdot
.35435 .07568 Mdot
.3544 .03849 Mdot
.35444 .13358 Mdot
.35449 .12281 Mdot
.35454 .0434 Mdot
.35459 .30722 Mdot
.35463 .17373 Mdot
.35468 .17136 Mdot
.35473 .08365 Mdot
.35478 .05667 Mdot
.35482 .21125 Mdot
.35487 .06625 Mdot
.35492 .2476 Mdot
.35497 .26576 Mdot
.35501 .23696 Mdot
.35506 .05677 Mdot
.35511 .06978 Mdot
.35516 .1667 Mdot
.3552 .04062 Mdot
.35525 .11396 Mdot
.3553 .04115 Mdot
.35535 .1521 Mdot
.3554 .21823 Mdot
.35544 .08148 Mdot
.35549 .27961 Mdot
.35554 .13295 Mdot
.35559 .10404 Mdot
.35563 .27297 Mdot
.35568 .25571 Mdot
.35573 .14015 Mdot
.35578 .24478 Mdot
.35582 .12128 Mdot
.35587 .1918 Mdot
.35592 .10327 Mdot
.35597 .05339 Mdot
.35601 .07493 Mdot
.35606 .25903 Mdot
.35611 .1524 Mdot
.35616 .13136 Mdot
.3562 .03831 Mdot
.35625 .20945 Mdot
.3563 .30082 Mdot
.35635 .11107 Mdot
.3564 .23959 Mdot
.35644 .18874 Mdot
.35649 .16922 Mdot
.35654 .20826 Mdot
.35659 .17874 Mdot
.35663 .22467 Mdot
.35668 .05702 Mdot
.35673 .12504 Mdot
.35678 .22151 Mdot
.35682 .28475 Mdot
.35687 .23273 Mdot
.35692 .19617 Mdot
.35697 .12136 Mdot
.35701 .11414 Mdot
.35706 .15071 Mdot
.35711 .16411 Mdot
.35716 .06781 Mdot
.3572 .17143 Mdot
.35725 .31469 Mdot
.3573 .05433 Mdot
.35735 .05116 Mdot
.3574 .27855 Mdot
.35744 .03565 Mdot
.35749 .25997 Mdot
.35754 .12834 Mdot
.35759 .1118 Mdot
.35763 .18334 Mdot
.35768 .07383 Mdot
.35773 .26664 Mdot
.35778 .20424 Mdot
.35782 .14864 Mdot
.35787 .26604 Mdot
.35792 .0676 Mdot
.35797 .23687 Mdot
.35801 .23337 Mdot
.35806 .09254 Mdot
.35811 .26384 Mdot
.35816 .14554 Mdot
.3582 .10553 Mdot
.35825 .24624 Mdot
.3583 .21905 Mdot
.35835 .29207 Mdot
.3584 .10887 Mdot
.35844 .21515 Mdot
.35849 .19121 Mdot
.35854 .0369 Mdot
.35859 .09668 Mdot
.35863 .27356 Mdot
.35868 .08648 Mdot
.35873 .24364 Mdot
.35878 .23195 Mdot
.35882 .22356 Mdot
.35887 .13859 Mdot
.35892 .06338 Mdot
.35897 .10736 Mdot
.35901 .2765 Mdot
.35906 .09519 Mdot
.35911 .14564 Mdot
.35916 .19321 Mdot
.3592 .20839 Mdot
.35925 .15072 Mdot
.3593 .31954 Mdot
.35935 .11234 Mdot
.3594 .28174 Mdot
.35944 .25134 Mdot
.35949 .05237 Mdot
.35954 .02844 Mdot
.35959 .09165 Mdot
.35963 .08526 Mdot
.35968 .04068 Mdot
.35973 .25191 Mdot
.35978 .13831 Mdot
.35982 .31909 Mdot
.35987 .11742 Mdot
.35992 .04557 Mdot
.35997 .2353 Mdot
.36001 .20627 Mdot
.36006 .07989 Mdot
.36011 .259 Mdot
.36016 .27967 Mdot
.3602 .13717 Mdot
.36025 .25529 Mdot
.3603 .09205 Mdot
.36035 .09763 Mdot
.36039 .30774 Mdot
.36044 .25711 Mdot
.36049 .30117 Mdot
.36054 .13742 Mdot
.36059 .08317 Mdot
.36063 .23159 Mdot
.36068 .29966 Mdot
.36073 .07279 Mdot
.36078 .31987 Mdot
.36082 .21811 Mdot
.36087 .07502 Mdot
.36092 .25669 Mdot
.36097 .32308 Mdot
.36101 .12822 Mdot
.36106 .05707 Mdot
.36111 .0491 Mdot
.36116 .14461 Mdot
.3612 .07621 Mdot
.36125 .12089 Mdot
.3613 .09234 Mdot
.36135 .03558 Mdot
.36139 .14401 Mdot
.36144 .05716 Mdot
.36149 .31798 Mdot
.36154 .0512 Mdot
.36159 .21034 Mdot
.36163 .07953 Mdot
.36168 .20933 Mdot
.36173 .29175 Mdot
.36178 .30255 Mdot
.36182 .10377 Mdot
.36187 .16567 Mdot
.36192 .29596 Mdot
.36197 .11376 Mdot
.36201 .05815 Mdot
.36206 .23334 Mdot
.36211 .29733 Mdot
.36216 .31008 Mdot
.3622 .32571 Mdot
.36225 .2141 Mdot
.3623 .18269 Mdot
.36235 .26394 Mdot
.36239 .23497 Mdot
.36244 .15201 Mdot
.36249 .17745 Mdot
.36254 .15036 Mdot
.36259 .20834 Mdot
.36263 .15951 Mdot
.36268 .15697 Mdot
.36273 .2657 Mdot
.36278 .15972 Mdot
.36282 .27604 Mdot
.36287 .19118 Mdot
.36292 .28921 Mdot
.36297 .08726 Mdot
.36301 .14176 Mdot
.36306 .22157 Mdot
.36311 .20704 Mdot
.36316 .0608 Mdot
.3632 .23507 Mdot
.36325 .25099 Mdot
.3633 .2238 Mdot
.36335 .06202 Mdot
.36339 .05315 Mdot
.36344 .10058 Mdot
.36349 .2871 Mdot
.36354 .15439 Mdot
.36359 .22859 Mdot
.36363 .25068 Mdot
.36368 .16952 Mdot
.36373 .27379 Mdot
.36378 .10207 Mdot
.36382 .1268 Mdot
.36387 .23186 Mdot
.36392 .14737 Mdot
.36397 .15428 Mdot
.36401 .26397 Mdot
.36406 .27111 Mdot
.36411 .09381 Mdot
.36416 .04632 Mdot
.3642 .0763 Mdot
.36425 .09809 Mdot
.3643 .06713 Mdot
.36435 .14033 Mdot
.36439 .1545 Mdot
.36444 .20358 Mdot
.36449 .03965 Mdot
.36454 .12182 Mdot
.36458 .08866 Mdot
.36463 .24619 Mdot
.36468 .21507 Mdot
.36473 .22316 Mdot
.36478 .16801 Mdot
.36482 .11195 Mdot
.36487 .27152 Mdot
.36492 .15658 Mdot
.36497 .07682 Mdot
.36501 .21065 Mdot
.36506 .15997 Mdot
.36511 .03823 Mdot
.36516 .14374 Mdot
.3652 .27053 Mdot
.36525 .10241 Mdot
.3653 .32312 Mdot
.36535 .1039 Mdot
.36539 .20902 Mdot
.36544 .07196 Mdot
.36549 .21959 Mdot
.36554 .28117 Mdot
.36558 .04246 Mdot
.36563 .06944 Mdot
.36568 .13501 Mdot
.36573 .22986 Mdot
.36578 .12859 Mdot
.36582 .1868 Mdot
.36587 .2444 Mdot
.36592 .09964 Mdot
.36597 .05455 Mdot
.36601 .24817 Mdot
.36606 .12596 Mdot
.36611 .06108 Mdot
.36616 .17712 Mdot
.3662 .12668 Mdot
.36625 .12632 Mdot
.3663 .25091 Mdot
.36635 .24026 Mdot
.36639 .06321 Mdot
.36644 .13711 Mdot
.36649 .18617 Mdot
.36654 .07052 Mdot
.36658 .3255 Mdot
.36663 .2519 Mdot
.36668 .23949 Mdot
.36673 .06781 Mdot
.36678 .29593 Mdot
.36682 .15687 Mdot
.36687 .04973 Mdot
.36692 .27429 Mdot
.36697 .14946 Mdot
.36701 .24778 Mdot
.36706 .28551 Mdot
.36711 .26043 Mdot
.36716 .23695 Mdot
.3672 .16275 Mdot
.36725 .26548 Mdot
.3673 .12447 Mdot
.36735 .15155 Mdot
.36739 .07782 Mdot
.36744 .05609 Mdot
.36749 .22071 Mdot
.36754 .13011 Mdot
.36758 .27745 Mdot
.36763 .20678 Mdot
.36768 .19231 Mdot
.36773 .14171 Mdot
.36778 .06792 Mdot
.36782 .30463 Mdot
.36787 .16712 Mdot
.36792 .18337 Mdot
.36797 .24877 Mdot
.36801 .29788 Mdot
.36806 .23078 Mdot
.36811 .07714 Mdot
.36816 .33919 Mdot
.3682 .05584 Mdot
.36825 .30881 Mdot
.3683 .17876 Mdot
.36835 .22029 Mdot
.36839 .12918 Mdot
.36844 .22843 Mdot
.36849 .07143 Mdot
.36854 .18681 Mdot
.36858 .11756 Mdot
.36863 .05231 Mdot
.36868 .28089 Mdot
.36873 .24906 Mdot
.36878 .25061 Mdot
.36882 .19995 Mdot
.36887 .18442 Mdot
.36892 .22649 Mdot
.36897 .28631 Mdot
.36901 .07844 Mdot
.36906 .34164 Mdot
.36911 .31845 Mdot
.36916 .32928 Mdot
.3692 .18863 Mdot
.36925 .31075 Mdot
.3693 .32049 Mdot
.36935 .31995 Mdot
.36939 .22132 Mdot
.36944 .17875 Mdot
.36949 .14709 Mdot
.36954 .23779 Mdot
.36958 .33491 Mdot
.36963 .15461 Mdot
.36968 .30255 Mdot
.36973 .16778 Mdot
.36977 .33028 Mdot
.36982 .21638 Mdot
.36987 .10143 Mdot
.36992 .2601 Mdot
.36997 .17853 Mdot
.37001 .08031 Mdot
.37006 .21826 Mdot
.37011 .31725 Mdot
.37016 .14883 Mdot
.3702 .08239 Mdot
.37025 .24367 Mdot
.3703 .33196 Mdot
.37035 .30432 Mdot
.37039 .1159 Mdot
.37044 .26758 Mdot
.37049 .06168 Mdot
.37054 .1328 Mdot
.37058 .28195 Mdot
.37063 .17056 Mdot
.37068 .16895 Mdot
.37073 .1431 Mdot
.37077 .17782 Mdot
.37082 .21349 Mdot
.37087 .34678 Mdot
.37092 .15857 Mdot
.37097 .30731 Mdot
.37101 .16322 Mdot
.37106 .13799 Mdot
.37111 .32633 Mdot
.37116 .27858 Mdot
.3712 .29152 Mdot
.37125 .16745 Mdot
.3713 .22949 Mdot
.37135 .24832 Mdot
.37139 .10012 Mdot
.37144 .18275 Mdot
.37149 .27257 Mdot
.37154 .1851 Mdot
.37158 .18022 Mdot
.37163 .17403 Mdot
.37168 .19287 Mdot
.37173 .25125 Mdot
.37177 .06303 Mdot
.37182 .0586 Mdot
.37187 .10344 Mdot
.37192 .12723 Mdot
.37197 .19835 Mdot
.37201 .06076 Mdot
.37206 .29396 Mdot
.37211 .16914 Mdot
.37216 .08964 Mdot
.3722 .27228 Mdot
.37225 .31728 Mdot
.3723 .24035 Mdot
.37235 .14805 Mdot
.37239 .16006 Mdot
.37244 .14315 Mdot
.37249 .3424 Mdot
.37254 .10358 Mdot
.37258 .32796 Mdot
.37263 .22138 Mdot
.37268 .21339 Mdot
.37273 .27445 Mdot
.37277 .2103 Mdot
.37282 .08502 Mdot
.37287 .31366 Mdot
.37292 .26823 Mdot
.37297 .20865 Mdot
.37301 .33354 Mdot
.37306 .24367 Mdot
.37311 .12727 Mdot
.37316 .20542 Mdot
.3732 .09726 Mdot
.37325 .13235 Mdot
.3733 .09561 Mdot
.37335 .28612 Mdot
.37339 .13311 Mdot
.37344 .24527 Mdot
.37349 .30098 Mdot
.37354 .18477 Mdot
.37358 .34367 Mdot
.37363 .25674 Mdot
.37368 .25655 Mdot
.37373 .21097 Mdot
.37377 .18175 Mdot
.37382 .10295 Mdot
.37387 .33671 Mdot
.37392 .35543 Mdot
.37396 .15678 Mdot
.37401 .14435 Mdot
.37406 .12883 Mdot
.37411 .20728 Mdot
.37416 .17875 Mdot
.3742 .25634 Mdot
.37425 .35737 Mdot
.3743 .35782 Mdot
.37435 .14274 Mdot
.37439 .18539 Mdot
.37444 .32332 Mdot
.37449 .13341 Mdot
.37454 .0715 Mdot
.37458 .29699 Mdot
.37463 .0845 Mdot
.37468 .30581 Mdot
.37473 .08516 Mdot
.37477 .10287 Mdot
.37482 .18558 Mdot
.37487 .15778 Mdot
.37492 .26135 Mdot
.37496 .35802 Mdot
.37501 .20711 Mdot
.37506 .16075 Mdot
.37511 .16827 Mdot
.37516 .27752 Mdot
.3752 .14229 Mdot
.37525 .31249 Mdot
.3753 .34869 Mdot
.37535 .08566 Mdot
.37539 .1444 Mdot
.37544 .31431 Mdot
.37549 .27088 Mdot
.37554 .26022 Mdot
.37558 .1812 Mdot
.37563 .24631 Mdot
.37568 .26495 Mdot
.37573 .32381 Mdot
.37577 .16257 Mdot
.37582 .30138 Mdot
.37587 .24598 Mdot
.37592 .28729 Mdot
.37596 .33836 Mdot
.37601 .21027 Mdot
.37606 .34632 Mdot
.37611 .29111 Mdot
.37616 .19838 Mdot
.3762 .11682 Mdot
.37625 .2455 Mdot
.3763 .0812 Mdot
.37635 .12387 Mdot
.37639 .16712 Mdot
.37644 .25976 Mdot
.37649 .35865 Mdot
.37654 .34273 Mdot
.37658 .21624 Mdot
.37663 .35247 Mdot
.37668 .16732 Mdot
.37673 .23059 Mdot
.37677 .334 Mdot
.37682 .15689 Mdot
.37687 .2079 Mdot
.37692 .13771 Mdot
.37696 .10247 Mdot
.37701 .27578 Mdot
.37706 .28566 Mdot
.37711 .16455 Mdot
.37716 .25756 Mdot
.3772 .29499 Mdot
.37725 .36024 Mdot
.3773 .33202 Mdot
.37735 .2119 Mdot
.37739 .1208 Mdot
.37744 .35052 Mdot
.37749 .27979 Mdot
.37754 .11658 Mdot
.37758 .22787 Mdot
.37763 .35886 Mdot
.37768 .30422 Mdot
.37773 .26766 Mdot
.37777 .24288 Mdot
.37782 .26433 Mdot
.37787 .14659 Mdot
.37792 .30164 Mdot
.37796 .15928 Mdot
.37801 .12988 Mdot
.37806 .0825 Mdot
.37811 .27295 Mdot
.37816 .2523 Mdot
.3782 .21319 Mdot
.37825 .28709 Mdot
.3783 .08983 Mdot
.37835 .32678 Mdot
.37839 .22259 Mdot
.37844 .32487 Mdot
.37849 .24791 Mdot
.37854 .28125 Mdot
.37858 .24238 Mdot
.37863 .1207 Mdot
.37868 .20711 Mdot
.37873 .12934 Mdot
.37877 .25449 Mdot
.37882 .18762 Mdot
.37887 .31076 Mdot
.37892 .25793 Mdot
.37896 .36181 Mdot
.37901 .11799 Mdot
.37906 .08625 Mdot
.37911 .17595 Mdot
.37915 .3094 Mdot
.3792 .11313 Mdot
.37925 .18597 Mdot
.3793 .29649 Mdot
.37935 .17436 Mdot
.37939 .19922 Mdot
.37944 .17463 Mdot
.37949 .34323 Mdot
.37954 .32545 Mdot
.37958 .2482 Mdot
.37963 .30075 Mdot
.37968 .14132 Mdot
.37973 .16258 Mdot
.37977 .20719 Mdot
.37982 .17349 Mdot
.37987 .09201 Mdot
.37992 .28314 Mdot
.37996 .09994 Mdot
.38001 .23813 Mdot
.38006 .20965 Mdot
.38011 .29708 Mdot
.38015 .35786 Mdot
.3802 .23311 Mdot
.38025 .1151 Mdot
.3803 .36411 Mdot
.38035 .32648 Mdot
.38039 .12907 Mdot
.38044 .19556 Mdot
.38049 .27202 Mdot
.38054 .2097 Mdot
.38058 .33192 Mdot
.38063 .22999 Mdot
.38068 .32439 Mdot
.38073 .3395 Mdot
.38077 .11449 Mdot
.38082 .17216 Mdot
.38087 .24548 Mdot
.38092 .21616 Mdot
.38096 .31987 Mdot
.38101 .16435 Mdot
.38106 .34156 Mdot
.38111 .20077 Mdot
.38115 .16646 Mdot
.3812 .33446 Mdot
.38125 .12956 Mdot
.3813 .22301 Mdot
.38135 .31364 Mdot
.38139 .30496 Mdot
.38144 .14608 Mdot
.38149 .27735 Mdot
.38154 .2707 Mdot
.38158 .19571 Mdot
.38163 .25541 Mdot
.38168 .15431 Mdot
.38173 .32048 Mdot
.38177 .3476 Mdot
.38182 .31307 Mdot
.38187 .19704 Mdot
.38192 .29355 Mdot
.38196 .26317 Mdot
.38201 .1555 Mdot
.38206 .36383 Mdot
.38211 .3568 Mdot
.38215 .18727 Mdot
.3822 .19743 Mdot
.38225 .25187 Mdot
.3823 .27932 Mdot
.38235 .23683 Mdot
.38239 .15721 Mdot
.38244 .11838 Mdot
.38249 .35024 Mdot
.38254 .31661 Mdot
.38258 .10119 Mdot
.38263 .22613 Mdot
.38268 .16996 Mdot
.38273 .21151 Mdot
.38277 .23142 Mdot
.38282 .16278 Mdot
.38287 .23548 Mdot
.38292 .25009 Mdot
.38296 .30472 Mdot
.38301 .35229 Mdot
.38306 .32866 Mdot
.38311 .37383 Mdot
.38315 .24146 Mdot
.3832 .37574 Mdot
.38325 .35932 Mdot
.3833 .27935 Mdot
.38334 .13699 Mdot
.38339 .21702 Mdot
.38344 .17333 Mdot
.38349 .13603 Mdot
.38354 .36833 Mdot
.38358 .19252 Mdot
.38363 .212 Mdot
.38368 .20852 Mdot
.38373 .36157 Mdot
.38377 .35586 Mdot
.38382 .13684 Mdot
.38387 .38685 Mdot
.38392 .22531 Mdot
.38396 .28842 Mdot
.38401 .29174 Mdot
.38406 .23247 Mdot
.38411 .31134 Mdot
.38415 .32707 Mdot
.3842 .3542 Mdot
.38425 .24995 Mdot
.3843 .16652 Mdot
.38434 .34301 Mdot
.38439 .38675 Mdot
.38444 .36265 Mdot
.38449 .12691 Mdot
.38454 .22356 Mdot
.38458 .31117 Mdot
.38463 .32455 Mdot
.38468 .15156 Mdot
.38473 .12935 Mdot
.38477 .19766 Mdot
.38482 .21471 Mdot
.38487 .18371 Mdot
.38492 .1674 Mdot
.38496 .16007 Mdot
.38501 .22215 Mdot
.38506 .35288 Mdot
.38511 .27363 Mdot
.38515 .26317 Mdot
.3852 .3847 Mdot
.38525 .1419 Mdot
.3853 .34197 Mdot
.38534 .30456 Mdot
.38539 .23568 Mdot
.38544 .37134 Mdot
.38549 .39512 Mdot
.38554 .31416 Mdot
.38558 .26956 Mdot
.38563 .3463 Mdot
.38568 .27361 Mdot
.38573 .40008 Mdot
.38577 .3423 Mdot
.38582 .29737 Mdot
.38587 .24707 Mdot
.38592 .30542 Mdot
.38596 .23077 Mdot
.38601 .21703 Mdot
.38606 .18324 Mdot
.38611 .24911 Mdot
.38615 .11257 Mdot
.3862 .26315 Mdot
.38625 .30879 Mdot
.3863 .38531 Mdot
.38634 .12743 Mdot
.38639 .22615 Mdot
.38644 .36676 Mdot
.38649 .18602 Mdot
.38654 .29207 Mdot
.38658 .25531 Mdot
.38663 .37234 Mdot
.38668 .27276 Mdot
.38673 .12874 Mdot
.38677 .31029 Mdot
.38682 .20534 Mdot
.38687 .27434 Mdot
.38692 .18829 Mdot
.38696 .1201 Mdot
.38701 .3605 Mdot
.38706 .37134 Mdot
.38711 .36013 Mdot
.38715 .30588 Mdot
.3872 .2854 Mdot
.38725 .23057 Mdot
.3873 .35609 Mdot
.38734 .15145 Mdot
.38739 .38038 Mdot
.38744 .24922 Mdot
.38749 .33796 Mdot
.38754 .32965 Mdot
.38758 .1233 Mdot
.38763 .17307 Mdot
.38768 .15596 Mdot
.38773 .1846 Mdot
.38777 .15627 Mdot
.38782 .30582 Mdot
.38787 .13806 Mdot
.38792 .2802 Mdot
.38796 .35701 Mdot
.38801 .1429 Mdot
.38806 .35624 Mdot
.38811 .27191 Mdot
.38815 .40338 Mdot
.3882 .17862 Mdot
.38825 .40336 Mdot
.3883 .37347 Mdot
.38834 .23076 Mdot
.38839 .35588 Mdot
.38844 .16044 Mdot
.38849 .33539 Mdot
.38853 .25879 Mdot
.38858 .22041 Mdot
.38863 .23128 Mdot
.38868 .11988 Mdot
.38873 .24983 Mdot
.38877 .16187 Mdot
.38882 .19006 Mdot
.38887 .34507 Mdot
.38892 .20868 Mdot
.38896 .26622 Mdot
.38901 .16751 Mdot
.38906 .18057 Mdot
.38911 .26242 Mdot
.38915 .23941 Mdot
.3892 .22241 Mdot
.38925 .32001 Mdot
.3893 .27059 Mdot
.38934 .17768 Mdot
.38939 .23099 Mdot
.38944 .35867 Mdot
.38949 .1573 Mdot
.38953 .23432 Mdot
.38958 .18841 Mdot
.38963 .14134 Mdot
.38968 .31162 Mdot
.38973 .13237 Mdot
.38977 .37064 Mdot
.38982 .14031 Mdot
.38987 .18084 Mdot
.38992 .3846 Mdot
.38996 .30002 Mdot
.39001 .20973 Mdot
.39006 .38685 Mdot
.39011 .23841 Mdot
.39015 .25275 Mdot
.3902 .14959 Mdot
.39025 .24506 Mdot
.3903 .41468 Mdot
.39034 .15136 Mdot
.39039 .24566 Mdot
.39044 .39074 Mdot
.39049 .35861 Mdot
.39053 .33704 Mdot
.39058 .30386 Mdot
.39063 .35565 Mdot
.39068 .2467 Mdot
.39073 .27124 Mdot
.39077 .28533 Mdot
.39082 .16704 Mdot
.39087 .23753 Mdot
.39092 .31886 Mdot
.39096 .26863 Mdot
.39101 .40486 Mdot
.39106 .27179 Mdot
.39111 .14303 Mdot
.39115 .18329 Mdot
.3912 .14261 Mdot
.39125 .15818 Mdot
.3913 .31014 Mdot
.39134 .1589 Mdot
.39139 .3178 Mdot
.39144 .16395 Mdot
.39149 .28458 Mdot
.39153 .33409 Mdot
.39158 .34811 Mdot
.39163 .22659 Mdot
.39168 .36899 Mdot
.39173 .15702 Mdot
.39177 .41431 Mdot
.39182 .40195 Mdot
.39187 .22515 Mdot
.39192 .29414 Mdot
.39196 .37507 Mdot
.39201 .29241 Mdot
.39206 .32935 Mdot
.39211 .15391 Mdot
.39215 .39366 Mdot
.3922 .14942 Mdot
.39225 .31531 Mdot
.3923 .39468 Mdot
.39234 .38046 Mdot
.39239 .4157 Mdot
.39244 .13498 Mdot
.39249 .36578 Mdot
.39253 .19286 Mdot
.39258 .38216 Mdot
.39263 .27586 Mdot
.39268 .16251 Mdot
.39273 .27062 Mdot
.39277 .28678 Mdot
.39282 .33314 Mdot
.39287 .1371 Mdot
.39292 .28299 Mdot
.39296 .31171 Mdot
.39301 .24021 Mdot
.39306 .27024 Mdot
.39311 .3354 Mdot
.39315 .15212 Mdot
.3932 .33875 Mdot
.39325 .24956 Mdot
.3933 .37003 Mdot
.39334 .43119 Mdot
.39339 .15727 Mdot
.39344 .28378 Mdot
.39349 .41867 Mdot
.39353 .14994 Mdot
.39358 .15694 Mdot
.39363 .3477 Mdot
.39368 .36086 Mdot
.39372 .19789 Mdot
.39377 .31139 Mdot
.39382 .32085 Mdot
.39387 .2261 Mdot
.39392 .34204 Mdot
.39396 .40937 Mdot
.39401 .32022 Mdot
.39406 .37464 Mdot
.39411 .16721 Mdot
.39415 .30624 Mdot
.3942 .18726 Mdot
.39425 .17672 Mdot
.3943 .15278 Mdot
.39434 .40024 Mdot
.39439 .37066 Mdot
.39444 .23984 Mdot
.39449 .15494 Mdot
.39453 .38168 Mdot
.39458 .22579 Mdot
.39463 .25514 Mdot
.39468 .14432 Mdot
.39472 .36426 Mdot
.39477 .31267 Mdot
.39482 .32907 Mdot
.39487 .38141 Mdot
.39492 .1932 Mdot
.39496 .42721 Mdot
.39501 .24372 Mdot
.39506 .18032 Mdot
.39511 .21984 Mdot
.39515 .24834 Mdot
.3952 .30549 Mdot
.39525 .15487 Mdot
.3953 .35042 Mdot
.39534 .20325 Mdot
.39539 .27115 Mdot
.39544 .43953 Mdot
.39549 .38781 Mdot
.39553 .27043 Mdot
.39558 .17449 Mdot
.39563 .42798 Mdot
.39568 .14973 Mdot
.39572 .18845 Mdot
.39577 .35821 Mdot
.39582 .42787 Mdot
.39587 .22474 Mdot
.39592 .31525 Mdot
.39596 .17397 Mdot
.39601 .19149 Mdot
.39606 .17677 Mdot
.39611 .32834 Mdot
.39615 .37075 Mdot
.3962 .15702 Mdot
.39625 .39785 Mdot
.3963 .22625 Mdot
.39634 .21172 Mdot
.39639 .44367 Mdot
.39644 .1943 Mdot
.39649 .17008 Mdot
.39653 .38271 Mdot
.39658 .15162 Mdot
.39663 .24903 Mdot
.39668 .3424 Mdot
.39672 .35632 Mdot
.39677 .1668 Mdot
.39682 .24781 Mdot
.39687 .30267 Mdot
.39692 .44189 Mdot
.39696 .18291 Mdot
.39701 .1724 Mdot
.39706 .43181 Mdot
.39711 .41766 Mdot
.39715 .43623 Mdot
.3972 .44064 Mdot
.39725 .25383 Mdot
.3973 .19747 Mdot
.39734 .42998 Mdot
.39739 .19377 Mdot
.39744 .17876 Mdot
.39749 .43199 Mdot
.39753 .43276 Mdot
.39758 .44612 Mdot
.39763 .16068 Mdot
.39768 .20149 Mdot
.39772 .43355 Mdot
.39777 .3497 Mdot
.39782 .26595 Mdot
.39787 .29305 Mdot
.39791 .41998 Mdot
.39796 .25533 Mdot
.39801 .41178 Mdot
.39806 .29987 Mdot
.39811 .39112 Mdot
.39815 .23718 Mdot
.3982 .4293 Mdot
.39825 .33174 Mdot
.3983 .40463 Mdot
.39834 .24649 Mdot
.39839 .33076 Mdot
.39844 .28976 Mdot
.39849 .4252 Mdot
.39853 .20863 Mdot
.39858 .30811 Mdot
.39863 .30894 Mdot
.39868 .44382 Mdot
.39872 .21409 Mdot
.39877 .30437 Mdot
.39882 .26459 Mdot
.39887 .16762 Mdot
.39891 .3168 Mdot
.39896 .19617 Mdot
.39901 .42436 Mdot
.39906 .20067 Mdot
.39911 .21985 Mdot
.39915 .23783 Mdot
.3992 .28328 Mdot
.39925 .26339 Mdot
.3993 .43672 Mdot
.39934 .26279 Mdot
.39939 .40601 Mdot
.39944 .31344 Mdot
.39949 .35026 Mdot
.39953 .38712 Mdot
.39958 .27668 Mdot
.39963 .34374 Mdot
.39968 .30247 Mdot
.39972 .24005 Mdot
.39977 .42385 Mdot
.39982 .35623 Mdot
.39987 .25005 Mdot
.39991 .39241 Mdot
.39996 .32134 Mdot
.40001 .3509 Mdot
.40006 .3906 Mdot
.40011 .35894 Mdot
.40015 .35473 Mdot
.4002 .31334 Mdot
.40025 .33406 Mdot
.4003 .28463 Mdot
.40034 .23518 Mdot
.40039 .21388 Mdot
.40044 .35634 Mdot
.40049 .18618 Mdot
.40053 .28858 Mdot
.40058 .36005 Mdot
.40063 .17104 Mdot
.40068 .25909 Mdot
.40072 .17727 Mdot
.40077 .18189 Mdot
.40082 .32921 Mdot
.40087 .18503 Mdot
.40091 .21447 Mdot
.40096 .28692 Mdot
.40101 .24576 Mdot
.40106 .25428 Mdot
.40111 .355 Mdot
.40115 .3981 Mdot
.4012 .31745 Mdot
.40125 .35784 Mdot
.4013 .46296 Mdot
.40134 .2528 Mdot
.40139 .44649 Mdot
.40144 .24166 Mdot
.40149 .39645 Mdot
.40153 .20778 Mdot
.40158 .25923 Mdot
.40163 .22476 Mdot
.40168 .27735 Mdot
.40172 .31228 Mdot
.40177 .25808 Mdot
.40182 .43062 Mdot
.40187 .27039 Mdot
.40191 .3009 Mdot
.40196 .39445 Mdot
.40201 .41652 Mdot
.40206 .22705 Mdot
.40211 .18531 Mdot
.40215 .32023 Mdot
.4022 .33398 Mdot
.40225 .33886 Mdot
.4023 .25423 Mdot
.40234 .46999 Mdot
.40239 .44357 Mdot
.40244 .34352 Mdot
.40249 .46926 Mdot
.40253 .19668 Mdot
.40258 .37529 Mdot
.40263 .41552 Mdot
.40268 .43527 Mdot
.40272 .40631 Mdot
.40277 .32474 Mdot
.40282 .31258 Mdot
.40287 .29761 Mdot
.40291 .32304 Mdot
.40296 .364 Mdot
.40301 .21742 Mdot
.40306 .467 Mdot
.4031 .39909 Mdot
.40315 .41818 Mdot
.4032 .46127 Mdot
.40325 .45795 Mdot
.4033 .25532 Mdot
.40334 .26086 Mdot
.40339 .29928 Mdot
.40344 .38079 Mdot
.40349 .25746 Mdot
.40353 .28963 Mdot
.40358 .42831 Mdot
.40363 .38428 Mdot
.40368 .23888 Mdot
.40372 .38749 Mdot
.40377 .19129 Mdot
.40382 .42258 Mdot
.40387 .30634 Mdot
.40391 .24187 Mdot
.40396 .35289 Mdot
.40401 .30449 Mdot
.40406 .45789 Mdot
.4041 .35266 Mdot
.40415 .31562 Mdot
.4042 .31269 Mdot
.40425 .23935 Mdot
.4043 .41009 Mdot
.40434 .33016 Mdot
.40439 .33076 Mdot
.40444 .46024 Mdot
.40449 .3308 Mdot
.40453 .21265 Mdot
.40458 .42679 Mdot
.40463 .38496 Mdot
.40468 .22355 Mdot
.40472 .26178 Mdot
.40477 .2253 Mdot
.40482 .32907 Mdot
.40487 .31411 Mdot
.40491 .25389 Mdot
.40496 .28119 Mdot
.40501 .20653 Mdot
.40506 .25625 Mdot
.4051 .38006 Mdot
.40515 .45597 Mdot
.4052 .22812 Mdot
.40525 .38327 Mdot
.4053 .24947 Mdot
.40534 .32851 Mdot
.40539 .46906 Mdot
.40544 .45367 Mdot
.40549 .40001 Mdot
.40553 .47865 Mdot
.40558 .19506 Mdot
.40563 .30932 Mdot
.40568 .37401 Mdot
.40572 .23871 Mdot
.40577 .29202 Mdot
.40582 .27303 Mdot
.40587 .2997 Mdot
.40591 .20107 Mdot
.40596 .44567 Mdot
.40601 .44184 Mdot
.40606 .23408 Mdot
.4061 .40322 Mdot
.40615 .42781 Mdot
.4062 .37446 Mdot
.40625 .33795 Mdot
.4063 .43139 Mdot
.40634 .38917 Mdot
.40639 .47573 Mdot
.40644 .27837 Mdot
.40649 .29297 Mdot
.40653 .40525 Mdot
.40658 .21255 Mdot
.40663 .36391 Mdot
.40668 .30007 Mdot
.40672 .40129 Mdot
.40677 .38939 Mdot
.40682 .47626 Mdot
.40687 .25306 Mdot
.40691 .30117 Mdot
.40696 .30846 Mdot
.40701 .36887 Mdot
.40706 .24449 Mdot
.4071 .34307 Mdot
.40715 .35439 Mdot
.4072 .3279 Mdot
.40725 .32944 Mdot
.40729 .40363 Mdot
.40734 .4685 Mdot
.40739 .47871 Mdot
.40744 .38703 Mdot
.40749 .20878 Mdot
.40753 .48214 Mdot
.40758 .39506 Mdot
.40763 .28897 Mdot
.40768 .2935 Mdot
.40772 .46491 Mdot
.40777 .22666 Mdot
.40782 .47948 Mdot
.40787 .38298 Mdot
.40791 .27164 Mdot
.40796 .24158 Mdot
.40801 .42293 Mdot
.40806 .27853 Mdot
.4081 .45495 Mdot
.40815 .36469 Mdot
.4082 .37576 Mdot
.40825 .42783 Mdot
.40829 .29827 Mdot
.40834 .23471 Mdot
.40839 .24443 Mdot
.40844 .22251 Mdot
.40849 .32314 Mdot
.40853 .24956 Mdot
.40858 .35117 Mdot
.40863 .21285 Mdot
.40868 .33516 Mdot
.40872 .34887 Mdot
.40877 .2619 Mdot
.40882 .41411 Mdot
.40887 .36522 Mdot
.40891 .3225 Mdot
.40896 .27778 Mdot
.40901 .23183 Mdot
.40906 .29448 Mdot
.4091 .28202 Mdot
.40915 .35099 Mdot
.4092 .44965 Mdot
.40925 .33608 Mdot
.40929 .41407 Mdot
.40934 .47218 Mdot
.40939 .2241 Mdot
.40944 .24029 Mdot
.40949 .38204 Mdot
.40953 .43062 Mdot
.40958 .49952 Mdot
.40963 .41527 Mdot
.40968 .33594 Mdot
.40972 .28312 Mdot
.40977 .49053 Mdot
.40982 .28417 Mdot
.40987 .48619 Mdot
.40991 .22567 Mdot
.40996 .28107 Mdot
.41001 .41865 Mdot
.41006 .36872 Mdot
.4101 .44799 Mdot
.41015 .25468 Mdot
.4102 .32981 Mdot
.41025 .29254 Mdot
.41029 .30302 Mdot
.41034 .30611 Mdot
.41039 .495 Mdot
.41044 .37993 Mdot
.41049 .33251 Mdot
.41053 .28901 Mdot
.41058 .46192 Mdot
.41063 .50014 Mdot
.41068 .40433 Mdot
.41072 .29213 Mdot
.41077 .25462 Mdot
.41082 .37238 Mdot
.41087 .32958 Mdot
.41091 .30502 Mdot
.41096 .47407 Mdot
.41101 .39 Mdot
.41106 .31306 Mdot
.4111 .23329 Mdot
.41115 .26495 Mdot
.4112 .23101 Mdot
.41125 .36986 Mdot
.41129 .48359 Mdot
.41134 .44031 Mdot
.41139 .44384 Mdot
.41144 .27754 Mdot
.41149 .38838 Mdot
.41153 .45126 Mdot
.41158 .27519 Mdot
.41163 .45137 Mdot
.41168 .31104 Mdot
.41172 .49606 Mdot
.41177 .28196 Mdot
.41182 .25929 Mdot
.41187 .23135 Mdot
.41191 .45408 Mdot
.41196 .41727 Mdot
.41201 .43759 Mdot
.41206 .4344 Mdot
.4121 .48828 Mdot
.41215 .24087 Mdot
.4122 .33832 Mdot
.41225 .4151 Mdot
.41229 .4375 Mdot
.41234 .22423 Mdot
.41239 .47788 Mdot
.41244 .44112 Mdot
.41248 .50699 Mdot
.41253 .29039 Mdot
.41258 .41567 Mdot
.41263 .26827 Mdot
.41268 .27145 Mdot
.41272 .2311 Mdot
.41277 .47525 Mdot
.41282 .46837 Mdot
.41287 .28672 Mdot
.41291 .46066 Mdot
.41296 .43282 Mdot
.41301 .45407 Mdot
.41306 .34473 Mdot
.4131 .26082 Mdot
.41315 .50771 Mdot
.4132 .23747 Mdot
.41325 .36931 Mdot
.41329 .23814 Mdot
.41334 .38777 Mdot
.41339 .3358 Mdot
.41344 .44542 Mdot
.41348 .23286 Mdot
.41353 .42388 Mdot
.41358 .40885 Mdot
.41363 .4528 Mdot
.41368 .45703 Mdot
.41372 .2281 Mdot
.41377 .36067 Mdot
.41382 .40162 Mdot
.41387 .44639 Mdot
.41391 .26835 Mdot
.41396 .40799 Mdot
.41401 .33593 Mdot
.41406 .50179 Mdot
.4141 .35178 Mdot
.41415 .47036 Mdot
.4142 .50783 Mdot
.41425 .46293 Mdot
.41429 .36108 Mdot
.41434 .45522 Mdot
.41439 .36104 Mdot
.41444 .4475 Mdot
.41448 .49107 Mdot
.41453 .34251 Mdot
.41458 .43375 Mdot
.41463 .43811 Mdot
.41468 .29083 Mdot
.41472 .45235 Mdot
.41477 .49983 Mdot
.41482 .50014 Mdot
.41487 .28712 Mdot
.41491 .31626 Mdot
.41496 .32297 Mdot
.41501 .2787 Mdot
.41506 .24391 Mdot
.4151 .42845 Mdot
.41515 .5074 Mdot
.4152 .29745 Mdot
.41525 .41285 Mdot
.41529 .479 Mdot
.41534 .52067 Mdot
.41539 .3558 Mdot
.41544 .27839 Mdot
.41548 .25058 Mdot
.41553 .38661 Mdot
.41558 .43032 Mdot
.41563 .30953 Mdot
.41568 .43045 Mdot
.41572 .47543 Mdot
.41577 .51497 Mdot
.41582 .24678 Mdot
.41587 .50123 Mdot
.41591 .49891 Mdot
.41596 .24347 Mdot
.41601 .48333 Mdot
.41606 .41398 Mdot
.4161 .40512 Mdot
.41615 .48899 Mdot
.4162 .46897 Mdot
.41625 .51012 Mdot
.41629 .42249 Mdot
.41634 .42164 Mdot
.41639 .28639 Mdot
.41644 .26157 Mdot
.41648 .42731 Mdot
.41653 .29666 Mdot
.41658 .23901 Mdot
.41663 .24218 Mdot
.41667 .27206 Mdot
.41672 .39274 Mdot
.41677 .45607 Mdot
.41682 .33849 Mdot
.41687 .32358 Mdot
.41691 .40489 Mdot
.41696 .44174 Mdot
.41701 .36474 Mdot
.41706 .35234 Mdot
.4171 .39441 Mdot
.41715 .48644 Mdot
.4172 .47897 Mdot
.41725 .4756 Mdot
.41729 .43398 Mdot
.41734 .25136 Mdot
.41739 .49778 Mdot
.41744 .28736 Mdot
.41748 .24676 Mdot
.41753 .49442 Mdot
.41758 .47099 Mdot
.41763 .38987 Mdot
.41767 .4801 Mdot
.41772 .49073 Mdot
.41777 .4643 Mdot
.41782 .35347 Mdot
.41787 .32321 Mdot
.41791 .27068 Mdot
.41796 .36202 Mdot
.41801 .26627 Mdot
.41806 .44974 Mdot
.4181 .36053 Mdot
.41815 .52904 Mdot
.4182 .44588 Mdot
.41825 .29259 Mdot
.41829 .40639 Mdot
.41834 .28768 Mdot
.41839 .50293 Mdot
.41844 .39144 Mdot
.41848 .39318 Mdot
.41853 .32308 Mdot
.41858 .45406 Mdot
.41863 .38335 Mdot
.41867 .43246 Mdot
.41872 .38597 Mdot
.41877 .30339 Mdot
.41882 .43748 Mdot
.41887 .47613 Mdot
.41891 .45624 Mdot
.41896 .48467 Mdot
.41901 .35434 Mdot
.41906 .44569 Mdot
.4191 .33464 Mdot
.41915 .45898 Mdot
.4192 .44022 Mdot
.41925 .32609 Mdot
.41929 .34156 Mdot
.41934 .25438 Mdot
.41939 .38908 Mdot
.41944 .45618 Mdot
.41948 .29567 Mdot
.41953 .28828 Mdot
.41958 .53463 Mdot
.41963 .30532 Mdot
.41967 .50994 Mdot
.41972 .37173 Mdot
.41977 .39411 Mdot
.41982 .41072 Mdot
.41987 .36714 Mdot
.41991 .31168 Mdot
.41996 .495 Mdot
.42001 .47313 Mdot
.42006 .44961 Mdot
.4201 .36589 Mdot
.42015 .38486 Mdot
.4202 .2718 Mdot
.42025 .35951 Mdot
.42029 .44646 Mdot
.42034 .48438 Mdot
.42039 .48561 Mdot
.42044 .26316 Mdot
.42048 .43747 Mdot
.42053 .34085 Mdot
.42058 .27515 Mdot
.42063 .50823 Mdot
.42067 .39524 Mdot
.42072 .3473 Mdot
.42077 .51108 Mdot
.42082 .53972 Mdot
.42087 .27025 Mdot
.42091 .49494 Mdot
.42096 .34742 Mdot
.42101 .41981 Mdot
.42106 .50082 Mdot
.4211 .54236 Mdot
.42115 .41689 Mdot
.4212 .51295 Mdot
.42125 .383 Mdot
.42129 .40573 Mdot
.42134 .39348 Mdot
.42139 .40201 Mdot
.42144 .48012 Mdot
.42148 .46511 Mdot
.42153 .45178 Mdot
.42158 .38807 Mdot
.42163 .29205 Mdot
.42167 .37381 Mdot
.42172 .42636 Mdot
.42177 .42458 Mdot
.42182 .44171 Mdot
.42186 .27672 Mdot
.42191 .46051 Mdot
.42196 .43026 Mdot
.42201 .42217 Mdot
.42206 .3275 Mdot
.4221 .36412 Mdot
.42215 .26164 Mdot
.4222 .46756 Mdot
.42225 .33152 Mdot
.42229 .49377 Mdot
.42234 .29539 Mdot
.42239 .33656 Mdot
.42244 .47281 Mdot
.42248 .35263 Mdot
.42253 .44073 Mdot
.42258 .40395 Mdot
.42263 .26052 Mdot
.42267 .44867 Mdot
.42272 .3058 Mdot
.42277 .3652 Mdot
.42282 .43503 Mdot
.42286 .27594 Mdot
.42291 .42986 Mdot
.42296 .47229 Mdot
.42301 .41241 Mdot
.42306 .36454 Mdot
.4231 .54888 Mdot
.42315 .3047 Mdot
.4232 .33965 Mdot
.42325 .55018 Mdot
.42329 .5423 Mdot
.42334 .38721 Mdot
.42339 .26351 Mdot
.42344 .31194 Mdot
.42348 .5026 Mdot
.42353 .3065 Mdot
.42358 .34156 Mdot
.42363 .51034 Mdot
.42367 .31819 Mdot
.42372 .45388 Mdot
.42377 .33767 Mdot
.42382 .31845 Mdot
.42386 .26934 Mdot
.42391 .34579 Mdot
.42396 .45476 Mdot
.42401 .29993 Mdot
.42406 .3919 Mdot
.4241 .42608 Mdot
.42415 .30024 Mdot
.4242 .48828 Mdot
.42425 .39607 Mdot
.42429 .37974 Mdot
.42434 .51395 Mdot
.42439 .49162 Mdot
.42444 .40744 Mdot
.42448 .54635 Mdot
.42453 .50957 Mdot
.42458 .43896 Mdot
.42463 .45913 Mdot
.42467 .49943 Mdot
.42472 .42774 Mdot
.42477 .48337 Mdot
.42482 .40098 Mdot
.42486 .30575 Mdot
.42491 .35041 Mdot
.42496 .42541 Mdot
.42501 .3923 Mdot
.42506 .51562 Mdot
.4251 .45146 Mdot
.42515 .38659 Mdot
.4252 .55651 Mdot
.42525 .35095 Mdot
.42529 .41279 Mdot
.42534 .45487 Mdot
.42539 .4223 Mdot
.42544 .52808 Mdot
.42548 .45585 Mdot
.42553 .52042 Mdot
.42558 .27732 Mdot
.42563 .5392 Mdot
.42567 .50391 Mdot
.42572 .34437 Mdot
.42577 .37611 Mdot
.42582 .30298 Mdot
.42586 .33952 Mdot
.42591 .41936 Mdot
.42596 .53364 Mdot
.42601 .55588 Mdot
.42606 .54791 Mdot
.4261 .5529 Mdot
.42615 .40559 Mdot
.4262 .30465 Mdot
.42625 .36098 Mdot
.42629 .431 Mdot
.42634 .40877 Mdot
.42639 .51354 Mdot
.42644 .50818 Mdot
.42648 .53626 Mdot
.42653 .54674 Mdot
.42658 .54587 Mdot
.42663 .31803 Mdot
.42667 .28169 Mdot
.42672 .53541 Mdot
.42677 .27281 Mdot
.42682 .37526 Mdot
.42686 .4986 Mdot
.42691 .42588 Mdot
.42696 .53141 Mdot
.42701 .3026 Mdot
.42705 .34624 Mdot
.4271 .45425 Mdot
.42715 .53767 Mdot
.4272 .31698 Mdot
.42725 .35577 Mdot
.42729 .31638 Mdot
.42734 .50088 Mdot
.42739 .51886 Mdot
.42744 .48777 Mdot
.42748 .47076 Mdot
.42753 .55063 Mdot
.42758 .27925 Mdot
.42763 .51508 Mdot
.42767 .48772 Mdot
.42772 .27375 Mdot
.42777 .52521 Mdot
.42782 .50266 Mdot
.42786 .51658 Mdot
.42791 .56535 Mdot
.42796 .41964 Mdot
.42801 .27389 Mdot
.42805 .36067 Mdot
.4281 .30405 Mdot
.42815 .38728 Mdot
.4282 .49289 Mdot
.42825 .4718 Mdot
.42829 .3319 Mdot
.42834 .34109 Mdot
.42839 .40806 Mdot
.42844 .4265 Mdot
.42848 .39708 Mdot
.42853 .38844 Mdot
.42858 .48663 Mdot
.42863 .52222 Mdot
.42867 .41307 Mdot
.42872 .38109 Mdot
.42877 .53843 Mdot
.42882 .30667 Mdot
.42886 .41162 Mdot
.42891 .42317 Mdot
.42896 .30834 Mdot
.42901 .35765 Mdot
.42905 .41397 Mdot
.4291 .27651 Mdot
.42915 .30756 Mdot
.4292 .56508 Mdot
.42925 .3833 Mdot
.42929 .4576 Mdot
.42934 .38317 Mdot
.42939 .36705 Mdot
.42944 .32532 Mdot
.42948 .39055 Mdot
.42953 .54414 Mdot
.42958 .50972 Mdot
.42963 .49753 Mdot
.42967 .57154 Mdot
.42972 .33222 Mdot
.42977 .55718 Mdot
.42982 .35942 Mdot
.42986 .46555 Mdot
.42991 .36387 Mdot
.42996 .52587 Mdot
.43001 .51814 Mdot
.43005 .31799 Mdot
.4301 .33128 Mdot
.43015 .4441 Mdot
.4302 .38017 Mdot
.43025 .31761 Mdot
.43029 .29999 Mdot
.43034 .45027 Mdot
.43039 .56825 Mdot
.43044 .43152 Mdot
.43048 .48845 Mdot
.43053 .36012 Mdot
.43058 .51996 Mdot
.43063 .31812 Mdot
.43067 .51645 Mdot
.43072 .42267 Mdot
.43077 .29997 Mdot
.43082 .31911 Mdot
.43086 .46203 Mdot
.43091 .43826 Mdot
.43096 .51345 Mdot
.43101 .42659 Mdot
.43105 .37645 Mdot
.4311 .48567 Mdot
.43115 .56871 Mdot
.4312 .38727 Mdot
.43124 .32396 Mdot
.43129 .32049 Mdot
.43134 .46758 Mdot
.43139 .34882 Mdot
.43144 .30327 Mdot
.43148 .44449 Mdot
.43153 .47373 Mdot
.43158 .49182 Mdot
.43163 .38945 Mdot
.43167 .36427 Mdot
.43172 .52865 Mdot
.43177 .45384 Mdot
.43182 .44812 Mdot
.43186 .51685 Mdot
.43191 .50918 Mdot
.43196 .41536 Mdot
.43201 .5617 Mdot
.43205 .35946 Mdot
.4321 .57158 Mdot
.43215 .56474 Mdot
.4322 .46649 Mdot
.43224 .45 Mdot
.43229 .28434 Mdot
.43234 .45906 Mdot
.43239 .42423 Mdot
.43244 .41134 Mdot
.43248 .39356 Mdot
.43253 .3923 Mdot
.43258 .40314 Mdot
.43263 .544 Mdot
.43267 .49711 Mdot
.43272 .47787 Mdot
.43277 .29634 Mdot
.43282 .46249 Mdot
.43286 .5462 Mdot
.43291 .30702 Mdot
.43296 .42619 Mdot
.43301 .52373 Mdot
.43305 .32036 Mdot
.4331 .46998 Mdot
.43315 .44292 Mdot
.4332 .44797 Mdot
.43324 .32744 Mdot
.43329 .48402 Mdot
.43334 .55533 Mdot
.43339 .57697 Mdot
.43344 .32736 Mdot
.43348 .30934 Mdot
.43353 .41559 Mdot
.43358 .45024 Mdot
.43363 .51337 Mdot
.43367 .49672 Mdot
.43372 .29738 Mdot
.43377 .48614 Mdot
.43382 .30142 Mdot
.43386 .30412 Mdot
.43391 .58127 Mdot
.43396 .30914 Mdot
.43401 .33568 Mdot
.43405 .57767 Mdot
.4341 .4409 Mdot
.43415 .3662 Mdot
.4342 .30136 Mdot
.43424 .39384 Mdot
.43429 .5791 Mdot
.43434 .49946 Mdot
.43439 .55525 Mdot
.43444 .49127 Mdot
.43448 .31047 Mdot
.43453 .50415 Mdot
.43458 .5148 Mdot
.43463 .46896 Mdot
.43467 .47687 Mdot
.43472 .34115 Mdot
.43477 .58363 Mdot
.43482 .55454 Mdot
.43486 .46704 Mdot
.43491 .43752 Mdot
.43496 .56998 Mdot
.43501 .53829 Mdot
.43505 .4686 Mdot
.4351 .41647 Mdot
.43515 .52249 Mdot
.4352 .54377 Mdot
.43524 .3161 Mdot
.43529 .33877 Mdot
.43534 .50973 Mdot
.43539 .43863 Mdot
.43544 .32067 Mdot
.43548 .42308 Mdot
.43553 .53835 Mdot
.43558 .53134 Mdot
.43563 .29942 Mdot
.43567 .50311 Mdot
.43572 .31297 Mdot
.43577 .35191 Mdot
.43582 .40704 Mdot
.43586 .45169 Mdot
.43591 .31402 Mdot
.43596 .38215 Mdot
.43601 .52488 Mdot
.43605 .3043 Mdot
.4361 .32913 Mdot
.43615 .42905 Mdot
.4362 .3467 Mdot
.43624 .47321 Mdot
.43629 .39213 Mdot
.43634 .47086 Mdot
.43639 .32143 Mdot
.43643 .42537 Mdot
.43648 .46827 Mdot
.43653 .32334 Mdot
.43658 .58683 Mdot
.43663 .2936 Mdot
.43667 .51619 Mdot
.43672 .37837 Mdot
.43677 .57902 Mdot
.43682 .37704 Mdot
.43686 .49501 Mdot
.43691 .31835 Mdot
.43696 .46396 Mdot
.43701 .51229 Mdot
.43705 .47316 Mdot
.4371 .52332 Mdot
.43715 .5263 Mdot
.4372 .50045 Mdot
.43724 .43658 Mdot
.43729 .38692 Mdot
.43734 .47233 Mdot
.43739 .32006 Mdot
.43743 .33737 Mdot
.43748 .50393 Mdot
.43753 .44401 Mdot
.43758 .48275 Mdot
.43763 .45724 Mdot
.43767 .47396 Mdot
.43772 .4455 Mdot
.43777 .48271 Mdot
.43782 .52957 Mdot
.43786 .38934 Mdot
.43791 .45517 Mdot
.43796 .39959 Mdot
.43801 .32857 Mdot
.43805 .36509 Mdot
.4381 .58026 Mdot
.43815 .47644 Mdot
.4382 .44464 Mdot
.43824 .43108 Mdot
.43829 .34851 Mdot
.43834 .56548 Mdot
.43839 .30279 Mdot
.43843 .33897 Mdot
.43848 .46593 Mdot
.43853 .5404 Mdot
.43858 .55534 Mdot
.43863 .42506 Mdot
.43867 .31716 Mdot
.43872 .35298 Mdot
.43877 .39351 Mdot
.43882 .54144 Mdot
.43886 .4621 Mdot
.43891 .46079 Mdot
.43896 .45455 Mdot
.43901 .44794 Mdot
.43905 .30284 Mdot
.4391 .3572 Mdot
.43915 .42206 Mdot
.4392 .37902 Mdot
.43924 .31369 Mdot
.43929 .47196 Mdot
.43934 .56869 Mdot
.43939 .53929 Mdot
.43943 .55662 Mdot
.43948 .49799 Mdot
.43953 .56264 Mdot
.43958 .49714 Mdot
.43963 .3876 Mdot
.43967 .54943 Mdot
.43972 .30437 Mdot
.43977 .36923 Mdot
.43982 .36766 Mdot
.43986 .49375 Mdot
.43991 .5031 Mdot
.43996 .4201 Mdot
.44001 .49795 Mdot
.44005 .33058 Mdot
.4401 .34625 Mdot
.44015 .56479 Mdot
.4402 .49296 Mdot
.44024 .56616 Mdot
.44029 .51705 Mdot
.44034 .48385 Mdot
.44039 .47743 Mdot
.44043 .39244 Mdot
.44048 .54153 Mdot
.44053 .53781 Mdot
.44058 .51413 Mdot
.44062 .48784 Mdot
.44067 .57235 Mdot
.44072 .33936 Mdot
.44077 .42529 Mdot
.44082 .5321 Mdot
.44086 .56689 Mdot
.44091 .56397 Mdot
.44096 .35669 Mdot
.44101 .33747 Mdot
.44105 .36299 Mdot
.4411 .44314 Mdot
.44115 .45294 Mdot
.4412 .30631 Mdot
.44124 .31623 Mdot
.44129 .47277 Mdot
.44134 .55446 Mdot
.44139 .33471 Mdot
.44143 .39381 Mdot
.44148 .58361 Mdot
.44153 .37694 Mdot
.44158 .53711 Mdot
.44162 .44719 Mdot
.44167 .34592 Mdot
.44172 .45786 Mdot
.44177 .34953 Mdot
.44182 .47002 Mdot
.44186 .30696 Mdot
.44191 .33303 Mdot
.44196 .41281 Mdot
.44201 .49858 Mdot
.44205 .33851 Mdot
.4421 .57193 Mdot
.44215 .37614 Mdot
.4422 .43645 Mdot
.44224 .49116 Mdot
.44229 .41999 Mdot
.44234 .37089 Mdot
.44239 .42134 Mdot
.44243 .31958 Mdot
.44248 .46164 Mdot
.44253 .33751 Mdot
.44258 .32892 Mdot
.44262 .33228 Mdot
.44267 .3862 Mdot
.44272 .39683 Mdot
.44277 .47822 Mdot
.44282 .58291 Mdot
.44286 .52496 Mdot
.44291 .34913 Mdot
.44296 .31009 Mdot
.44301 .5779 Mdot
.44305 .49394 Mdot
.4431 .53324 Mdot
.44315 .4085 Mdot
.4432 .54157 Mdot
.44324 .51912 Mdot
.44329 .45941 Mdot
.44334 .56928 Mdot
.44339 .35284 Mdot
.44343 .40163 Mdot
.44348 .39106 Mdot
.44353 .45055 Mdot
.44358 .33592 Mdot
.44362 .53757 Mdot
.44367 .35633 Mdot
.44372 .42447 Mdot
.44377 .30654 Mdot
.44382 .45431 Mdot
.44386 .55737 Mdot
.44391 .54416 Mdot
.44396 .32161 Mdot
.44401 .52738 Mdot
.44405 .51147 Mdot
.4441 .53736 Mdot
.44415 .34191 Mdot
.4442 .33684 Mdot
.44424 .57654 Mdot
.44429 .43236 Mdot
.44434 .39875 Mdot
.44439 .41618 Mdot
.44443 .42079 Mdot
.44448 .46165 Mdot
.44453 .34968 Mdot
.44458 .31838 Mdot
.44462 .3336 Mdot
.44467 .31504 Mdot
.44472 .31774 Mdot
.44477 .3797 Mdot
.44482 .57621 Mdot
.44486 .48956 Mdot
.44491 .31538 Mdot
.44496 .52447 Mdot
.44501 .32312 Mdot
.44505 .54458 Mdot
.4451 .59301 Mdot
.44515 .59638 Mdot
.4452 .41099 Mdot
.44524 .31175 Mdot
.44529 .55568 Mdot
.44534 .56417 Mdot
.44539 .43398 Mdot
.44543 .47897 Mdot
.44548 .4617 Mdot
.44553 .4528 Mdot
.44558 .31805 Mdot
.44562 .32222 Mdot
.44567 .41697 Mdot
.44572 .43942 Mdot
.44577 .58435 Mdot
.44581 .31228 Mdot
.44586 .40437 Mdot
.44591 .3649 Mdot
.44596 .31337 Mdot
.44601 .42284 Mdot
.44605 .3943 Mdot
.4461 .44063 Mdot
.44615 .5905 Mdot
.4462 .47855 Mdot
.44624 .40163 Mdot
.44629 .44464 Mdot
.44634 .48507 Mdot
.44639 .47241 Mdot
.44643 .44646 Mdot
.44648 .48102 Mdot
.44653 .35682 Mdot
.44658 .59407 Mdot
.44662 .58543 Mdot
.44667 .33407 Mdot
.44672 .34466 Mdot
.44677 .57778 Mdot
.44681 .47444 Mdot
.44686 .49552 Mdot
.44691 .36122 Mdot
.44696 .5716 Mdot
.44701 .37619 Mdot
.44705 .43679 Mdot
.4471 .35405 Mdot
.44715 .455 Mdot
.4472 .58303 Mdot
.44724 .59732 Mdot
.44729 .36476 Mdot
.44734 .57768 Mdot
.44739 .48782 Mdot
.44743 .45915 Mdot
.44748 .48104 Mdot
.44753 .4118 Mdot
.44758 .34792 Mdot
.44762 .57958 Mdot
.44767 .43085 Mdot
.44772 .41925 Mdot
.44777 .36404 Mdot
.44781 .55224 Mdot
.44786 .39295 Mdot
.44791 .44313 Mdot
.44796 .49129 Mdot
.44801 .36358 Mdot
.44805 .33863 Mdot
.4481 .47331 Mdot
.44815 .42205 Mdot
.4482 .52864 Mdot
.44824 .58645 Mdot
.44829 .32537 Mdot
.44834 .44097 Mdot
.44839 .53328 Mdot
.44843 .52883 Mdot
.44848 .34971 Mdot
.44853 .5552 Mdot
.44858 .38136 Mdot
.44862 .35504 Mdot
.44867 .54005 Mdot
.44872 .5146 Mdot
.44877 .40398 Mdot
.44881 .52642 Mdot
.44886 .42819 Mdot
.44891 .45798 Mdot
.44896 .45404 Mdot
.44901 .44094 Mdot
.44905 .58742 Mdot
.4491 .56907 Mdot
.44915 .39801 Mdot
.4492 .40988 Mdot
.44924 .42171 Mdot
.44929 .45464 Mdot
.44934 .47187 Mdot
.44939 .42596 Mdot
.44943 .40404 Mdot
.44948 .32139 Mdot
.44953 .54119 Mdot
.44958 .49975 Mdot
.44962 .36212 Mdot
.44967 .36885 Mdot
.44972 .46766 Mdot
.44977 .45256 Mdot
.44981 .4248 Mdot
.44986 .45701 Mdot
.44991 .3716 Mdot
.44996 .52894 Mdot
.45 .59943 Mdot
.45005 .60187 Mdot
.4501 .52042 Mdot
.45015 .39602 Mdot
.4502 .32004 Mdot
.45024 .34086 Mdot
.45029 .43049 Mdot
.45034 .58909 Mdot
.45039 .5013 Mdot
.45043 .4892 Mdot
.45048 .56161 Mdot
.45053 .47129 Mdot
.45058 .40545 Mdot
.45062 .47601 Mdot
.45067 .32863 Mdot
.45072 .57462 Mdot
.45077 .35157 Mdot
.45081 .41541 Mdot
.45086 .4641 Mdot
.45091 .43034 Mdot
.45096 .52993 Mdot
.451 .56158 Mdot
.45105 .40083 Mdot
.4511 .5046 Mdot
.45115 .53372 Mdot
.4512 .56294 Mdot
.45124 .48365 Mdot
.45129 .41698 Mdot
.45134 .52208 Mdot
.45139 .5305 Mdot
.45143 .3616 Mdot
.45148 .43119 Mdot
.45153 .32923 Mdot
.45158 .34977 Mdot
.45162 .40331 Mdot
.45167 .56324 Mdot
.45172 .52714 Mdot
.45177 .47712 Mdot
.45181 .38319 Mdot
.45186 .592 Mdot
.45191 .4841 Mdot
.45196 .37025 Mdot
.452 .5225 Mdot
.45205 .47022 Mdot
.4521 .55759 Mdot
.45215 .4121 Mdot
.4522 .43025 Mdot
.45224 .56906 Mdot
.45229 .33246 Mdot
.45234 .45262 Mdot
.45239 .55006 Mdot
.45243 .46069 Mdot
.45248 .41385 Mdot
.45253 .52559 Mdot
.45258 .49709 Mdot
.45262 .33814 Mdot
.45267 .39325 Mdot
.45272 .48446 Mdot
.45277 .40242 Mdot
.45281 .37839 Mdot
.45286 .46961 Mdot
.45291 .31599 Mdot
.45296 .32787 Mdot
.453 .3899 Mdot
.45305 .58903 Mdot
.4531 .54926 Mdot
.45315 .40889 Mdot
.4532 .5232 Mdot
.45324 .3401 Mdot
.45329 .44582 Mdot
.45334 .58216 Mdot
.45339 .55766 Mdot
.45343 .31629 Mdot
.45348 .59672 Mdot
.45353 .34076 Mdot
.45358 .40562 Mdot
.45362 .50595 Mdot
.45367 .37979 Mdot
.45372 .44718 Mdot
.45377 .37614 Mdot
.45381 .42135 Mdot
.45386 .49882 Mdot
.45391 .3534 Mdot
.45396 .60124 Mdot
.454 .55523 Mdot
.45405 .49146 Mdot
.4541 .33415 Mdot
.45415 .51995 Mdot
.4542 .56967 Mdot
.45424 .54567 Mdot
.45429 .52872 Mdot
.45434 .60021 Mdot
.45439 .53817 Mdot
.45443 .40843 Mdot
.45448 .55 Mdot
.45453 .35112 Mdot
.45458 .53044 Mdot
.45462 .41513 Mdot
.45467 .51779 Mdot
.45472 .54889 Mdot
.45477 .33302 Mdot
.45481 .34386 Mdot
.45486 .37912 Mdot
.45491 .48126 Mdot
.45496 .51502 Mdot
.455 .44838 Mdot
.45505 .3342 Mdot
.4551 .48334 Mdot
.45515 .5631 Mdot
.45519 .56022 Mdot
.45524 .30847 Mdot
.45529 .56667 Mdot
.45534 .59669 Mdot
.45539 .32295 Mdot
.45543 .38299 Mdot
.45548 .56968 Mdot
.45553 .36688 Mdot
.45558 .51771 Mdot
.45562 .43618 Mdot
.45567 .52688 Mdot
.45572 .4396 Mdot
.45577 .41088 Mdot
.45581 .52152 Mdot
.45586 .5811 Mdot
.45591 .41482 Mdot
.45596 .37524 Mdot
.456 .45061 Mdot
.45605 .40804 Mdot
.4561 .50284 Mdot
.45615 .52988 Mdot
.45619 .42456 Mdot
.45624 .52767 Mdot
.45629 .5427 Mdot
.45634 .57261 Mdot
.45639 .42416 Mdot
.45643 .56392 Mdot
.45648 .5489 Mdot
.45653 .55768 Mdot
.45658 .34916 Mdot
.45662 .59707 Mdot
.45667 .48998 Mdot
.45672 .3479 Mdot
.45677 .51576 Mdot
.45681 .37809 Mdot
.45686 .35826 Mdot
.45691 .53974 Mdot
.45696 .59693 Mdot
.457 .39965 Mdot
.45705 .54608 Mdot
.4571 .47226 Mdot
.45715 .45406 Mdot
.45719 .59419 Mdot
.45724 .35094 Mdot
.45729 .54492 Mdot
.45734 .33716 Mdot
.45739 .37414 Mdot
.45743 .4107 Mdot
.45748 .57474 Mdot
.45753 .51541 Mdot
.45758 .4126 Mdot
.45762 .46416 Mdot
.45767 .32454 Mdot
.45772 .47369 Mdot
.45777 .41781 Mdot
.45781 .57643 Mdot
.45786 .57886 Mdot
.45791 .56012 Mdot
.45796 .34704 Mdot
.458 .52546 Mdot
.45805 .34637 Mdot
.4581 .56528 Mdot
.45815 .54944 Mdot
.45819 .5814 Mdot
.45824 .47611 Mdot
.45829 .41832 Mdot
.45834 .55718 Mdot
.45839 .53751 Mdot
.45843 .53307 Mdot
.45848 .38816 Mdot
.45853 .49 Mdot
.45858 .43374 Mdot
.45862 .56007 Mdot
.45867 .47447 Mdot
.45872 .38423 Mdot
.45877 .57123 Mdot
.45881 .5423 Mdot
.45886 .30751 Mdot
.45891 .56797 Mdot
.45896 .59633 Mdot
.459 .56493 Mdot
.45905 .34884 Mdot
.4591 .5275 Mdot
.45915 .3774 Mdot
.45919 .52505 Mdot
.45924 .38488 Mdot
.45929 .57934 Mdot
.45934 .39724 Mdot
.45939 .35529 Mdot
.45943 .56772 Mdot
.45948 .32843 Mdot
.45953 .46083 Mdot
.45958 .42329 Mdot
.45962 .48573 Mdot
.45967 .43941 Mdot
.45972 .33319 Mdot
.45977 .46412 Mdot
.45981 .31728 Mdot
.45986 .36116 Mdot
.45991 .36274 Mdot
.45996 .52257 Mdot
.46 .31562 Mdot
.46005 .39386 Mdot
.4601 .36704 Mdot
.46015 .55823 Mdot
.46019 .56732 Mdot
.46024 .46686 Mdot
.46029 .59011 Mdot
.46034 .33874 Mdot
.46038 .48797 Mdot
.46043 .48786 Mdot
.46048 .49831 Mdot
.46053 .5837 Mdot
.46058 .52046 Mdot
.46062 .46474 Mdot
.46067 .34274 Mdot
.46072 .46564 Mdot
.46077 .3399 Mdot
.46081 .33046 Mdot
.46086 .31465 Mdot
.46091 .30656 Mdot
.46096 .32763 Mdot
.461 .56911 Mdot
.46105 .55167 Mdot
.4611 .38371 Mdot
.46115 .31682 Mdot
.46119 .48002 Mdot
.46124 .48934 Mdot
.46129 .42501 Mdot
.46134 .34898 Mdot
.46138 .31774 Mdot
.46143 .49862 Mdot
.46148 .39075 Mdot
.46153 .4603 Mdot
.46158 .42911 Mdot
.46162 .30464 Mdot
.46167 .40618 Mdot
.46172 .53893 Mdot
.46177 .56341 Mdot
.46181 .56089 Mdot
.46186 .53948 Mdot
.46191 .50306 Mdot
.46196 .53693 Mdot
.462 .55017 Mdot
.46205 .5368 Mdot
.4621 .47926 Mdot
.46215 .56645 Mdot
.46219 .59708 Mdot
.46224 .45676 Mdot
.46229 .46605 Mdot
.46234 .38999 Mdot
.46238 .41124 Mdot
.46243 .3352 Mdot
.46248 .42046 Mdot
.46253 .3756 Mdot
.46258 .51077 Mdot
.46262 .54254 Mdot
.46267 .55819 Mdot
.46272 .54446 Mdot
.46277 .50919 Mdot
.46281 .43937 Mdot
.46286 .32221 Mdot
.46291 .5788 Mdot
.46296 .546 Mdot
.463 .49752 Mdot
.46305 .41673 Mdot
.4631 .34453 Mdot
.46315 .59329 Mdot
.46319 .55813 Mdot
.46324 .53482 Mdot
.46329 .37536 Mdot
.46334 .59344 Mdot
.46338 .40368 Mdot
.46343 .37103 Mdot
.46348 .58242 Mdot
.46353 .48432 Mdot
.46358 .37054 Mdot
.46362 .54743 Mdot
.46367 .50877 Mdot
.46372 .57029 Mdot
.46377 .42468 Mdot
.46381 .58586 Mdot
.46386 .56087 Mdot
.46391 .36274 Mdot
.46396 .58174 Mdot
.464 .56515 Mdot
.46405 .57837 Mdot
.4641 .41298 Mdot
.46415 .38554 Mdot
.46419 .44968 Mdot
.46424 .53504 Mdot
.46429 .41567 Mdot
.46434 .42333 Mdot
.46438 .51071 Mdot
.46443 .46061 Mdot
.46448 .41796 Mdot
.46453 .32045 Mdot
.46457 .44041 Mdot
.46462 .47371 Mdot
.46467 .52909 Mdot
.46472 .54529 Mdot
.46477 .4883 Mdot
.46481 .56019 Mdot
.46486 .55398 Mdot
.46491 .42087 Mdot
.46496 .49748 Mdot
.465 .29945 Mdot
.46505 .49129 Mdot
.4651 .43397 Mdot
.46515 .5271 Mdot
.46519 .31577 Mdot
.46524 .37808 Mdot
.46529 .34813 Mdot
.46534 .37705 Mdot
.46538 .37515 Mdot
.46543 .55675 Mdot
.46548 .51907 Mdot
.46553 .46055 Mdot
.46557 .50868 Mdot
.46562 .438 Mdot
.46567 .49775 Mdot
.46572 .31919 Mdot
.46577 .33395 Mdot
.46581 .50267 Mdot
.46586 .54616 Mdot
.46591 .42451 Mdot
.46596 .3673 Mdot
.466 .54216 Mdot
.46605 .42382 Mdot
.4661 .52035 Mdot
.46615 .36624 Mdot
.46619 .34918 Mdot
.46624 .58295 Mdot
.46629 .58627 Mdot
.46634 .34855 Mdot
.46638 .56396 Mdot
.46643 .53275 Mdot
.46648 .50706 Mdot
.46653 .56603 Mdot
.46657 .3049 Mdot
.46662 .31129 Mdot
.46667 .34406 Mdot
.46672 .35481 Mdot
.46677 .45915 Mdot
.46681 .4057 Mdot
.46686 .32209 Mdot
.46691 .31801 Mdot
.46696 .5484 Mdot
.467 .45138 Mdot
.46705 .48933 Mdot
.4671 .54239 Mdot
.46715 .30298 Mdot
.46719 .32422 Mdot
.46724 .56042 Mdot
.46729 .47264 Mdot
.46734 .54507 Mdot
.46738 .33246 Mdot
.46743 .56526 Mdot
.46748 .42026 Mdot
.46753 .57205 Mdot
.46757 .39056 Mdot
.46762 .35411 Mdot
.46767 .44493 Mdot
.46772 .56289 Mdot
.46777 .37494 Mdot
.46781 .30564 Mdot
.46786 .38561 Mdot
.46791 .39916 Mdot
.46796 .55942 Mdot
.468 .57365 Mdot
.46805 .36276 Mdot
.4681 .44068 Mdot
.46815 .40302 Mdot
.46819 .37921 Mdot
.46824 .41004 Mdot
.46829 .43242 Mdot
.46834 .37344 Mdot
.46838 .4082 Mdot
.46843 .52671 Mdot
.46848 .47658 Mdot
.46853 .33527 Mdot
.46857 .43199 Mdot
.46862 .40055 Mdot
.46867 .4934 Mdot
.46872 .53348 Mdot
.46877 .37171 Mdot
.46881 .54422 Mdot
.46886 .51902 Mdot
.46891 .4521 Mdot
.46896 .35954 Mdot
.469 .45199 Mdot
.46905 .41315 Mdot
.4691 .48073 Mdot
.46915 .37385 Mdot
.46919 .38224 Mdot
.46924 .56025 Mdot
.46929 .37054 Mdot
.46934 .58223 Mdot
.46938 .5597 Mdot
.46943 .42037 Mdot
.46948 .58441 Mdot
.46953 .46639 Mdot
.46957 .32526 Mdot
.46962 .53082 Mdot
.46967 .54122 Mdot
.46972 .32639 Mdot
.46976 .51146 Mdot
.46981 .32921 Mdot
.46986 .29944 Mdot
.46991 .54114 Mdot
.46996 .5536 Mdot
.47 .39645 Mdot
.47005 .4335 Mdot
.4701 .47282 Mdot
.47015 .39272 Mdot
.47019 .56918 Mdot
.47024 .53854 Mdot
.47029 .38979 Mdot
.47034 .3012 Mdot
.47038 .29956 Mdot
.47043 .45854 Mdot
.47048 .39285 Mdot
.47053 .32669 Mdot
.47057 .46427 Mdot
.47062 .45911 Mdot
.47067 .51134 Mdot
.47072 .29135 Mdot
.47076 .51814 Mdot
.47081 .50248 Mdot
.47086 .47458 Mdot
.47091 .36428 Mdot
.47096 .47836 Mdot
.471 .49237 Mdot
.47105 .51752 Mdot
.4711 .39465 Mdot
.47115 .37092 Mdot
.47119 .34778 Mdot
.47124 .33351 Mdot
.47129 .29064 Mdot
.47134 .3852 Mdot
.47138 .39259 Mdot
.47143 .52697 Mdot
.47148 .57258 Mdot
.47153 .37383 Mdot
.47157 .51699 Mdot
.47162 .4221 Mdot
.47167 .53377 Mdot
.47172 .49219 Mdot
.47176 .34554 Mdot
.47181 .49317 Mdot
.47186 .52986 Mdot
.47191 .55625 Mdot
.47196 .42515 Mdot
.472 .30572 Mdot
.47205 .45261 Mdot
.4721 .3648 Mdot
.47215 .51445 Mdot
.47219 .36976 Mdot
.47224 .34454 Mdot
.47229 .57522 Mdot
.47234 .45304 Mdot
.47238 .32252 Mdot
.47243 .34006 Mdot
.47248 .47606 Mdot
.47253 .34639 Mdot
.47257 .37622 Mdot
.47262 .34805 Mdot
.47267 .38783 Mdot
.47272 .40974 Mdot
.47276 .53436 Mdot
.47281 .39442 Mdot
.47286 .47567 Mdot
.47291 .34925 Mdot
.47296 .32612 Mdot
.473 .44423 Mdot
.47305 .49899 Mdot
.4731 .50356 Mdot
.47315 .30488 Mdot
.47319 .57086 Mdot
.47324 .41845 Mdot
.47329 .56811 Mdot
.47334 .51401 Mdot
.47338 .51024 Mdot
.47343 .42189 Mdot
.47348 .39876 Mdot
.47353 .47507 Mdot
.47357 .45364 Mdot
.47362 .52402 Mdot
.47367 .33561 Mdot
.47372 .38196 Mdot
.47376 .38858 Mdot
.47381 .41907 Mdot
.47386 .50349 Mdot
.47391 .42511 Mdot
.47395 .57156 Mdot
.474 .52068 Mdot
.47405 .43653 Mdot
.4741 .38117 Mdot
.47415 .40938 Mdot
.47419 .30363 Mdot
.47424 .50966 Mdot
.47429 .35799 Mdot
.47434 .41497 Mdot
.47438 .46151 Mdot
.47443 .51775 Mdot
.47448 .42007 Mdot
.47453 .4807 Mdot
.47457 .32062 Mdot
.47462 .39986 Mdot
.47467 .5206 Mdot
.47472 .3077 Mdot
.47476 .37196 Mdot
.47481 .34464 Mdot
.47486 .41891 Mdot
.47491 .49412 Mdot
.47495 .52777 Mdot
.475 .41591 Mdot
.47505 .56843 Mdot
.4751 .49708 Mdot
.47515 .28663 Mdot
.47519 .55365 Mdot
.47524 .46655 Mdot
.47529 .36686 Mdot
.47534 .55689 Mdot
.47538 .32291 Mdot
.47543 .38735 Mdot
.47548 .52541 Mdot
.47553 .37392 Mdot
.47557 .37844 Mdot
.47562 .54044 Mdot
.47567 .32288 Mdot
.47572 .33135 Mdot
.47576 .55135 Mdot
.47581 .29763 Mdot
.47586 .29284 Mdot
.47591 .53178 Mdot
.47595 .48413 Mdot
.476 .45086 Mdot
.47605 .37074 Mdot
.4761 .28104 Mdot
.47615 .34512 Mdot
.47619 .45406 Mdot
.47624 .44517 Mdot
.47629 .56579 Mdot
.47634 .36272 Mdot
.47638 .55863 Mdot
.47643 .35445 Mdot
.47648 .28491 Mdot
.47653 .31568 Mdot
.47657 .44702 Mdot
.47662 .39951 Mdot
.47667 .48133 Mdot
.47672 .50746 Mdot
.47676 .47667 Mdot
.47681 .35174 Mdot
.47686 .42495 Mdot
.47691 .5258 Mdot
.47695 .45374 Mdot
.477 .33346 Mdot
.47705 .46246 Mdot
.4771 .31598 Mdot
.47715 .27706 Mdot
.47719 .53162 Mdot
.47724 .45533 Mdot
.47729 .53949 Mdot
.47734 .3915 Mdot
.47738 .35996 Mdot
.47743 .45777 Mdot
.47748 .45002 Mdot
.47753 .40084 Mdot
.47757 .27849 Mdot
.47762 .44571 Mdot
.47767 .40704 Mdot
.47772 .52124 Mdot
.47776 .44627 Mdot
.47781 .53154 Mdot
.47786 .4666 Mdot
.47791 .31661 Mdot
.47795 .36643 Mdot
.478 .37835 Mdot
.47805 .50728 Mdot
.4781 .4292 Mdot
.47815 .30431 Mdot
.47819 .48195 Mdot
.47824 .46238 Mdot
.47829 .42308 Mdot
.47834 .33835 Mdot
.47838 .29728 Mdot
.47843 .48827 Mdot
.47848 .30197 Mdot
.47853 .54349 Mdot
.47857 .40447 Mdot
.47862 .30823 Mdot
.47867 .46583 Mdot
.47872 .53469 Mdot
.47876 .52317 Mdot
.47881 .46546 Mdot
.47886 .50871 Mdot
.47891 .35755 Mdot
.47895 .55548 Mdot
.479 .26771 Mdot
.47905 .46082 Mdot
.4791 .55455 Mdot
.47914 .44556 Mdot
.47919 .32357 Mdot
.47924 .29976 Mdot
.47929 .51824 Mdot
.47934 .52632 Mdot
.47938 .42376 Mdot
.47943 .4391 Mdot
.47948 .44732 Mdot
.47953 .49633 Mdot
.47957 .4975 Mdot
.47962 .40414 Mdot
.47967 .46555 Mdot
.47972 .35858 Mdot
.47976 .45584 Mdot
.47981 .4996 Mdot
.47986 .49201 Mdot
.47991 .3964 Mdot
.47995 .55124 Mdot
.48 .55159 Mdot
.48005 .40016 Mdot
.4801 .40134 Mdot
.48014 .54894 Mdot
.48019 .35605 Mdot
.48024 .40559 Mdot
.48029 .51561 Mdot
.48034 .49021 Mdot
.48038 .32097 Mdot
.48043 .44675 Mdot
.48048 .54853 Mdot
.48053 .33069 Mdot
.48057 .44082 Mdot
.48062 .26337 Mdot
.48067 .316 Mdot
.48072 .3917 Mdot
.48076 .30019 Mdot
.48081 .35603 Mdot
.48086 .51549 Mdot
.48091 .49377 Mdot
.48095 .35836 Mdot
.481 .42164 Mdot
.48105 .3817 Mdot
.4811 .49985 Mdot
.48114 .36394 Mdot
.48119 .28365 Mdot
.48124 .53722 Mdot
.48129 .50763 Mdot
.48134 .2696 Mdot
.48138 .43447 Mdot
.48143 .28302 Mdot
.48148 .27868 Mdot
.48153 .50459 Mdot
.48157 .54354 Mdot
.48162 .29015 Mdot
.48167 .5035 Mdot
.48172 .32427 Mdot
.48176 .54051 Mdot
.48181 .5292 Mdot
.48186 .37185 Mdot
.48191 .28397 Mdot
.48195 .44421 Mdot
.482 .27329 Mdot
.48205 .43236 Mdot
.4821 .47974 Mdot
.48214 .28169 Mdot
.48219 .44542 Mdot
.48224 .48618 Mdot
.48229 .37446 Mdot
.48234 .25655 Mdot
.48238 .4614 Mdot
.48243 .53161 Mdot
.48248 .36291 Mdot
.48253 .37482 Mdot
.48257 .43611 Mdot
.48262 .5105 Mdot
.48267 .41059 Mdot
.48272 .38341 Mdot
.48276 .40307 Mdot
.48281 .26395 Mdot
.48286 .34312 Mdot
.48291 .39439 Mdot
.48295 .42521 Mdot
.483 .44328 Mdot
.48305 .31531 Mdot
.4831 .50104 Mdot
.48314 .40777 Mdot
.48319 .26661 Mdot
.48324 .38596 Mdot
.48329 .47472 Mdot
.48333 .51242 Mdot
.48338 .33034 Mdot
.48343 .2664 Mdot
.48348 .4729 Mdot
.48353 .3056 Mdot
.48357 .34801 Mdot
.48362 .45261 Mdot
.48367 .35218 Mdot
.48372 .41828 Mdot
.48376 .38614 Mdot
.48381 .29564 Mdot
.48386 .51709 Mdot
.48391 .26851 Mdot
.48395 .37533 Mdot
.484 .50036 Mdot
.48405 .37552 Mdot
.4841 .39081 Mdot
.48414 .4794 Mdot
.48419 .43738 Mdot
.48424 .42151 Mdot
.48429 .5299 Mdot
.48433 .46464 Mdot
.48438 .3031 Mdot
.48443 .49317 Mdot
.48448 .26884 Mdot
.48453 .38549 Mdot
.48457 .28774 Mdot
.48462 .27114 Mdot
.48467 .50881 Mdot
.48472 .28803 Mdot
.48476 .38036 Mdot
.48481 .46402 Mdot
.48486 .34058 Mdot
.48491 .44662 Mdot
.48495 .33444 Mdot
.485 .49134 Mdot
.48505 .32146 Mdot
.4851 .32052 Mdot
.48514 .378 Mdot
.48519 .36471 Mdot
.48524 .47424 Mdot
.48529 .38454 Mdot
.48533 .48387 Mdot
.48538 .48629 Mdot
.48543 .48726 Mdot
.48548 .46266 Mdot
.48553 .42851 Mdot
.48557 .53554 Mdot
.48562 .46581 Mdot
.48567 .3244 Mdot
.48572 .38784 Mdot
.48576 .5113 Mdot
.48581 .49859 Mdot
.48586 .28293 Mdot
.48591 .25387 Mdot
.48595 .2935 Mdot
.486 .40407 Mdot
.48605 .37705 Mdot
.4861 .46001 Mdot
.48614 .34256 Mdot
.48619 .32799 Mdot
.48624 .30175 Mdot
.48629 .32705 Mdot
.48633 .51758 Mdot
.48638 .39331 Mdot
.48643 .4566 Mdot
.48648 .3824 Mdot
.48653 .27549 Mdot
.48657 .44493 Mdot
.48662 .53266 Mdot
.48667 .49244 Mdot
.48672 .27832 Mdot
.48676 .51732 Mdot
.48681 .45143 Mdot
.48686 .3476 Mdot
.48691 .30471 Mdot
.48695 .26139 Mdot
.487 .41099 Mdot
.48705 .33605 Mdot
.4871 .25336 Mdot
.48714 .39415 Mdot
.48719 .27573 Mdot
.48724 .41252 Mdot
.48729 .4471 Mdot
.48733 .30744 Mdot
.48738 .50994 Mdot
.48743 .3264 Mdot
.48748 .46514 Mdot
.48753 .44958 Mdot
.48757 .29375 Mdot
.48762 .4791 Mdot
.48767 .42972 Mdot
.48772 .24454 Mdot
.48776 .29567 Mdot
.48781 .52106 Mdot
.48786 .39077 Mdot
.48791 .26128 Mdot
.48795 .37811 Mdot
.488 .4123 Mdot
.48805 .32473 Mdot
.4881 .23838 Mdot
.48814 .5003 Mdot
.48819 .3144 Mdot
.48824 .30934 Mdot
.48829 .37688 Mdot
.48833 .46219 Mdot
.48838 .43417 Mdot
.48843 .39436 Mdot
.48848 .30653 Mdot
.48852 .48401 Mdot
.48857 .34451 Mdot
.48862 .46063 Mdot
.48867 .38819 Mdot
.48872 .42646 Mdot
.48876 .39629 Mdot
.48881 .26676 Mdot
.48886 .37932 Mdot
.48891 .36628 Mdot
.48895 .4054 Mdot
.489 .40599 Mdot
.48905 .353 Mdot
.4891 .51781 Mdot
.48914 .52256 Mdot
.48919 .31568 Mdot
.48924 .34886 Mdot
.48929 .25157 Mdot
.48933 .44204 Mdot
.48938 .24005 Mdot
.48943 .50036 Mdot
.48948 .31759 Mdot
.48952 .24104 Mdot
.48957 .37354 Mdot
.48962 .42664 Mdot
.48967 .36107 Mdot
.48972 .42384 Mdot
.48976 .44003 Mdot
.48981 .27054 Mdot
.48986 .46138 Mdot
.48991 .25928 Mdot
.48995 .40482 Mdot
.49 .41745 Mdot
.49005 .32628 Mdot
.4901 .37974 Mdot
.49014 .22965 Mdot
.49019 .29509 Mdot
.49024 .33379 Mdot
.49029 .38231 Mdot
.49033 .43892 Mdot
.49038 .471 Mdot
.49043 .31195 Mdot
.49048 .46468 Mdot
.49052 .42824 Mdot
.49057 .49467 Mdot
.49062 .51822 Mdot
.49067 .45245 Mdot
.49072 .28333 Mdot
.49076 .29648 Mdot
.49081 .38542 Mdot
.49086 .2567 Mdot
.49091 .36606 Mdot
.49095 .25366 Mdot
.491 .44643 Mdot
.49105 .22477 Mdot
.4911 .48326 Mdot
.49114 .35805 Mdot
.49119 .34695 Mdot
.49124 .3665 Mdot
.49129 .48004 Mdot
.49133 .2892 Mdot
.49138 .23921 Mdot
.49143 .50492 Mdot
.49148 .26681 Mdot
.49152 .33857 Mdot
.49157 .44744 Mdot
.49162 .26538 Mdot
.49167 .35838 Mdot
.49172 .36351 Mdot
.49176 .44865 Mdot
.49181 .33217 Mdot
.49186 .29925 Mdot
.49191 .29105 Mdot
.49195 .28707 Mdot
.492 .29912 Mdot
.49205 .45151 Mdot
.4921 .26066 Mdot
.49214 .35858 Mdot
.49219 .29725 Mdot
.49224 .48582 Mdot
.49229 .42 Mdot
.49233 .23397 Mdot
.49238 .44775 Mdot
.49243 .22774 Mdot
.49248 .35257 Mdot
.49252 .5112 Mdot
.49257 .45908 Mdot
.49262 .477 Mdot
.49267 .23503 Mdot
.49272 .2846 Mdot
.49276 .41435 Mdot
.49281 .33908 Mdot
.49286 .38664 Mdot
.49291 .35089 Mdot
.49295 .30207 Mdot
.493 .25954 Mdot
.49305 .31511 Mdot
.4931 .28315 Mdot
.49314 .22209 Mdot
.49319 .32183 Mdot
.49324 .2732 Mdot
.49329 .43799 Mdot
.49333 .43808 Mdot
.49338 .34906 Mdot
.49343 .36606 Mdot
.49348 .42183 Mdot
.49352 .5028 Mdot
.49357 .33874 Mdot
.49362 .23073 Mdot
.49367 .42253 Mdot
.49371 .26058 Mdot
.49376 .37326 Mdot
.49381 .50704 Mdot
.49386 .35422 Mdot
.49391 .35718 Mdot
.49395 .25008 Mdot
.494 .33611 Mdot
.49405 .21885 Mdot
.4941 .27044 Mdot
.49414 .50054 Mdot
.49419 .23595 Mdot
.49424 .44531 Mdot
.49429 .26291 Mdot
.49433 .39308 Mdot
.49438 .47178 Mdot
.49443 .22131 Mdot
.49448 .33349 Mdot
.49452 .25763 Mdot
.49457 .31912 Mdot
.49462 .30755 Mdot
.49467 .33856 Mdot
.49471 .42658 Mdot
.49476 .30103 Mdot
.49481 .39232 Mdot
.49486 .29024 Mdot
.49491 .26537 Mdot
.49495 .30071 Mdot
.495 .24977 Mdot
.49505 .43939 Mdot
.4951 .22657 Mdot
.49514 .47055 Mdot
.49519 .24182 Mdot
.49524 .37966 Mdot
.49529 .2314 Mdot
.49533 .44491 Mdot
.49538 .30149 Mdot
.49543 .32668 Mdot
.49548 .3429 Mdot
.49552 .47753 Mdot
.49557 .28952 Mdot
.49562 .4972 Mdot
.49567 .29423 Mdot
.49571 .36717 Mdot
.49576 .48539 Mdot
.49581 .36701 Mdot
.49586 .37068 Mdot
.49591 .27412 Mdot
.49595 .30086 Mdot
.496 .28436 Mdot
.49605 .31271 Mdot
.4961 .47546 Mdot
.49614 .25809 Mdot
.49619 .34663 Mdot
.49624 .29275 Mdot
.49629 .21133 Mdot
.49633 .22249 Mdot
.49638 .46785 Mdot
.49643 .26718 Mdot
.49648 .2669 Mdot
.49652 .42129 Mdot
.49657 .34641 Mdot
.49662 .42418 Mdot
.49667 .28908 Mdot
.49671 .33642 Mdot
.49676 .34852 Mdot
.49681 .33421 Mdot
.49686 .42083 Mdot
.49691 .34974 Mdot
.49695 .48003 Mdot
.497 .46185 Mdot
.49705 .34998 Mdot
.4971 .25196 Mdot
.49714 .39854 Mdot
.49719 .35182 Mdot
.49724 .37186 Mdot
.49729 .49101 Mdot
.49733 .254 Mdot
.49738 .26096 Mdot
.49743 .36221 Mdot
.49748 .47001 Mdot
.49752 .2823 Mdot
.49757 .48973 Mdot
.49762 .29621 Mdot
.49767 .24942 Mdot
.49771 .43125 Mdot
.49776 .26586 Mdot
.49781 .20723 Mdot
.49786 .40776 Mdot
.4979 .28244 Mdot
.49795 .42602 Mdot
.498 .28057 Mdot
.49805 .25713 Mdot
.4981 .29618 Mdot
.49814 .45774 Mdot
.49819 .42396 Mdot
.49824 .20349 Mdot
.49829 .39061 Mdot
.49833 .30383 Mdot
.49838 .24982 Mdot
.49843 .20486 Mdot
.49848 .33393 Mdot
.49852 .23999 Mdot
.49857 .37938 Mdot
.49862 .22642 Mdot
.49867 .24815 Mdot
.49871 .24143 Mdot
.49876 .27929 Mdot
.49881 .46777 Mdot
.49886 .30747 Mdot
.4989 .46594 Mdot
.49895 .26737 Mdot
.499 .25513 Mdot
.49905 .21995 Mdot
.4991 .23464 Mdot
.49914 .47617 Mdot
.49919 .19231 Mdot
.49924 .41274 Mdot
.49929 .26567 Mdot
.49933 .24593 Mdot
.49938 .47719 Mdot
.49943 .21545 Mdot
.49948 .44981 Mdot
.49952 .18902 Mdot
.49957 .46504 Mdot
.49962 .36889 Mdot
.49967 .40213 Mdot
.49971 .2966 Mdot
.49976 .43053 Mdot
.49981 .31245 Mdot
.49986 .35221 Mdot
.4999 .20861 Mdot
.49995 .44871 Mdot
.5 .19587 Mdot
.50005 .37182 Mdot
.5001 .42658 Mdot
.50014 .38387 Mdot
.50019 .46087 Mdot
.50024 .32706 Mdot
.50029 .43495 Mdot
.50033 .38105 Mdot
.50038 .2374 Mdot
.50043 .25047 Mdot
.50048 .3779 Mdot
.50052 .38739 Mdot
.50057 .21043 Mdot
.50062 .28379 Mdot
.50067 .37696 Mdot
.50071 .40507 Mdot
.50076 .32406 Mdot
.50081 .36397 Mdot
.50086 .26762 Mdot
.5009 .45645 Mdot
.50095 .19847 Mdot
.501 .19842 Mdot
.50105 .24546 Mdot
.5011 .19399 Mdot
.50114 .18864 Mdot
.50119 .3073 Mdot
.50124 .29936 Mdot
.50129 .2904 Mdot
.50133 .20786 Mdot
.50138 .46012 Mdot
.50143 .34409 Mdot
.50148 .38883 Mdot
.50152 .44973 Mdot
.50157 .39386 Mdot
.50162 .44506 Mdot
.50167 .18525 Mdot
.50171 .42291 Mdot
.50176 .29348 Mdot
.50181 .2513 Mdot
.50186 .25804 Mdot
.5019 .28164 Mdot
.50195 .40694 Mdot
.502 .46092 Mdot
.50205 .27862 Mdot
.5021 .26515 Mdot
.50214 .3903 Mdot
.50219 .39703 Mdot
.50224 .266 Mdot
.50229 .25767 Mdot
.50233 .26395 Mdot
.50238 .27842 Mdot
.50243 .451 Mdot
.50248 .23016 Mdot
.50252 .27883 Mdot
.50257 .40912 Mdot
.50262 .2419 Mdot
.50267 .25481 Mdot
.50271 .35915 Mdot
.50276 .43804 Mdot
.50281 .23556 Mdot
.50286 .30548 Mdot
.5029 .24417 Mdot
.50295 .36504 Mdot
.503 .45047 Mdot
.50305 .20173 Mdot
.50309 .30977 Mdot
.50314 .37646 Mdot
.50319 .34913 Mdot
.50324 .40851 Mdot
.50329 .3912 Mdot
.50333 .45095 Mdot
.50338 .25959 Mdot
.50343 .32709 Mdot
.50348 .3033 Mdot
.50352 .34838 Mdot
.50357 .27909 Mdot
.50362 .27237 Mdot
.50367 .1997 Mdot
.50371 .40914 Mdot
.50376 .21201 Mdot
.50381 .19217 Mdot
.50386 .30983 Mdot
.5039 .44017 Mdot
.50395 .44531 Mdot
.504 .35535 Mdot
.50405 .23924 Mdot
.50409 .24851 Mdot
.50414 .46287 Mdot
.50419 .3266 Mdot
.50424 .3971 Mdot
.50429 .33947 Mdot
.50433 .2861 Mdot
.50438 .3851 Mdot
.50443 .17784 Mdot
.50448 .35512 Mdot
.50452 .19805 Mdot
.50457 .22934 Mdot
.50462 .34052 Mdot
.50467 .17767 Mdot
.50471 .38454 Mdot
.50476 .42234 Mdot
.50481 .31113 Mdot
.50486 .23349 Mdot
.5049 .34242 Mdot
.50495 .39986 Mdot
.505 .17079 Mdot
.50505 .25745 Mdot
.50509 .36105 Mdot
.50514 .21338 Mdot
.50519 .39506 Mdot
.50524 .1774 Mdot
.50529 .36128 Mdot
.50533 .34969 Mdot
.50538 .16581 Mdot
.50543 .30042 Mdot
.50548 .24261 Mdot
.50552 .42667 Mdot
.50557 .44984 Mdot
.50562 .40696 Mdot
.50567 .21117 Mdot
.50571 .36373 Mdot
.50576 .27551 Mdot
.50581 .39528 Mdot
.50586 .28727 Mdot
.5059 .40183 Mdot
.50595 .42461 Mdot
.506 .32696 Mdot
.50605 .40467 Mdot
.50609 .16672 Mdot
.50614 .41838 Mdot
.50619 .23385 Mdot
.50624 .20776 Mdot
.50629 .41213 Mdot
.50633 .18704 Mdot
.50638 .21997 Mdot
.50643 .30465 Mdot
.50648 .22555 Mdot
.50652 .18414 Mdot
.50657 .37711 Mdot
.50662 .22453 Mdot
.50667 .25603 Mdot
.50671 .19123 Mdot
.50676 .42688 Mdot
.50681 .17502 Mdot
.50686 .34862 Mdot
.5069 .37183 Mdot
.50695 .19265 Mdot
.507 .34345 Mdot
.50705 .40229 Mdot
.50709 .40251 Mdot
.50714 .32077 Mdot
.50719 .39366 Mdot
.50724 .39538 Mdot
.50728 .4386 Mdot
.50733 .24632 Mdot
.50738 .3451 Mdot
.50743 .4371 Mdot
.50748 .41035 Mdot
.50752 .18493 Mdot
.50757 .19883 Mdot
.50762 .36972 Mdot
.50767 .38417 Mdot
.50771 .26044 Mdot
.50776 .42672 Mdot
.50781 .27104 Mdot
.50786 .35008 Mdot
.5079 .28535 Mdot
.50795 .40842 Mdot
.508 .3738 Mdot
.50805 .42942 Mdot
.50809 .24882 Mdot
.50814 .22088 Mdot
.50819 .42207 Mdot
.50824 .1824 Mdot
.50828 .37819 Mdot
.50833 .27716 Mdot
.50838 .18157 Mdot
.50843 .19333 Mdot
.50848 .28634 Mdot
.50852 .38117 Mdot
.50857 .19338 Mdot
.50862 .23169 Mdot
.50867 .25505 Mdot
.50871 .33578 Mdot
.50876 .27175 Mdot
.50881 .29541 Mdot
.50886 .44229 Mdot
.5089 .35654 Mdot
.50895 .15313 Mdot
.509 .39239 Mdot
.50905 .30894 Mdot
.50909 .39476 Mdot
.50914 .22578 Mdot
.50919 .40921 Mdot
.50924 .21131 Mdot
.50928 .32486 Mdot
.50933 .24933 Mdot
.50938 .37737 Mdot
.50943 .27833 Mdot
.50948 .19786 Mdot
.50952 .21771 Mdot
.50957 .33378 Mdot
.50962 .43638 Mdot
.50967 .26088 Mdot
.50971 .17346 Mdot
.50976 .25101 Mdot
.50981 .33005 Mdot
.50986 .36847 Mdot
.5099 .34487 Mdot
.50995 .39856 Mdot
.51 .33051 Mdot
.51005 .15963 Mdot
.51009 .33923 Mdot
.51014 .15345 Mdot
.51019 .16864 Mdot
.51024 .20659 Mdot
.51028 .26012 Mdot
.51033 .18556 Mdot
.51038 .39845 Mdot
.51043 .32264 Mdot
.51048 .15663 Mdot
.51052 .24869 Mdot
.51057 .26556 Mdot
.51062 .27001 Mdot
.51067 .3788 Mdot
.51071 .35459 Mdot
.51076 .26866 Mdot
.51081 .15355 Mdot
.51086 .34955 Mdot
.5109 .2476 Mdot
.51095 .37727 Mdot
.511 .22354 Mdot
.51105 .14808 Mdot
.51109 .28709 Mdot
.51114 .18975 Mdot
.51119 .2067 Mdot
.51124 .24629 Mdot
.51128 .27601 Mdot
.51133 .16328 Mdot
.51138 .14207 Mdot
.51143 .42279 Mdot
.51148 .23201 Mdot
.51152 .20104 Mdot
.51157 .25544 Mdot
.51162 .4071 Mdot
.51167 .41891 Mdot
.51171 .37087 Mdot
.51176 .42062 Mdot
.51181 .16843 Mdot
.51186 .20424 Mdot
.5119 .24193 Mdot
.51195 .40658 Mdot
.512 .25305 Mdot
.51205 .39062 Mdot
.51209 .29843 Mdot
.51214 .32175 Mdot
.51219 .24347 Mdot
.51224 .24183 Mdot
.51228 .24677 Mdot
.51233 .25295 Mdot
.51238 .13488 Mdot
.51243 .39817 Mdot
.51247 .22078 Mdot
.51252 .24796 Mdot
.51257 .14382 Mdot
.51262 .30283 Mdot
.51267 .15621 Mdot
.51271 .42364 Mdot
.51276 .16764 Mdot
.51281 .31464 Mdot
.51286 .21586 Mdot
.5129 .13848 Mdot
.51295 .13446 Mdot
.513 .24545 Mdot
.51305 .40363 Mdot
.51309 .1614 Mdot
.51314 .31072 Mdot
.51319 .28393 Mdot
.51324 .23925 Mdot
.51328 .26835 Mdot
.51333 .20088 Mdot
.51338 .17553 Mdot
.51343 .42056 Mdot
.51347 .14843 Mdot
.51352 .19883 Mdot
.51357 .20485 Mdot
.51362 .33221 Mdot
.51367 .32755 Mdot
.51371 .18703 Mdot
.51376 .32869 Mdot
.51381 .30761 Mdot
.51386 .33018 Mdot
.5139 .15061 Mdot
.51395 .14506 Mdot
.514 .22256 Mdot
.51405 .3223 Mdot
.51409 .14655 Mdot
.51414 .32468 Mdot
.51419 .24379 Mdot
.51424 .29071 Mdot
.51428 .26029 Mdot
.51433 .17015 Mdot
.51438 .13375 Mdot
.51443 .15136 Mdot
.51447 .18821 Mdot
.51452 .41807 Mdot
.51457 .13644 Mdot
.51462 .13113 Mdot
.51467 .41223 Mdot
.51471 .34101 Mdot
.51476 .22668 Mdot
.51481 .22584 Mdot
.51486 .3524 Mdot
.5149 .13932 Mdot
.51495 .34072 Mdot
.515 .31711 Mdot
.51505 .32818 Mdot
.51509 .41531 Mdot
.51514 .24416 Mdot
.51519 .41546 Mdot
.51524 .30723 Mdot
.51528 .21603 Mdot
.51533 .12556 Mdot
.51538 .24975 Mdot
.51543 .17173 Mdot
.51547 .17048 Mdot
.51552 .41107 Mdot
.51557 .22259 Mdot
.51562 .40238 Mdot
.51567 .17107 Mdot
.51571 .39824 Mdot
.51576 .21486 Mdot
.51581 .4082 Mdot
.51586 .24791 Mdot
.5159 .29436 Mdot
.51595 .40649 Mdot
.516 .17822 Mdot
.51605 .23081 Mdot
.51609 .37051 Mdot
.51614 .2112 Mdot
.51619 .2665 Mdot
.51624 .23178 Mdot
.51628 .24757 Mdot
.51633 .21161 Mdot
.51638 .37496 Mdot
.51643 .13637 Mdot
.51647 .24244 Mdot
.51652 .37695 Mdot
.51657 .32326 Mdot
.51662 .38059 Mdot
.51667 .24586 Mdot
.51671 .2738 Mdot
.51676 .33498 Mdot
.51681 .32857 Mdot
.51686 .26133 Mdot
.5169 .17759 Mdot
.51695 .34009 Mdot
.517 .19891 Mdot
.51705 .37988 Mdot
.51709 .18382 Mdot
.51714 .27954 Mdot
.51719 .38043 Mdot
.51724 .12665 Mdot
.51728 .38455 Mdot
.51733 .12992 Mdot
.51738 .26534 Mdot
.51743 .29043 Mdot
.51747 .28923 Mdot
.51752 .16592 Mdot
.51757 .24487 Mdot
.51762 .1637 Mdot
.51766 .32265 Mdot
.51771 .25283 Mdot
.51776 .27426 Mdot
.51781 .32762 Mdot
.51786 .16358 Mdot
.5179 .32724 Mdot
.51795 .35488 Mdot
.518 .18044 Mdot
.51805 .3948 Mdot
.51809 .39576 Mdot
.51814 .26953 Mdot
.51819 .20877 Mdot
.51824 .32415 Mdot
.51828 .22919 Mdot
.51833 .29673 Mdot
.51838 .1947 Mdot
.51843 .34685 Mdot
.51847 .21147 Mdot
.51852 .14339 Mdot
.51857 .31094 Mdot
.51862 .16923 Mdot
.51866 .15698 Mdot
.51871 .30461 Mdot
.51876 .25828 Mdot
.51881 .25228 Mdot
.51886 .30965 Mdot
.5189 .14081 Mdot
.51895 .33577 Mdot
.519 .19876 Mdot
.51905 .38715 Mdot
.51909 .19047 Mdot
.51914 .26483 Mdot
.51919 .20812 Mdot
.51924 .39535 Mdot
.51928 .32471 Mdot
.51933 .16478 Mdot
.51938 .28735 Mdot
.51943 .27449 Mdot
.51947 .13612 Mdot
.51952 .37288 Mdot
.51957 .34312 Mdot
.51962 .17059 Mdot
.51966 .39496 Mdot
.51971 .16913 Mdot
.51976 .28088 Mdot
.51981 .12041 Mdot
.51986 .19696 Mdot
.5199 .31213 Mdot
.51995 .13484 Mdot
.52 .21165 Mdot
.52005 .162 Mdot
.52009 .37686 Mdot
.52014 .3364 Mdot
.52019 .22464 Mdot
.52024 .37147 Mdot
.52028 .21693 Mdot
.52033 .23298 Mdot
.52038 .22866 Mdot
.52043 .15109 Mdot
.52047 .15629 Mdot
.52052 .34444 Mdot
.52057 .35278 Mdot
.52062 .11854 Mdot
.52066 .18164 Mdot
.52071 .1045 Mdot
.52076 .28519 Mdot
.52081 .12125 Mdot
.52086 .11514 Mdot
.5209 .22091 Mdot
.52095 .26702 Mdot
.521 .3212 Mdot
.52105 .19974 Mdot
.52109 .18775 Mdot
.52114 .15686 Mdot
.52119 .2605 Mdot
.52124 .21884 Mdot
.52128 .24713 Mdot
.52133 .32782 Mdot
.52138 .28444 Mdot
.52143 .10227 Mdot
.52147 .11433 Mdot
.52152 .19915 Mdot
.52157 .23315 Mdot
.52162 .34045 Mdot
.52166 .16417 Mdot
.52171 .24047 Mdot
.52176 .21366 Mdot
.52181 .25768 Mdot
.52185 .15835 Mdot
.5219 .34864 Mdot
.52195 .19072 Mdot
.522 .24066 Mdot
.52205 .33023 Mdot
.52209 .17937 Mdot
.52214 .26194 Mdot
.52219 .1383 Mdot
.52224 .23968 Mdot
.52228 .11952 Mdot
.52233 .09826 Mdot
.52238 .31096 Mdot
.52243 .38386 Mdot
.52247 .18283 Mdot
.52252 .20476 Mdot
.52257 .30458 Mdot
.52262 .36525 Mdot
.52266 .37407 Mdot
.52271 .36182 Mdot
.52276 .35415 Mdot
.52281 .29605 Mdot
.52285 .2284 Mdot
.5229 .24277 Mdot
.52295 .1909 Mdot
.523 .23195 Mdot
.52305 .26868 Mdot
.52309 .14593 Mdot
.52314 .33879 Mdot
.52319 .29008 Mdot
.52324 .18264 Mdot
.52328 .272 Mdot
.52333 .29345 Mdot
.52338 .14318 Mdot
.52343 .15572 Mdot
.52347 .26615 Mdot
.52352 .36959 Mdot
.52357 .14624 Mdot
.52362 .35962 Mdot
.52366 .15308 Mdot
.52371 .15651 Mdot
.52376 .16718 Mdot
.52381 .37155 Mdot
.52385 .17708 Mdot
.5239 .18801 Mdot
.52395 .25659 Mdot
.524 .23358 Mdot
.52405 .31941 Mdot
.52409 .08717 Mdot
.52414 .11452 Mdot
.52419 .34946 Mdot
.52424 .263 Mdot
.52428 .13258 Mdot
.52433 .20846 Mdot
.52438 .2558 Mdot
.52443 .37467 Mdot
.52447 .22261 Mdot
.52452 .15373 Mdot
.52457 .18835 Mdot
.52462 .1966 Mdot
.52466 .23579 Mdot
.52471 .09522 Mdot
.52476 .21115 Mdot
.52481 .13089 Mdot
.52485 .16647 Mdot
.5249 .30992 Mdot
.52495 .2213 Mdot
.525 .33533 Mdot
.52505 .35981 Mdot
.52509 .13964 Mdot
.52514 .36871 Mdot
.52519 .10188 Mdot
.52524 .35842 Mdot
.52528 .11072 Mdot
.52533 .10468 Mdot
.52538 .21898 Mdot
.52543 .31091 Mdot
.52547 .28201 Mdot
.52552 .22845 Mdot
.52557 .22372 Mdot
.52562 .17268 Mdot
.52566 .21247 Mdot
.52571 .12412 Mdot
.52576 .11096 Mdot
.52581 .31541 Mdot
.52585 .20075 Mdot
.5259 .29115 Mdot
.52595 .35807 Mdot
.526 .23191 Mdot
.52605 .26848 Mdot
.52609 .15247 Mdot
.52614 .10518 Mdot
.52619 .24923 Mdot
.52624 .21094 Mdot
.52628 .16054 Mdot
.52633 .08506 Mdot
.52638 .26725 Mdot
.52643 .18163 Mdot
.52647 .1371 Mdot
.52652 .24199 Mdot
.52657 .33208 Mdot
.52662 .2752 Mdot
.52666 .28405 Mdot
.52671 .09865 Mdot
.52676 .2396 Mdot
.52681 .14275 Mdot
.52685 .23978 Mdot
.5269 .36222 Mdot
.52695 .29856 Mdot
.527 .3162 Mdot
.52704 .32266 Mdot
.52709 .08316 Mdot
.52714 .14548 Mdot
.52719 .12638 Mdot
.52724 .24867 Mdot
.52728 .35115 Mdot
.52733 .26925 Mdot
.52738 .28827 Mdot
.52743 .16594 Mdot
.52747 .34373 Mdot
.52752 .07947 Mdot
.52757 .18394 Mdot
.52762 .10597 Mdot
.52766 .1787 Mdot
.52771 .11904 Mdot
.52776 .28022 Mdot
.52781 .19324 Mdot
.52785 .15634 Mdot
.5279 .25042 Mdot
.52795 .21342 Mdot
.528 .32409 Mdot
.52804 .16459 Mdot
.52809 .32216 Mdot
.52814 .26736 Mdot
.52819 .07655 Mdot
.52824 .15638 Mdot
.52828 .25147 Mdot
.52833 .2156 Mdot
.52838 .19718 Mdot
.52843 .17437 Mdot
.52847 .35119 Mdot
.52852 .29614 Mdot
.52857 .10502 Mdot
.52862 .19911 Mdot
.52866 .34517 Mdot
.52871 .18549 Mdot
.52876 .07218 Mdot
.52881 .09337 Mdot
.52885 .29892 Mdot
.5289 .27275 Mdot
.52895 .24626 Mdot
.529 .30418 Mdot
.52904 .12064 Mdot
.52909 .1313 Mdot
.52914 .28883 Mdot
.52919 .21123 Mdot
.52924 .16481 Mdot
.52928 .23011 Mdot
.52933 .28344 Mdot
.52938 .12584 Mdot
.52943 .27903 Mdot
.52947 .08518 Mdot
.52952 .15676 Mdot
.52957 .31667 Mdot
.52962 .29288 Mdot
.52966 .15392 Mdot
.52971 .1216 Mdot
.52976 .18726 Mdot
.52981 .3121 Mdot
.52985 .33267 Mdot
.5299 .11863 Mdot
.52995 .16294 Mdot
.53 .08208 Mdot
.53004 .12865 Mdot
.53009 .2358 Mdot
.53014 .22203 Mdot
.53019 .32455 Mdot
.53024 .06544 Mdot
.53028 .30975 Mdot
.53033 .07858 Mdot
.53038 .22736 Mdot
.53043 .19764 Mdot
.53047 .09361 Mdot
.53052 .31473 Mdot
.53057 .31016 Mdot
.53062 .17928 Mdot
.53066 .29837 Mdot
.53071 .06456 Mdot
.53076 .08363 Mdot
.53081 .09155 Mdot
.53085 .24281 Mdot
.5309 .23804 Mdot
.53095 .13211 Mdot
.531 .1193 Mdot
.53104 .18958 Mdot
.53109 .14035 Mdot
.53114 .11513 Mdot
.53119 .35045 Mdot
.53123 .31342 Mdot
.53128 .2778 Mdot
.53133 .14991 Mdot
.53138 .34932 Mdot
.53143 .06783 Mdot
.53147 .26323 Mdot
.53152 .28126 Mdot
.53157 .21539 Mdot
.53162 .33262 Mdot
.53166 .30675 Mdot
.53171 .32919 Mdot
.53176 .09919 Mdot
.53181 .09718 Mdot
.53185 .30496 Mdot
.5319 .30818 Mdot
.53195 .07012 Mdot
.532 .21155 Mdot
.53204 .12909 Mdot
.53209 .23808 Mdot
.53214 .30754 Mdot
.53219 .08367 Mdot
.53223 .34516 Mdot
.53228 .18436 Mdot
.53233 .3132 Mdot
.53238 .12621 Mdot
.53243 .12831 Mdot
.53247 .09526 Mdot
.53252 .31938 Mdot
.53257 .11888 Mdot
.53262 .22029 Mdot
.53266 .16905 Mdot
.53271 .16405 Mdot
.53276 .14102 Mdot
.53281 .26815 Mdot
.53285 .19432 Mdot
.5329 .12431 Mdot
.53295 .10314 Mdot
.533 .3172 Mdot
.53304 .24 Mdot
.53309 .11305 Mdot
.53314 .24516 Mdot
.53319 .24667 Mdot
.53323 .06034 Mdot
.53328 .15864 Mdot
.53333 .21961 Mdot
.53338 .25435 Mdot
.53343 .22866 Mdot
.53347 .19798 Mdot
.53352 .15094 Mdot
.53357 .18343 Mdot
.53362 .19065 Mdot
.53366 .23056 Mdot
.53371 .08902 Mdot
.53376 .3148 Mdot
.53381 .07826 Mdot
.53385 .12303 Mdot
.5339 .29923 Mdot
.53395 .10289 Mdot
.534 .23488 Mdot
.53404 .05466 Mdot
.53409 .25189 Mdot
.53414 .1362 Mdot
.53419 .34524 Mdot
.53423 .29182 Mdot
.53428 .06194 Mdot
.53433 .23946 Mdot
.53438 .33985 Mdot
.53443 .18798 Mdot
.53447 .19184 Mdot
.53452 .33448 Mdot
.53457 .16555 Mdot
.53462 .33908 Mdot
.53466 .09498 Mdot
.53471 .20499 Mdot
.53476 .32356 Mdot
.53481 .16218 Mdot
.53485 .05949 Mdot
.5349 .23843 Mdot
.53495 .29854 Mdot
.535 .09226 Mdot
.53504 .10807 Mdot
.53509 .18836 Mdot
.53514 .11635 Mdot
.53519 .09015 Mdot
.53523 .20345 Mdot
.53528 .10443 Mdot
.53533 .11808 Mdot
.53538 .14517 Mdot
.53543 .19336 Mdot
.53547 .21154 Mdot
.53552 .12467 Mdot
.53557 .30349 Mdot
.53562 .05282 Mdot
.53566 .22309 Mdot
.53571 .305 Mdot
.53576 .31016 Mdot
.53581 .30345 Mdot
.53585 .06871 Mdot
.5359 .32678 Mdot
.53595 .19832 Mdot
.536 .29417 Mdot
.53604 .17522 Mdot
.53609 .07817 Mdot
.53614 .15587 Mdot
.53619 .23577 Mdot
.53623 .33125 Mdot
.53628 .30609 Mdot
.53633 .115 Mdot
.53638 .08146 Mdot
.53642 .27582 Mdot
.53647 .23687 Mdot
.53652 .31342 Mdot
.53657 .23156 Mdot
.53662 .11275 Mdot
.53666 .16054 Mdot
.53671 .05814 Mdot
.53676 .22681 Mdot
.53681 .23246 Mdot
.53685 .1982 Mdot
.5369 .09052 Mdot
.53695 .26577 Mdot
.537 .21116 Mdot
.53704 .21357 Mdot
.53709 .23421 Mdot
.53714 .31348 Mdot
.53719 .08284 Mdot
.53723 .18216 Mdot
.53728 .12497 Mdot
.53733 .12422 Mdot
.53738 .09282 Mdot
.53742 .21718 Mdot
.53747 .0561 Mdot
.53752 .08876 Mdot
.53757 .15772 Mdot
.53762 .3209 Mdot
.53766 .08314 Mdot
.53771 .19754 Mdot
.53776 .09033 Mdot
.53781 .20559 Mdot
.53785 .0701 Mdot
.5379 .31055 Mdot
.53795 .19758 Mdot
.538 .05211 Mdot
.53804 .31903 Mdot
.53809 .08925 Mdot
.53814 .32561 Mdot
.53819 .17762 Mdot
.53823 .12892 Mdot
.53828 .1146 Mdot
.53833 .28662 Mdot
.53838 .33403 Mdot
.53842 .04754 Mdot
.53847 .3287 Mdot
.53852 .23714 Mdot
.53857 .16007 Mdot
.53862 .3294 Mdot
.53866 .28292 Mdot
.53871 .12228 Mdot
.53876 .17676 Mdot
.53881 .28887 Mdot
.53885 .12788 Mdot
.5389 .07431 Mdot
.53895 .30827 Mdot
.539 .2609 Mdot
.53904 .15418 Mdot
.53909 .21348 Mdot
.53914 .29792 Mdot
.53919 .27836 Mdot
.53923 .10645 Mdot
.53928 .22412 Mdot
.53933 .16159 Mdot
.53938 .19061 Mdot
.53942 .32775 Mdot
.53947 .27328 Mdot
.53952 .16322 Mdot
.53957 .18375 Mdot
.53962 .03962 Mdot
.53966 .07659 Mdot
.53971 .04348 Mdot
.53976 .18942 Mdot
.53981 .09165 Mdot
.53985 .28915 Mdot
.5399 .20144 Mdot
.53995 .23515 Mdot
.54 .29826 Mdot
.54004 .25435 Mdot
.54009 .22742 Mdot
.54014 .30839 Mdot
.54019 .18325 Mdot
.54023 .07993 Mdot
.54028 .26329 Mdot
.54033 .06885 Mdot
.54038 .1155 Mdot
.54042 .18926 Mdot
.54047 .14018 Mdot
.54052 .21147 Mdot
.54057 .12086 Mdot
.54061 .24897 Mdot
.54066 .30985 Mdot
.54071 .06563 Mdot
.54076 .11904 Mdot
.54081 .21007 Mdot
.54085 .30395 Mdot
.5409 .20853 Mdot
.54095 .06474 Mdot
.541 .25301 Mdot
.54104 .13964 Mdot
.54109 .30526 Mdot
.54114 .09825 Mdot
.54119 .03546 Mdot
.54123 .24377 Mdot
.54128 .3283 Mdot
.54133 .24633 Mdot
.54138 .28674 Mdot
.54142 .31158 Mdot
.54147 .29559 Mdot
.54152 .16686 Mdot
.54157 .13341 Mdot
.54161 .20721 Mdot
.54166 .11983 Mdot
.54171 .0816 Mdot
.54176 .21479 Mdot
.54181 .22761 Mdot
.54185 .08948 Mdot
.5419 .29259 Mdot
.54195 .03979 Mdot
.542 .25347 Mdot
.54204 .21065 Mdot
.54209 .26259 Mdot
.54214 .11628 Mdot
.54219 .14837 Mdot
.54223 .23468 Mdot
.54228 .19867 Mdot
.54233 .11504 Mdot
.54238 .23357 Mdot
.54242 .23525 Mdot
.54247 .28111 Mdot
.54252 .15696 Mdot
.54257 .25055 Mdot
.54261 .26811 Mdot
.54266 .14774 Mdot
.54271 .05695 Mdot
.54276 .07663 Mdot
.54281 .18147 Mdot
.54285 .09923 Mdot
.5429 .17 Mdot
.54295 .17676 Mdot
.543 .12478 Mdot
.54304 .13418 Mdot
.54309 .16279 Mdot
.54314 .25063 Mdot
.54319 .24136 Mdot
.54323 .19873 Mdot
.54328 .07869 Mdot
.54333 .13434 Mdot
.54338 .03867 Mdot
.54342 .03195 Mdot
.54347 .29029 Mdot
.54352 .22732 Mdot
.54357 .12987 Mdot
.54361 .07719 Mdot
.54366 .16473 Mdot
.54371 .30292 Mdot
.54376 .18782 Mdot
.54381 .25541 Mdot
.54385 .13879 Mdot
.5439 .25721 Mdot
.54395 .03717 Mdot
.544 .1869 Mdot
.54404 .29428 Mdot
.54409 .11098 Mdot
.54414 .23768 Mdot
.54419 .08306 Mdot
.54423 .16173 Mdot
.54428 .18536 Mdot
.54433 .32123 Mdot
.54438 .20915 Mdot
.54442 .11291 Mdot
.54447 .0808 Mdot
.54452 .31225 Mdot
.54457 .20679 Mdot
.54461 .14698 Mdot
.54466 .17774 Mdot
.54471 .21169 Mdot
.54476 .15882 Mdot
.54481 .30624 Mdot
.54485 .19872 Mdot
.5449 .05283 Mdot
.54495 .22712 Mdot
.545 .19622 Mdot
.54504 .26504 Mdot
.54509 .04425 Mdot
.54514 .06872 Mdot
.54519 .22521 Mdot
.54523 .18238 Mdot
.54528 .12965 Mdot
.54533 .30867 Mdot
.54538 .09154 Mdot
.54542 .31985 Mdot
.54547 .13116 Mdot
.54552 .12731 Mdot
.54557 .30118 Mdot
.54561 .26667 Mdot
.54566 .14129 Mdot
.54571 .24283 Mdot
.54576 .18157 Mdot
.5458 .1162 Mdot
.54585 .25164 Mdot
.5459 .11111 Mdot
.54595 .1972 Mdot
.546 .23927 Mdot
.54604 .22567 Mdot
.54609 .20561 Mdot
.54614 .02766 Mdot
.54619 .29568 Mdot
.54623 .20793 Mdot
.54628 .16332 Mdot
.54633 .12364 Mdot
.54638 .13956 Mdot
.54642 .10446 Mdot
.54647 .17561 Mdot
.54652 .05812 Mdot
.54657 .1405 Mdot
.54661 .29401 Mdot
.54666 .07406 Mdot
.54671 .07748 Mdot
.54676 .1943 Mdot
.5468 .17824 Mdot
.54685 .15154 Mdot
.5469 .21614 Mdot
.54695 .10339 Mdot
.547 .24667 Mdot
.54704 .06556 Mdot
.54709 .044 Mdot
.54714 .18395 Mdot
.54719 .0459 Mdot
.54723 .17963 Mdot
.54728 .04108 Mdot
.54733 .20779 Mdot
.54738 .15741 Mdot
.54742 .04082 Mdot
.54747 .23673 Mdot
.54752 .09259 Mdot
.54757 .07723 Mdot
.54761 .18427 Mdot
.54766 .20273 Mdot
.54771 .27099 Mdot
.54776 .10206 Mdot
.5478 .13411 Mdot
.54785 .14908 Mdot
.5479 .10045 Mdot
.54795 .24235 Mdot
.548 .30103 Mdot
.54804 .25132 Mdot
.54809 .31537 Mdot
.54814 .31392 Mdot
.54819 .25878 Mdot
.54823 .23056 Mdot
.54828 .15459 Mdot
.54833 .29112 Mdot
.54838 .10218 Mdot
.54842 .21243 Mdot
.54847 .26454 Mdot
.54852 .15652 Mdot
.54857 .0841 Mdot
.54861 .29323 Mdot
.54866 .19456 Mdot
.54871 .10182 Mdot
.54876 .21715 Mdot
.5488 .11289 Mdot
.54885 .24075 Mdot
.5489 .02202 Mdot
.54895 .10523 Mdot
.549 .28079 Mdot
.54904 .16235 Mdot
.54909 .09651 Mdot
.54914 .12097 Mdot
.54919 .05132 Mdot
.54923 .16362 Mdot
.54928 .09916 Mdot
.54933 .1787 Mdot
.54938 .1372 Mdot
.54942 .03054 Mdot
.54947 .12435 Mdot
.54952 .09791 Mdot
.54957 .24094 Mdot
.54961 .08211 Mdot
.54966 .28388 Mdot
.54971 .03494 Mdot
.54976 .26363 Mdot
.5498 .20341 Mdot
.54985 .20299 Mdot
.5499 .13353 Mdot
.54995 .17156 Mdot
.55 .27827 Mdot
.55004 .20166 Mdot
.55009 .04892 Mdot
.55014 .20619 Mdot
.55019 .13642 Mdot
.55023 .12559 Mdot
.55028 .24319 Mdot
.55033 .1752 Mdot
.55038 .28793 Mdot
.55042 .04663 Mdot
.55047 .08463 Mdot
.55052 .05808 Mdot
.55057 .27741 Mdot
.55061 .2371 Mdot
.55066 .30148 Mdot
.55071 .13185 Mdot
.55076 .21509 Mdot
.5508 .26781 Mdot
.55085 .28621 Mdot
.5509 .18269 Mdot
.55095 .03124 Mdot
.55099 .08432 Mdot
.55104 .17214 Mdot
.55109 .03052 Mdot
.55114 .06716 Mdot
.55119 .1968 Mdot
.55123 .14244 Mdot
.55128 .13836 Mdot
.55133 .24471 Mdot
.55138 .09028 Mdot
.55142 .21311 Mdot
.55147 .27697 Mdot
.55152 .27055 Mdot
.55157 .0625 Mdot
.55161 .14728 Mdot
.55166 .23763 Mdot
.55171 .30668 Mdot
.55176 .13889 Mdot
.5518 .15924 Mdot
.55185 .12432 Mdot
.5519 .11008 Mdot
.55195 .18437 Mdot
.55199 .18626 Mdot
.55204 .25482 Mdot
.55209 .09711 Mdot
.55214 .11827 Mdot
.55219 .03231 Mdot
.55223 .24243 Mdot
.55228 .04803 Mdot
.55233 .23436 Mdot
.55238 .20271 Mdot
.55242 .12201 Mdot
.55247 .11606 Mdot
.55252 .16192 Mdot
.55257 .30225 Mdot
.55261 .15764 Mdot
.55266 .15807 Mdot
.55271 .11708 Mdot
.55276 .17258 Mdot
.5528 .23242 Mdot
.55285 .16376 Mdot
.5529 .29051 Mdot
.55295 .03077 Mdot
.55299 .12547 Mdot
.55304 .07102 Mdot
.55309 .12344 Mdot
.55314 .1566 Mdot
.55319 .18271 Mdot
.55323 .28592 Mdot
.55328 .02228 Mdot
.55333 .14137 Mdot
.55338 .25217 Mdot
.55342 .25488 Mdot
.55347 .09972 Mdot
.55352 .25041 Mdot
.55357 .14702 Mdot
.55361 .15564 Mdot
.55366 .24943 Mdot
.55371 .25976 Mdot
.55376 .30094 Mdot
.5538 .30908 Mdot
.55385 .14897 Mdot
.5539 .10376 Mdot
.55395 .08506 Mdot
.55399 .16182 Mdot
.55404 .16977 Mdot
.55409 .08942 Mdot
.55414 .27083 Mdot
.55419 .10715 Mdot
.55423 .06265 Mdot
.55428 .24394 Mdot
.55433 .10436 Mdot
.55438 .13228 Mdot
.55442 .05653 Mdot
.55447 .1187 Mdot
.55452 .16314 Mdot
.55457 .18832 Mdot
.55461 .26769 Mdot
.55466 .17913 Mdot
.55471 .03207 Mdot
.55476 .0486 Mdot
.5548 .03414 Mdot
.55485 .23007 Mdot
.5549 .04179 Mdot
.55495 .05015 Mdot
.55499 .19577 Mdot
.55504 .14203 Mdot
.55509 .26727 Mdot
.55514 .19884 Mdot
.55518 .04161 Mdot
.55523 .0682 Mdot
.55528 .30685 Mdot
.55533 .10722 Mdot
.55538 .28932 Mdot
.55542 .13458 Mdot
.55547 .21793 Mdot
.55552 .28519 Mdot
.55557 .24816 Mdot
.55561 .03122 Mdot
.55566 .0701 Mdot
.55571 .11216 Mdot
.55576 .29058 Mdot
.5558 .16218 Mdot
.55585 .05324 Mdot
.5559 .07873 Mdot
.55595 .27159 Mdot
.55599 .24208 Mdot
.55604 .02654 Mdot
.55609 .04364 Mdot
.55614 .09086 Mdot
.55618 .11507 Mdot
.55623 .06911 Mdot
.55628 .15462 Mdot
.55633 .06418 Mdot
.55638 .06178 Mdot
.55642 .07201 Mdot
.55647 .06227 Mdot
.55652 .08456 Mdot
.55657 .23688 Mdot
.55661 .16373 Mdot
.55666 .08671 Mdot
.55671 .14601 Mdot
.55676 .22038 Mdot
.5568 .10833 Mdot
.55685 .28409 Mdot
.5569 .16495 Mdot
.55695 .07284 Mdot
.55699 .0697 Mdot
.55704 .21995 Mdot
.55709 .20279 Mdot
.55714 .14017 Mdot
.55718 .0577 Mdot
.55723 .19082 Mdot
.55728 .12642 Mdot
.55733 .03958 Mdot
.55738 .2979 Mdot
.55742 .05064 Mdot
.55747 .07666 Mdot
.55752 .28706 Mdot
.55757 .24028 Mdot
.55761 .29759 Mdot
.55766 .30131 Mdot
.55771 .06452 Mdot
.55776 .09087 Mdot
.5578 .22518 Mdot
.55785 .16958 Mdot
.5579 .15326 Mdot
.55795 .29165 Mdot
.55799 .25019 Mdot
.55804 .01886 Mdot
.55809 .09463 Mdot
.55814 .23615 Mdot
.55818 .04442 Mdot
.55823 .1251 Mdot
.55828 .26348 Mdot
.55833 .19259 Mdot
.55838 .16259 Mdot
.55842 .30765 Mdot
.55847 .238 Mdot
.55852 .20363 Mdot
.55857 .12603 Mdot
.55861 .24506 Mdot
.55866 .25986 Mdot
.55871 .27225 Mdot
.55876 .13733 Mdot
.5588 .25264 Mdot
.55885 .20936 Mdot
.5589 .19539 Mdot
.55895 .22101 Mdot
.55899 .09704 Mdot
.55904 .07008 Mdot
.55909 .21257 Mdot
.55914 .27963 Mdot
.55918 .09214 Mdot
.55923 .28425 Mdot
.55928 .28522 Mdot
.55933 .24915 Mdot
.55938 .27583 Mdot
.55942 .03469 Mdot
.55947 .10655 Mdot
.55952 .10047 Mdot
.55957 .27694 Mdot
.55961 .10545 Mdot
.55966 .21166 Mdot
.55971 .28318 Mdot
.55976 .04576 Mdot
.5598 .15432 Mdot
.55985 .24814 Mdot
.5599 .15972 Mdot
.55995 .10185 Mdot
.55999 .25369 Mdot
.56004 .06661 Mdot
.56009 .24743 Mdot
.56014 .01867 Mdot
.56018 .19747 Mdot
.56023 .16276 Mdot
.56028 .27651 Mdot
.56033 .23523 Mdot
.56037 .22193 Mdot
.56042 .18625 Mdot
.56047 .04121 Mdot
.56052 .26812 Mdot
.56057 .20109 Mdot
.56061 .09355 Mdot
.56066 .24945 Mdot
.56071 .29989 Mdot
.56076 .1095 Mdot
.5608 .1906 Mdot
.56085 .27499 Mdot
.5609 .26799 Mdot
.56095 .2639 Mdot
.56099 .25119 Mdot
.56104 .12914 Mdot
.56109 .18002 Mdot
.56114 .02409 Mdot
.56118 .19846 Mdot
.56123 .19046 Mdot
.56128 .17524 Mdot
.56133 .13538 Mdot
.56137 .0496 Mdot
.56142 .22272 Mdot
.56147 .24878 Mdot
.56152 .22222 Mdot
.56157 .17214 Mdot
.56161 .19544 Mdot
.56166 .28946 Mdot
.56171 .03508 Mdot
.56176 .09254 Mdot
.5618 .25481 Mdot
.56185 .2984 Mdot
.5619 .23441 Mdot
.56195 .21078 Mdot
.56199 .28867 Mdot
.56204 .04441 Mdot
.56209 .27938 Mdot
.56214 .26848 Mdot
.56218 .17357 Mdot
.56223 .1733 Mdot
.56228 .26935 Mdot
.56233 .0841 Mdot
.56237 .29205 Mdot
.56242 .307 Mdot
.56247 .14808 Mdot
.56252 .04861 Mdot
.56257 .08346 Mdot
.56261 .07236 Mdot
.56266 .23487 Mdot
.56271 .1855 Mdot
.56276 .19705 Mdot
.5628 .09196 Mdot
.56285 .214 Mdot
.5629 .10719 Mdot
.56295 .25134 Mdot
.56299 .10267 Mdot
.56304 .28872 Mdot
.56309 .20554 Mdot
.56314 .27183 Mdot
.56318 .07258 Mdot
.56323 .02367 Mdot
.56328 .24627 Mdot
.56333 .11263 Mdot
.56337 .20852 Mdot
.56342 .06358 Mdot
.56347 .17659 Mdot
.56352 .12988 Mdot
.56357 .21083 Mdot
.56361 .22484 Mdot
.56366 .14247 Mdot
.56371 .06094 Mdot
.56376 .153 Mdot
.5638 .29938 Mdot
.56385 .2664 Mdot
.5639 .17334 Mdot
.56395 .07566 Mdot
.56399 .10002 Mdot
.56404 .17388 Mdot
.56409 .23153 Mdot
.56414 .28255 Mdot
.56418 .12088 Mdot
.56423 .27794 Mdot
.56428 .26933 Mdot
.56433 .22477 Mdot
.56437 .11202 Mdot
.56442 .04651 Mdot
.56447 .17156 Mdot
.56452 .03114 Mdot
.56456 .06335 Mdot
.56461 .17971 Mdot
.56466 .05665 Mdot
.56471 .13015 Mdot
.56476 .14838 Mdot
.5648 .05228 Mdot
.56485 .30563 Mdot
.5649 .2871 Mdot
.56495 .15898 Mdot
.56499 .09588 Mdot
.56504 .14747 Mdot
.56509 .22664 Mdot
.56514 .07419 Mdot
.56518 .23212 Mdot
.56523 .22608 Mdot
.56528 .25426 Mdot
.56533 .26351 Mdot
.56537 .26441 Mdot
.56542 .26701 Mdot
.56547 .04492 Mdot
.56552 .16696 Mdot
.56556 .2334 Mdot
.56561 .11097 Mdot
.56566 .02934 Mdot
.56571 .11919 Mdot
.56576 .0693 Mdot
.5658 .06997 Mdot
.56585 .20973 Mdot
.5659 .28138 Mdot
.56595 .03277 Mdot
.56599 .07498 Mdot
.56604 .2333 Mdot
.56609 .13826 Mdot
.56614 .24763 Mdot
.56618 .23828 Mdot
.56623 .02261 Mdot
.56628 .08005 Mdot
.56633 .03153 Mdot
.56637 .02825 Mdot
.56642 .07929 Mdot
.56647 .12752 Mdot
.56652 .07813 Mdot
.56656 .0723 Mdot
.56661 .05061 Mdot
.56666 .2717 Mdot
.56671 .1559 Mdot
.56676 .27254 Mdot
.5668 .03765 Mdot
.56685 .16893 Mdot
.5669 .10306 Mdot
.56695 .21907 Mdot
.56699 .13933 Mdot
.56704 .19898 Mdot
.56709 .08691 Mdot
.56714 .16075 Mdot
.56718 .21758 Mdot
.56723 .07746 Mdot
.56728 .15092 Mdot
.56733 .23415 Mdot
.56737 .21184 Mdot
.56742 .30917 Mdot
.56747 .13634 Mdot
.56752 .22288 Mdot
.56756 .14958 Mdot
.56761 .19872 Mdot
.56766 .07532 Mdot
.56771 .16774 Mdot
.56776 .11617 Mdot
.5678 .23913 Mdot
.56785 .23157 Mdot
.5679 .20739 Mdot
.56795 .09589 Mdot
.56799 .08763 Mdot
.56804 .14598 Mdot
.56809 .3007 Mdot
.56814 .26898 Mdot
.56818 .20111 Mdot
.56823 .07672 Mdot
.56828 .15765 Mdot
.56833 .06915 Mdot
.56837 .14144 Mdot
.56842 .2385 Mdot
.56847 .23625 Mdot
.56852 .1701 Mdot
.56856 .14511 Mdot
.56861 .12019 Mdot
.56866 .03145 Mdot
.56871 .03865 Mdot
.56876 .25942 Mdot
.5688 .0631 Mdot
.56885 .17685 Mdot
.5689 .23567 Mdot
.56895 .03867 Mdot
.56899 .14482 Mdot
.56904 .28279 Mdot
.56909 .15831 Mdot
.56914 .26449 Mdot
.56918 .31234 Mdot
.56923 .29564 Mdot
.56928 .20292 Mdot
.56933 .08217 Mdot
.56937 .25447 Mdot
.56942 .1569 Mdot
.56947 .15273 Mdot
.56952 .2546 Mdot
.56956 .03503 Mdot
.56961 .23462 Mdot
.56966 .29666 Mdot
.56971 .12871 Mdot
.56975 .22898 Mdot
.5698 .22251 Mdot
.56985 .2774 Mdot
.5699 .1836 Mdot
.56995 .18539 Mdot
.56999 .06522 Mdot
.57004 .06135 Mdot
.57009 .1646 Mdot
.57014 .0603 Mdot
.57018 .09708 Mdot
.57023 .21775 Mdot
.57028 .21488 Mdot
.57033 .06279 Mdot
.57037 .11631 Mdot
.57042 .03491 Mdot
.57047 .15285 Mdot
.57052 .12338 Mdot
.57056 .27454 Mdot
.57061 .19735 Mdot
.57066 .21349 Mdot
.57071 .10879 Mdot
.57075 .06042 Mdot
.5708 .21611 Mdot
.57085 .10541 Mdot
.5709 .19536 Mdot
.57095 .15352 Mdot
.57099 .25438 Mdot
.57104 .23754 Mdot
.57109 .03091 Mdot
.57114 .10929 Mdot
.57118 .21409 Mdot
.57123 .09407 Mdot
.57128 .28665 Mdot
.57133 .03348 Mdot
.57137 .31253 Mdot
.57142 .19543 Mdot
.57147 .24532 Mdot
.57152 .23354 Mdot
.57156 .2992 Mdot
.57161 .06423 Mdot
.57166 .14365 Mdot
.57171 .27564 Mdot
.57175 .1237 Mdot
.5718 .16751 Mdot
.57185 .05684 Mdot
.5719 .23727 Mdot
.57195 .22456 Mdot
.57199 .08429 Mdot
.57204 .1786 Mdot
.57209 .10608 Mdot
.57214 .28743 Mdot
.57218 .16407 Mdot
.57223 .17022 Mdot
.57228 .31424 Mdot
.57233 .096 Mdot
.57237 .09274 Mdot
.57242 .20124 Mdot
.57247 .30365 Mdot
.57252 .10129 Mdot
.57256 .21519 Mdot
.57261 .27387 Mdot
.57266 .09328 Mdot
.57271 .12018 Mdot
.57275 .17427 Mdot
.5728 .15361 Mdot
.57285 .13596 Mdot
.5729 .31487 Mdot
.57295 .03036 Mdot
.57299 .12045 Mdot
.57304 .2173 Mdot
.57309 .11414 Mdot
.57314 .26482 Mdot
.57318 .26068 Mdot
.57323 .13527 Mdot
.57328 .14569 Mdot
.57333 .12495 Mdot
.57337 .11474 Mdot
.57342 .14024 Mdot
.57347 .07412 Mdot
.57352 .05672 Mdot
.57356 .23294 Mdot
.57361 .15611 Mdot
.57366 .29243 Mdot
.57371 .1612 Mdot
.57375 .27882 Mdot
.5738 .08781 Mdot
.57385 .1973 Mdot
.5739 .30692 Mdot
.57394 .15042 Mdot
.57399 .272 Mdot
.57404 .20265 Mdot
.57409 .30201 Mdot
.57414 .0555 Mdot
.57418 .08031 Mdot
.57423 .11421 Mdot
.57428 .06296 Mdot
.57433 .11553 Mdot
.57437 .26583 Mdot
.57442 .28938 Mdot
.57447 .25896 Mdot
.57452 .32183 Mdot
.57456 .15185 Mdot
.57461 .24161 Mdot
.57466 .22867 Mdot
.57471 .11539 Mdot
.57475 .31719 Mdot
.5748 .27071 Mdot
.57485 .09423 Mdot
.5749 .15828 Mdot
.57494 .25631 Mdot
.57499 .10043 Mdot
.57504 .10926 Mdot
.57509 .03505 Mdot
.57514 .30645 Mdot
.57518 .21999 Mdot
.57523 .12955 Mdot
.57528 .30193 Mdot
.57533 .25376 Mdot
.57537 .13349 Mdot
.57542 .09438 Mdot
.57547 .21428 Mdot
.57552 .31075 Mdot
.57556 .16702 Mdot
.57561 .15842 Mdot
.57566 .21555 Mdot
.57571 .18723 Mdot
.57575 .24868 Mdot
.5758 .2531 Mdot
.57585 .12874 Mdot
.5759 .19358 Mdot
.57594 .30159 Mdot
.57599 .18773 Mdot
.57604 .29427 Mdot
.57609 .26117 Mdot
.57614 .2303 Mdot
.57618 .10769 Mdot
.57623 .28854 Mdot
.57628 .27898 Mdot
.57633 .03981 Mdot
.57637 .30259 Mdot
.57642 .31115 Mdot
.57647 .05501 Mdot
.57652 .23105 Mdot
.57656 .23817 Mdot
.57661 .12693 Mdot
.57666 .06926 Mdot
.57671 .09427 Mdot
.57675 .11009 Mdot
.5768 .23667 Mdot
.57685 .20742 Mdot
.5769 .17108 Mdot
.57694 .18257 Mdot
.57699 .13874 Mdot
.57704 .04475 Mdot
.57709 .19535 Mdot
.57714 .3208 Mdot
.57718 .17053 Mdot
.57723 .10974 Mdot
.57728 .2913 Mdot
.57733 .2446 Mdot
.57737 .20844 Mdot
.57742 .1573 Mdot
.57747 .28328 Mdot
.57752 .26875 Mdot
.57756 .22413 Mdot
.57761 .13438 Mdot
.57766 .08441 Mdot
.57771 .06287 Mdot
.57775 .12958 Mdot
.5778 .0976 Mdot
.57785 .31758 Mdot
.5779 .28031 Mdot
.57794 .22055 Mdot
.57799 .21793 Mdot
.57804 .17949 Mdot
.57809 .13084 Mdot
.57814 .115 Mdot
.57818 .20647 Mdot
.57823 .31239 Mdot
.57828 .13839 Mdot
.57833 .27293 Mdot
.57837 .13043 Mdot
.57842 .0549 Mdot
.57847 .22256 Mdot
.57852 .09851 Mdot
.57856 .3021 Mdot
.57861 .1007 Mdot
.57866 .28299 Mdot
.57871 .20367 Mdot
.57875 .20225 Mdot
.5788 .05093 Mdot
.57885 .25487 Mdot
.5789 .10894 Mdot
.57894 .13961 Mdot
.57899 .06327 Mdot
.57904 .30458 Mdot
.57909 .21852 Mdot
.57913 .25192 Mdot
.57918 .21413 Mdot
.57923 .20935 Mdot
.57928 .13922 Mdot
.57933 .08127 Mdot
.57937 .23252 Mdot
.57942 .10699 Mdot
.57947 .19729 Mdot
.57952 .28195 Mdot
.57956 .21398 Mdot
.57961 .21575 Mdot
.57966 .13537 Mdot
.57971 .31139 Mdot
.57975 .15008 Mdot
.5798 .26453 Mdot
.57985 .26357 Mdot
.5799 .14626 Mdot
.57994 .13639 Mdot
.57999 .04701 Mdot
.58004 .1921 Mdot
.58009 .04423 Mdot
.58013 .11081 Mdot
.58018 .07509 Mdot
.58023 .30635 Mdot
.58028 .12519 Mdot
.58033 .22967 Mdot
.58037 .19885 Mdot
.58042 .20549 Mdot
.58047 .0824 Mdot
.58052 .3306 Mdot
.58056 .13057 Mdot
.58061 .04702 Mdot
.58066 .13425 Mdot
.58071 .15568 Mdot
.58075 .24884 Mdot
.5808 .2458 Mdot
.58085 .15712 Mdot
.5809 .04512 Mdot
.58094 .3188 Mdot
.58099 .31683 Mdot
.58104 .05071 Mdot
.58109 .24356 Mdot
.58113 .31188 Mdot
.58118 .16494 Mdot
.58123 .04682 Mdot
.58128 .17321 Mdot
.58133 .27736 Mdot
.58137 .19413 Mdot
.58142 .25729 Mdot
.58147 .27932 Mdot
.58152 .11956 Mdot
.58156 .32465 Mdot
.58161 .21617 Mdot
.58166 .28497 Mdot
.58171 .32536 Mdot
.58175 .31927 Mdot
.5818 .12368 Mdot
.58185 .17118 Mdot
.5819 .11852 Mdot
.58194 .1156 Mdot
.58199 .30366 Mdot
.58204 .16843 Mdot
.58209 .13707 Mdot
.58213 .13624 Mdot
.58218 .29568 Mdot
.58223 .26257 Mdot
.58228 .16302 Mdot
.58233 .30926 Mdot
.58237 .29209 Mdot
.58242 .13271 Mdot
.58247 .22398 Mdot
.58252 .15872 Mdot
.58256 .07852 Mdot
.58261 .1921 Mdot
.58266 .14839 Mdot
.58271 .17301 Mdot
.58275 .20143 Mdot
.5828 .24632 Mdot
.58285 .16235 Mdot
.5829 .19319 Mdot
.58294 .12248 Mdot
.58299 .11999 Mdot
.58304 .0888 Mdot
.58309 .12269 Mdot
.58313 .1589 Mdot
.58318 .29178 Mdot
.58323 .29208 Mdot
.58328 .32692 Mdot
.58333 .20381 Mdot
.58337 .07507 Mdot
.58342 .17505 Mdot
.58347 .06379 Mdot
.58352 .25282 Mdot
.58356 .28359 Mdot
.58361 .29244 Mdot
.58366 .24656 Mdot
.58371 .22107 Mdot
.58375 .13839 Mdot
.5838 .19107 Mdot
.58385 .1207 Mdot
.5839 .06692 Mdot
.58394 .23434 Mdot
.58399 .07626 Mdot
.58404 .27004 Mdot
.58409 .28711 Mdot
.58413 .16228 Mdot
.58418 .33039 Mdot
.58423 .19555 Mdot
.58428 .17655 Mdot
.58432 .21383 Mdot
.58437 .08692 Mdot
.58442 .21222 Mdot
.58447 .31647 Mdot
.58452 .18777 Mdot
.58456 .25586 Mdot
.58461 .19771 Mdot
.58466 .11304 Mdot
.58471 .24857 Mdot
.58475 .30795 Mdot
.5848 .29581 Mdot
.58485 .23678 Mdot
.5849 .16026 Mdot
.58494 .16709 Mdot
.58499 .22546 Mdot
.58504 .22034 Mdot
.58509 .2714 Mdot
.58513 .14158 Mdot
.58518 .30116 Mdot
.58523 .27911 Mdot
.58528 .16028 Mdot
.58532 .15735 Mdot
.58537 .15705 Mdot
.58542 .15414 Mdot
.58547 .29301 Mdot
.58552 .12228 Mdot
.58556 .29168 Mdot
.58561 .18466 Mdot
.58566 .15751 Mdot
.58571 .21369 Mdot
.58575 .14651 Mdot
.5858 .1243 Mdot
.58585 .25662 Mdot
.5859 .25355 Mdot
.58594 .19866 Mdot
.58599 .23562 Mdot
.58604 .14974 Mdot
.58609 .13998 Mdot
.58613 .32172 Mdot
.58618 .06908 Mdot
.58623 .22714 Mdot
.58628 .34735 Mdot
.58632 .07478 Mdot
.58637 .13919 Mdot
.58642 .12137 Mdot
.58647 .24465 Mdot
.58652 .26738 Mdot
.58656 .33484 Mdot
.58661 .17829 Mdot
.58666 .17759 Mdot
.58671 .32593 Mdot
.58675 .20569 Mdot
.5868 .07643 Mdot
.58685 .31455 Mdot
.5869 .23535 Mdot
.58694 .13748 Mdot
.58699 .1709 Mdot
.58704 .11737 Mdot
.58709 .09321 Mdot
.58713 .25338 Mdot
.58718 .07797 Mdot
.58723 .3292 Mdot
.58728 .12344 Mdot
.58732 .24154 Mdot
.58737 .20308 Mdot
.58742 .33424 Mdot
.58747 .10634 Mdot
.58752 .16018 Mdot
.58756 .13969 Mdot
.58761 .14772 Mdot
.58766 .19209 Mdot
.58771 .17861 Mdot
.58775 .31482 Mdot
.5878 .3237 Mdot
.58785 .21988 Mdot
.5879 .32678 Mdot
.58794 .29754 Mdot
.58799 .06845 Mdot
.58804 .33883 Mdot
.58809 .24891 Mdot
.58813 .18639 Mdot
.58818 .30583 Mdot
.58823 .30567 Mdot
.58828 .35059 Mdot
.58832 .16877 Mdot
.58837 .33199 Mdot
.58842 .24288 Mdot
.58847 .16985 Mdot
.58851 .32149 Mdot
.58856 .35371 Mdot
.58861 .19779 Mdot
.58866 .07108 Mdot
.58871 .24336 Mdot
.58875 .2677 Mdot
.5888 .06756 Mdot
.58885 .24934 Mdot
.5889 .28557 Mdot
.58894 .30118 Mdot
.58899 .20501 Mdot
.58904 .28003 Mdot
.58909 .34566 Mdot
.58913 .29566 Mdot
.58918 .22412 Mdot
.58923 .09436 Mdot
.58928 .22266 Mdot
.58932 .34823 Mdot
.58937 .277 Mdot
.58942 .10248 Mdot
.58947 .1179 Mdot
.58951 .08039 Mdot
.58956 .09844 Mdot
.58961 .29195 Mdot
.58966 .15589 Mdot
.58971 .08632 Mdot
.58975 .26045 Mdot
.5898 .28597 Mdot
.58985 .27263 Mdot
.5899 .17888 Mdot
.58994 .25845 Mdot
.58999 .10235 Mdot
.59004 .3478 Mdot
.59009 .23859 Mdot
.59013 .11962 Mdot
.59018 .18352 Mdot
.59023 .3635 Mdot
.59028 .30445 Mdot
.59032 .25718 Mdot
.59037 .15614 Mdot
.59042 .20799 Mdot
.59047 .31838 Mdot
.59051 .34249 Mdot
.59056 .12128 Mdot
.59061 .15786 Mdot
.59066 .30592 Mdot
.59071 .31215 Mdot
.59075 .19244 Mdot
.5908 .36525 Mdot
.59085 .28817 Mdot
.5909 .12043 Mdot
.59094 .27022 Mdot
.59099 .16167 Mdot
.59104 .1785 Mdot
.59109 .22622 Mdot
.59113 .2374 Mdot
.59118 .17842 Mdot
.59123 .30462 Mdot
.59128 .17661 Mdot
.59132 .12406 Mdot
.59137 .18011 Mdot
.59142 .36553 Mdot
.59147 .28495 Mdot
.59151 .3336 Mdot
.59156 .33798 Mdot
.59161 .1183 Mdot
.59166 .30863 Mdot
.59171 .2838 Mdot
.59175 .25176 Mdot
.5918 .17904 Mdot
.59185 .36331 Mdot
.5919 .1635 Mdot
.59194 .25367 Mdot
.59199 .25819 Mdot
.59204 .31551 Mdot
.59209 .26093 Mdot
.59213 .16496 Mdot
.59218 .15282 Mdot
.59223 .16258 Mdot
.59228 .09698 Mdot
.59232 .35501 Mdot
.59237 .21684 Mdot
.59242 .35477 Mdot
.59247 .34189 Mdot
.59251 .24918 Mdot
.59256 .22062 Mdot
.59261 .14444 Mdot
.59266 .08307 Mdot
.59271 .28101 Mdot
.59275 .17743 Mdot
.5928 .20594 Mdot
.59285 .16957 Mdot
.5929 .10486 Mdot
.59294 .36903 Mdot
.59299 .21344 Mdot
.59304 .08219 Mdot
.59309 .22234 Mdot
.59313 .18729 Mdot
.59318 .26941 Mdot
.59323 .1929 Mdot
.59328 .13434 Mdot
.59332 .11161 Mdot
.59337 .18413 Mdot
.59342 .17339 Mdot
.59347 .15182 Mdot
.59351 .26743 Mdot
.59356 .20219 Mdot
.59361 .2045 Mdot
.59366 .27582 Mdot
.5937 .1253 Mdot
.59375 .13641 Mdot
.5938 .20026 Mdot
.59385 .36867 Mdot
.5939 .3219 Mdot
.59394 .30467 Mdot
.59399 .11021 Mdot
.59404 .34348 Mdot
.59409 .32758 Mdot
.59413 .17126 Mdot
.59418 .10822 Mdot
.59423 .20151 Mdot
.59428 .22083 Mdot
.59432 .27742 Mdot
.59437 .29107 Mdot
.59442 .14823 Mdot
.59447 .19046 Mdot
.59451 .17469 Mdot
.59456 .19926 Mdot
.59461 .37302 Mdot
.59466 .29981 Mdot
.5947 .34945 Mdot
.59475 .37188 Mdot
.5948 .17965 Mdot
.59485 .25713 Mdot
.5949 .29583 Mdot
.59494 .25459 Mdot
.59499 .18898 Mdot
.59504 .3134 Mdot
.59509 .36951 Mdot
.59513 .22804 Mdot
.59518 .2242 Mdot
.59523 .3647 Mdot
.59528 .28245 Mdot
.59532 .20419 Mdot
.59537 .10723 Mdot
.59542 .22858 Mdot
.59547 .08993 Mdot
.59551 .29305 Mdot
.59556 .3391 Mdot
.59561 .12355 Mdot
.59566 .2957 Mdot
.5957 .17958 Mdot
.59575 .34689 Mdot
.5958 .20472 Mdot
.59585 .32741 Mdot
.5959 .18904 Mdot
.59594 .25391 Mdot
.59599 .32929 Mdot
.59604 .11859 Mdot
.59609 .31651 Mdot
.59613 .1523 Mdot
.59618 .10344 Mdot
.59623 .13167 Mdot
.59628 .17637 Mdot
.59632 .31105 Mdot
.59637 .12187 Mdot
.59642 .23252 Mdot
.59647 .35566 Mdot
.59651 .29263 Mdot
.59656 .27713 Mdot
.59661 .23176 Mdot
.59666 .15195 Mdot
.5967 .33791 Mdot
.59675 .24328 Mdot
.5968 .3208 Mdot
.59685 .3573 Mdot
.5969 .37612 Mdot
.59694 .12898 Mdot
.59699 .37885 Mdot
.59704 .25904 Mdot
.59709 .21317 Mdot
.59713 .18569 Mdot
.59718 .35159 Mdot
.59723 .3289 Mdot
.59728 .15256 Mdot
.59732 .17412 Mdot
.59737 .31197 Mdot
.59742 .24477 Mdot
.59747 .22878 Mdot
.59751 .14485 Mdot
.59756 .17223 Mdot
.59761 .27693 Mdot
.59766 .32415 Mdot
.5977 .2559 Mdot
.59775 .32884 Mdot
.5978 .21867 Mdot
.59785 .37497 Mdot
.59789 .10668 Mdot
.59794 .10228 Mdot
.59799 .25065 Mdot
.59804 .38832 Mdot
.59809 .36735 Mdot
.59813 .11326 Mdot
.59818 .38163 Mdot
.59823 .2705 Mdot
.59828 .27719 Mdot
.59832 .15224 Mdot
.59837 .14862 Mdot
.59842 .21402 Mdot
.59847 .19934 Mdot
.59851 .23158 Mdot
.59856 .29535 Mdot
.59861 .37692 Mdot
.59866 .1515 Mdot
.5987 .15655 Mdot
.59875 .1158 Mdot
.5988 .15034 Mdot
.59885 .2882 Mdot
.59889 .2205 Mdot
.59894 .29011 Mdot
.59899 .16853 Mdot
.59904 .28001 Mdot
.59909 .2169 Mdot
.59913 .13833 Mdot
.59918 .17411 Mdot
.59923 .30676 Mdot
.59928 .20306 Mdot
.59932 .15117 Mdot
.59937 .29827 Mdot
.59942 .12956 Mdot
.59947 .15099 Mdot
.59951 .39776 Mdot
.59956 .1848 Mdot
.59961 .32582 Mdot
.59966 .31519 Mdot
.5997 .20353 Mdot
.59975 .20404 Mdot
.5998 .27581 Mdot
.59985 .26033 Mdot
.59989 .1896 Mdot
.59994 .15576 Mdot
.59999 .38471 Mdot
.60004 .14226 Mdot
.60009 .29696 Mdot
.60013 .38489 Mdot
.60018 .2077 Mdot
.60023 .32341 Mdot
.60028 .26201 Mdot
.60032 .31435 Mdot
.60037 .29955 Mdot
.60042 .22429 Mdot
.60047 .21498 Mdot
.60051 .1204 Mdot
.60056 .2745 Mdot
.60061 .178 Mdot
.60066 .21696 Mdot
.6007 .33553 Mdot
.60075 .34881 Mdot
.6008 .26313 Mdot
.60085 .11909 Mdot
.60089 .23734 Mdot
.60094 .17904 Mdot
.60099 .40389 Mdot
.60104 .33077 Mdot
.60109 .1882 Mdot
.60113 .19598 Mdot
.60118 .36862 Mdot
.60123 .14099 Mdot
.60128 .20553 Mdot
.60132 .39071 Mdot
.60137 .15297 Mdot
.60142 .28179 Mdot
.60147 .29419 Mdot
.60151 .1995 Mdot
.60156 .33207 Mdot
.60161 .17553 Mdot
.60166 .2827 Mdot
.6017 .32895 Mdot
.60175 .26337 Mdot
.6018 .36292 Mdot
.60185 .3517 Mdot
.60189 .38487 Mdot
.60194 .40516 Mdot
.60199 .35409 Mdot
.60204 .22482 Mdot
.60209 .31648 Mdot
.60213 .40697 Mdot
.60218 .13435 Mdot
.60223 .14785 Mdot
.60228 .23191 Mdot
.60232 .14997 Mdot
.60237 .40003 Mdot
.60242 .34917 Mdot
.60247 .24826 Mdot
.60251 .40424 Mdot
.60256 .23082 Mdot
.60261 .16777 Mdot
.60266 .16174 Mdot
.6027 .18534 Mdot
.60275 .16865 Mdot
.6028 .29348 Mdot
.60285 .24139 Mdot
.60289 .33078 Mdot
.60294 .21473 Mdot
.60299 .35097 Mdot
.60304 .26591 Mdot
.60308 .3352 Mdot
.60313 .27042 Mdot
.60318 .24127 Mdot
.60323 .3596 Mdot
.60328 .33859 Mdot
.60332 .25177 Mdot
.60337 .20933 Mdot
.60342 .24379 Mdot
.60347 .30492 Mdot
.60351 .26309 Mdot
.60356 .2717 Mdot
.60361 .40727 Mdot
.60366 .31261 Mdot
.6037 .14955 Mdot
.60375 .2214 Mdot
.6038 .3632 Mdot
.60385 .24513 Mdot
.60389 .39381 Mdot
.60394 .34104 Mdot
.60399 .24026 Mdot
.60404 .32786 Mdot
.60408 .29793 Mdot
.60413 .40397 Mdot
.60418 .38845 Mdot
.60423 .40696 Mdot
.60428 .14715 Mdot
.60432 .28254 Mdot
.60437 .14888 Mdot
.60442 .18859 Mdot
.60447 .31066 Mdot
.60451 .19384 Mdot
.60456 .32077 Mdot
.60461 .29956 Mdot
.60466 .16879 Mdot
.6047 .33841 Mdot
.60475 .32997 Mdot
.6048 .40362 Mdot
.60485 .14126 Mdot
.60489 .23922 Mdot
.60494 .38404 Mdot
.60499 .2811 Mdot
.60504 .1651 Mdot
.60508 .31605 Mdot
.60513 .26698 Mdot
.60518 .3715 Mdot
.60523 .28563 Mdot
.60528 .33074 Mdot
.60532 .29739 Mdot
.60537 .3836 Mdot
.60542 .26288 Mdot
.60547 .1728 Mdot
.60551 .27331 Mdot
.60556 .32 Mdot
.60561 .37228 Mdot
.60566 .39922 Mdot
.6057 .37299 Mdot
.60575 .14624 Mdot
.6058 .32948 Mdot
.60585 .187 Mdot
.60589 .16941 Mdot
.60594 .16407 Mdot
.60599 .31502 Mdot
.60604 .36962 Mdot
.60608 .20742 Mdot
.60613 .30523 Mdot
.60618 .27751 Mdot
.60623 .18137 Mdot
.60628 .36329 Mdot
.60632 .35679 Mdot
.60637 .41514 Mdot
.60642 .27409 Mdot
.60647 .1947 Mdot
.60651 .39705 Mdot
.60656 .28145 Mdot
.60661 .23069 Mdot
.60666 .34585 Mdot
.6067 .20685 Mdot
.60675 .33404 Mdot
.6068 .25654 Mdot
.60685 .39813 Mdot
.60689 .19122 Mdot
.60694 .13537 Mdot
.60699 .20056 Mdot
.60704 .35993 Mdot
.60708 .15856 Mdot
.60713 .24682 Mdot
.60718 .25761 Mdot
.60723 .28452 Mdot
.60727 .28041 Mdot
.60732 .39658 Mdot
.60737 .20886 Mdot
.60742 .34891 Mdot
.60747 .35151 Mdot
.60751 .40953 Mdot
.60756 .36306 Mdot
.60761 .28784 Mdot
.60766 .38315 Mdot
.6077 .26212 Mdot
.60775 .26661 Mdot
.6078 .37129 Mdot
.60785 .31094 Mdot
.60789 .35778 Mdot
.60794 .14512 Mdot
.60799 .40327 Mdot
.60804 .25518 Mdot
.60808 .35808 Mdot
.60813 .37528 Mdot
.60818 .17941 Mdot
.60823 .23288 Mdot
.60827 .24773 Mdot
.60832 .25435 Mdot
.60837 .32662 Mdot
.60842 .3844 Mdot
.60847 .28329 Mdot
.60851 .18297 Mdot
.60856 .41026 Mdot
.60861 .17079 Mdot
.60866 .30671 Mdot
.6087 .25307 Mdot
.60875 .26092 Mdot
.6088 .2212 Mdot
.60885 .1835 Mdot
.60889 .42043 Mdot
.60894 .3238 Mdot
.60899 .34463 Mdot
.60904 .26029 Mdot
.60908 .41523 Mdot
.60913 .35551 Mdot
.60918 .22979 Mdot
.60923 .33761 Mdot
.60927 .18069 Mdot
.60932 .31704 Mdot
.60937 .43291 Mdot
.60942 .23123 Mdot
.60947 .36276 Mdot
.60951 .42704 Mdot
.60956 .19047 Mdot
.60961 .38497 Mdot
.60966 .32216 Mdot
.6097 .15936 Mdot
.60975 .16247 Mdot
.6098 .22125 Mdot
.60985 .21229 Mdot
.60989 .33669 Mdot
.60994 .37972 Mdot
.60999 .18155 Mdot
.61004 .23072 Mdot
.61008 .15711 Mdot
.61013 .17951 Mdot
.61018 .36074 Mdot
.61023 .25517 Mdot
.61027 .24148 Mdot
.61032 .38981 Mdot
.61037 .16856 Mdot
.61042 .22012 Mdot
.61047 .36514 Mdot
.61051 .39781 Mdot
.61056 .37844 Mdot
.61061 .29868 Mdot
.61066 .37963 Mdot
.6107 .3542 Mdot
.61075 .43541 Mdot
.6108 .41866 Mdot
.61085 .36775 Mdot
.61089 .33943 Mdot
.61094 .36205 Mdot
.61099 .35447 Mdot
.61104 .17937 Mdot
.61108 .40307 Mdot
.61113 .32922 Mdot
.61118 .27267 Mdot
.61123 .17139 Mdot
.61127 .3729 Mdot
.61132 .41287 Mdot
.61137 .16724 Mdot
.61142 .37471 Mdot
.61147 .4281 Mdot
.61151 .39467 Mdot
.61156 .39254 Mdot
.61161 .16034 Mdot
.61166 .18127 Mdot
.6117 .1674 Mdot
.61175 .24524 Mdot
.6118 .22716 Mdot
.61185 .27372 Mdot
.61189 .17885 Mdot
.61194 .27365 Mdot
.61199 .30667 Mdot
.61204 .38176 Mdot
.61208 .26448 Mdot
.61213 .36706 Mdot
.61218 .28054 Mdot
.61223 .42698 Mdot
.61227 .38376 Mdot
.61232 .24824 Mdot
.61237 .26321 Mdot
.61242 .20834 Mdot
.61246 .42021 Mdot
.61251 .23567 Mdot
.61256 .33823 Mdot
.61261 .23018 Mdot
.61266 .18083 Mdot
.6127 .29348 Mdot
.61275 .3336 Mdot
.6128 .20482 Mdot
.61285 .16954 Mdot
.61289 .20456 Mdot
.61294 .26296 Mdot
.61299 .38269 Mdot
.61304 .44248 Mdot
.61308 .38291 Mdot
.61313 .40849 Mdot
.61318 .45334 Mdot
.61323 .33576 Mdot
.61327 .17381 Mdot
.61332 .28612 Mdot
.61337 .18473 Mdot
.61342 .40543 Mdot
.61346 .37922 Mdot
.61351 .18191 Mdot
.61356 .43044 Mdot
.61361 .43948 Mdot
.61366 .30316 Mdot
.6137 .29835 Mdot
.61375 .36028 Mdot
.6138 .41887 Mdot
.61385 .17012 Mdot
.61389 .42024 Mdot
.61394 .3163 Mdot
.61399 .41038 Mdot
.61404 .42167 Mdot
.61408 .31874 Mdot
.61413 .39013 Mdot
.61418 .42463 Mdot
.61423 .20084 Mdot
.61427 .36739 Mdot
.61432 .39414 Mdot
.61437 .25157 Mdot
.61442 .18993 Mdot
.61446 .24437 Mdot
.61451 .37272 Mdot
.61456 .30451 Mdot
.61461 .26929 Mdot
.61466 .2264 Mdot
.6147 .40128 Mdot
.61475 .32423 Mdot
.6148 .42554 Mdot
.61485 .38766 Mdot
.61489 .20596 Mdot
.61494 .36538 Mdot
.61499 .42079 Mdot
.61504 .42785 Mdot
.61508 .35029 Mdot
.61513 .41584 Mdot
.61518 .46017 Mdot
.61523 .27551 Mdot
.61527 .42162 Mdot
.61532 .45288 Mdot
.61537 .42634 Mdot
.61542 .3702 Mdot
.61546 .19491 Mdot
.61551 .36895 Mdot
.61556 .40425 Mdot
.61561 .29388 Mdot
.61566 .28529 Mdot
.6157 .23289 Mdot
.61575 .30362 Mdot
.6158 .23635 Mdot
.61585 .34795 Mdot
.61589 .3728 Mdot
.61594 .34243 Mdot
.61599 .31324 Mdot
.61604 .31189 Mdot
.61608 .17752 Mdot
.61613 .3868 Mdot
.61618 .35075 Mdot
.61623 .42717 Mdot
.61627 .22745 Mdot
.61632 .39261 Mdot
.61637 .24657 Mdot
.61642 .17708 Mdot
.61646 .24117 Mdot
.61651 .43307 Mdot
.61656 .34338 Mdot
.61661 .44939 Mdot
.61666 .33964 Mdot
.6167 .20159 Mdot
.61675 .22247 Mdot
.6168 .33728 Mdot
.61685 .28013 Mdot
.61689 .36642 Mdot
.61694 .45478 Mdot
.61699 .45819 Mdot
.61704 .3764 Mdot
.61708 .1984 Mdot
.61713 .31616 Mdot
.61718 .32113 Mdot
.61723 .3739 Mdot
.61727 .28169 Mdot
.61732 .4357 Mdot
.61737 .36446 Mdot
.61742 .3223 Mdot
.61746 .35999 Mdot
.61751 .36538 Mdot
.61756 .36384 Mdot
.61761 .25779 Mdot
.61765 .39864 Mdot
.6177 .19908 Mdot
.61775 .38658 Mdot
.6178 .39048 Mdot
.61785 .37474 Mdot
.61789 .44935 Mdot
.61794 .22739 Mdot
.61799 .28865 Mdot
.61804 .18682 Mdot
.61808 .46814 Mdot
.61813 .24297 Mdot
.61818 .38623 Mdot
.61823 .4626 Mdot
.61827 .33151 Mdot
.61832 .39642 Mdot
.61837 .19226 Mdot
.61842 .36104 Mdot
.61846 .37101 Mdot
.61851 .21251 Mdot
.61856 .34557 Mdot
.61861 .47687 Mdot
.61865 .18679 Mdot
.6187 .32489 Mdot
.61875 .26935 Mdot
.6188 .26 Mdot
.61885 .46455 Mdot
.61889 .41535 Mdot
.61894 .35611 Mdot
.61899 .36271 Mdot
.61904 .19799 Mdot
.61908 .37095 Mdot
.61913 .25065 Mdot
.61918 .35928 Mdot
.61923 .20831 Mdot
.61927 .31179 Mdot
.61932 .34329 Mdot
.61937 .37575 Mdot
.61942 .35607 Mdot
.61946 .39484 Mdot
.61951 .33586 Mdot
.61956 .19974 Mdot
.61961 .46515 Mdot
.61965 .36776 Mdot
.6197 .47078 Mdot
.61975 .20356 Mdot
.6198 .46439 Mdot
.61985 .22911 Mdot
.61989 .38787 Mdot
.61994 .42507 Mdot
.61999 .48155 Mdot
.62004 .29568 Mdot
.62008 .21903 Mdot
.62013 .24983 Mdot
.62018 .47122 Mdot
.62023 .40745 Mdot
.62027 .4513 Mdot
.62032 .37367 Mdot
.62037 .45138 Mdot
.62042 .28433 Mdot
.62046 .29689 Mdot
.62051 .48185 Mdot
.62056 .28459 Mdot
.62061 .37383 Mdot
.62065 .44557 Mdot
.6207 .472 Mdot
.62075 .30439 Mdot
.6208 .19636 Mdot
.62085 .46014 Mdot
.62089 .45913 Mdot
.62094 .32575 Mdot
.62099 .4532 Mdot
.62104 .26357 Mdot
.62108 .22556 Mdot
.62113 .33076 Mdot
.62118 .34943 Mdot
.62123 .23665 Mdot
.62127 .4629 Mdot
.62132 .3469 Mdot
.62137 .42954 Mdot
.62142 .27311 Mdot
.62146 .28234 Mdot
.62151 .38368 Mdot
.62156 .33872 Mdot
.62161 .46479 Mdot
.62165 .28926 Mdot
.6217 .2932 Mdot
.62175 .45406 Mdot
.6218 .21374 Mdot
.62184 .30683 Mdot
.62189 .47858 Mdot
.62194 .45281 Mdot
.62199 .24377 Mdot
.62204 .33807 Mdot
.62208 .34855 Mdot
.62213 .49039 Mdot
.62218 .47118 Mdot
.62223 .30882 Mdot
.62227 .21431 Mdot
.62232 .33768 Mdot
.62237 .43145 Mdot
.62242 .33789 Mdot
.62246 .35958 Mdot
.62251 .40051 Mdot
.62256 .35605 Mdot
.62261 .25347 Mdot
.62265 .46887 Mdot
.6227 .2601 Mdot
.62275 .38462 Mdot
.6228 .45778 Mdot
.62284 .37458 Mdot
.62289 .30001 Mdot
.62294 .37019 Mdot
.62299 .35046 Mdot
.62304 .39055 Mdot
.62308 .34196 Mdot
.62313 .32653 Mdot
.62318 .21269 Mdot
.62323 .2425 Mdot
.62327 .34712 Mdot
.62332 .3511 Mdot
.62337 .39982 Mdot
.62342 .22949 Mdot
.62346 .21094 Mdot
.62351 .4162 Mdot
.62356 .26381 Mdot
.62361 .36684 Mdot
.62365 .30757 Mdot
.6237 .26263 Mdot
.62375 .21302 Mdot
.6238 .39571 Mdot
.62384 .25054 Mdot
.62389 .37613 Mdot
.62394 .25357 Mdot
.62399 .22479 Mdot
.62404 .44925 Mdot
.62408 .21 Mdot
.62413 .40222 Mdot
.62418 .33355 Mdot
.62423 .31194 Mdot
.62427 .38317 Mdot
.62432 .39457 Mdot
.62437 .29628 Mdot
.62442 .46511 Mdot
.62446 .2377 Mdot
.62451 .49544 Mdot
.62456 .27282 Mdot
.62461 .46039 Mdot
.62465 .32277 Mdot
.6247 .43824 Mdot
.62475 .40764 Mdot
.6248 .35982 Mdot
.62484 .26734 Mdot
.62489 .43261 Mdot
.62494 .21952 Mdot
.62499 .31707 Mdot
.62504 .39404 Mdot
.62508 .38722 Mdot
.62513 .49795 Mdot
.62518 .37124 Mdot
.62523 .39281 Mdot
.62527 .4888 Mdot
.62532 .37356 Mdot
.62537 .26865 Mdot
.62542 .21917 Mdot
.62546 .30396 Mdot
.62551 .2872 Mdot
.62556 .30852 Mdot
.62561 .48664 Mdot
.62565 .31389 Mdot
.6257 .22508 Mdot
.62575 .35389 Mdot
.6258 .37496 Mdot
.62584 .38179 Mdot
.62589 .32378 Mdot
.62594 .50059 Mdot
.62599 .31948 Mdot
.62604 .4561 Mdot
.62608 .31651 Mdot
.62613 .39596 Mdot
.62618 .43293 Mdot
.62623 .28171 Mdot
.62627 .32644 Mdot
.62632 .23793 Mdot
.62637 .25354 Mdot
.62642 .30137 Mdot
.62646 .46153 Mdot
.62651 .47813 Mdot
.62656 .24854 Mdot
.62661 .50663 Mdot
.62665 .38889 Mdot
.6267 .38436 Mdot
.62675 .27171 Mdot
.6268 .40787 Mdot
.62684 .37913 Mdot
.62689 .24599 Mdot
.62694 .40731 Mdot
.62699 .24198 Mdot
.62703 .27144 Mdot
.62708 .25654 Mdot
.62713 .30431 Mdot
.62718 .29741 Mdot
.62723 .46665 Mdot
.62727 .37248 Mdot
.62732 .38347 Mdot
.62737 .23312 Mdot
.62742 .35783 Mdot
.62746 .35236 Mdot
.62751 .34793 Mdot
.62756 .4448 Mdot
.62761 .40954 Mdot
.62765 .38766 Mdot
.6277 .31815 Mdot
.62775 .45197 Mdot
.6278 .23978 Mdot
.62784 .51748 Mdot
.62789 .26596 Mdot
.62794 .2638 Mdot
.62799 .3754 Mdot
.62803 .49157 Mdot
.62808 .37377 Mdot
.62813 .24228 Mdot
.62818 .3246 Mdot
.62823 .45586 Mdot
.62827 .29048 Mdot
.62832 .46094 Mdot
.62837 .37421 Mdot
.62842 .30496 Mdot
.62846 .42364 Mdot
.62851 .44978 Mdot
.62856 .23853 Mdot
.62861 .46979 Mdot
.62865 .29824 Mdot
.6287 .2277 Mdot
.62875 .34675 Mdot
.6288 .30522 Mdot
.62884 .49822 Mdot
.62889 .29404 Mdot
.62894 .33061 Mdot
.62899 .30644 Mdot
.62903 .45628 Mdot
.62908 .25444 Mdot
.62913 .47446 Mdot
.62918 .3343 Mdot
.62923 .30728 Mdot
.62927 .23711 Mdot
.62932 .37499 Mdot
.62937 .39862 Mdot
.62942 .2423 Mdot
.62946 .29671 Mdot
.62951 .52152 Mdot
.62956 .31972 Mdot
.62961 .33976 Mdot
.62965 .36822 Mdot
.6297 .5096 Mdot
.62975 .37158 Mdot
.6298 .2685 Mdot
.62984 .36769 Mdot
.62989 .3902 Mdot
.62994 .29389 Mdot
.62999 .29286 Mdot
.63003 .30155 Mdot
.63008 .28767 Mdot
.63013 .51058 Mdot
.63018 .35988 Mdot
.63023 .27575 Mdot
.63027 .33689 Mdot
.63032 .40528 Mdot
.63037 .28179 Mdot
.63042 .26801 Mdot
.63046 .4863 Mdot
.63051 .23639 Mdot
.63056 .2694 Mdot
.63061 .49624 Mdot
.63065 .48991 Mdot
.6307 .44198 Mdot
.63075 .45514 Mdot
.6308 .35885 Mdot
.63084 .50617 Mdot
.63089 .30158 Mdot
.63094 .41801 Mdot
.63099 .51756 Mdot
.63103 .3477 Mdot
.63108 .23959 Mdot
.63113 .35724 Mdot
.63118 .44828 Mdot
.63122 .29248 Mdot
.63127 .2565 Mdot
.63132 .52503 Mdot
.63137 .40552 Mdot
.63142 .48361 Mdot
.63146 .37942 Mdot
.63151 .47677 Mdot
.63156 .37122 Mdot
.63161 .52606 Mdot
.63165 .3771 Mdot
.6317 .44161 Mdot
.63175 .40426 Mdot
.6318 .27075 Mdot
.63184 .46475 Mdot
.63189 .51628 Mdot
.63194 .28054 Mdot
.63199 .29475 Mdot
.63203 .39867 Mdot
.63208 .33394 Mdot
.63213 .29369 Mdot
.63218 .47793 Mdot
.63222 .39527 Mdot
.63227 .50794 Mdot
.63232 .37682 Mdot
.63237 .42219 Mdot
.63242 .37569 Mdot
.63246 .51485 Mdot
.63251 .50342 Mdot
.63256 .47087 Mdot
.63261 .52874 Mdot
.63265 .27588 Mdot
.6327 .37017 Mdot
.63275 .47781 Mdot
.6328 .38996 Mdot
.63284 .36762 Mdot
.63289 .49944 Mdot
.63294 .4459 Mdot
.63299 .45908 Mdot
.63303 .38539 Mdot
.63308 .45827 Mdot
.63313 .3907 Mdot
.63318 .30014 Mdot
.63322 .29134 Mdot
.63327 .40465 Mdot
.63332 .44787 Mdot
.63337 .44013 Mdot
.63342 .31885 Mdot
.63346 .26859 Mdot
.63351 .26661 Mdot
.63356 .30555 Mdot
.63361 .34013 Mdot
.63365 .30147 Mdot
.6337 .33223 Mdot
.63375 .31346 Mdot
.6338 .30622 Mdot
.63384 .4683 Mdot
.63389 .39159 Mdot
.63394 .46085 Mdot
.63399 .47612 Mdot
.63403 .50654 Mdot
.63408 .48354 Mdot
.63413 .53979 Mdot
.63418 .33407 Mdot
.63422 .29179 Mdot
.63427 .33653 Mdot
.63432 .48351 Mdot
.63437 .28675 Mdot
.63442 .42619 Mdot
.63446 .42788 Mdot
.63451 .28791 Mdot
.63456 .50747 Mdot
.63461 .40248 Mdot
.63465 .40631 Mdot
.6347 .52243 Mdot
.63475 .41272 Mdot
.6348 .34656 Mdot
.63484 .3198 Mdot
.63489 .45486 Mdot
.63494 .35256 Mdot
.63499 .41934 Mdot
.63503 .46946 Mdot
.63508 .53543 Mdot
.63513 .41803 Mdot
.63518 .45455 Mdot
.63522 .52784 Mdot
.63527 .53773 Mdot
.63532 .33136 Mdot
.63537 .41033 Mdot
.63542 .43905 Mdot
.63546 .30212 Mdot
.63551 .29267 Mdot
.63556 .52722 Mdot
.63561 .25956 Mdot
.63565 .26277 Mdot
.6357 .32879 Mdot
.63575 .37364 Mdot
.6358 .39717 Mdot
.63584 .28442 Mdot
.63589 .46031 Mdot
.63594 .27663 Mdot
.63599 .32709 Mdot
.63603 .3743 Mdot
.63608 .35781 Mdot
.63613 .40235 Mdot
.63618 .40286 Mdot
.63622 .38427 Mdot
.63627 .48534 Mdot
.63632 .49352 Mdot
.63637 .42091 Mdot
.63641 .3926 Mdot
.63646 .40535 Mdot
.63651 .33471 Mdot
.63656 .5284 Mdot
.63661 .34233 Mdot
.63665 .36469 Mdot
.6367 .35452 Mdot
.63675 .52117 Mdot
.6368 .33205 Mdot
.63684 .28855 Mdot
.63689 .52855 Mdot
.63694 .37698 Mdot
.63699 .30077 Mdot
.63703 .3764 Mdot
.63708 .50539 Mdot
.63713 .30351 Mdot
.63718 .47511 Mdot
.63722 .27253 Mdot
.63727 .35713 Mdot
.63732 .44977 Mdot
.63737 .34526 Mdot
.63741 .33662 Mdot
.63746 .41321 Mdot
.63751 .28377 Mdot
.63756 .50257 Mdot
.63761 .48135 Mdot
.63765 .33387 Mdot
.6377 .30575 Mdot
.63775 .41594 Mdot
.6378 .37251 Mdot
.63784 .53021 Mdot
.63789 .3356 Mdot
.63794 .3402 Mdot
.63799 .34044 Mdot
.63803 .55315 Mdot
.63808 .51027 Mdot
.63813 .29638 Mdot
.63818 .516 Mdot
.63822 .30502 Mdot
.63827 .46418 Mdot
.63832 .3737 Mdot
.63837 .5012 Mdot
.63841 .50063 Mdot
.63846 .27244 Mdot
.63851 .28664 Mdot
.63856 .42293 Mdot
.63861 .34593 Mdot
.63865 .54219 Mdot
.6387 .33774 Mdot
.63875 .49541 Mdot
.6388 .27119 Mdot
.63884 .49572 Mdot
.63889 .47609 Mdot
.63894 .38248 Mdot
.63899 .29557 Mdot
.63903 .42 Mdot
.63908 .39593 Mdot
.63913 .30224 Mdot
.63918 .29762 Mdot
.63922 .46509 Mdot
.63927 .3602 Mdot
.63932 .3419 Mdot
.63937 .54841 Mdot
.63941 .55687 Mdot
.63946 .54261 Mdot
.63951 .39696 Mdot
.63956 .30934 Mdot
.63961 .54614 Mdot
.63965 .51783 Mdot
.6397 .5309 Mdot
.63975 .52043 Mdot
.6398 .26626 Mdot
.63984 .44256 Mdot
.63989 .29811 Mdot
.63994 .512 Mdot
.63999 .32831 Mdot
.64003 .52438 Mdot
.64008 .47369 Mdot
.64013 .47979 Mdot
.64018 .46666 Mdot
.64022 .39211 Mdot
.64027 .43526 Mdot
.64032 .44611 Mdot
.64037 .56053 Mdot
.64041 .29615 Mdot
.64046 .35775 Mdot
.64051 .45709 Mdot
.64056 .26834 Mdot
.6406 .31323 Mdot
.64065 .52062 Mdot
.6407 .41288 Mdot
.64075 .28233 Mdot
.6408 .35566 Mdot
.64084 .55013 Mdot
.64089 .45301 Mdot
.64094 .28192 Mdot
.64099 .47396 Mdot
.64103 .51817 Mdot
.64108 .50215 Mdot
.64113 .5149 Mdot
.64118 .51101 Mdot
.64122 .31119 Mdot
.64127 .28923 Mdot
.64132 .31524 Mdot
.64137 .38605 Mdot
.64141 .43808 Mdot
.64146 .40541 Mdot
.64151 .31714 Mdot
.64156 .35762 Mdot
.6416 .34819 Mdot
.64165 .51117 Mdot
.6417 .31694 Mdot
.64175 .31268 Mdot
.6418 .39085 Mdot
.64184 .36686 Mdot
.64189 .30333 Mdot
.64194 .52072 Mdot
.64199 .40457 Mdot
.64203 .47784 Mdot
.64208 .29068 Mdot
.64213 .31617 Mdot
.64218 .45081 Mdot
.64222 .54023 Mdot
.64227 .34046 Mdot
.64232 .36999 Mdot
.64237 .40973 Mdot
.64241 .52125 Mdot
.64246 .29561 Mdot
.64251 .54932 Mdot
.64256 .53716 Mdot
.6426 .38664 Mdot
.64265 .54426 Mdot
.6427 .46278 Mdot
.64275 .46019 Mdot
.6428 .44168 Mdot
.64284 .4988 Mdot
.64289 .42172 Mdot
.64294 .34109 Mdot
.64299 .34671 Mdot
.64303 .4675 Mdot
.64308 .46803 Mdot
.64313 .50368 Mdot
.64318 .43616 Mdot
.64322 .4494 Mdot
.64327 .42457 Mdot
.64332 .32571 Mdot
.64337 .46376 Mdot
.64341 .38205 Mdot
.64346 .32782 Mdot
.64351 .48422 Mdot
.64356 .51088 Mdot
.6436 .36008 Mdot
.64365 .34714 Mdot
.6437 .51582 Mdot
.64375 .39828 Mdot
.6438 .38486 Mdot
.64384 .45353 Mdot
.64389 .33008 Mdot
.64394 .52603 Mdot
.64399 .45561 Mdot
.64403 .30664 Mdot
.64408 .55881 Mdot
.64413 .45442 Mdot
.64418 .55819 Mdot
.64422 .40882 Mdot
.64427 .33061 Mdot
.64432 .29388 Mdot
.64437 .38454 Mdot
.64441 .55499 Mdot
.64446 .28091 Mdot
.64451 .4011 Mdot
.64456 .57362 Mdot
.6446 .50356 Mdot
.64465 .36806 Mdot
.6447 .46172 Mdot
.64475 .49031 Mdot
.6448 .43333 Mdot
.64484 .42413 Mdot
.64489 .3406 Mdot
.64494 .38274 Mdot
.64499 .55207 Mdot
.64503 .37159 Mdot
.64508 .38709 Mdot
.64513 .49978 Mdot
.64518 .52335 Mdot
.64522 .38569 Mdot
.64527 .50569 Mdot
.64532 .51473 Mdot
.64537 .39294 Mdot
.64541 .33362 Mdot
.64546 .49048 Mdot
.64551 .40898 Mdot
.64556 .41172 Mdot
.6456 .33175 Mdot
.64565 .36855 Mdot
.6457 .40951 Mdot
.64575 .48243 Mdot
.64579 .53808 Mdot
.64584 .48134 Mdot
.64589 .49384 Mdot
.64594 .32901 Mdot
.64599 .39397 Mdot
.64603 .42088 Mdot
.64608 .39136 Mdot
.64613 .35218 Mdot
.64618 .30289 Mdot
.64622 .31442 Mdot
.64627 .46719 Mdot
.64632 .40456 Mdot
.64637 .49305 Mdot
.64641 .3847 Mdot
.64646 .52855 Mdot
.64651 .29297 Mdot
.64656 .44091 Mdot
.6466 .47066 Mdot
.64665 .40127 Mdot
.6467 .45793 Mdot
.64675 .3911 Mdot
.64679 .38418 Mdot
.64684 .5688 Mdot
.64689 .55265 Mdot
.64694 .43029 Mdot
.64699 .48023 Mdot
.64703 .35761 Mdot
.64708 .50641 Mdot
.64713 .3192 Mdot
.64718 .34234 Mdot
.64722 .54422 Mdot
.64727 .43746 Mdot
.64732 .29966 Mdot
.64737 .31138 Mdot
.64741 .3606 Mdot
.64746 .31659 Mdot
.64751 .38527 Mdot
.64756 .50546 Mdot
.6476 .41094 Mdot
.64765 .30777 Mdot
.6477 .52348 Mdot
.64775 .31917 Mdot
.64779 .29416 Mdot
.64784 .42929 Mdot
.64789 .41709 Mdot
.64794 .51467 Mdot
.64799 .30516 Mdot
.64803 .45654 Mdot
.64808 .56682 Mdot
.64813 .31972 Mdot
.64818 .52779 Mdot
.64822 .53048 Mdot
.64827 .53322 Mdot
.64832 .55795 Mdot
.64837 .56425 Mdot
.64841 .37895 Mdot
.64846 .5196 Mdot
.64851 .53272 Mdot
.64856 .48991 Mdot
.6486 .34873 Mdot
.64865 .42081 Mdot
.6487 .31385 Mdot
.64875 .36566 Mdot
.64879 .32777 Mdot
.64884 .4791 Mdot
.64889 .57656 Mdot
.64894 .35863 Mdot
.64899 .48057 Mdot
.64903 .34935 Mdot
.64908 .34934 Mdot
.64913 .34103 Mdot
.64918 .31168 Mdot
.64922 .36516 Mdot
.64927 .31749 Mdot
.64932 .39608 Mdot
.64937 .36414 Mdot
.64941 .41498 Mdot
.64946 .34269 Mdot
.64951 .41508 Mdot
.64956 .56855 Mdot
.6496 .47884 Mdot
.64965 .39353 Mdot
.6497 .50884 Mdot
.64975 .50873 Mdot
.64979 .34704 Mdot
.64984 .3688 Mdot
.64989 .4324 Mdot
.64994 .47028 Mdot
.64999 .45222 Mdot
.65003 .37662 Mdot
.65008 .3634 Mdot
.65013 .5743 Mdot
.65018 .3927 Mdot
.65022 .31721 Mdot
.65027 .3124 Mdot
.65032 .55274 Mdot
.65037 .31777 Mdot
.65041 .58491 Mdot
.65046 .50161 Mdot
.65051 .47913 Mdot
.65056 .48828 Mdot
.6506 .53294 Mdot
.65065 .37735 Mdot
.6507 .49636 Mdot
.65075 .30046 Mdot
.65079 .43052 Mdot
.65084 .45458 Mdot
.65089 .57379 Mdot
.65094 .53968 Mdot
.65098 .35323 Mdot
.65103 .31378 Mdot
.65108 .39521 Mdot
.65113 .37925 Mdot
.65118 .56336 Mdot
.65122 .53723 Mdot
.65127 .40784 Mdot
.65132 .57358 Mdot
.65137 .53842 Mdot
.65141 .51719 Mdot
.65146 .44241 Mdot
.65151 .54835 Mdot
.65156 .54101 Mdot
.6516 .30832 Mdot
.65165 .55097 Mdot
.6517 .353 Mdot
.65175 .30108 Mdot
.65179 .51893 Mdot
.65184 .34781 Mdot
.65189 .34583 Mdot
.65194 .45879 Mdot
.65198 .35782 Mdot
.65203 .36244 Mdot
.65208 .39466 Mdot
.65213 .3993 Mdot
.65218 .33787 Mdot
.65222 .55601 Mdot
.65227 .30943 Mdot
.65232 .4249 Mdot
.65237 .38969 Mdot
.65241 .44245 Mdot
.65246 .32507 Mdot
.65251 .4758 Mdot
.65256 .4619 Mdot
.6526 .58952 Mdot
.65265 .36629 Mdot
.6527 .52446 Mdot
.65275 .44848 Mdot
.65279 .33354 Mdot
.65284 .30836 Mdot
.65289 .51853 Mdot
.65294 .51964 Mdot
.65298 .57591 Mdot
.65303 .5528 Mdot
.65308 .35523 Mdot
.65313 .4574 Mdot
.65318 .50913 Mdot
.65322 .45388 Mdot
.65327 .54662 Mdot
.65332 .41545 Mdot
.65337 .54398 Mdot
.65341 .44054 Mdot
.65346 .41788 Mdot
.65351 .32201 Mdot
.65356 .39787 Mdot
.6536 .41188 Mdot
.65365 .53343 Mdot
.6537 .45154 Mdot
.65375 .39986 Mdot
.65379 .34233 Mdot
.65384 .3058 Mdot
.65389 .29997 Mdot
.65394 .36331 Mdot
.65398 .33103 Mdot
.65403 .37927 Mdot
.65408 .3724 Mdot
.65413 .37957 Mdot
.65418 .37048 Mdot
.65422 .3215 Mdot
.65427 .5074 Mdot
.65432 .4629 Mdot
.65437 .50915 Mdot
.65441 .36751 Mdot
.65446 .3898 Mdot
.65451 .5117 Mdot
.65456 .36661 Mdot
.6546 .54257 Mdot
.65465 .36595 Mdot
.6547 .41207 Mdot
.65475 .5479 Mdot
.65479 .30752 Mdot
.65484 .50773 Mdot
.65489 .31074 Mdot
.65494 .50418 Mdot
.65498 .3004 Mdot
.65503 .50652 Mdot
.65508 .54112 Mdot
.65513 .47205 Mdot
.65517 .51497 Mdot
.65522 .43318 Mdot
.65527 .46068 Mdot
.65532 .40077 Mdot
.65537 .49274 Mdot
.65541 .51998 Mdot
.65546 .59205 Mdot
.65551 .48597 Mdot
.65556 .42479 Mdot
.6556 .42981 Mdot
.65565 .38005 Mdot
.6557 .41913 Mdot
.65575 .47692 Mdot
.65579 .36377 Mdot
.65584 .56282 Mdot
.65589 .46614 Mdot
.65594 .46952 Mdot
.65598 .45109 Mdot
.65603 .55233 Mdot
.65608 .55714 Mdot
.65613 .46951 Mdot
.65617 .53989 Mdot
.65622 .31174 Mdot
.65627 .38569 Mdot
.65632 .55006 Mdot
.65637 .40744 Mdot
.65641 .44672 Mdot
.65646 .58064 Mdot
.65651 .35825 Mdot
.65656 .48331 Mdot
.6566 .45058 Mdot
.65665 .3958 Mdot
.6567 .52951 Mdot
.65675 .35476 Mdot
.65679 .37186 Mdot
.65684 .57291 Mdot
.65689 .35404 Mdot
.65694 .58735 Mdot
.65698 .40547 Mdot
.65703 .40841 Mdot
.65708 .48108 Mdot
.65713 .43802 Mdot
.65717 .44982 Mdot
.65722 .44801 Mdot
.65727 .31352 Mdot
.65732 .495 Mdot
.65737 .44014 Mdot
.65741 .36445 Mdot
.65746 .36051 Mdot
.65751 .38981 Mdot
.65756 .59059 Mdot
.6576 .38103 Mdot
.65765 .30469 Mdot
.6577 .50384 Mdot
.65775 .44256 Mdot
.65779 .58269 Mdot
.65784 .37271 Mdot
.65789 .45181 Mdot
.65794 .37348 Mdot
.65798 .31262 Mdot
.65803 .32157 Mdot
.65808 .46227 Mdot
.65813 .56588 Mdot
.65817 .50213 Mdot
.65822 .43847 Mdot
.65827 .32742 Mdot
.65832 .41929 Mdot
.65837 .3574 Mdot
.65841 .42829 Mdot
.65846 .43068 Mdot
.65851 .57746 Mdot
.65856 .59132 Mdot
.6586 .37134 Mdot
.65865 .34448 Mdot
.6587 .58539 Mdot
.65875 .51401 Mdot
.65879 .37042 Mdot
.65884 .43932 Mdot
.65889 .44671 Mdot
.65894 .5301 Mdot
.65898 .59654 Mdot
.65903 .5864 Mdot
.65908 .37731 Mdot
.65913 .52161 Mdot
.65917 .57916 Mdot
.65922 .42837 Mdot
.65927 .41057 Mdot
.65932 .32382 Mdot
.65937 .44507 Mdot
.65941 .40538 Mdot
.65946 .59061 Mdot
.65951 .5658 Mdot
.65956 .32136 Mdot
.6596 .57418 Mdot
.65965 .31783 Mdot
.6597 .57406 Mdot
.65975 .54965 Mdot
.65979 .53452 Mdot
.65984 .33216 Mdot
.65989 .36496 Mdot
.65994 .48418 Mdot
.65998 .40019 Mdot
.66003 .48535 Mdot
.66008 .43481 Mdot
.66013 .48763 Mdot
.66017 .41382 Mdot
.66022 .41327 Mdot
.66027 .51332 Mdot
.66032 .50864 Mdot
.66036 .58566 Mdot
.66041 .3081 Mdot
.66046 .49494 Mdot
.66051 .36905 Mdot
.66056 .48581 Mdot
.6606 .3179 Mdot
.66065 .5296 Mdot
.6607 .35333 Mdot
.66075 .51217 Mdot
.66079 .60066 Mdot
.66084 .55617 Mdot
.66089 .40436 Mdot
.66094 .57837 Mdot
.66098 .5744 Mdot
.66103 .49715 Mdot
.66108 .52101 Mdot
.66113 .48419 Mdot
.66117 .3951 Mdot
.66122 .36843 Mdot
.66127 .3395 Mdot
.66132 .37653 Mdot
.66136 .58289 Mdot
.66141 .4562 Mdot
.66146 .432 Mdot
.66151 .39203 Mdot
.66156 .58114 Mdot
.6616 .56251 Mdot
.66165 .36938 Mdot
.6617 .50754 Mdot
.66175 .56973 Mdot
.66179 .33943 Mdot
.66184 .32261 Mdot
.66189 .59682 Mdot
.66194 .57056 Mdot
.66198 .38478 Mdot
.66203 .5198 Mdot
.66208 .32519 Mdot
.66213 .59778 Mdot
.66217 .48928 Mdot
.66222 .60048 Mdot
.66227 .44272 Mdot
.66232 .50958 Mdot
.66236 .42778 Mdot
.66241 .56794 Mdot
.66246 .37318 Mdot
.66251 .52856 Mdot
.66256 .57348 Mdot
.6626 .44301 Mdot
.66265 .58312 Mdot
.6627 .54942 Mdot
.66275 .31815 Mdot
.66279 .38083 Mdot
.66284 .38281 Mdot
.66289 .58179 Mdot
.66294 .58086 Mdot
.66298 .36554 Mdot
.66303 .38818 Mdot
.66308 .3186 Mdot
.66313 .50347 Mdot
.66317 .44801 Mdot
.66322 .37044 Mdot
.66327 .32315 Mdot
.66332 .32169 Mdot
.66336 .44991 Mdot
.66341 .53013 Mdot
.66346 .41601 Mdot
.66351 .49636 Mdot
.66356 .48446 Mdot
.6636 .4646 Mdot
.66365 .48998 Mdot
.6637 .52543 Mdot
.66375 .34916 Mdot
.66379 .48408 Mdot
.66384 .54318 Mdot
.66389 .51507 Mdot
.66394 .571 Mdot
.66398 .4091 Mdot
.66403 .5641 Mdot
.66408 .53695 Mdot
.66413 .51335 Mdot
.66417 .32884 Mdot
.66422 .55343 Mdot
.66427 .34143 Mdot
.66432 .37332 Mdot
.66436 .56125 Mdot
.66441 .53829 Mdot
.66446 .32778 Mdot
.66451 .52632 Mdot
.66455 .33919 Mdot
.6646 .43037 Mdot
.66465 .43438 Mdot
.6647 .34998 Mdot
.66475 .4776 Mdot
.66479 .54342 Mdot
.66484 .51199 Mdot
.66489 .30901 Mdot
.66494 .59658 Mdot
.66498 .60332 Mdot
.66503 .60001 Mdot
.66508 .34113 Mdot
.66513 .49575 Mdot
.66517 .34751 Mdot
.66522 .37137 Mdot
.66527 .43095 Mdot
.66532 .47524 Mdot
.66536 .39728 Mdot
.66541 .33829 Mdot
.66546 .36601 Mdot
.66551 .51723 Mdot
.66555 .46224 Mdot
.6656 .31892 Mdot
.66565 .44297 Mdot
.6657 .48648 Mdot
.66575 .34031 Mdot
.66579 .48785 Mdot
.66584 .40145 Mdot
.66589 .31736 Mdot
.66594 .40023 Mdot
.66598 .57921 Mdot
.66603 .40094 Mdot
.66608 .32414 Mdot
.66613 .40029 Mdot
.66617 .58259 Mdot
.66622 .36835 Mdot
.66627 .43179 Mdot
.66632 .36134 Mdot
.66636 .51979 Mdot
.66641 .54082 Mdot
.66646 .55999 Mdot
.66651 .5675 Mdot
.66655 .49009 Mdot
.6666 .48342 Mdot
.66665 .35135 Mdot
.6667 .41387 Mdot
.66675 .47978 Mdot
.66679 .34907 Mdot
.66684 .46836 Mdot
.66689 .38219 Mdot
.66694 .59543 Mdot
.66698 .55111 Mdot
.66703 .45965 Mdot
.66708 .58546 Mdot
.66713 .32486 Mdot
.66717 .45882 Mdot
.66722 .44416 Mdot
.66727 .49382 Mdot
.66732 .34579 Mdot
.66736 .39913 Mdot
.66741 .32102 Mdot
.66746 .44114 Mdot
.66751 .42952 Mdot
.66755 .46183 Mdot
.6676 .36456 Mdot
.66765 .47715 Mdot
.6677 .54295 Mdot
.66775 .58193 Mdot
.66779 .32186 Mdot
.66784 .37194 Mdot
.66789 .37182 Mdot
.66794 .54151 Mdot
.66798 .45701 Mdot
.66803 .59325 Mdot
.66808 .3799 Mdot
.66813 .5939 Mdot
.66817 .60086 Mdot
.66822 .31643 Mdot
.66827 .36367 Mdot
.66832 .44371 Mdot
.66836 .46532 Mdot
.66841 .42608 Mdot
.66846 .3265 Mdot
.66851 .35318 Mdot
.66855 .45291 Mdot
.6686 .5884 Mdot
.66865 .50043 Mdot
.6687 .4948 Mdot
.66875 .39693 Mdot
.66879 .41982 Mdot
.66884 .5609 Mdot
.66889 .51628 Mdot
.66894 .38362 Mdot
.66898 .35642 Mdot
.66903 .49761 Mdot
.66908 .57815 Mdot
.66913 .52998 Mdot
.66917 .36653 Mdot
.66922 .4262 Mdot
.66927 .58759 Mdot
.66932 .53246 Mdot
.66936 .35857 Mdot
.66941 .37099 Mdot
.66946 .45233 Mdot
.66951 .37556 Mdot
.66955 .53576 Mdot
.6696 .3529 Mdot
.66965 .40754 Mdot
.6697 .5259 Mdot
.66974 .55059 Mdot
.66979 .45569 Mdot
.66984 .51595 Mdot
.66989 .4373 Mdot
.66994 .43909 Mdot
.66998 .49795 Mdot
.67003 .60281 Mdot
.67008 .36195 Mdot
.67013 .39092 Mdot
.67017 .30858 Mdot
.67022 .33289 Mdot
.67027 .43504 Mdot
.67032 .33259 Mdot
.67036 .48541 Mdot
.67041 .34832 Mdot
.67046 .50558 Mdot
.67051 .577 Mdot
.67055 .42253 Mdot
.6706 .49894 Mdot
.67065 .43809 Mdot
.6707 .34929 Mdot
.67074 .37767 Mdot
.67079 .39942 Mdot
.67084 .51505 Mdot
.67089 .40153 Mdot
.67094 .5248 Mdot
.67098 .48627 Mdot
.67103 .38567 Mdot
.67108 .5652 Mdot
.67113 .33473 Mdot
.67117 .48617 Mdot
.67122 .33155 Mdot
.67127 .48209 Mdot
.67132 .33393 Mdot
.67136 .46104 Mdot
.67141 .49911 Mdot
.67146 .45722 Mdot
.67151 .45107 Mdot
.67155 .42039 Mdot
.6716 .59604 Mdot
.67165 .4827 Mdot
.6717 .33614 Mdot
.67174 .52388 Mdot
.67179 .4655 Mdot
.67184 .44093 Mdot
.67189 .56082 Mdot
.67194 .43193 Mdot
.67198 .55275 Mdot
.67203 .34682 Mdot
.67208 .34342 Mdot
.67213 .54789 Mdot
.67217 .47442 Mdot
.67222 .38379 Mdot
.67227 .31597 Mdot
.67232 .36898 Mdot
.67236 .4501 Mdot
.67241 .50376 Mdot
.67246 .58406 Mdot
.67251 .50993 Mdot
.67255 .55296 Mdot
.6726 .35362 Mdot
.67265 .44004 Mdot
.6727 .39656 Mdot
.67274 .55877 Mdot
.67279 .47273 Mdot
.67284 .41083 Mdot
.67289 .47443 Mdot
.67294 .40014 Mdot
.67298 .33863 Mdot
.67303 .45166 Mdot
.67308 .34926 Mdot
.67313 .44897 Mdot
.67317 .59337 Mdot
.67322 .41491 Mdot
.67327 .40286 Mdot
.67332 .576 Mdot
.67336 .51614 Mdot
.67341 .40546 Mdot
.67346 .34037 Mdot
.67351 .43236 Mdot
.67355 .3188 Mdot
.6736 .42264 Mdot
.67365 .43165 Mdot
.6737 .48057 Mdot
.67374 .56632 Mdot
.67379 .5837 Mdot
.67384 .34129 Mdot
.67389 .52282 Mdot
.67393 .39971 Mdot
.67398 .47896 Mdot
.67403 .46777 Mdot
.67408 .4287 Mdot
.67413 .36705 Mdot
.67417 .33323 Mdot
.67422 .4244 Mdot
.67427 .58044 Mdot
.67432 .37436 Mdot
.67436 .51895 Mdot
.67441 .32728 Mdot
.67446 .31013 Mdot
.67451 .45872 Mdot
.67455 .4191 Mdot
.6746 .58733 Mdot
.67465 .47815 Mdot
.6747 .4454 Mdot
.67474 .59675 Mdot
.67479 .46108 Mdot
.67484 .5978 Mdot
.67489 .47926 Mdot
.67493 .31832 Mdot
.67498 .42502 Mdot
.67503 .38015 Mdot
.67508 .38468 Mdot
.67513 .43931 Mdot
.67517 .55715 Mdot
.67522 .55131 Mdot
.67527 .32258 Mdot
.67532 .41098 Mdot
.67536 .43761 Mdot
.67541 .57054 Mdot
.67546 .54785 Mdot
.67551 .49161 Mdot
.67555 .415 Mdot
.6756 .56504 Mdot
.67565 .3937 Mdot
.6757 .37703 Mdot
.67574 .42701 Mdot
.67579 .39131 Mdot
.67584 .54753 Mdot
.67589 .37947 Mdot
.67593 .56506 Mdot
.67598 .39261 Mdot
.67603 .37246 Mdot
.67608 .36528 Mdot
.67613 .44413 Mdot
.67617 .31649 Mdot
.67622 .58662 Mdot
.67627 .52476 Mdot
.67632 .48571 Mdot
.67636 .36386 Mdot
.67641 .56781 Mdot
.67646 .41749 Mdot
.67651 .35177 Mdot
.67655 .39179 Mdot
.6766 .32352 Mdot
.67665 .52425 Mdot
.6767 .53508 Mdot
.67674 .42501 Mdot
.67679 .52801 Mdot
.67684 .4505 Mdot
.67689 .41131 Mdot
.67693 .33687 Mdot
.67698 .57846 Mdot
.67703 .37409 Mdot
.67708 .44411 Mdot
.67713 .54207 Mdot
.67717 .50889 Mdot
.67722 .31165 Mdot
.67727 .30276 Mdot
.67732 .5283 Mdot
.67736 .51979 Mdot
.67741 .38436 Mdot
.67746 .41445 Mdot
.67751 .46693 Mdot
.67755 .54927 Mdot
.6776 .56409 Mdot
.67765 .36499 Mdot
.6777 .37739 Mdot
.67774 .52795 Mdot
.67779 .34197 Mdot
.67784 .42683 Mdot
.67789 .54925 Mdot
.67793 .30188 Mdot
.67798 .48821 Mdot
.67803 .31734 Mdot
.67808 .51415 Mdot
.67813 .31998 Mdot
.67817 .41576 Mdot
.67822 .46966 Mdot
.67827 .56845 Mdot
.67832 .4074 Mdot
.67836 .40549 Mdot
.67841 .46822 Mdot
.67846 .3414 Mdot
.67851 .48365 Mdot
.67855 .32226 Mdot
.6786 .35483 Mdot
.67865 .47032 Mdot
.6787 .53016 Mdot
.67874 .35389 Mdot
.67879 .5855 Mdot
.67884 .39366 Mdot
.67889 .30288 Mdot
.67893 .31252 Mdot
.67898 .4592 Mdot
.67903 .43972 Mdot
.67908 .3014 Mdot
.67912 .41949 Mdot
.67917 .44212 Mdot
.67922 .52062 Mdot
.67927 .57639 Mdot
.67932 .30378 Mdot
.67936 .56729 Mdot
.67941 .54694 Mdot
.67946 .46884 Mdot
.67951 .49292 Mdot
.67955 .39877 Mdot
.6796 .50517 Mdot
.67965 .57961 Mdot
.6797 .47015 Mdot
.67974 .34335 Mdot
.67979 .33419 Mdot
.67984 .34872 Mdot
.67989 .41546 Mdot
.67993 .35184 Mdot
.67998 .53445 Mdot
.68003 .34481 Mdot
.68008 .40185 Mdot
.68012 .48632 Mdot
.68017 .39348 Mdot
.68022 .3421 Mdot
.68027 .57584 Mdot
.68032 .34274 Mdot
.68036 .46618 Mdot
.68041 .35895 Mdot
.68046 .57037 Mdot
.68051 .36854 Mdot
.68055 .51226 Mdot
.6806 .48305 Mdot
.68065 .37545 Mdot
.6807 .56255 Mdot
.68074 .30495 Mdot
.68079 .49607 Mdot
.68084 .49785 Mdot
.68089 .51681 Mdot
.68093 .56315 Mdot
.68098 .44482 Mdot
.68103 .37977 Mdot
.68108 .46228 Mdot
.68112 .32593 Mdot
.68117 .39715 Mdot
.68122 .56984 Mdot
.68127 .5678 Mdot
.68132 .52421 Mdot
.68136 .35187 Mdot
.68141 .5856 Mdot
.68146 .52172 Mdot
.68151 .3546 Mdot
.68155 .58427 Mdot
.6816 .31165 Mdot
.68165 .44951 Mdot
.6817 .43344 Mdot
.68174 .39739 Mdot
.68179 .52714 Mdot
.68184 .47782 Mdot
.68189 .42441 Mdot
.68193 .49201 Mdot
.68198 .32504 Mdot
.68203 .55153 Mdot
.68208 .4517 Mdot
.68212 .34269 Mdot
.68217 .53553 Mdot
.68222 .38458 Mdot
.68227 .42101 Mdot
.68232 .53555 Mdot
.68236 .55562 Mdot
.68241 .40662 Mdot
.68246 .48656 Mdot
.68251 .47849 Mdot
.68255 .55959 Mdot
.6826 .47439 Mdot
.68265 .4265 Mdot
.6827 .48354 Mdot
.68274 .54231 Mdot
.68279 .31916 Mdot
.68284 .58211 Mdot
.68289 .38025 Mdot
.68293 .30918 Mdot
.68298 .43011 Mdot
.68303 .45152 Mdot
.68308 .47685 Mdot
.68312 .57265 Mdot
.68317 .467 Mdot
.68322 .2933 Mdot
.68327 .42754 Mdot
.68332 .33041 Mdot
.68336 .37562 Mdot
.68341 .46025 Mdot
.68346 .47986 Mdot
.68351 .36257 Mdot
.68355 .55668 Mdot
.6836 .56128 Mdot
.68365 .29401 Mdot
.6837 .39038 Mdot
.68374 .37475 Mdot
.68379 .42714 Mdot
.68384 .39759 Mdot
.68389 .4351 Mdot
.68393 .34767 Mdot
.68398 .43188 Mdot
.68403 .30923 Mdot
.68408 .41771 Mdot
.68412 .50411 Mdot
.68417 .56681 Mdot
.68422 .41874 Mdot
.68427 .43133 Mdot
.68431 .32842 Mdot
.68436 .56473 Mdot
.68441 .57717 Mdot
.68446 .39194 Mdot
.68451 .53858 Mdot
.68455 .3953 Mdot
.6846 .38804 Mdot
.68465 .32 Mdot
.6847 .56728 Mdot
.68474 .41931 Mdot
.68479 .38436 Mdot
.68484 .5147 Mdot
.68489 .48266 Mdot
.68493 .57705 Mdot
.68498 .57155 Mdot
.68503 .36943 Mdot
.68508 .42472 Mdot
.68512 .4348 Mdot
.68517 .55185 Mdot
.68522 .536 Mdot
.68527 .50479 Mdot
.68531 .45207 Mdot
.68536 .42223 Mdot
.68541 .39369 Mdot
.68546 .46528 Mdot
.68551 .47101 Mdot
.68555 .42862 Mdot
.6856 .29036 Mdot
.68565 .51005 Mdot
.6857 .3641 Mdot
.68574 .32888 Mdot
.68579 .5534 Mdot
.68584 .5257 Mdot
.68589 .52763 Mdot
.68593 .52724 Mdot
.68598 .32647 Mdot
.68603 .3307 Mdot
.68608 .53299 Mdot
.68612 .53799 Mdot
.68617 .53923 Mdot
.68622 .48807 Mdot
.68627 .38532 Mdot
.68631 .56802 Mdot
.68636 .29014 Mdot
.68641 .56494 Mdot
.68646 .5148 Mdot
.68651 .43237 Mdot
.68655 .47779 Mdot
.6866 .38604 Mdot
.68665 .33005 Mdot
.6867 .2899 Mdot
.68674 .47347 Mdot
.68679 .45678 Mdot
.68684 .54663 Mdot
.68689 .5416 Mdot
.68693 .50053 Mdot
.68698 .51143 Mdot
.68703 .30439 Mdot
.68708 .29963 Mdot
.68712 .45922 Mdot
.68717 .46578 Mdot
.68722 .35119 Mdot
.68727 .34132 Mdot
.68731 .49956 Mdot
.68736 .55717 Mdot
.68741 .54522 Mdot
.68746 .35253 Mdot
.68751 .49368 Mdot
.68755 .57123 Mdot
.6876 .31445 Mdot
.68765 .49893 Mdot
.6877 .2997 Mdot
.68774 .46888 Mdot
.68779 .56283 Mdot
.68784 .49249 Mdot
.68789 .40443 Mdot
.68793 .29533 Mdot
.68798 .29932 Mdot
.68803 .52875 Mdot
.68808 .48164 Mdot
.68812 .36153 Mdot
.68817 .57244 Mdot
.68822 .51165 Mdot
.68827 .30483 Mdot
.68831 .4729 Mdot
.68836 .50343 Mdot
.68841 .4524 Mdot
.68846 .38207 Mdot
.6885 .49242 Mdot
.68855 .53477 Mdot
.6886 .38146 Mdot
.68865 .46471 Mdot
.6887 .4974 Mdot
.68874 .50155 Mdot
.68879 .45849 Mdot
.68884 .446 Mdot
.68889 .30939 Mdot
.68893 .51433 Mdot
.68898 .54149 Mdot
.68903 .32208 Mdot
.68908 .29444 Mdot
.68912 .49528 Mdot
.68917 .29288 Mdot
.68922 .41532 Mdot
.68927 .50767 Mdot
.68931 .49748 Mdot
.68936 .35574 Mdot
.68941 .39002 Mdot
.68946 .31418 Mdot
.6895 .5682 Mdot
.68955 .47736 Mdot
.6896 .28699 Mdot
.68965 .39554 Mdot
.6897 .31222 Mdot
.68974 .37458 Mdot
.68979 .39568 Mdot
.68984 .47142 Mdot
.68989 .38382 Mdot
.68993 .48911 Mdot
.68998 .52257 Mdot
.69003 .43995 Mdot
.69008 .44214 Mdot
.69012 .52015 Mdot
.69017 .47803 Mdot
.69022 .42293 Mdot
.69027 .51901 Mdot
.69031 .50442 Mdot
.69036 .33975 Mdot
.69041 .48701 Mdot
.69046 .29831 Mdot
.6905 .42533 Mdot
.69055 .5211 Mdot
.6906 .44922 Mdot
.69065 .30123 Mdot
.6907 .51896 Mdot
.69074 .51012 Mdot
.69079 .32956 Mdot
.69084 .55961 Mdot
.69089 .42 Mdot
.69093 .38993 Mdot
.69098 .42836 Mdot
.69103 .45102 Mdot
.69108 .50084 Mdot
.69112 .43718 Mdot
.69117 .55809 Mdot
.69122 .28358 Mdot
.69127 .55012 Mdot
.69131 .52845 Mdot
.69136 .40948 Mdot
.69141 .33361 Mdot
.69146 .31974 Mdot
.6915 .46261 Mdot
.69155 .4911 Mdot
.6916 .30895 Mdot
.69165 .46278 Mdot
.6917 .50974 Mdot
.69174 .31512 Mdot
.69179 .28083 Mdot
.69184 .51165 Mdot
.69189 .27246 Mdot
.69193 .55312 Mdot
.69198 .28864 Mdot
.69203 .36409 Mdot
.69208 .44969 Mdot
.69212 .39693 Mdot
.69217 .40451 Mdot
.69222 .43 Mdot
.69227 .28426 Mdot
.69231 .40531 Mdot
.69236 .39241 Mdot
.69241 .44609 Mdot
.69246 .32188 Mdot
.6925 .56177 Mdot
.69255 .32974 Mdot
.6926 .39715 Mdot
.69265 .42479 Mdot
.6927 .3412 Mdot
.69274 .29118 Mdot
.69279 .49948 Mdot
.69284 .48001 Mdot
.69289 .29605 Mdot
.69293 .28018 Mdot
.69298 .55238 Mdot
.69303 .4771 Mdot
.69308 .3072 Mdot
.69312 .55566 Mdot
.69317 .45742 Mdot
.69322 .29641 Mdot
.69327 .47397 Mdot
.69331 .41987 Mdot
.69336 .29598 Mdot
.69341 .28057 Mdot
.69346 .33695 Mdot
.6935 .2956 Mdot
.69355 .41275 Mdot
.6936 .5214 Mdot
.69365 .33775 Mdot
.69369 .5283 Mdot
.69374 .28303 Mdot
.69379 .3639 Mdot
.69384 .55856 Mdot
.69389 .50413 Mdot
.69393 .34527 Mdot
.69398 .44547 Mdot
.69403 .52909 Mdot
.69408 .49038 Mdot
.69412 .35404 Mdot
.69417 .52936 Mdot
.69422 .48789 Mdot
.69427 .49542 Mdot
.69431 .45719 Mdot
.69436 .49852 Mdot
.69441 .27933 Mdot
.69446 .34083 Mdot
.6945 .42633 Mdot
.69455 .48292 Mdot
.6946 .50207 Mdot
.69465 .30991 Mdot
.69469 .27811 Mdot
.69474 .52077 Mdot
.69479 .42856 Mdot
.69484 .34056 Mdot
.69489 .55388 Mdot
.69493 .42066 Mdot
.69498 .42851 Mdot
.69503 .3948 Mdot
.69508 .47197 Mdot
.69512 .53326 Mdot
.69517 .45733 Mdot
.69522 .46219 Mdot
.69527 .38069 Mdot
.69531 .26651 Mdot
.69536 .52676 Mdot
.69541 .52394 Mdot
.69546 .48052 Mdot
.6955 .32487 Mdot
.69555 .5093 Mdot
.6956 .44482 Mdot
.69565 .31576 Mdot
.69569 .39821 Mdot
.69574 .26849 Mdot
.69579 .39602 Mdot
.69584 .2986 Mdot
.69589 .4331 Mdot
.69593 .39544 Mdot
.69598 .31595 Mdot
.69603 .29992 Mdot
.69608 .27263 Mdot
.69612 .52183 Mdot
.69617 .4759 Mdot
.69622 .38255 Mdot
.69627 .29381 Mdot
.69631 .32393 Mdot
.69636 .27299 Mdot
.69641 .26098 Mdot
.69646 .28627 Mdot
.6965 .35083 Mdot
.69655 .30257 Mdot
.6966 .33382 Mdot
.69665 .51461 Mdot
.69669 .39459 Mdot
.69674 .41065 Mdot
.69679 .27595 Mdot
.69684 .37413 Mdot
.69689 .38367 Mdot
.69693 .27205 Mdot
.69698 .52947 Mdot
.69703 .49299 Mdot
.69708 .54004 Mdot
.69712 .50774 Mdot
.69717 .48618 Mdot
.69722 .47684 Mdot
.69727 .27454 Mdot
.69731 .288 Mdot
.69736 .35964 Mdot
.69741 .43887 Mdot
.69746 .50116 Mdot
.6975 .27055 Mdot
.69755 .35403 Mdot
.6976 .40783 Mdot
.69765 .40538 Mdot
.69769 .51773 Mdot
.69774 .27495 Mdot
.69779 .44266 Mdot
.69784 .26522 Mdot
.69788 .36135 Mdot
.69793 .2531 Mdot
.69798 .32247 Mdot
.69803 .43018 Mdot
.69808 .34292 Mdot
.69812 .27195 Mdot
.69817 .37764 Mdot
.69822 .43814 Mdot
.69827 .38301 Mdot
.69831 .33344 Mdot
.69836 .44831 Mdot
.69841 .41609 Mdot
.69846 .34734 Mdot
.6985 .52083 Mdot
.69855 .26145 Mdot
.6986 .46164 Mdot
.69865 .32848 Mdot
.69869 .41832 Mdot
.69874 .39984 Mdot
.69879 .30745 Mdot
.69884 .35664 Mdot
.69888 .39423 Mdot
.69893 .50274 Mdot
.69898 .29277 Mdot
.69903 .54052 Mdot
.69908 .39135 Mdot
.69912 .43032 Mdot
.69917 .40733 Mdot
.69922 .44732 Mdot
.69927 .36895 Mdot
.69931 .30207 Mdot
.69936 .51328 Mdot
.69941 .31337 Mdot
.69946 .28441 Mdot
.6995 .39735 Mdot
.69955 .34574 Mdot
.6996 .50928 Mdot
.69965 .30667 Mdot
.69969 .38396 Mdot
.69974 .42686 Mdot
.69979 .42853 Mdot
.69984 .43078 Mdot
.69988 .52638 Mdot
.69993 .36664 Mdot
.69998 .31896 Mdot
.70003 .28344 Mdot
.70008 .27037 Mdot
.70012 .32043 Mdot
.70017 .31969 Mdot
.70022 .43317 Mdot
.70027 .38096 Mdot
.70031 .45385 Mdot
.70036 .41294 Mdot
.70041 .30977 Mdot
.70046 .32427 Mdot
.7005 .48064 Mdot
.70055 .34462 Mdot
.7006 .27024 Mdot
.70065 .46648 Mdot
.70069 .37944 Mdot
.70074 .37456 Mdot
.70079 .50262 Mdot
.70084 .32655 Mdot
.70088 .49128 Mdot
.70093 .48457 Mdot
.70098 .31536 Mdot
.70103 .33836 Mdot
.70108 .36781 Mdot
.70112 .40861 Mdot
.70117 .27475 Mdot
.70122 .31065 Mdot
.70127 .28986 Mdot
.70131 .33123 Mdot
.70136 .37857 Mdot
.70141 .46652 Mdot
.70146 .37267 Mdot
.7015 .45477 Mdot
.70155 .31025 Mdot
.7016 .38353 Mdot
.70165 .42799 Mdot
.70169 .35108 Mdot
.70174 .28077 Mdot
.70179 .45249 Mdot
.70184 .28897 Mdot
.70188 .51162 Mdot
.70193 .31308 Mdot
.70198 .36583 Mdot
.70203 .33226 Mdot
.70208 .26659 Mdot
.70212 .23709 Mdot
.70217 .26666 Mdot
.70222 .49832 Mdot
.70227 .39168 Mdot
.70231 .49587 Mdot
.70236 .48936 Mdot
.70241 .44678 Mdot
.70246 .29859 Mdot
.7025 .35527 Mdot
.70255 .26064 Mdot
.7026 .31172 Mdot
.70265 .37612 Mdot
.70269 .28228 Mdot
.70274 .40905 Mdot
.70279 .4155 Mdot
.70284 .26177 Mdot
.70288 .23806 Mdot
.70293 .4878 Mdot
.70298 .36274 Mdot
.70303 .28104 Mdot
.70307 .45569 Mdot
.70312 .35764 Mdot
.70317 .26597 Mdot
.70322 .24976 Mdot
.70327 .45374 Mdot
.70331 .32593 Mdot
.70336 .29729 Mdot
.70341 .38754 Mdot
.70346 .48715 Mdot
.7035 .36567 Mdot
.70355 .37944 Mdot
.7036 .32283 Mdot
.70365 .36559 Mdot
.70369 .33856 Mdot
.70374 .30106 Mdot
.70379 .47473 Mdot
.70384 .3163 Mdot
.70388 .45718 Mdot
.70393 .41304 Mdot
.70398 .44541 Mdot
.70403 .31051 Mdot
.70407 .49632 Mdot
.70412 .28222 Mdot
.70417 .39611 Mdot
.70422 .38122 Mdot
.70427 .37006 Mdot
.70431 .24743 Mdot
.70436 .37735 Mdot
.70441 .45316 Mdot
.70446 .27477 Mdot
.7045 .47545 Mdot
.70455 .51495 Mdot
.7046 .49096 Mdot
.70465 .43387 Mdot
.70469 .32575 Mdot
.70474 .42167 Mdot
.70479 .35473 Mdot
.70484 .32449 Mdot
.70488 .25369 Mdot
.70493 .47061 Mdot
.70498 .26707 Mdot
.70503 .39062 Mdot
.70507 .36377 Mdot
.70512 .25328 Mdot
.70517 .47932 Mdot
.70522 .41687 Mdot
.70527 .30909 Mdot
.70531 .37938 Mdot
.70536 .32527 Mdot
.70541 .27379 Mdot
.70546 .28846 Mdot
.7055 .22864 Mdot
.70555 .39339 Mdot
.7056 .22527 Mdot
.70565 .33392 Mdot
.70569 .23443 Mdot
.70574 .42298 Mdot
.70579 .31177 Mdot
.70584 .2335 Mdot
.70588 .33275 Mdot
.70593 .29319 Mdot
.70598 .5069 Mdot
.70603 .49924 Mdot
.70607 .38139 Mdot
.70612 .25033 Mdot
.70617 .3403 Mdot
.70622 .3593 Mdot
.70627 .35175 Mdot
.70631 .28933 Mdot
.70636 .44156 Mdot
.70641 .2733 Mdot
.70646 .49013 Mdot
.7065 .48163 Mdot
.70655 .3903 Mdot
.7066 .50204 Mdot
.70665 .48364 Mdot
.70669 .3102 Mdot
.70674 .3868 Mdot
.70679 .3897 Mdot
.70684 .47061 Mdot
.70688 .40329 Mdot
.70693 .29605 Mdot
.70698 .37704 Mdot
.70703 .35851 Mdot
.70707 .33055 Mdot
.70712 .30428 Mdot
.70717 .39274 Mdot
.70722 .49187 Mdot
.70726 .29992 Mdot
.70731 .47835 Mdot
.70736 .25276 Mdot
.70741 .35925 Mdot
.70746 .22954 Mdot
.7075 .25554 Mdot
.70755 .49288 Mdot
.7076 .38236 Mdot
.70765 .26096 Mdot
.70769 .3781 Mdot
.70774 .50351 Mdot
.70779 .4112 Mdot
.70784 .46304 Mdot
.70788 .5034 Mdot
.70793 .33086 Mdot
.70798 .4523 Mdot
.70803 .27642 Mdot
.70807 .42382 Mdot
.70812 .46496 Mdot
.70817 .30989 Mdot
.70822 .45663 Mdot
.70826 .33525 Mdot
.70831 .28774 Mdot
.70836 .3282 Mdot
.70841 .37184 Mdot
.70846 .36671 Mdot
.7085 .24974 Mdot
.70855 .47837 Mdot
.7086 .35667 Mdot
.70865 .32535 Mdot
.70869 .2657 Mdot
.70874 .3098 Mdot
.70879 .30932 Mdot
.70884 .45551 Mdot
.70888 .27026 Mdot
.70893 .40648 Mdot
.70898 .35396 Mdot
.70903 .45961 Mdot
.70907 .4467 Mdot
.70912 .46129 Mdot
.70917 .2896 Mdot
.70922 .24766 Mdot
.70926 .48827 Mdot
.70931 .36288 Mdot
.70936 .33911 Mdot
.70941 .41835 Mdot
.70946 .41142 Mdot
.7095 .24538 Mdot
.70955 .47263 Mdot
.7096 .26196 Mdot
.70965 .37181 Mdot
.70969 .2718 Mdot
.70974 .3257 Mdot
.70979 .44101 Mdot
.70984 .31546 Mdot
.70988 .46601 Mdot
.70993 .22534 Mdot
.70998 .48911 Mdot
.71003 .25376 Mdot
.71007 .26789 Mdot
.71012 .37441 Mdot
.71017 .23748 Mdot
.71022 .30971 Mdot
.71026 .30905 Mdot
.71031 .2922 Mdot
.71036 .49187 Mdot
.71041 .3233 Mdot
.71046 .44784 Mdot
.7105 .45456 Mdot
.71055 .27994 Mdot
.7106 .41295 Mdot
.71065 .40848 Mdot
.71069 .48261 Mdot
.71074 .22361 Mdot
.71079 .24657 Mdot
.71084 .34192 Mdot
.71088 .36195 Mdot
.71093 .2823 Mdot
.71098 .43062 Mdot
.71103 .37522 Mdot
.71107 .34087 Mdot
.71112 .29211 Mdot
.71117 .38072 Mdot
.71122 .31099 Mdot
.71126 .46479 Mdot
.71131 .2579 Mdot
.71136 .27409 Mdot
.71141 .20481 Mdot
.71146 .37527 Mdot
.7115 .26336 Mdot
.71155 .44793 Mdot
.7116 .25392 Mdot
.71165 .41745 Mdot
.71169 .47997 Mdot
.71174 .23647 Mdot
.71179 .34159 Mdot
.71184 .43079 Mdot
.71188 .45726 Mdot
.71193 .48546 Mdot
.71198 .20017 Mdot
.71203 .26914 Mdot
.71207 .37506 Mdot
.71212 .25474 Mdot
.71217 .31951 Mdot
.71222 .42263 Mdot
.71226 .28226 Mdot
.71231 .36799 Mdot
.71236 .20743 Mdot
.71241 .45141 Mdot
.71245 .22287 Mdot
.7125 .29221 Mdot
.71255 .20074 Mdot
.7126 .27406 Mdot
.71265 .45208 Mdot
.71269 .33666 Mdot
.71274 .43899 Mdot
.71279 .34858 Mdot
.71284 .46388 Mdot
.71288 .2969 Mdot
.71293 .29392 Mdot
.71298 .40896 Mdot
.71303 .20274 Mdot
.71307 .30222 Mdot
.71312 .28947 Mdot
.71317 .33534 Mdot
.71322 .31785 Mdot
.71326 .2426 Mdot
.71331 .45973 Mdot
.71336 .40228 Mdot
.71341 .23011 Mdot
.71345 .36378 Mdot
.7135 .44641 Mdot
.71355 .43964 Mdot
.7136 .20096 Mdot
.71365 .26508 Mdot
.71369 .43899 Mdot
.71374 .35869 Mdot
.71379 .23665 Mdot
.71384 .41599 Mdot
.71388 .1925 Mdot
.71393 .20241 Mdot
.71398 .25973 Mdot
.71403 .31099 Mdot
.71407 .38514 Mdot
.71412 .27981 Mdot
.71417 .24829 Mdot
.71422 .19987 Mdot
.71426 .28656 Mdot
.71431 .43002 Mdot
.71436 .41579 Mdot
.71441 .44242 Mdot
.71445 .31178 Mdot
.7145 .21763 Mdot
.71455 .37536 Mdot
.7146 .26812 Mdot
.71465 .3495 Mdot
.71469 .26192 Mdot
.71474 .36328 Mdot
.71479 .19171 Mdot
.71484 .39385 Mdot
.71488 .38636 Mdot
.71493 .3147 Mdot
.71498 .25845 Mdot
.71503 .38901 Mdot
.71507 .37141 Mdot
.71512 .24223 Mdot
.71517 .42937 Mdot
.71522 .19073 Mdot
.71526 .27825 Mdot
.71531 .47525 Mdot
.71536 .41575 Mdot
.71541 .38506 Mdot
.71545 .32892 Mdot
.7155 .2451 Mdot
.71555 .45362 Mdot
.7156 .25852 Mdot
.71565 .29632 Mdot
.71569 .34942 Mdot
.71574 .37012 Mdot
.71579 .38829 Mdot
.71584 .21861 Mdot
.71588 .465 Mdot
.71593 .36222 Mdot
.71598 .4729 Mdot
.71603 .31051 Mdot
.71607 .33349 Mdot
.71612 .28676 Mdot
.71617 .26668 Mdot
.71622 .41655 Mdot
.71626 .27364 Mdot
.71631 .33443 Mdot
.71636 .25793 Mdot
.71641 .32007 Mdot
.71645 .27482 Mdot
.7165 .3949 Mdot
.71655 .34888 Mdot
.7166 .46696 Mdot
.71665 .21048 Mdot
.71669 .41668 Mdot
.71674 .27071 Mdot
.71679 .35078 Mdot
.71684 .33585 Mdot
.71688 .22629 Mdot
.71693 .35681 Mdot
.71698 .31149 Mdot
.71703 .34482 Mdot
.71707 .33784 Mdot
.71712 .35747 Mdot
.71717 .17948 Mdot
.71722 .18963 Mdot
.71726 .22917 Mdot
.71731 .26868 Mdot
.71736 .23547 Mdot
.71741 .38833 Mdot
.71745 .36688 Mdot
.7175 .18783 Mdot
.71755 .38713 Mdot
.7176 .29017 Mdot
.71764 .4433 Mdot
.71769 .31006 Mdot
.71774 .39107 Mdot
.71779 .25554 Mdot
.71784 .20226 Mdot
.71788 .21478 Mdot
.71793 .21552 Mdot
.71798 .38957 Mdot
.71803 .44565 Mdot
.71807 .32744 Mdot
.71812 .3733 Mdot
.71817 .21896 Mdot
.71822 .28181 Mdot
.71826 .43862 Mdot
.71831 .36741 Mdot
.71836 .20271 Mdot
.71841 .22581 Mdot
.71845 .34291 Mdot
.7185 .30471 Mdot
.71855 .28181 Mdot
.7186 .32615 Mdot
.71864 .32724 Mdot
.71869 .38439 Mdot
.71874 .45823 Mdot
.71879 .34925 Mdot
.71884 .18852 Mdot
.71888 .4593 Mdot
.71893 .37361 Mdot
.71898 .31771 Mdot
.71903 .43911 Mdot
.71907 .41409 Mdot
.71912 .449 Mdot
.71917 .33681 Mdot
.71922 .28135 Mdot
.71926 .21028 Mdot
.71931 .39932 Mdot
.71936 .22408 Mdot
.71941 .30646 Mdot
.71945 .30639 Mdot
.7195 .36507 Mdot
.71955 .16652 Mdot
.7196 .42644 Mdot
.71964 .16952 Mdot
.71969 .2509 Mdot
.71974 .30266 Mdot
.71979 .26643 Mdot
.71984 .24701 Mdot
.71988 .25433 Mdot
.71993 .41487 Mdot
.71998 .24431 Mdot
.72003 .24876 Mdot
.72007 .34156 Mdot
.72012 .26295 Mdot
.72017 .26563 Mdot
.72022 .2949 Mdot
.72026 .35259 Mdot
.72031 .38595 Mdot
.72036 .44389 Mdot
.72041 .24917 Mdot
.72045 .41247 Mdot
.7205 .32601 Mdot
.72055 .30137 Mdot
.7206 .40137 Mdot
.72064 .21092 Mdot
.72069 .3228 Mdot
.72074 .33289 Mdot
.72079 .39475 Mdot
.72084 .41758 Mdot
.72088 .18264 Mdot
.72093 .22875 Mdot
.72098 .30982 Mdot
.72103 .32512 Mdot
.72107 .22429 Mdot
.72112 .44076 Mdot
.72117 .22231 Mdot
.72122 .43947 Mdot
.72126 .41705 Mdot
.72131 .33576 Mdot
.72136 .38271 Mdot
.72141 .2471 Mdot
.72145 .19112 Mdot
.7215 .34654 Mdot
.72155 .29315 Mdot
.7216 .28889 Mdot
.72164 .31916 Mdot
.72169 .20417 Mdot
.72174 .34543 Mdot
.72179 .23655 Mdot
.72183 .15474 Mdot
.72188 .3243 Mdot
.72193 .4035 Mdot
.72198 .27158 Mdot
.72203 .42451 Mdot
.72207 .2529 Mdot
.72212 .25082 Mdot
.72217 .39825 Mdot
.72222 .35694 Mdot
.72226 .26352 Mdot
.72231 .18483 Mdot
.72236 .40975 Mdot
.72241 .39066 Mdot
.72245 .37832 Mdot
.7225 .25247 Mdot
.72255 .31794 Mdot
.7226 .35463 Mdot
.72264 .18665 Mdot
.72269 .40885 Mdot
.72274 .18352 Mdot
.72279 .18972 Mdot
.72283 .43139 Mdot
.72288 .21728 Mdot
.72293 .39547 Mdot
.72298 .18843 Mdot
.72303 .26032 Mdot
.72307 .26166 Mdot
.72312 .27671 Mdot
.72317 .21139 Mdot
.72322 .15983 Mdot
.72326 .16305 Mdot
.72331 .32531 Mdot
.72336 .3011 Mdot
.72341 .34276 Mdot
.72345 .42446 Mdot
.7235 .3616 Mdot
.72355 .35627 Mdot
.7236 .41007 Mdot
.72364 .32256 Mdot
.72369 .19401 Mdot
.72374 .1518 Mdot
.72379 .37336 Mdot
.72383 .3583 Mdot
.72388 .16003 Mdot
.72393 .40626 Mdot
.72398 .38596 Mdot
.72403 .28995 Mdot
.72407 .20814 Mdot
.72412 .36635 Mdot
.72417 .27394 Mdot
.72422 .17639 Mdot
.72426 .37418 Mdot
.72431 .30265 Mdot
.72436 .26159 Mdot
.72441 .16062 Mdot
.72445 .19594 Mdot
.7245 .14842 Mdot
.72455 .36036 Mdot
.7246 .17748 Mdot
.72464 .27546 Mdot
.72469 .23306 Mdot
.72474 .391 Mdot
.72479 .29542 Mdot
.72483 .22689 Mdot
.72488 .22649 Mdot
.72493 .16267 Mdot
.72498 .3768 Mdot
.72503 .21148 Mdot
.72507 .2595 Mdot
.72512 .21578 Mdot
.72517 .23086 Mdot
.72522 .14715 Mdot
.72526 .33161 Mdot
.72531 .38009 Mdot
.72536 .19766 Mdot
.72541 .21081 Mdot
.72545 .17175 Mdot
.7255 .26107 Mdot
.72555 .17941 Mdot
.7256 .15703 Mdot
.72564 .16529 Mdot
.72569 .33733 Mdot
.72574 .14349 Mdot
.72579 .31778 Mdot
.72583 .36824 Mdot
.72588 .38213 Mdot
.72593 .28367 Mdot
.72598 .23143 Mdot
.72603 .28208 Mdot
.72607 .3596 Mdot
.72612 .34165 Mdot
.72617 .15967 Mdot
.72622 .16209 Mdot
.72626 .28313 Mdot
.72631 .24991 Mdot
.72636 .15143 Mdot
.72641 .26405 Mdot
.72645 .3364 Mdot
.7265 .19055 Mdot
.72655 .37358 Mdot
.7266 .23019 Mdot
.72664 .21302 Mdot
.72669 .14862 Mdot
.72674 .35382 Mdot
.72679 .20198 Mdot
.72683 .30742 Mdot
.72688 .14181 Mdot
.72693 .17251 Mdot
.72698 .26487 Mdot
.72702 .35621 Mdot
.72707 .28886 Mdot
.72712 .3716 Mdot
.72717 .4131 Mdot
.72722 .13187 Mdot
.72726 .37712 Mdot
.72731 .34678 Mdot
.72736 .38565 Mdot
.72741 .27804 Mdot
.72745 .26145 Mdot
.7275 .32939 Mdot
.72755 .25545 Mdot
.7276 .37013 Mdot
.72764 .20434 Mdot
.72769 .3839 Mdot
.72774 .15828 Mdot
.72779 .28994 Mdot
.72783 .18834 Mdot
.72788 .1625 Mdot
.72793 .38338 Mdot
.72798 .4094 Mdot
.72802 .17835 Mdot
.72807 .41646 Mdot
.72812 .24993 Mdot
.72817 .1844 Mdot
.72822 .31536 Mdot
.72826 .17567 Mdot
.72831 .26229 Mdot
.72836 .18294 Mdot
.72841 .3633 Mdot
.72845 .25375 Mdot
.7285 .3013 Mdot
.72855 .32937 Mdot
.7286 .23125 Mdot
.72864 .34842 Mdot
.72869 .17485 Mdot
.72874 .38289 Mdot
.72879 .15552 Mdot
.72883 .38777 Mdot
.72888 .14477 Mdot
.72893 .22095 Mdot
.72898 .38983 Mdot
.72902 .35287 Mdot
.72907 .18364 Mdot
.72912 .2336 Mdot
.72917 .33848 Mdot
.72922 .35806 Mdot
.72926 .35516 Mdot
.72931 .17559 Mdot
.72936 .14932 Mdot
.72941 .30838 Mdot
.72945 .21866 Mdot
.7295 .4131 Mdot
.72955 .20627 Mdot
.7296 .17983 Mdot
.72964 .33722 Mdot
.72969 .20853 Mdot
.72974 .39447 Mdot
.72979 .25067 Mdot
.72983 .28656 Mdot
.72988 .2445 Mdot
.72993 .36275 Mdot
.72998 .28135 Mdot
.73002 .2652 Mdot
.73007 .14675 Mdot
.73012 .39079 Mdot
.73017 .34615 Mdot
.73022 .20417 Mdot
.73026 .33042 Mdot
.73031 .17452 Mdot
.73036 .40496 Mdot
.73041 .26568 Mdot
.73045 .27645 Mdot
.7305 .14662 Mdot
.73055 .2178 Mdot
.7306 .16803 Mdot
.73064 .27903 Mdot
.73069 .35583 Mdot
.73074 .1584 Mdot
.73079 .2459 Mdot
.73083 .19053 Mdot
.73088 .37605 Mdot
.73093 .32223 Mdot
.73098 .37364 Mdot
.73102 .36014 Mdot
.73107 .13235 Mdot
.73112 .15972 Mdot
.73117 .22709 Mdot
.73121 .33184 Mdot
.73126 .15468 Mdot
.73131 .22649 Mdot
.73136 .14079 Mdot
.73141 .11909 Mdot
.73145 .39249 Mdot
.7315 .23366 Mdot
.73155 .28705 Mdot
.7316 .25438 Mdot
.73164 .36255 Mdot
.73169 .13235 Mdot
.73174 .23531 Mdot
.73179 .3863 Mdot
.73183 .12262 Mdot
.73188 .38451 Mdot
.73193 .39977 Mdot
.73198 .31108 Mdot
.73202 .15654 Mdot
.73207 .1772 Mdot
.73212 .14086 Mdot
.73217 .36033 Mdot
.73221 .13854 Mdot
.73226 .13162 Mdot
.73231 .32258 Mdot
.73236 .14225 Mdot
.73241 .39227 Mdot
.73245 .31335 Mdot
.7325 .29496 Mdot
.73255 .13613 Mdot
.7326 .11257 Mdot
.73264 .19228 Mdot
.73269 .1203 Mdot
.73274 .28881 Mdot
.73279 .15687 Mdot
.73283 .17174 Mdot
.73288 .29146 Mdot
.73293 .30879 Mdot
.73298 .14548 Mdot
.73302 .19312 Mdot
.73307 .29738 Mdot
.73312 .10836 Mdot
.73317 .39425 Mdot
.73321 .12618 Mdot
.73326 .26658 Mdot
.73331 .15275 Mdot
.73336 .36539 Mdot
.73341 .3989 Mdot
.73345 .34816 Mdot
.7335 .11961 Mdot
.73355 .37689 Mdot
.7336 .19427 Mdot
.73364 .16173 Mdot
.73369 .38667 Mdot
.73374 .37246 Mdot
.73379 .10994 Mdot
.73383 .1492 Mdot
.73388 .20543 Mdot
.73393 .32296 Mdot
.73398 .34024 Mdot
.73402 .25959 Mdot
.73407 .2983 Mdot
.73412 .28409 Mdot
.73417 .25354 Mdot
.73421 .36329 Mdot
.73426 .29598 Mdot
.73431 .29055 Mdot
.73436 .23301 Mdot
.73441 .20217 Mdot
.73445 .2485 Mdot
.7345 .3251 Mdot
.73455 .23386 Mdot
.7346 .25357 Mdot
.73464 .2334 Mdot
.73469 .3474 Mdot
.73474 .14372 Mdot
.73479 .19578 Mdot
.73483 .24534 Mdot
.73488 .37336 Mdot
.73493 .13715 Mdot
.73498 .14978 Mdot
.73502 .14291 Mdot
.73507 .1532 Mdot
.73512 .19439 Mdot
.73517 .28748 Mdot
.73521 .24171 Mdot
.73526 .26602 Mdot
.73531 .33758 Mdot
.73536 .32072 Mdot
.73541 .34208 Mdot
.73545 .37163 Mdot
.7355 .20568 Mdot
.73555 .21947 Mdot
.7356 .19431 Mdot
.73564 .14708 Mdot
.73569 .36704 Mdot
.73574 .36093 Mdot
.73579 .35575 Mdot
.73583 .19434 Mdot
.73588 .32293 Mdot
.73593 .26457 Mdot
.73598 .20965 Mdot
.73602 .21489 Mdot
.73607 .28465 Mdot
.73612 .21348 Mdot
.73617 .16523 Mdot
.73621 .16 Mdot
.73626 .18838 Mdot
.73631 .3188 Mdot
.73636 .31613 Mdot
.7364 .2864 Mdot
.73645 .24304 Mdot
.7365 .09527 Mdot
.73655 .36591 Mdot
.7366 .30645 Mdot
.73664 .134 Mdot
.73669 .26711 Mdot
.73674 .26787 Mdot
.73679 .25546 Mdot
.73683 .15772 Mdot
.73688 .29675 Mdot
.73693 .3025 Mdot
.73698 .15647 Mdot
.73702 .2248 Mdot
.73707 .12715 Mdot
.73712 .18764 Mdot
.73717 .33104 Mdot
.73721 .32944 Mdot
.73726 .30278 Mdot
.73731 .11647 Mdot
.73736 .26492 Mdot
.7374 .23476 Mdot
.73745 .37235 Mdot
.7375 .18853 Mdot
.73755 .36652 Mdot
.7376 .37954 Mdot
.73764 .36986 Mdot
.73769 .21008 Mdot
.73774 .15249 Mdot
.73779 .33777 Mdot
.73783 .1948 Mdot
.73788 .32894 Mdot
.73793 .28358 Mdot
.73798 .27157 Mdot
.73802 .28424 Mdot
.73807 .11758 Mdot
.73812 .21808 Mdot
.73817 .13755 Mdot
.73821 .24769 Mdot
.73826 .31522 Mdot
.73831 .27214 Mdot
.73836 .19303 Mdot
.7384 .32965 Mdot
.73845 .28845 Mdot
.7385 .09675 Mdot
.73855 .34247 Mdot
.7386 .34132 Mdot
.73864 .1889 Mdot
.73869 .11388 Mdot
.73874 .34642 Mdot
.73879 .35477 Mdot
.73883 .36195 Mdot
.73888 .34434 Mdot
.73893 .09655 Mdot
.73898 .2477 Mdot
.73902 .12057 Mdot
.73907 .14813 Mdot
.73912 .20704 Mdot
.73917 .34534 Mdot
.73921 .08983 Mdot
.73926 .31157 Mdot
.73931 .15598 Mdot
.73936 .18396 Mdot
.7394 .1556 Mdot
.73945 .12539 Mdot
.7395 .34358 Mdot
.73955 .23477 Mdot
.7396 .24743 Mdot
.73964 .11389 Mdot
.73969 .08618 Mdot
.73974 .2732 Mdot
.73979 .14325 Mdot
.73983 .08455 Mdot
.73988 .11899 Mdot
.73993 .29749 Mdot
.73998 .16018 Mdot
.74002 .11891 Mdot
.74007 .10611 Mdot
.74012 .13328 Mdot
.74017 .12293 Mdot
.74021 .34878 Mdot
.74026 .27689 Mdot
.74031 .16559 Mdot
.74036 .11572 Mdot
.7404 .11965 Mdot
.74045 .20319 Mdot
.7405 .35859 Mdot
.74055 .33691 Mdot
.74059 .37087 Mdot
.74064 .23604 Mdot
.74069 .20522 Mdot
.74074 .17072 Mdot
.74079 .33805 Mdot
.74083 .23074 Mdot
.74088 .30759 Mdot
.74093 .10801 Mdot
.74098 .33387 Mdot
.74102 .19195 Mdot
.74107 .09013 Mdot
.74112 .32255 Mdot
.74117 .29464 Mdot
.74121 .16535 Mdot
.74126 .33104 Mdot
.74131 .27879 Mdot
.74136 .31972 Mdot
.7414 .26215 Mdot
.74145 .24411 Mdot
.7415 .24155 Mdot
.74155 .27838 Mdot
.74159 .13711 Mdot
.74164 .25836 Mdot
.74169 .27731 Mdot
.74174 .28 Mdot
.74179 .2734 Mdot
.74183 .13044 Mdot
.74188 .18372 Mdot
.74193 .31378 Mdot
.74198 .11945 Mdot
.74202 .19433 Mdot
.74207 .15217 Mdot
.74212 .35105 Mdot
.74217 .29848 Mdot
.74221 .18016 Mdot
.74226 .20026 Mdot
.74231 .13203 Mdot
.74236 .20858 Mdot
.7424 .21925 Mdot
.74245 .29144 Mdot
.7425 .18212 Mdot
.74255 .31607 Mdot
.74259 .34462 Mdot
.74264 .12434 Mdot
.74269 .27287 Mdot
.74274 .25307 Mdot
.74279 .16021 Mdot
.74283 .21567 Mdot
.74288 .36134 Mdot
.74293 .34798 Mdot
.74298 .10306 Mdot
.74302 .10508 Mdot
.74307 .12053 Mdot
.74312 .30132 Mdot
.74317 .27622 Mdot
.74321 .32023 Mdot
.74326 .13663 Mdot
.74331 .07498 Mdot
.74336 .16803 Mdot
.7434 .19178 Mdot
.74345 .07624 Mdot
.7435 .23274 Mdot
.74355 .31495 Mdot
.74359 .26635 Mdot
.74364 .25997 Mdot
.74369 .28236 Mdot
.74374 .33586 Mdot
.74379 .21252 Mdot
.74383 .3523 Mdot
.74388 .09947 Mdot
.74393 .24567 Mdot
.74398 .0667 Mdot
.74402 .35551 Mdot
.74407 .11588 Mdot
.74412 .21198 Mdot
.74417 .32569 Mdot
.74421 .30404 Mdot
.74426 .1783 Mdot
.74431 .29935 Mdot
.74436 .07404 Mdot
.7444 .23582 Mdot
.74445 .17158 Mdot
.7445 .19941 Mdot
.74455 .24505 Mdot
.74459 .22735 Mdot
.74464 .30131 Mdot
.74469 .24677 Mdot
.74474 .34085 Mdot
.74479 .32937 Mdot
.74483 .08593 Mdot
.74488 .27259 Mdot
.74493 .195 Mdot
.74498 .33844 Mdot
.74502 .34767 Mdot
.74507 .09312 Mdot
.74512 .19433 Mdot
.74517 .34366 Mdot
.74521 .29752 Mdot
.74526 .24156 Mdot
.74531 .2289 Mdot
.74536 .10487 Mdot
.7454 .18431 Mdot
.74545 .30201 Mdot
.7455 .21965 Mdot
.74555 .22853 Mdot
.74559 .07721 Mdot
.74564 .16691 Mdot
.74569 .33362 Mdot
.74574 .06519 Mdot
.74578 .13461 Mdot
.74583 .2787 Mdot
.74588 .35117 Mdot
.74593 .09406 Mdot
.74598 .11191 Mdot
.74602 .06919 Mdot
.74607 .2191 Mdot
.74612 .11326 Mdot
.74617 .12172 Mdot
.74621 .3334 Mdot
.74626 .08709 Mdot
.74631 .12662 Mdot
.74636 .18108 Mdot
.7464 .1537 Mdot
.74645 .21475 Mdot
.7465 .08331 Mdot
.74655 .35303 Mdot
.74659 .20781 Mdot
.74664 .35106 Mdot
.74669 .21058 Mdot
.74674 .33662 Mdot
.74678 .10155 Mdot
.74683 .07794 Mdot
.74688 .20575 Mdot
.74693 .26222 Mdot
.74698 .17776 Mdot
.74702 .08153 Mdot
.74707 .17144 Mdot
.74712 .20991 Mdot
.74717 .16802 Mdot
.74721 .21659 Mdot
.74726 .11733 Mdot
.74731 .1472 Mdot
.74736 .18834 Mdot
.7474 .18821 Mdot
.74745 .34413 Mdot
.7475 .31939 Mdot
.74755 .09291 Mdot
.74759 .32644 Mdot
.74764 .3188 Mdot
.74769 .31905 Mdot
.74774 .23764 Mdot
.74778 .32778 Mdot
.74783 .16561 Mdot
.74788 .33453 Mdot
.74793 .19319 Mdot
.74798 .30679 Mdot
.74802 .31152 Mdot
.74807 .12897 Mdot
.74812 .07195 Mdot
.74817 .28164 Mdot
.74821 .19631 Mdot
.74826 .27 Mdot
.74831 .25473 Mdot
.74836 .12085 Mdot
.7484 .13463 Mdot
.74845 .17832 Mdot
.7485 .12175 Mdot
.74855 .28271 Mdot
.74859 .14043 Mdot
.74864 .20872 Mdot
.74869 .08364 Mdot
.74874 .30578 Mdot
.74878 .171 Mdot
.74883 .23889 Mdot
.74888 .19508 Mdot
.74893 .32694 Mdot
.74898 .05934 Mdot
.74902 .25302 Mdot
.74907 .05555 Mdot
.74912 .07367 Mdot
.74917 .09605 Mdot
.74921 .17729 Mdot
.74926 .33155 Mdot
.74931 .13985 Mdot
.74936 .24742 Mdot
.7494 .25482 Mdot
.74945 .12937 Mdot
.7495 .07141 Mdot
.74955 .16505 Mdot
.74959 .12864 Mdot
.74964 .0596 Mdot
.74969 .13541 Mdot
.74974 .07633 Mdot
.74978 .26635 Mdot
.74983 .32226 Mdot
.74988 .17579 Mdot
.74993 .25135 Mdot
.74998 .07849 Mdot
.75002 .17806 Mdot
.75007 .19446 Mdot
.75012 .24263 Mdot
.75017 .17081 Mdot
.75021 .17286 Mdot
.75026 .171 Mdot
.75031 .19665 Mdot
.75036 .33832 Mdot
.7504 .18597 Mdot
.75045 .08082 Mdot
.7505 .29363 Mdot
.75055 .1329 Mdot
.75059 .10587 Mdot
.75064 .05854 Mdot
.75069 .17758 Mdot
.75074 .05313 Mdot
.75078 .09501 Mdot
.75083 .26659 Mdot
.75088 .14972 Mdot
.75093 .12997 Mdot
.75097 .11581 Mdot
.75102 .13887 Mdot
.75107 .24117 Mdot
.75112 .09929 Mdot
.75117 .28028 Mdot
.75121 .28682 Mdot
.75126 .04595 Mdot
.75131 .27062 Mdot
.75136 .15458 Mdot
.7514 .16285 Mdot
.75145 .19106 Mdot
.7515 .27393 Mdot
.75155 .3101 Mdot
.75159 .12854 Mdot
.75164 .23866 Mdot
.75169 .18728 Mdot
.75174 .25035 Mdot
.75178 .11599 Mdot
.75183 .10695 Mdot
.75188 .17989 Mdot
.75193 .20095 Mdot
.75197 .18974 Mdot
.75202 .29745 Mdot
.75207 .09514 Mdot
.75212 .13024 Mdot
.75217 .09584 Mdot
.75221 .10113 Mdot
.75226 .33543 Mdot
.75231 .18941 Mdot
.75236 .14835 Mdot
.7524 .09952 Mdot
.75245 .10902 Mdot
.7525 .07893 Mdot
.75255 .32433 Mdot
.75259 .24716 Mdot
.75264 .17367 Mdot
.75269 .10728 Mdot
.75274 .23926 Mdot
.75278 .05184 Mdot
.75283 .32447 Mdot
.75288 .19489 Mdot
.75293 .16624 Mdot
.75297 .2826 Mdot
.75302 .18732 Mdot
.75307 .3314 Mdot
.75312 .31385 Mdot
.75317 .32238 Mdot
.75321 .13442 Mdot
.75326 .24329 Mdot
.75331 .26001 Mdot
.75336 .26314 Mdot
.7534 .13562 Mdot
.75345 .09552 Mdot
.7535 .15318 Mdot
.75355 .20502 Mdot
.75359 .06788 Mdot
.75364 .05776 Mdot
.75369 .16476 Mdot
.75374 .29364 Mdot
.75378 .22987 Mdot
.75383 .28602 Mdot
.75388 .26092 Mdot
.75393 .28225 Mdot
.75397 .24059 Mdot
.75402 .13135 Mdot
.75407 .13478 Mdot
.75412 .03963 Mdot
.75417 .09313 Mdot
.75421 .13454 Mdot
.75426 .15542 Mdot
.75431 .05162 Mdot
.75436 .29296 Mdot
.7544 .2254 Mdot
.75445 .22944 Mdot
.7545 .12239 Mdot
.75455 .19628 Mdot
.75459 .1687 Mdot
.75464 .11496 Mdot
.75469 .25081 Mdot
.75474 .16688 Mdot
.75478 .14931 Mdot
.75483 .28332 Mdot
.75488 .29017 Mdot
.75493 .2699 Mdot
.75497 .19606 Mdot
.75502 .06019 Mdot
.75507 .04561 Mdot
.75512 .06689 Mdot
.75516 .10218 Mdot
.75521 .25762 Mdot
.75526 .04322 Mdot
.75531 .30575 Mdot
.75536 .29951 Mdot
.7554 .13911 Mdot
.75545 .32326 Mdot
.7555 .04947 Mdot
.75555 .11069 Mdot
.75559 .241 Mdot
.75564 .23723 Mdot
.75569 .1843 Mdot
.75574 .27299 Mdot
.75578 .16207 Mdot
.75583 .3172 Mdot
.75588 .05323 Mdot
.75593 .15939 Mdot
.75597 .20921 Mdot
.75602 .06252 Mdot
.75607 .11357 Mdot
.75612 .29347 Mdot
.75616 .18419 Mdot
.75621 .05198 Mdot
.75626 .08164 Mdot
.75631 .22614 Mdot
.75636 .25617 Mdot
.7564 .04341 Mdot
.75645 .10529 Mdot
.7565 .25592 Mdot
.75655 .15138 Mdot
.75659 .04922 Mdot
.75664 .08993 Mdot
.75669 .17925 Mdot
.75674 .23915 Mdot
.75678 .14065 Mdot
.75683 .2342 Mdot
.75688 .23471 Mdot
.75693 .11058 Mdot
.75697 .15171 Mdot
.75702 .21426 Mdot
.75707 .10852 Mdot
.75712 .22932 Mdot
.75716 .12217 Mdot
.75721 .13358 Mdot
.75726 .14269 Mdot
.75731 .07781 Mdot
.75736 .10277 Mdot
.7574 .08442 Mdot
.75745 .24379 Mdot
.7575 .14878 Mdot
.75755 .09155 Mdot
.75759 .30607 Mdot
.75764 .3147 Mdot
.75769 .32414 Mdot
.75774 .07411 Mdot
.75778 .24783 Mdot
.75783 .16705 Mdot
.75788 .11649 Mdot
.75793 .25971 Mdot
.75797 .04493 Mdot
.75802 .25839 Mdot
.75807 .03701 Mdot
.75812 .13901 Mdot
.75816 .15644 Mdot
.75821 .18069 Mdot
.75826 .13327 Mdot
.75831 .04747 Mdot
.75836 .0534 Mdot
.7584 .06844 Mdot
.75845 .0858 Mdot
.7585 .2698 Mdot
.75855 .29399 Mdot
.75859 .14957 Mdot
.75864 .26184 Mdot
.75869 .20812 Mdot
.75874 .31255 Mdot
.75878 .1594 Mdot
.75883 .26214 Mdot
.75888 .16351 Mdot
.75893 .09413 Mdot
.75897 .31653 Mdot
.75902 .17488 Mdot
.75907 .22778 Mdot
.75912 .07824 Mdot
.75916 .08709 Mdot
.75921 .16673 Mdot
.75926 .11754 Mdot
.75931 .24533 Mdot
.75936 .22984 Mdot
.7594 .06195 Mdot
.75945 .09848 Mdot
.7595 .22026 Mdot
.75955 .18964 Mdot
.75959 .29915 Mdot
.75964 .1516 Mdot
.75969 .2491 Mdot
.75974 .06795 Mdot
.75978 .06511 Mdot
.75983 .26604 Mdot
.75988 .25903 Mdot
.75993 .23094 Mdot
.75997 .12526 Mdot
.76002 .12989 Mdot
.76007 .19217 Mdot
.76012 .23645 Mdot
.76016 .27234 Mdot
.76021 .22398 Mdot
.76026 .14087 Mdot
.76031 .17621 Mdot
.76035 .13238 Mdot
.7604 .13312 Mdot
.76045 .21698 Mdot
.7605 .26773 Mdot
.76055 .09685 Mdot
.76059 .06098 Mdot
.76064 .31784 Mdot
.76069 .10428 Mdot
.76074 .11865 Mdot
.76078 .23025 Mdot
.76083 .09467 Mdot
.76088 .06218 Mdot
.76093 .07932 Mdot
.76097 .28476 Mdot
.76102 .15611 Mdot
.76107 .15163 Mdot
.76112 .27436 Mdot
.76116 .18024 Mdot
.76121 .28409 Mdot
.76126 .23524 Mdot
.76131 .02715 Mdot
.76135 .27617 Mdot
.7614 .16819 Mdot
.76145 .08393 Mdot
.7615 .21444 Mdot
.76155 .1678 Mdot
.76159 .27073 Mdot
.76164 .13563 Mdot
.76169 .1421 Mdot
.76174 .13125 Mdot
.76178 .2721 Mdot
.76183 .05564 Mdot
.76188 .04765 Mdot
.76193 .21998 Mdot
.76197 .20148 Mdot
.76202 .31229 Mdot
.76207 .28709 Mdot
.76212 .2539 Mdot
.76216 .06912 Mdot
.76221 .18435 Mdot
.76226 .03634 Mdot
.76231 .09719 Mdot
.76235 .10335 Mdot
.7624 .26735 Mdot
.76245 .03251 Mdot
.7625 .13911 Mdot
.76255 .25318 Mdot
.76259 .20651 Mdot
.76264 .13595 Mdot
.76269 .28913 Mdot
.76274 .30019 Mdot
.76278 .09369 Mdot
.76283 .31144 Mdot
.76288 .18054 Mdot
.76293 .05069 Mdot
.76297 .06058 Mdot
.76302 .28625 Mdot
.76307 .27781 Mdot
.76312 .16639 Mdot
.76316 .0654 Mdot
.76321 .02135 Mdot
.76326 .04602 Mdot
.76331 .11932 Mdot
.76335 .1979 Mdot
.7634 .30178 Mdot
.76345 .26553 Mdot
.7635 .03775 Mdot
.76355 .24712 Mdot
.76359 .29092 Mdot
.76364 .148 Mdot
.76369 .10094 Mdot
.76374 .06206 Mdot
.76378 .17636 Mdot
.76383 .17506 Mdot
.76388 .11687 Mdot
.76393 .28442 Mdot
.76397 .18091 Mdot
.76402 .31044 Mdot
.76407 .08718 Mdot
.76412 .24478 Mdot
.76416 .21039 Mdot
.76421 .05344 Mdot
.76426 .2364 Mdot
.76431 .20006 Mdot
.76435 .20967 Mdot
.7644 .02798 Mdot
.76445 .13758 Mdot
.7645 .02261 Mdot
.76454 .22313 Mdot
.76459 .07763 Mdot
.76464 .1201 Mdot
.76469 .09054 Mdot
.76474 .2472 Mdot
.76478 .24457 Mdot
.76483 .03918 Mdot
.76488 .04845 Mdot
.76493 .09075 Mdot
.76497 .08936 Mdot
.76502 .23696 Mdot
.76507 .07861 Mdot
.76512 .22437 Mdot
.76516 .0934 Mdot
.76521 .16935 Mdot
.76526 .1482 Mdot
.76531 .03344 Mdot
.76535 .05935 Mdot
.7654 .24714 Mdot
.76545 .26227 Mdot
.7655 .13785 Mdot
.76554 .05054 Mdot
.76559 .12868 Mdot
.76564 .25872 Mdot
.76569 .22859 Mdot
.76574 .28672 Mdot
.76578 .02748 Mdot
.76583 .18703 Mdot
.76588 .29504 Mdot
.76593 .06089 Mdot
.76597 .30184 Mdot
.76602 .15722 Mdot
.76607 .22288 Mdot
.76612 .28493 Mdot
.76616 .08336 Mdot
.76621 .09703 Mdot
.76626 .31174 Mdot
.76631 .20986 Mdot
.76635 .22715 Mdot
.7664 .26192 Mdot
.76645 .29648 Mdot
.7665 .16864 Mdot
.76654 .29295 Mdot
.76659 .01769 Mdot
.76664 .17661 Mdot
.76669 .13604 Mdot
.76674 .18216 Mdot
.76678 .07166 Mdot
.76683 .26067 Mdot
.76688 .16193 Mdot
.76693 .17238 Mdot
.76697 .19714 Mdot
.76702 .2781 Mdot
.76707 .11859 Mdot
.76712 .18291 Mdot
.76716 .0574 Mdot
.76721 .07264 Mdot
.76726 .1459 Mdot
.76731 .11688 Mdot
.76735 .27251 Mdot
.7674 .07301 Mdot
.76745 .2481 Mdot
.7675 .20174 Mdot
.76754 .0277 Mdot
.76759 .08846 Mdot
.76764 .09649 Mdot
.76769 .22063 Mdot
.76774 .02696 Mdot
.76778 .2236 Mdot
.76783 .27217 Mdot
.76788 .05529 Mdot
.76793 .26694 Mdot
.76797 .27453 Mdot
.76802 .12694 Mdot
.76807 .19443 Mdot
.76812 .08641 Mdot
.76816 .30787 Mdot
.76821 .02489 Mdot
.76826 .02802 Mdot
.76831 .04548 Mdot
.76835 .25165 Mdot
.7684 .19023 Mdot
.76845 .22235 Mdot
.7685 .08414 Mdot
.76854 .19491 Mdot
.76859 .25322 Mdot
.76864 .03681 Mdot
.76869 .0726 Mdot
.76874 .12258 Mdot
.76878 .17282 Mdot
.76883 .12709 Mdot
.76888 .06166 Mdot
.76893 .20982 Mdot
.76897 .21146 Mdot
.76902 .08771 Mdot
.76907 .10546 Mdot
.76912 .246 Mdot
.76916 .10033 Mdot
.76921 .20392 Mdot
.76926 .0348 Mdot
.76931 .2487 Mdot
.76935 .09113 Mdot
.7694 .19155 Mdot
.76945 .29979 Mdot
.7695 .30749 Mdot
.76954 .21131 Mdot
.76959 .27958 Mdot
.76964 .23114 Mdot
.76969 .12804 Mdot
.76973 .26838 Mdot
.76978 .25817 Mdot
.76983 .17391 Mdot
.76988 .0208 Mdot
.76993 .11088 Mdot
.76997 .14637 Mdot
.77002 .12751 Mdot
.77007 .12107 Mdot
.77012 .20948 Mdot
.77016 .07383 Mdot
.77021 .03719 Mdot
.77026 .18504 Mdot
.77031 .12424 Mdot
.77035 .17983 Mdot
.7704 .01743 Mdot
.77045 .24621 Mdot
.7705 .0481 Mdot
.77054 .29811 Mdot
.77059 .02744 Mdot
.77064 .24849 Mdot
.77069 .14654 Mdot
.77073 .03339 Mdot
.77078 .10599 Mdot
.77083 .13526 Mdot
.77088 .18781 Mdot
.77093 .08485 Mdot
.77097 .24168 Mdot
.77102 .12918 Mdot
.77107 .09163 Mdot
.77112 .24802 Mdot
.77116 .12884 Mdot
.77121 .02275 Mdot
.77126 .19163 Mdot
.77131 .18879 Mdot
.77135 .10622 Mdot
.7714 .14712 Mdot
.77145 .08192 Mdot
.7715 .02347 Mdot
.77154 .10328 Mdot
.77159 .21024 Mdot
.77164 .04828 Mdot
.77169 .03466 Mdot
.77173 .09026 Mdot
.77178 .27102 Mdot
.77183 .21098 Mdot
.77188 .01564 Mdot
.77193 .29348 Mdot
.77197 .15009 Mdot
.77202 .03749 Mdot
.77207 .23994 Mdot
.77212 .06608 Mdot
.77216 .03518 Mdot
.77221 .25497 Mdot
.77226 .30102 Mdot
.77231 .24633 Mdot
.77235 .02664 Mdot
.7724 .07754 Mdot
.77245 .12642 Mdot
.7725 .15428 Mdot
.77254 .18853 Mdot
.77259 .30462 Mdot
.77264 .11708 Mdot
.77269 .06511 Mdot
.77273 .28724 Mdot
.77278 .27043 Mdot
.77283 .0965 Mdot
.77288 .28378 Mdot
.77293 .03028 Mdot
.77297 .0735 Mdot
.77302 .0949 Mdot
.77307 .29918 Mdot
.77312 .18907 Mdot
.77316 .05001 Mdot
.77321 .16381 Mdot
.77326 .24709 Mdot
.77331 .16787 Mdot
.77335 .10387 Mdot
.7734 .17161 Mdot
.77345 .01472 Mdot
.7735 .15518 Mdot
.77354 .04027 Mdot
.77359 .05913 Mdot
.77364 .16922 Mdot
.77369 .27543 Mdot
.77373 .04443 Mdot
.77378 .25081 Mdot
.77383 .11801 Mdot
.77388 .29694 Mdot
.77392 .08274 Mdot
.77397 .16821 Mdot
.77402 .14298 Mdot
.77407 .28054 Mdot
.77412 .02312 Mdot
.77416 .08718 Mdot
.77421 .15252 Mdot
.77426 .10534 Mdot
.77431 .28183 Mdot
.77435 .23209 Mdot
.7744 .21415 Mdot
.77445 .24618 Mdot
.7745 .19181 Mdot
.77454 .07433 Mdot
.77459 .21329 Mdot
.77464 .10486 Mdot
.77469 .16539 Mdot
.77473 .02906 Mdot
.77478 .05792 Mdot
.77483 .13814 Mdot
.77488 .13482 Mdot
.77492 .08695 Mdot
.77497 .24862 Mdot
.77502 .14991 Mdot
.77507 .06593 Mdot
.77512 .22746 Mdot
.77516 .1195 Mdot
.77521 .17809 Mdot
.77526 .05668 Mdot
.77531 .15416 Mdot
.77535 .27571 Mdot
.7754 .08664 Mdot
.77545 .0836 Mdot
.7755 .23081 Mdot
.77554 .07546 Mdot
.77559 .14921 Mdot
.77564 .20055 Mdot
.77569 .17039 Mdot
.77573 .17094 Mdot
.77578 .05827 Mdot
.77583 .04908 Mdot
.77588 .15527 Mdot
.77592 .12696 Mdot
.77597 .22894 Mdot
.77602 .22308 Mdot
.77607 .08228 Mdot
.77612 .18718 Mdot
.77616 .09302 Mdot
.77621 .17113 Mdot
.77626 .16368 Mdot
.77631 .08168 Mdot
.77635 .22379 Mdot
.7764 .12847 Mdot
.77645 .02356 Mdot
.7765 .11487 Mdot
.77654 .15122 Mdot
.77659 .05895 Mdot
.77664 .10168 Mdot
.77669 .0535 Mdot
.77673 .01611 Mdot
.77678 .16737 Mdot
.77683 .24027 Mdot
.77688 .19156 Mdot
.77692 .26685 Mdot
.77697 .13246 Mdot
.77702 .09919 Mdot
.77707 .07879 Mdot
.77712 .05211 Mdot
.77716 .21847 Mdot
.77721 .03114 Mdot
.77726 .20073 Mdot
.77731 .26823 Mdot
.77735 .06162 Mdot
.7774 .17662 Mdot
.77745 .13337 Mdot
.7775 .05876 Mdot
.77754 .24235 Mdot
.77759 .16744 Mdot
.77764 .03289 Mdot
.77769 .21681 Mdot
.77773 .19783 Mdot
.77778 .0802 Mdot
.77783 .2887 Mdot
.77788 .21518 Mdot
.77792 .04495 Mdot
.77797 .1493 Mdot
.77802 .11167 Mdot
.77807 .25774 Mdot
.77812 .22192 Mdot
.77816 .06471 Mdot
.77821 .04749 Mdot
.77826 .22026 Mdot
.77831 .01811 Mdot
.77835 .04825 Mdot
.7784 .15632 Mdot
.77845 .26162 Mdot
.7785 .26609 Mdot
.77854 .18125 Mdot
.77859 .03774 Mdot
.77864 .21767 Mdot
.77869 .03858 Mdot
.77873 .02867 Mdot
.77878 .01974 Mdot
.77883 .01577 Mdot
.77888 .15055 Mdot
.77892 .2583 Mdot
.77897 .04089 Mdot
.77902 .11047 Mdot
.77907 .12064 Mdot
.77911 .12407 Mdot
.77916 .23917 Mdot
.77921 .1627 Mdot
.77926 .20872 Mdot
.77931 .07453 Mdot
.77935 .20688 Mdot
.7794 .25253 Mdot
.77945 .20586 Mdot
.7795 .04157 Mdot
.77954 .06588 Mdot
.77959 .30111 Mdot
.77964 .25 Mdot
.77969 .17059 Mdot
.77973 .04357 Mdot
.77978 .0989 Mdot
.77983 .22691 Mdot
.77988 .15744 Mdot
.77992 .03938 Mdot
.77997 .09871 Mdot
.78002 .09199 Mdot
.78007 .20965 Mdot
.78011 .30903 Mdot
.78016 .29881 Mdot
.78021 .28195 Mdot
.78026 .10136 Mdot
.78031 .08567 Mdot
.78035 .15196 Mdot
.7804 .08912 Mdot
.78045 .04275 Mdot
.7805 .1896 Mdot
.78054 .21027 Mdot
.78059 .19413 Mdot
.78064 .01723 Mdot
.78069 .13981 Mdot
.78073 .22015 Mdot
.78078 .25515 Mdot
.78083 .1577 Mdot
.78088 .11248 Mdot
.78092 .13752 Mdot
.78097 .04455 Mdot
.78102 .31147 Mdot
.78107 .08948 Mdot
.78111 .05524 Mdot
.78116 .26388 Mdot
.78121 .11832 Mdot
.78126 .09185 Mdot
.78131 .06786 Mdot
.78135 .2934 Mdot
.7814 .03362 Mdot
.78145 .02287 Mdot
.7815 .2275 Mdot
.78154 .22107 Mdot
.78159 .30255 Mdot
.78164 .14499 Mdot
.78169 .03413 Mdot
.78173 .04388 Mdot
.78178 .30231 Mdot
.78183 .02221 Mdot
.78188 .12591 Mdot
.78192 .1007 Mdot
.78197 .16177 Mdot
.78202 .22179 Mdot
.78207 .30048 Mdot
.78211 .07344 Mdot
.78216 .16249 Mdot
.78221 .14969 Mdot
.78226 .26267 Mdot
.78231 .12188 Mdot
.78235 .06168 Mdot
.7824 .0754 Mdot
.78245 .21242 Mdot
.7825 .14099 Mdot
.78254 .04577 Mdot
.78259 .07028 Mdot
.78264 .29757 Mdot
.78269 .23262 Mdot
.78273 .05596 Mdot
.78278 .23808 Mdot
.78283 .28143 Mdot
.78288 .20677 Mdot
.78292 .0666 Mdot
.78297 .234 Mdot
.78302 .1737 Mdot
.78307 .1243 Mdot
.78311 .21797 Mdot
.78316 .03054 Mdot
.78321 .18646 Mdot
.78326 .06929 Mdot
.78331 .07396 Mdot
.78335 .19425 Mdot
.7834 .23723 Mdot
.78345 .2609 Mdot
.7835 .03097 Mdot
.78354 .13759 Mdot
.78359 .0436 Mdot
.78364 .13876 Mdot
.78369 .29896 Mdot
.78373 .08626 Mdot
.78378 .0599 Mdot
.78383 .22006 Mdot
.78388 .26211 Mdot
.78392 .16221 Mdot
.78397 .09255 Mdot
.78402 .03257 Mdot
.78407 .21485 Mdot
.78411 .24246 Mdot
.78416 .23315 Mdot
.78421 .22263 Mdot
.78426 .3113 Mdot
.7843 .23153 Mdot
.78435 .06637 Mdot
.7844 .17307 Mdot
.78445 .25713 Mdot
.7845 .05713 Mdot
.78454 .1439 Mdot
.78459 .22699 Mdot
.78464 .24618 Mdot
.78469 .23448 Mdot
.78473 .12044 Mdot
.78478 .10843 Mdot
.78483 .26234 Mdot
.78488 .16854 Mdot
.78492 .08093 Mdot
.78497 .20368 Mdot
.78502 .3156 Mdot
.78507 .0269 Mdot
.78511 .30386 Mdot
.78516 .1918 Mdot
.78521 .1215 Mdot
.78526 .10011 Mdot
.7853 .09159 Mdot
.78535 .28497 Mdot
.7854 .12606 Mdot
.78545 .1845 Mdot
.7855 .04635 Mdot
.78554 .13309 Mdot
.78559 .18505 Mdot
.78564 .14869 Mdot
.78569 .21869 Mdot
.78573 .22241 Mdot
.78578 .25524 Mdot
.78583 .23065 Mdot
.78588 .1199 Mdot
.78592 .13569 Mdot
.78597 .30953 Mdot
.78602 .08395 Mdot
.78607 .06089 Mdot
.78611 .24886 Mdot
.78616 .31084 Mdot
.78621 .07918 Mdot
.78626 .07407 Mdot
.7863 .07931 Mdot
.78635 .21167 Mdot
.7864 .29632 Mdot
.78645 .29981 Mdot
.7865 .11173 Mdot
.78654 .10821 Mdot
.78659 .13449 Mdot
.78664 .2762 Mdot
.78669 .2963 Mdot
.78673 .2409 Mdot
.78678 .30361 Mdot
.78683 .08053 Mdot
.78688 .09699 Mdot
.78692 .30369 Mdot
.78697 .0962 Mdot
.78702 .2788 Mdot
.78707 .27953 Mdot
.78711 .31247 Mdot
.78716 .03578 Mdot
.78721 .24152 Mdot
.78726 .05436 Mdot
.7873 .02539 Mdot
.78735 .27528 Mdot
.7874 .19134 Mdot
.78745 .29388 Mdot
.7875 .13263 Mdot
.78754 .29795 Mdot
.78759 .2106 Mdot
.78764 .20643 Mdot
.78769 .04878 Mdot
.78773 .1879 Mdot
.78778 .25376 Mdot
.78783 .22956 Mdot
.78788 .1274 Mdot
.78792 .20389 Mdot
.78797 .19805 Mdot
.78802 .15747 Mdot
.78807 .14354 Mdot
.78811 .13274 Mdot
.78816 .23923 Mdot
.78821 .198 Mdot
.78826 .15121 Mdot
.7883 .12233 Mdot
.78835 .31802 Mdot
.7884 .16917 Mdot
.78845 .15143 Mdot
.78849 .16759 Mdot
.78854 .15245 Mdot
.78859 .19601 Mdot
.78864 .04474 Mdot
.78869 .19051 Mdot
.78873 .26281 Mdot
.78878 .31062 Mdot
.78883 .31708 Mdot
.78888 .02896 Mdot
.78892 .03547 Mdot
.78897 .10757 Mdot
.78902 .21628 Mdot
.78907 .14661 Mdot
.78911 .15905 Mdot
.78916 .2718 Mdot
.78921 .09968 Mdot
.78926 .04089 Mdot
.7893 .24177 Mdot
.78935 .10098 Mdot
.7894 .2706 Mdot
.78945 .24077 Mdot
.78949 .24605 Mdot
.78954 .2542 Mdot
.78959 .14678 Mdot
.78964 .10088 Mdot
.78969 .1214 Mdot
.78973 .08607 Mdot
.78978 .13001 Mdot
.78983 .23328 Mdot
.78988 .18159 Mdot
.78992 .09855 Mdot
.78997 .13611 Mdot
.79002 .23273 Mdot
.79007 .17461 Mdot
.79011 .31443 Mdot
.79016 .24336 Mdot
.79021 .11488 Mdot
.79026 .04443 Mdot
.7903 .07158 Mdot
.79035 .17273 Mdot
.7904 .10313 Mdot
.79045 .12673 Mdot
.79049 .29477 Mdot
.79054 .22639 Mdot
.79059 .18671 Mdot
.79064 .20513 Mdot
.79069 .07025 Mdot
.79073 .10939 Mdot
.79078 .1157 Mdot
.79083 .11369 Mdot
.79088 .30909 Mdot
.79092 .30439 Mdot
.79097 .20753 Mdot
.79102 .2573 Mdot
.79107 .24098 Mdot
.79111 .19881 Mdot
.79116 .30028 Mdot
.79121 .11341 Mdot
.79126 .25223 Mdot
.7913 .28122 Mdot
.79135 .21641 Mdot
.7914 .10009 Mdot
.79145 .21185 Mdot
.79149 .13979 Mdot
.79154 .14467 Mdot
.79159 .29971 Mdot
.79164 .24353 Mdot
.79169 .23994 Mdot
.79173 .2846 Mdot
.79178 .12647 Mdot
.79183 .20526 Mdot
.79188 .16264 Mdot
.79192 .20108 Mdot
.79197 .04506 Mdot
.79202 .22341 Mdot
.79207 .18559 Mdot
.79211 .321 Mdot
.79216 .11529 Mdot
.79221 .31007 Mdot
.79226 .31453 Mdot
.7923 .0537 Mdot
.79235 .32983 Mdot
.7924 .09103 Mdot
.79245 .0666 Mdot
.79249 .16555 Mdot
.79254 .26324 Mdot
.79259 .20763 Mdot
.79264 .25537 Mdot
.79269 .05468 Mdot
.79273 .29229 Mdot
.79278 .29297 Mdot
.79283 .04954 Mdot
.79288 .09916 Mdot
.79292 .20015 Mdot
.79297 .12214 Mdot
.79302 .2163 Mdot
.79307 .22757 Mdot
.79311 .18984 Mdot
.79316 .22844 Mdot
.79321 .06566 Mdot
.79326 .23649 Mdot
.7933 .10972 Mdot
.79335 .24851 Mdot
.7934 .08138 Mdot
.79345 .21828 Mdot
.79349 .11035 Mdot
.79354 .19319 Mdot
.79359 .05059 Mdot
.79364 .08865 Mdot
.79368 .178 Mdot
.79373 .31655 Mdot
.79378 .12632 Mdot
.79383 .07033 Mdot
.79388 .21703 Mdot
.79392 .06016 Mdot
.79397 .11347 Mdot
.79402 .30283 Mdot
.79407 .05379 Mdot
.79411 .26989 Mdot
.79416 .22916 Mdot
.79421 .1125 Mdot
.79426 .19616 Mdot
.7943 .07892 Mdot
.79435 .20107 Mdot
.7944 .20855 Mdot
.79445 .12424 Mdot
.79449 .16318 Mdot
.79454 .15772 Mdot
.79459 .32327 Mdot
.79464 .05214 Mdot
.79468 .30321 Mdot
.79473 .14561 Mdot
.79478 .27321 Mdot
.79483 .20771 Mdot
.79488 .32034 Mdot
.79492 .05823 Mdot
.79497 .24193 Mdot
.79502 .3247 Mdot
.79507 .29946 Mdot
.79511 .27901 Mdot
.79516 .27347 Mdot
.79521 .31054 Mdot
.79526 .06932 Mdot
.7953 .08972 Mdot
.79535 .20095 Mdot
.7954 .15448 Mdot
.79545 .32548 Mdot
.79549 .22384 Mdot
.79554 .3277 Mdot
.79559 .07081 Mdot
.79564 .20299 Mdot
.79568 .10692 Mdot
.79573 .04536 Mdot
.79578 .05971 Mdot
.79583 .23579 Mdot
.79588 .29745 Mdot
.79592 .10841 Mdot
.79597 .18838 Mdot
.79602 .25195 Mdot
.79607 .28098 Mdot
.79611 .20322 Mdot
.79616 .20054 Mdot
.79621 .28947 Mdot
.79626 .33907 Mdot
.7963 .26697 Mdot
.79635 .22734 Mdot
.7964 .26276 Mdot
.79645 .29208 Mdot
.79649 .10887 Mdot
.79654 .11584 Mdot
.79659 .27524 Mdot
.79664 .11147 Mdot
.79668 .11937 Mdot
.79673 .08849 Mdot
.79678 .11585 Mdot
.79683 .04827 Mdot
.79688 .11786 Mdot
.79692 .07275 Mdot
.79697 .21901 Mdot
.79702 .08989 Mdot
.79707 .05379 Mdot
.79711 .2237 Mdot
.79716 .3065 Mdot
.79721 .14849 Mdot
.79726 .19028 Mdot
.7973 .06813 Mdot
.79735 .06213 Mdot
.7974 .1495 Mdot
.79745 .26352 Mdot
.79749 .18113 Mdot
.79754 .13984 Mdot
.79759 .19802 Mdot
.79764 .20051 Mdot
.79768 .11129 Mdot
.79773 .20557 Mdot
.79778 .1328 Mdot
.79783 .12752 Mdot
.79787 .0693 Mdot
.79792 .13636 Mdot
.79797 .1313 Mdot
.79802 .05656 Mdot
.79807 .33843 Mdot
.79811 .25936 Mdot
.79816 .08869 Mdot
.79821 .05018 Mdot
.79826 .16228 Mdot
.7983 .2954 Mdot
.79835 .28287 Mdot
.7984 .2027 Mdot
.79845 .14222 Mdot
.79849 .28147 Mdot
.79854 .1817 Mdot
.79859 .28251 Mdot
.79864 .30455 Mdot
.79868 .19037 Mdot
.79873 .32741 Mdot
.79878 .13101 Mdot
.79883 .24239 Mdot
.79887 .32892 Mdot
.79892 .24401 Mdot
.79897 .05303 Mdot
.79902 .22277 Mdot
.79907 .24237 Mdot
.79911 .16266 Mdot
.79916 .3414 Mdot
.79921 .2294 Mdot
.79926 .32821 Mdot
.7993 .12445 Mdot
.79935 .34184 Mdot
.7994 .11788 Mdot
.79945 .08371 Mdot
.79949 .18747 Mdot
.79954 .1903 Mdot
.79959 .32181 Mdot
.79964 .14853 Mdot
.79968 .05734 Mdot
.79973 .25436 Mdot
.79978 .06912 Mdot
.79983 .30501 Mdot
.79987 .07692 Mdot
.79992 .17562 Mdot
.79997 .17398 Mdot
.80002 .32349 Mdot
.80007 .18045 Mdot
.80011 .17541 Mdot
.80016 .29903 Mdot
.80021 .13422 Mdot
.80026 .07103 Mdot
.8003 .18224 Mdot
.80035 .12315 Mdot
.8004 .15452 Mdot
.80045 .29524 Mdot
.80049 .1892 Mdot
.80054 .05936 Mdot
.80059 .12504 Mdot
.80064 .16214 Mdot
.80068 .34827 Mdot
.80073 .08706 Mdot
.80078 .32616 Mdot
.80083 .15974 Mdot
.80087 .14899 Mdot
.80092 .07316 Mdot
.80097 .07652 Mdot
.80102 .13832 Mdot
.80107 .32388 Mdot
.80111 .24983 Mdot
.80116 .10382 Mdot
.80121 .30881 Mdot
.80126 .2047 Mdot
.8013 .30203 Mdot
.80135 .32098 Mdot
.8014 .29444 Mdot
.80145 .07927 Mdot
.80149 .23583 Mdot
.80154 .22356 Mdot
.80159 .3513 Mdot
.80164 .24231 Mdot
.80168 .234 Mdot
.80173 .1562 Mdot
.80178 .24699 Mdot
.80183 .24688 Mdot
.80187 .20506 Mdot
.80192 .18316 Mdot
.80197 .14567 Mdot
.80202 .15646 Mdot
.80207 .19061 Mdot
.80211 .1655 Mdot
.80216 .06635 Mdot
.80221 .18659 Mdot
.80226 .29494 Mdot
.8023 .12113 Mdot
.80235 .112 Mdot
.8024 .3365 Mdot
.80245 .34767 Mdot
.80249 .15506 Mdot
.80254 .17261 Mdot
.80259 .31758 Mdot
.80264 .17235 Mdot
.80268 .28701 Mdot
.80273 .17697 Mdot
.80278 .13622 Mdot
.80283 .29431 Mdot
.80287 .19207 Mdot
.80292 .28624 Mdot
.80297 .24575 Mdot
.80302 .15096 Mdot
.80306 .07077 Mdot
.80311 .20259 Mdot
.80316 .15146 Mdot
.80321 .31752 Mdot
.80326 .26259 Mdot
.8033 .19886 Mdot
.80335 .32251 Mdot
.8034 .0855 Mdot
.80345 .20454 Mdot
.80349 .1501 Mdot
.80354 .34426 Mdot
.80359 .09623 Mdot
.80364 .11318 Mdot
.80368 .33619 Mdot
.80373 .09069 Mdot
.80378 .2829 Mdot
.80383 .18534 Mdot
.80387 .2237 Mdot
.80392 .31395 Mdot
.80397 .34823 Mdot
.80402 .35307 Mdot
.80406 .29741 Mdot
.80411 .13345 Mdot
.80416 .26268 Mdot
.80421 .34786 Mdot
.80426 .16054 Mdot
.8043 .34272 Mdot
.80435 .30605 Mdot
.8044 .15146 Mdot
.80445 .32289 Mdot
.80449 .08672 Mdot
.80454 .28721 Mdot
.80459 .3086 Mdot
.80464 .23977 Mdot
.80468 .10446 Mdot
.80473 .25828 Mdot
.80478 .26287 Mdot
.80483 .26605 Mdot
.80487 .08154 Mdot
.80492 .33818 Mdot
.80497 .14563 Mdot
.80502 .1106 Mdot
.80506 .13086 Mdot
.80511 .35338 Mdot
.80516 .15615 Mdot
.80521 .17694 Mdot
.80526 .36131 Mdot
.8053 .15991 Mdot
.80535 .17252 Mdot
.8054 .08594 Mdot
.80545 .08829 Mdot
.80549 .21857 Mdot
.80554 .09108 Mdot
.80559 .12809 Mdot
.80564 .36677 Mdot
.80568 .29672 Mdot
.80573 .148 Mdot
.80578 .25401 Mdot
.80583 .3333 Mdot
.80587 .10959 Mdot
.80592 .2513 Mdot
.80597 .3543 Mdot
.80602 .32341 Mdot
.80606 .13808 Mdot
.80611 .17765 Mdot
.80616 .31583 Mdot
.80621 .26485 Mdot
.80626 .15202 Mdot
.8063 .09413 Mdot
.80635 .21168 Mdot
.8064 .27135 Mdot
.80645 .36009 Mdot
.80649 .28976 Mdot
.80654 .19919 Mdot
.80659 .25668 Mdot
.80664 .2153 Mdot
.80668 .27263 Mdot
.80673 .14521 Mdot
.80678 .25905 Mdot
.80683 .28788 Mdot
.80687 .19924 Mdot
.80692 .26084 Mdot
.80697 .29556 Mdot
.80702 .2534 Mdot
.80706 .31807 Mdot
.80711 .27685 Mdot
.80716 .34262 Mdot
.80721 .19111 Mdot
.80725 .21637 Mdot
.8073 .332 Mdot
.80735 .15406 Mdot
.8074 .11554 Mdot
.80745 .19887 Mdot
.80749 .19711 Mdot
.80754 .25453 Mdot
.80759 .12744 Mdot
.80764 .28127 Mdot
.80768 .37025 Mdot
.80773 .37034 Mdot
.80778 .2848 Mdot
.80783 .08662 Mdot
.80787 .30319 Mdot
.80792 .1896 Mdot
.80797 .37027 Mdot
.80802 .26089 Mdot
.80806 .12117 Mdot
.80811 .2679 Mdot
.80816 .19603 Mdot
.80821 .31702 Mdot
.80825 .21869 Mdot
.8083 .29982 Mdot
.80835 .08478 Mdot
.8084 .18068 Mdot
.80845 .26175 Mdot
.80849 .22613 Mdot
.80854 .34464 Mdot
.80859 .35738 Mdot
.80864 .14552 Mdot
.80868 .34752 Mdot
.80873 .29843 Mdot
.80878 .15752 Mdot
.80883 .1517 Mdot
.80887 .35379 Mdot
.80892 .09555 Mdot
.80897 .153 Mdot
.80902 .22564 Mdot
.80906 .24663 Mdot
.80911 .10276 Mdot
.80916 .26976 Mdot
.80921 .18744 Mdot
.80925 .35673 Mdot
.8093 .28491 Mdot
.80935 .33109 Mdot
.8094 .34728 Mdot
.80945 .14075 Mdot
.80949 .28414 Mdot
.80954 .2346 Mdot
.80959 .1699 Mdot
.80964 .29403 Mdot
.80968 .31908 Mdot
.80973 .25698 Mdot
.80978 .10945 Mdot
.80983 .32662 Mdot
.80987 .10607 Mdot
.80992 .18506 Mdot
.80997 .33839 Mdot
.81002 .35364 Mdot
.81006 .09665 Mdot
.81011 .11837 Mdot
.81016 .19923 Mdot
.81021 .19368 Mdot
.81025 .37559 Mdot
.8103 .23049 Mdot
.81035 .09899 Mdot
.8104 .21918 Mdot
.81045 .17823 Mdot
.81049 .28199 Mdot
.81054 .13448 Mdot
.81059 .16651 Mdot
.81064 .27721 Mdot
.81068 .13583 Mdot
.81073 .34806 Mdot
.81078 .25615 Mdot
.81083 .34197 Mdot
.81087 .26288 Mdot
.81092 .32795 Mdot
.81097 .31391 Mdot
.81102 .3256 Mdot
.81106 .1677 Mdot
.81111 .37448 Mdot
.81116 .34537 Mdot
.81121 .31937 Mdot
.81125 .13993 Mdot
.8113 .26604 Mdot
.81135 .24266 Mdot
.8114 .32979 Mdot
.81145 .29563 Mdot
.81149 .25856 Mdot
.81154 .11517 Mdot
.81159 .24343 Mdot
.81164 .10569 Mdot
.81168 .21632 Mdot
.81173 .33593 Mdot
.81178 .35367 Mdot
.81183 .3575 Mdot
.81187 .25608 Mdot
.81192 .17293 Mdot
.81197 .10502 Mdot
.81202 .18814 Mdot
.81206 .31668 Mdot
.81211 .24775 Mdot
.81216 .16834 Mdot
.81221 .11468 Mdot
.81225 .33148 Mdot
.8123 .29185 Mdot
.81235 .23862 Mdot
.8124 .36458 Mdot
.81244 .16061 Mdot
.81249 .14454 Mdot
.81254 .29922 Mdot
.81259 .16467 Mdot
.81264 .29281 Mdot
.81268 .12546 Mdot
.81273 .15206 Mdot
.81278 .15543 Mdot
.81283 .17313 Mdot
.81287 .18121 Mdot
.81292 .19026 Mdot
.81297 .18998 Mdot
.81302 .30929 Mdot
.81306 .10585 Mdot
.81311 .18298 Mdot
.81316 .39464 Mdot
.81321 .38559 Mdot
.81325 .25126 Mdot
.8133 .11314 Mdot
.81335 .37863 Mdot
.8134 .15297 Mdot
.81344 .35331 Mdot
.81349 .26862 Mdot
.81354 .11348 Mdot
.81359 .38684 Mdot
.81364 .30857 Mdot
.81368 .36425 Mdot
.81373 .34384 Mdot
.81378 .19439 Mdot
.81383 .28366 Mdot
.81387 .31293 Mdot
.81392 .28934 Mdot
.81397 .12238 Mdot
.81402 .20375 Mdot
.81406 .22416 Mdot
.81411 .20104 Mdot
.81416 .20981 Mdot
.81421 .19996 Mdot
.81425 .14342 Mdot
.8143 .20369 Mdot
.81435 .2217 Mdot
.8144 .34637 Mdot
.81444 .13328 Mdot
.81449 .2231 Mdot
.81454 .1721 Mdot
.81459 .39148 Mdot
.81464 .26327 Mdot
.81468 .21357 Mdot
.81473 .18426 Mdot
.81478 .18723 Mdot
.81483 .29839 Mdot
.81487 .26929 Mdot
.81492 .38962 Mdot
.81497 .30351 Mdot
.81502 .38559 Mdot
.81506 .38027 Mdot
.81511 .3729 Mdot
.81516 .2056 Mdot
.81521 .26747 Mdot
.81525 .28546 Mdot
.8153 .2695 Mdot
.81535 .11225 Mdot
.8154 .23085 Mdot
.81544 .18877 Mdot
.81549 .15499 Mdot
.81554 .16811 Mdot
.81559 .20514 Mdot
.81564 .36828 Mdot
.81568 .38569 Mdot
.81573 .17963 Mdot
.81578 .34506 Mdot
.81583 .26324 Mdot
.81587 .31015 Mdot
.81592 .39617 Mdot
.81597 .15578 Mdot
.81602 .39811 Mdot
.81606 .32488 Mdot
.81611 .20234 Mdot
.81616 .17492 Mdot
.81621 .12791 Mdot
.81625 .3571 Mdot
.8163 .40205 Mdot
.81635 .31295 Mdot
.8164 .24814 Mdot
.81644 .19863 Mdot
.81649 .40103 Mdot
.81654 .19352 Mdot
.81659 .17099 Mdot
.81664 .15545 Mdot
.81668 .34492 Mdot
.81673 .39544 Mdot
.81678 .20996 Mdot
.81683 .17721 Mdot
.81687 .27807 Mdot
.81692 .16335 Mdot
.81697 .35474 Mdot
.81702 .27528 Mdot
.81706 .29032 Mdot
.81711 .12132 Mdot
.81716 .36543 Mdot
.81721 .3594 Mdot
.81725 .20232 Mdot
.8173 .35579 Mdot
.81735 .35225 Mdot
.8174 .41208 Mdot
.81744 .21024 Mdot
.81749 .15816 Mdot
.81754 .21962 Mdot
.81759 .32915 Mdot
.81763 .21997 Mdot
.81768 .37558 Mdot
.81773 .16492 Mdot
.81778 .29019 Mdot
.81783 .28659 Mdot
.81787 .39189 Mdot
.81792 .36689 Mdot
.81797 .23026 Mdot
.81802 .12599 Mdot
.81806 .34621 Mdot
.81811 .13002 Mdot
.81816 .3679 Mdot
.81821 .24879 Mdot
.81825 .34334 Mdot
.8183 .17809 Mdot
.81835 .12735 Mdot
.8184 .16552 Mdot
.81844 .40164 Mdot
.81849 .24013 Mdot
.81854 .12977 Mdot
.81859 .36997 Mdot
.81863 .36352 Mdot
.81868 .14075 Mdot
.81873 .2159 Mdot
.81878 .27062 Mdot
.81883 .40362 Mdot
.81887 .39171 Mdot
.81892 .34179 Mdot
.81897 .40031 Mdot
.81902 .13335 Mdot
.81906 .14663 Mdot
.81911 .23355 Mdot
.81916 .39653 Mdot
.81921 .20441 Mdot
.81925 .13922 Mdot
.8193 .28331 Mdot
.81935 .27074 Mdot
.8194 .27913 Mdot
.81944 .37939 Mdot
.81949 .27956 Mdot
.81954 .22902 Mdot
.81959 .29635 Mdot
.81963 .26346 Mdot
.81968 .27419 Mdot
.81973 .27851 Mdot
.81978 .35248 Mdot
.81983 .24771 Mdot
.81987 .18349 Mdot
.81992 .13328 Mdot
.81997 .36931 Mdot
.82002 .27665 Mdot
.82006 .26255 Mdot
.82011 .15403 Mdot
.82016 .36236 Mdot
.82021 .25662 Mdot
.82025 .1558 Mdot
.8203 .17935 Mdot
.82035 .28515 Mdot
.8204 .24479 Mdot
.82044 .29494 Mdot
.82049 .33126 Mdot
.82054 .13401 Mdot
.82059 .28845 Mdot
.82063 .14377 Mdot
.82068 .23084 Mdot
.82073 .26132 Mdot
.82078 .15399 Mdot
.82083 .29363 Mdot
.82087 .37659 Mdot
.82092 .3333 Mdot
.82097 .33094 Mdot
.82102 .24015 Mdot
.82106 .37351 Mdot
.82111 .38926 Mdot
.82116 .1849 Mdot
.82121 .40327 Mdot
.82125 .3505 Mdot
.8213 .15811 Mdot
.82135 .35456 Mdot
.8214 .37909 Mdot
.82144 .30297 Mdot
.82149 .29984 Mdot
.82154 .24199 Mdot
.82159 .21658 Mdot
.82163 .39919 Mdot
.82168 .29865 Mdot
.82173 .38142 Mdot
.82178 .20604 Mdot
.82182 .30178 Mdot
.82187 .17096 Mdot
.82192 .36127 Mdot
.82197 .3413 Mdot
.82202 .35429 Mdot
.82206 .26696 Mdot
.82211 .16497 Mdot
.82216 .236 Mdot
.82221 .41068 Mdot
.82225 .30782 Mdot
.8223 .41038 Mdot
.82235 .26325 Mdot
.8224 .19604 Mdot
.82244 .28577 Mdot
.82249 .19209 Mdot
.82254 .31549 Mdot
.82259 .32461 Mdot
.82263 .41767 Mdot
.82268 .38204 Mdot
.82273 .2362 Mdot
.82278 .35776 Mdot
.82282 .25671 Mdot
.82287 .43337 Mdot
.82292 .16826 Mdot
.82297 .19428 Mdot
.82302 .22424 Mdot
.82306 .21081 Mdot
.82311 .26072 Mdot
.82316 .27396 Mdot
.82321 .39146 Mdot
.82325 .18536 Mdot
.8233 .16444 Mdot
.82335 .29806 Mdot
.8234 .22377 Mdot
.82344 .21017 Mdot
.82349 .33659 Mdot
.82354 .24276 Mdot
.82359 .3738 Mdot
.82363 .15922 Mdot
.82368 .16245 Mdot
.82373 .35457 Mdot
.82378 .39275 Mdot
.82382 .214 Mdot
.82387 .36328 Mdot
.82392 .43403 Mdot
.82397 .27862 Mdot
.82402 .21827 Mdot
.82406 .33801 Mdot
.82411 .38294 Mdot
.82416 .19777 Mdot
.82421 .15106 Mdot
.82425 .22109 Mdot
.8243 .25299 Mdot
.82435 .24538 Mdot
.8244 .40498 Mdot
.82444 .20127 Mdot
.82449 .3946 Mdot
.82454 .16664 Mdot
.82459 .34004 Mdot
.82463 .30498 Mdot
.82468 .29749 Mdot
.82473 .23354 Mdot
.82478 .32687 Mdot
.82482 .28879 Mdot
.82487 .38424 Mdot
.82492 .28232 Mdot
.82497 .25974 Mdot
.82502 .36744 Mdot
.82506 .39235 Mdot
.82511 .44604 Mdot
.82516 .18916 Mdot
.82521 .17732 Mdot
.82525 .15751 Mdot
.8253 .39658 Mdot
.82535 .18661 Mdot
.8254 .3998 Mdot
.82544 .3483 Mdot
.82549 .30033 Mdot
.82554 .22582 Mdot
.82559 .34807 Mdot
.82563 .39829 Mdot
.82568 .28364 Mdot
.82573 .33078 Mdot
.82578 .19345 Mdot
.82582 .25137 Mdot
.82587 .20086 Mdot
.82592 .44974 Mdot
.82597 .3507 Mdot
.82602 .31337 Mdot
.82606 .36499 Mdot
.82611 .3418 Mdot
.82616 .43011 Mdot
.82621 .36808 Mdot
.82625 .36621 Mdot
.8263 .30525 Mdot
.82635 .40561 Mdot
.8264 .3636 Mdot
.82644 .41772 Mdot
.82649 .27209 Mdot
.82654 .15946 Mdot
.82659 .16916 Mdot
.82663 .27145 Mdot
.82668 .20053 Mdot
.82673 .26071 Mdot
.82678 .22039 Mdot
.82682 .43755 Mdot
.82687 .31969 Mdot
.82692 .22256 Mdot
.82697 .41937 Mdot
.82701 .39239 Mdot
.82706 .32071 Mdot
.82711 .32283 Mdot
.82716 .26232 Mdot
.82721 .18392 Mdot
.82725 .4305 Mdot
.8273 .3445 Mdot
.82735 .34624 Mdot
.8274 .26991 Mdot
.82744 .28279 Mdot
.82749 .3915 Mdot
.82754 .43545 Mdot
.82759 .30521 Mdot
.82763 .16908 Mdot
.82768 .39063 Mdot
.82773 .42508 Mdot
.82778 .19275 Mdot
.82782 .42261 Mdot
.82787 .28932 Mdot
.82792 .3643 Mdot
.82797 .20988 Mdot
.82801 .26295 Mdot
.82806 .22699 Mdot
.82811 .40022 Mdot
.82816 .27299 Mdot
.82821 .39794 Mdot
.82825 .36007 Mdot
.8283 .29915 Mdot
.82835 .25053 Mdot
.8284 .42397 Mdot
.82844 .17744 Mdot
.82849 .40985 Mdot
.82854 .43777 Mdot
.82859 .30367 Mdot
.82863 .24349 Mdot
.82868 .43216 Mdot
.82873 .29566 Mdot
.82878 .2979 Mdot
.82882 .31123 Mdot
.82887 .1708 Mdot
.82892 .26684 Mdot
.82897 .33428 Mdot
.82901 .18626 Mdot
.82906 .26591 Mdot
.82911 .22172 Mdot
.82916 .23629 Mdot
.82921 .41929 Mdot
.82925 .32592 Mdot
.8293 .40916 Mdot
.82935 .29899 Mdot
.8294 .22521 Mdot
.82944 .19296 Mdot
.82949 .32503 Mdot
.82954 .33649 Mdot
.82959 .21458 Mdot
.82963 .24499 Mdot
.82968 .34935 Mdot
.82973 .20025 Mdot
.82978 .43358 Mdot
.82982 .27552 Mdot
.82987 .22173 Mdot
.82992 .36546 Mdot
.82997 .2908 Mdot
.83001 .27338 Mdot
.83006 .41861 Mdot
.83011 .20026 Mdot
.83016 .27383 Mdot
.83021 .17696 Mdot
.83025 .36658 Mdot
.8303 .42871 Mdot
.83035 .3195 Mdot
.8304 .3162 Mdot
.83044 .42279 Mdot
.83049 .30044 Mdot
.83054 .26521 Mdot
.83059 .29436 Mdot
.83063 .26909 Mdot
.83068 .43035 Mdot
.83073 .22238 Mdot
.83078 .22133 Mdot
.83082 .38675 Mdot
.83087 .40246 Mdot
.83092 .25622 Mdot
.83097 .41343 Mdot
.83101 .33799 Mdot
.83106 .21018 Mdot
.83111 .43365 Mdot
.83116 .31364 Mdot
.8312 .38804 Mdot
.83125 .18393 Mdot
.8313 .33403 Mdot
.83135 .31109 Mdot
.8314 .19607 Mdot
.83144 .22489 Mdot
.83149 .18956 Mdot
.83154 .46498 Mdot
.83159 .24357 Mdot
.83163 .39495 Mdot
.83168 .39505 Mdot
.83173 .34667 Mdot
.83178 .4456 Mdot
.83182 .43591 Mdot
.83187 .34934 Mdot
.83192 .30221 Mdot
.83197 .23592 Mdot
.83201 .21073 Mdot
.83206 .27061 Mdot
.83211 .36132 Mdot
.83216 .37068 Mdot
.8322 .4735 Mdot
.83225 .31011 Mdot
.8323 .22619 Mdot
.83235 .45621 Mdot
.8324 .46849 Mdot
.83244 .45005 Mdot
.83249 .38927 Mdot
.83254 .43967 Mdot
.83259 .42333 Mdot
.83263 .44043 Mdot
.83268 .39929 Mdot
.83273 .37644 Mdot
.83278 .20893 Mdot
.83282 .22613 Mdot
.83287 .23357 Mdot
.83292 .40685 Mdot
.83297 .24923 Mdot
.83301 .35321 Mdot
.83306 .40799 Mdot
.83311 .3529 Mdot
.83316 .22069 Mdot
.8332 .26499 Mdot
.83325 .22926 Mdot
.8333 .45987 Mdot
.83335 .22504 Mdot
.8334 .43293 Mdot
.83344 .48133 Mdot
.83349 .48213 Mdot
.83354 .23521 Mdot
.83359 .46174 Mdot
.83363 .27628 Mdot
.83368 .22688 Mdot
.83373 .29136 Mdot
.83378 .20614 Mdot
.83382 .35687 Mdot
.83387 .33053 Mdot
.83392 .26787 Mdot
.83397 .46051 Mdot
.83401 .30914 Mdot
.83406 .40457 Mdot
.83411 .20488 Mdot
.83416 .29375 Mdot
.8342 .38265 Mdot
.83425 .23852 Mdot
.8343 .46611 Mdot
.83435 .21602 Mdot
.8344 .34085 Mdot
.83444 .26117 Mdot
.83449 .42894 Mdot
.83454 .26601 Mdot
.83459 .34264 Mdot
.83463 .26237 Mdot
.83468 .3824 Mdot
.83473 .288 Mdot
.83478 .25545 Mdot
.83482 .22477 Mdot
.83487 .28052 Mdot
.83492 .27154 Mdot
.83497 .38332 Mdot
.83501 .37919 Mdot
.83506 .20294 Mdot
.83511 .29638 Mdot
.83516 .26487 Mdot
.8352 .46037 Mdot
.83525 .48401 Mdot
.8353 .48879 Mdot
.83535 .36858 Mdot
.8354 .41355 Mdot
.83544 .20981 Mdot
.83549 .46488 Mdot
.83554 .22004 Mdot
.83559 .3449 Mdot
.83563 .26843 Mdot
.83568 .39178 Mdot
.83573 .36536 Mdot
.83578 .27584 Mdot
.83582 .37441 Mdot
.83587 .29749 Mdot
.83592 .30383 Mdot
.83597 .24518 Mdot
.83601 .2882 Mdot
.83606 .22046 Mdot
.83611 .41008 Mdot
.83616 .35576 Mdot
.8362 .28038 Mdot
.83625 .41425 Mdot
.8363 .34072 Mdot
.83635 .38597 Mdot
.83639 .28715 Mdot
.83644 .41643 Mdot
.83649 .46331 Mdot
.83654 .46379 Mdot
.83659 .27406 Mdot
.83663 .44332 Mdot
.83668 .44039 Mdot
.83673 .31621 Mdot
.83678 .20314 Mdot
.83682 .24926 Mdot
.83687 .27295 Mdot
.83692 .23848 Mdot
.83697 .3219 Mdot
.83701 .44514 Mdot
.83706 .46269 Mdot
.83711 .48707 Mdot
.83716 .23281 Mdot
.8372 .42399 Mdot
.83725 .25211 Mdot
.8373 .33101 Mdot
.83735 .44718 Mdot
.83739 .20984 Mdot
.83744 .40655 Mdot
.83749 .4404 Mdot
.83754 .36073 Mdot
.83759 .28917 Mdot
.83763 .43919 Mdot
.83768 .47276 Mdot
.83773 .28816 Mdot
.83778 .34239 Mdot
.83782 .49554 Mdot
.83787 .35864 Mdot
.83792 .28731 Mdot
.83797 .2956 Mdot
.83801 .42527 Mdot
.83806 .32303 Mdot
.83811 .46333 Mdot
.83816 .34859 Mdot
.8382 .4609 Mdot
.83825 .33449 Mdot
.8383 .43439 Mdot
.83835 .42351 Mdot
.83839 .41304 Mdot
.83844 .50279 Mdot
.83849 .48671 Mdot
.83854 .41851 Mdot
.83859 .21154 Mdot
.83863 .26763 Mdot
.83868 .33141 Mdot
.83873 .33498 Mdot
.83878 .27303 Mdot
.83882 .29575 Mdot
.83887 .24947 Mdot
.83892 .49386 Mdot
.83897 .27896 Mdot
.83901 .43877 Mdot
.83906 .46402 Mdot
.83911 .40546 Mdot
.83916 .35594 Mdot
.8392 .32333 Mdot
.83925 .50332 Mdot
.8393 .26485 Mdot
.83935 .39807 Mdot
.83939 .49206 Mdot
.83944 .2775 Mdot
.83949 .34496 Mdot
.83954 .48884 Mdot
.83959 .49328 Mdot
.83963 .29499 Mdot
.83968 .43084 Mdot
.83973 .48704 Mdot
.83978 .43557 Mdot
.83982 .46856 Mdot
.83987 .30618 Mdot
.83992 .42451 Mdot
.83997 .35053 Mdot
.84001 .42999 Mdot
.84006 .31827 Mdot
.84011 .35684 Mdot
.84016 .41809 Mdot
.8402 .4725 Mdot
.84025 .41953 Mdot
.8403 .50781 Mdot
.84035 .30702 Mdot
.84039 .47648 Mdot
.84044 .36732 Mdot
.84049 .32257 Mdot
.84054 .32283 Mdot
.84058 .41219 Mdot
.84063 .23577 Mdot
.84068 .34219 Mdot
.84073 .33821 Mdot
.84078 .33119 Mdot
.84082 .31396 Mdot
.84087 .36438 Mdot
.84092 .41205 Mdot
.84097 .37224 Mdot
.84101 .22272 Mdot
.84106 .44986 Mdot
.84111 .27685 Mdot
.84116 .45262 Mdot
.8412 .41502 Mdot
.84125 .30892 Mdot
.8413 .36971 Mdot
.84135 .49126 Mdot
.84139 .50682 Mdot
.84144 .31264 Mdot
.84149 .27955 Mdot
.84154 .23183 Mdot
.84158 .35673 Mdot
.84163 .50236 Mdot
.84168 .46919 Mdot
.84173 .3323 Mdot
.84178 .33896 Mdot
.84182 .37836 Mdot
.84187 .34936 Mdot
.84192 .51454 Mdot
.84197 .24376 Mdot
.84201 .23293 Mdot
.84206 .4513 Mdot
.84211 .36163 Mdot
.84216 .24055 Mdot
.8422 .29763 Mdot
.84225 .39435 Mdot
.8423 .42395 Mdot
.84235 .34066 Mdot
.84239 .50403 Mdot
.84244 .24529 Mdot
.84249 .44838 Mdot
.84254 .34972 Mdot
.84258 .4126 Mdot
.84263 .482 Mdot
.84268 .43813 Mdot
.84273 .50962 Mdot
.84278 .42706 Mdot
.84282 .23496 Mdot
.84287 .32817 Mdot
.84292 .39318 Mdot
.84297 .27141 Mdot
.84301 .40336 Mdot
.84306 .33157 Mdot
.84311 .3727 Mdot
.84316 .26194 Mdot
.8432 .47056 Mdot
.84325 .48862 Mdot
.8433 .35616 Mdot
.84335 .48336 Mdot
.84339 .3006 Mdot
.84344 .28925 Mdot
.84349 .24027 Mdot
.84354 .49914 Mdot
.84358 .28044 Mdot
.84363 .36105 Mdot
.84368 .41091 Mdot
.84373 .31223 Mdot
.84378 .31918 Mdot
.84382 .44383 Mdot
.84387 .42239 Mdot
.84392 .40646 Mdot
.84397 .31083 Mdot
.84401 .34247 Mdot
.84406 .25618 Mdot
.84411 .36222 Mdot
.84416 .42968 Mdot
.8442 .23843 Mdot
.84425 .40606 Mdot
.8443 .32818 Mdot
.84435 .48206 Mdot
.84439 .27294 Mdot
.84444 .27835 Mdot
.84449 .36831 Mdot
.84454 .41028 Mdot
.84458 .50754 Mdot
.84463 .26727 Mdot
.84468 .39339 Mdot
.84473 .35939 Mdot
.84478 .37622 Mdot
.84482 .38113 Mdot
.84487 .31125 Mdot
.84492 .27049 Mdot
.84497 .4577 Mdot
.84501 .48424 Mdot
.84506 .43047 Mdot
.84511 .48552 Mdot
.84516 .34642 Mdot
.8452 .45942 Mdot
.84525 .2998 Mdot
.8453 .28757 Mdot
.84535 .33989 Mdot
.84539 .28545 Mdot
.84544 .49875 Mdot
.84549 .33281 Mdot
.84554 .29959 Mdot
.84558 .23991 Mdot
.84563 .36343 Mdot
.84568 .45055 Mdot
.84573 .32025 Mdot
.84577 .50103 Mdot
.84582 .4986 Mdot
.84587 .32505 Mdot
.84592 .47296 Mdot
.84597 .35414 Mdot
.84601 .42177 Mdot
.84606 .28916 Mdot
.84611 .25003 Mdot
.84616 .39971 Mdot
.8462 .52129 Mdot
.84625 .33381 Mdot
.8463 .43396 Mdot
.84635 .47082 Mdot
.84639 .45734 Mdot
.84644 .28227 Mdot
.84649 .33027 Mdot
.84654 .42175 Mdot
.84658 .49 Mdot
.84663 .48105 Mdot
.84668 .26759 Mdot
.84673 .41893 Mdot
.84677 .36384 Mdot
.84682 .26794 Mdot
.84687 .47981 Mdot
.84692 .45055 Mdot
.84697 .39807 Mdot
.84701 .4759 Mdot
.84706 .24518 Mdot
.84711 .3349 Mdot
.84716 .50982 Mdot
.8472 .42558 Mdot
.84725 .52902 Mdot
.8473 .46924 Mdot
.84735 .52276 Mdot
.84739 .33131 Mdot
.84744 .33477 Mdot
.84749 .53317 Mdot
.84754 .30549 Mdot
.84758 .28928 Mdot
.84763 .24491 Mdot
.84768 .35201 Mdot
.84773 .3511 Mdot
.84777 .34401 Mdot
.84782 .51328 Mdot
.84787 .46922 Mdot
.84792 .52357 Mdot
.84797 .31769 Mdot
.84801 .27527 Mdot
.84806 .26065 Mdot
.84811 .36764 Mdot
.84816 .37897 Mdot
.8482 .27258 Mdot
.84825 .46326 Mdot
.8483 .39551 Mdot
.84835 .49124 Mdot
.84839 .28159 Mdot
.84844 .53222 Mdot
.84849 .41112 Mdot
.84854 .40362 Mdot
.84858 .48552 Mdot
.84863 .53792 Mdot
.84868 .34982 Mdot
.84873 .35871 Mdot
.84877 .48515 Mdot
.84882 .43062 Mdot
.84887 .53845 Mdot
.84892 .25974 Mdot
.84897 .51193 Mdot
.84901 .50163 Mdot
.84906 .26044 Mdot
.84911 .48263 Mdot
.84916 .48255 Mdot
.8492 .48704 Mdot
.84925 .43388 Mdot
.8493 .35005 Mdot
.84935 .45654 Mdot
.84939 .27052 Mdot
.84944 .28527 Mdot
.84949 .40073 Mdot
.84954 .42219 Mdot
.84958 .28056 Mdot
.84963 .41657 Mdot
.84968 .5397 Mdot
.84973 .47942 Mdot
.84977 .28555 Mdot
.84982 .31498 Mdot
.84987 .42939 Mdot
.84992 .53769 Mdot
.84997 .39852 Mdot
.85001 .32028 Mdot
.85006 .41871 Mdot
.85011 .27498 Mdot
.85016 .44114 Mdot
.8502 .30939 Mdot
.85025 .48066 Mdot
.8503 .33717 Mdot
.85035 .499 Mdot
.85039 .42059 Mdot
.85044 .38098 Mdot
.85049 .42603 Mdot
.85054 .47919 Mdot
.85058 .38619 Mdot
.85063 .52614 Mdot
.85068 .25504 Mdot
.85073 .44999 Mdot
.85077 .51599 Mdot
.85082 .53298 Mdot
.85087 .32232 Mdot
.85092 .41644 Mdot
.85096 .45318 Mdot
.85101 .35592 Mdot
.85106 .33198 Mdot
.85111 .27058 Mdot
.85116 .38572 Mdot
.8512 .48505 Mdot
.85125 .31014 Mdot
.8513 .3776 Mdot
.85135 .32979 Mdot
.85139 .25802 Mdot
.85144 .5216 Mdot
.85149 .42739 Mdot
.85154 .45816 Mdot
.85158 .42615 Mdot
.85163 .35 Mdot
.85168 .49764 Mdot
.85173 .32671 Mdot
.85177 .44977 Mdot
.85182 .35002 Mdot
.85187 .30287 Mdot
.85192 .36095 Mdot
.85196 .46717 Mdot
.85201 .28339 Mdot
.85206 .43713 Mdot
.85211 .45863 Mdot
.85216 .36741 Mdot
.8522 .50258 Mdot
.85225 .42303 Mdot
.8523 .32954 Mdot
.85235 .43401 Mdot
.85239 .4494 Mdot
.85244 .30254 Mdot
.85249 .55187 Mdot
.85254 .43341 Mdot
.85258 .48022 Mdot
.85263 .42773 Mdot
.85268 .35159 Mdot
.85273 .2653 Mdot
.85277 .38842 Mdot
.85282 .4833 Mdot
.85287 .28339 Mdot
.85292 .36905 Mdot
.85296 .29722 Mdot
.85301 .43939 Mdot
.85306 .47641 Mdot
.85311 .45601 Mdot
.85316 .27327 Mdot
.8532 .5567 Mdot
.85325 .27752 Mdot
.8533 .34849 Mdot
.85335 .32558 Mdot
.85339 .39387 Mdot
.85344 .50318 Mdot
.85349 .46983 Mdot
.85354 .4317 Mdot
.85358 .35213 Mdot
.85363 .50713 Mdot
.85368 .29753 Mdot
.85373 .50759 Mdot
.85377 .48066 Mdot
.85382 .4171 Mdot
.85387 .29394 Mdot
.85392 .38102 Mdot
.85396 .55423 Mdot
.85401 .39587 Mdot
.85406 .48205 Mdot
.85411 .34626 Mdot
.85416 .37745 Mdot
.8542 .47708 Mdot
.85425 .28895 Mdot
.8543 .33606 Mdot
.85435 .37881 Mdot
.85439 .46291 Mdot
.85444 .49882 Mdot
.85449 .27412 Mdot
.85454 .5436 Mdot
.85458 .51853 Mdot
.85463 .29309 Mdot
.85468 .40153 Mdot
.85473 .45586 Mdot
.85477 .27594 Mdot
.85482 .5551 Mdot
.85487 .45363 Mdot
.85492 .53504 Mdot
.85496 .41882 Mdot
.85501 .52643 Mdot
.85506 .33802 Mdot
.85511 .54122 Mdot
.85515 .28865 Mdot
.8552 .31023 Mdot
.85525 .55261 Mdot
.8553 .42992 Mdot
.85535 .37272 Mdot
.85539 .28771 Mdot
.85544 .48313 Mdot
.85549 .31782 Mdot
.85554 .47152 Mdot
.85558 .35074 Mdot
.85563 .47615 Mdot
.85568 .33637 Mdot
.85573 .51528 Mdot
.85577 .32523 Mdot
.85582 .34234 Mdot
.85587 .44323 Mdot
.85592 .50734 Mdot
.85596 .33314 Mdot
.85601 .45185 Mdot
.85606 .47147 Mdot
.85611 .35709 Mdot
.85615 .37027 Mdot
.8562 .38268 Mdot
.85625 .4941 Mdot
.8563 .33757 Mdot
.85635 .32931 Mdot
.85639 .39434 Mdot
.85644 .33374 Mdot
.85649 .5294 Mdot
.85654 .31143 Mdot
.85658 .47604 Mdot
.85663 .28602 Mdot
.85668 .32812 Mdot
.85673 .52593 Mdot
.85677 .56527 Mdot
.85682 .51517 Mdot
.85687 .3785 Mdot
.85692 .47163 Mdot
.85696 .49401 Mdot
.85701 .34315 Mdot
.85706 .43736 Mdot
.85711 .40998 Mdot
.85715 .31378 Mdot
.8572 .43829 Mdot
.85725 .35216 Mdot
.8573 .31175 Mdot
.85735 .49812 Mdot
.85739 .51135 Mdot
.85744 .28703 Mdot
.85749 .54986 Mdot
.85754 .37648 Mdot
.85758 .45046 Mdot
.85763 .32547 Mdot
.85768 .51154 Mdot
.85773 .46854 Mdot
.85777 .43782 Mdot
.85782 .56571 Mdot
.85787 .55411 Mdot
.85792 .4719 Mdot
.85796 .49142 Mdot
.85801 .46126 Mdot
.85806 .35665 Mdot
.85811 .54705 Mdot
.85815 .4227 Mdot
.8582 .29847 Mdot
.85825 .51622 Mdot
.8583 .50811 Mdot
.85835 .55423 Mdot
.85839 .51626 Mdot
.85844 .4797 Mdot
.85849 .28535 Mdot
.85854 .31837 Mdot
.85858 .50485 Mdot
.85863 .50044 Mdot
.85868 .4796 Mdot
.85873 .43877 Mdot
.85877 .45552 Mdot
.85882 .56003 Mdot
.85887 .28746 Mdot
.85892 .57233 Mdot
.85896 .46131 Mdot
.85901 .2827 Mdot
.85906 .38732 Mdot
.85911 .35795 Mdot
.85915 .57207 Mdot
.8592 .49819 Mdot
.85925 .41254 Mdot
.8593 .50764 Mdot
.85935 .55126 Mdot
.85939 .55462 Mdot
.85944 .47721 Mdot
.85949 .52631 Mdot
.85954 .31317 Mdot
.85958 .35321 Mdot
.85963 .47028 Mdot
.85968 .48649 Mdot
.85973 .38185 Mdot
.85977 .42641 Mdot
.85982 .56445 Mdot
.85987 .32675 Mdot
.85992 .50036 Mdot
.85996 .44053 Mdot
.86001 .55641 Mdot
.86006 .32881 Mdot
.86011 .3187 Mdot
.86015 .43762 Mdot
.8602 .44899 Mdot
.86025 .54574 Mdot
.8603 .32164 Mdot
.86034 .51455 Mdot
.86039 .31684 Mdot
.86044 .31861 Mdot
.86049 .34586 Mdot
.86054 .53554 Mdot
.86058 .41536 Mdot
.86063 .36815 Mdot
.86068 .3138 Mdot
.86073 .46356 Mdot
.86077 .52129 Mdot
.86082 .45799 Mdot
.86087 .5084 Mdot
.86092 .31886 Mdot
.86096 .53352 Mdot
.86101 .41318 Mdot
.86106 .29011 Mdot
.86111 .45536 Mdot
.86115 .55427 Mdot
.8612 .36679 Mdot
.86125 .54879 Mdot
.8613 .3004 Mdot
.86134 .38805 Mdot
.86139 .39878 Mdot
.86144 .51015 Mdot
.86149 .36382 Mdot
.86154 .35444 Mdot
.86158 .36352 Mdot
.86163 .44775 Mdot
.86168 .40671 Mdot
.86173 .51762 Mdot
.86177 .57403 Mdot
.86182 .41786 Mdot
.86187 .52204 Mdot
.86192 .57534 Mdot
.86196 .4003 Mdot
.86201 .48869 Mdot
.86206 .48767 Mdot
.86211 .32641 Mdot
.86215 .56668 Mdot
.8622 .48341 Mdot
.86225 .31724 Mdot
.8623 .35205 Mdot
.86234 .48506 Mdot
.86239 .51475 Mdot
.86244 .30223 Mdot
.86249 .54435 Mdot
.86254 .37188 Mdot
.86258 .29032 Mdot
.86263 .51909 Mdot
.86268 .47585 Mdot
.86273 .29441 Mdot
.86277 .42358 Mdot
.86282 .39864 Mdot
.86287 .53945 Mdot
.86292 .30172 Mdot
.86296 .29231 Mdot
.86301 .45816 Mdot
.86306 .54578 Mdot
.86311 .48319 Mdot
.86315 .38549 Mdot
.8632 .55248 Mdot
.86325 .5066 Mdot
.8633 .49871 Mdot
.86334 .48439 Mdot
.86339 .52279 Mdot
.86344 .44221 Mdot
.86349 .30141 Mdot
.86354 .55236 Mdot
.86358 .50854 Mdot
.86363 .4808 Mdot
.86368 .51258 Mdot
.86373 .55034 Mdot
.86377 .5727 Mdot
.86382 .29345 Mdot
.86387 .50677 Mdot
.86392 .41546 Mdot
.86396 .46287 Mdot
.86401 .33777 Mdot
.86406 .49407 Mdot
.86411 .41227 Mdot
.86415 .29393 Mdot
.8642 .37617 Mdot
.86425 .3003 Mdot
.8643 .31631 Mdot
.86434 .32593 Mdot
.86439 .45416 Mdot
.86444 .38628 Mdot
.86449 .41671 Mdot
.86453 .38803 Mdot
.86458 .30208 Mdot
.86463 .3751 Mdot
.86468 .44953 Mdot
.86473 .46477 Mdot
.86477 .40666 Mdot
.86482 .448 Mdot
.86487 .48477 Mdot
.86492 .47775 Mdot
.86496 .40413 Mdot
.86501 .52711 Mdot
.86506 .36042 Mdot
.86511 .30609 Mdot
.86515 .35767 Mdot
.8652 .32445 Mdot
.86525 .53451 Mdot
.8653 .30376 Mdot
.86534 .56805 Mdot
.86539 .31594 Mdot
.86544 .51009 Mdot
.86549 .56467 Mdot
.86553 .40596 Mdot
.86558 .51669 Mdot
.86563 .38565 Mdot
.86568 .469 Mdot
.86573 .39634 Mdot
.86577 .43414 Mdot
.86582 .52362 Mdot
.86587 .29697 Mdot
.86592 .57736 Mdot
.86596 .57391 Mdot
.86601 .33187 Mdot
.86606 .40718 Mdot
.86611 .46643 Mdot
.86615 .34009 Mdot
.8662 .55968 Mdot
.86625 .39456 Mdot
.8663 .40233 Mdot
.86634 .30929 Mdot
.86639 .31892 Mdot
.86644 .38463 Mdot
.86649 .42306 Mdot
.86653 .58222 Mdot
.86658 .39779 Mdot
.86663 .40901 Mdot
.86668 .31138 Mdot
.86673 .3599 Mdot
.86677 .3066 Mdot
.86682 .5294 Mdot
.86687 .50452 Mdot
.86692 .51534 Mdot
.86696 .37264 Mdot
.86701 .52733 Mdot
.86706 .517 Mdot
.86711 .53136 Mdot
.86715 .33593 Mdot
.8672 .41539 Mdot
.86725 .34589 Mdot
.8673 .48668 Mdot
.86734 .3666 Mdot
.86739 .31641 Mdot
.86744 .53409 Mdot
.86749 .47314 Mdot
.86753 .34351 Mdot
.86758 .52256 Mdot
.86763 .40703 Mdot
.86768 .48186 Mdot
.86773 .53675 Mdot
.86777 .4098 Mdot
.86782 .39199 Mdot
.86787 .41837 Mdot
.86792 .52665 Mdot
.86796 .47183 Mdot
.86801 .47898 Mdot
.86806 .49462 Mdot
.86811 .45083 Mdot
.86815 .53626 Mdot
.8682 .55382 Mdot
.86825 .55518 Mdot
.8683 .41205 Mdot
.86834 .41809 Mdot
.86839 .50523 Mdot
.86844 .36588 Mdot
.86849 .34291 Mdot
.86853 .39922 Mdot
.86858 .56362 Mdot
.86863 .4853 Mdot
.86868 .59203 Mdot
.86873 .46937 Mdot
.86877 .45451 Mdot
.86882 .30144 Mdot
.86887 .35336 Mdot
.86892 .35773 Mdot
.86896 .36076 Mdot
.86901 .47624 Mdot
.86906 .41995 Mdot
.86911 .47922 Mdot
.86915 .47517 Mdot
.8692 .57509 Mdot
.86925 .56266 Mdot
.8693 .53657 Mdot
.86934 .51504 Mdot
.86939 .31881 Mdot
.86944 .44959 Mdot
.86949 .41753 Mdot
.86953 .30894 Mdot
.86958 .54699 Mdot
.86963 .40595 Mdot
.86968 .31765 Mdot
.86972 .33959 Mdot
.86977 .36118 Mdot
.86982 .40834 Mdot
.86987 .44277 Mdot
.86992 .47963 Mdot
.86996 .35951 Mdot
.87001 .35482 Mdot
.87006 .38495 Mdot
.87011 .41886 Mdot
.87015 .47817 Mdot
.8702 .52985 Mdot
.87025 .50078 Mdot
.8703 .5388 Mdot
.87034 .49827 Mdot
.87039 .56244 Mdot
.87044 .55952 Mdot
.87049 .32429 Mdot
.87053 .48006 Mdot
.87058 .41351 Mdot
.87063 .44273 Mdot
.87068 .31615 Mdot
.87072 .52879 Mdot
.87077 .30849 Mdot
.87082 .42607 Mdot
.87087 .57248 Mdot
.87092 .46874 Mdot
.87096 .49619 Mdot
.87101 .57942 Mdot
.87106 .39416 Mdot
.87111 .41061 Mdot
.87115 .44282 Mdot
.8712 .49598 Mdot
.87125 .57174 Mdot
.8713 .52893 Mdot
.87134 .50953 Mdot
.87139 .59182 Mdot
.87144 .33476 Mdot
.87149 .33254 Mdot
.87153 .5439 Mdot
.87158 .3343 Mdot
.87163 .31254 Mdot
.87168 .44947 Mdot
.87172 .43258 Mdot
.87177 .48868 Mdot
.87182 .59356 Mdot
.87187 .51791 Mdot
.87192 .42652 Mdot
.87196 .3651 Mdot
.87201 .32363 Mdot
.87206 .35178 Mdot
.87211 .52785 Mdot
.87215 .38327 Mdot
.8722 .5271 Mdot
.87225 .53886 Mdot
.8723 .38793 Mdot
.87234 .4851 Mdot
.87239 .55323 Mdot
.87244 .313 Mdot
.87249 .47638 Mdot
.87253 .49131 Mdot
.87258 .5217 Mdot
.87263 .5786 Mdot
.87268 .53068 Mdot
.87272 .4604 Mdot
.87277 .51261 Mdot
.87282 .43263 Mdot
.87287 .40166 Mdot
.87292 .57018 Mdot
.87296 .51757 Mdot
.87301 .51329 Mdot
.87306 .57376 Mdot
.87311 .5089 Mdot
.87315 .49782 Mdot
.8732 .46544 Mdot
.87325 .34989 Mdot
.8733 .42967 Mdot
.87334 .56966 Mdot
.87339 .52556 Mdot
.87344 .561 Mdot
.87349 .54366 Mdot
.87353 .32072 Mdot
.87358 .5169 Mdot
.87363 .389 Mdot
.87368 .35678 Mdot
.87372 .39835 Mdot
.87377 .53768 Mdot
.87382 .45776 Mdot
.87387 .49586 Mdot
.87391 .48527 Mdot
.87396 .40978 Mdot
.87401 .36087 Mdot
.87406 .52535 Mdot
.87411 .56741 Mdot
.87415 .49625 Mdot
.8742 .38692 Mdot
.87425 .32144 Mdot
.8743 .37463 Mdot
.87434 .3359 Mdot
.87439 .34217 Mdot
.87444 .49181 Mdot
.87449 .40505 Mdot
.87453 .41046 Mdot
.87458 .38134 Mdot
.87463 .54836 Mdot
.87468 .38973 Mdot
.87472 .49386 Mdot
.87477 .59267 Mdot
.87482 .49711 Mdot
.87487 .5918 Mdot
.87491 .55664 Mdot
.87496 .44056 Mdot
.87501 .30693 Mdot
.87506 .41226 Mdot
.87511 .45264 Mdot
.87515 .3855 Mdot
.8752 .3823 Mdot
.87525 .4456 Mdot
.8753 .55718 Mdot
.87534 .59941 Mdot
.87539 .36686 Mdot
.87544 .37701 Mdot
.87549 .52737 Mdot
.87553 .56337 Mdot
.87558 .47607 Mdot
.87563 .57302 Mdot
.87568 .42315 Mdot
.87572 .48831 Mdot
.87577 .52888 Mdot
.87582 .48964 Mdot
.87587 .53053 Mdot
.87591 .49691 Mdot
.87596 .33823 Mdot
.87601 .49919 Mdot
.87606 .57527 Mdot
.87611 .36291 Mdot
.87615 .33789 Mdot
.8762 .39356 Mdot
.87625 .42929 Mdot
.8763 .57896 Mdot
.87634 .55719 Mdot
.87639 .54958 Mdot
.87644 .47377 Mdot
.87649 .58124 Mdot
.87653 .49719 Mdot
.87658 .47946 Mdot
.87663 .54818 Mdot
.87668 .32483 Mdot
.87672 .3281 Mdot
.87677 .50831 Mdot
.87682 .43209 Mdot
.87687 .43846 Mdot
.87691 .40119 Mdot
.87696 .32581 Mdot
.87701 .50359 Mdot
.87706 .5436 Mdot
.87711 .37019 Mdot
.87715 .42874 Mdot
.8772 .53046 Mdot
.87725 .488 Mdot
.8773 .33963 Mdot
.87734 .34255 Mdot
.87739 .40856 Mdot
.87744 .51132 Mdot
.87749 .38475 Mdot
.87753 .39529 Mdot
.87758 .53715 Mdot
.87763 .53246 Mdot
.87768 .48997 Mdot
.87772 .51827 Mdot
.87777 .59142 Mdot
.87782 .51525 Mdot
.87787 .46951 Mdot
.87791 .31763 Mdot
.87796 .46703 Mdot
.87801 .38451 Mdot
.87806 .37606 Mdot
.87811 .59443 Mdot
.87815 .56608 Mdot
.8782 .44358 Mdot
.87825 .31371 Mdot
.8783 .47355 Mdot
.87834 .3435 Mdot
.87839 .55833 Mdot
.87844 .57685 Mdot
.87849 .43894 Mdot
.87853 .53775 Mdot
.87858 .35499 Mdot
.87863 .5001 Mdot
.87868 .35167 Mdot
.87872 .30864 Mdot
.87877 .42544 Mdot
.87882 .3182 Mdot
.87887 .43635 Mdot
.87891 .32019 Mdot
.87896 .51317 Mdot
.87901 .45169 Mdot
.87906 .42689 Mdot
.8791 .45619 Mdot
.87915 .43686 Mdot
.8792 .38384 Mdot
.87925 .43553 Mdot
.8793 .49321 Mdot
.87934 .5964 Mdot
.87939 .3784 Mdot
.87944 .56513 Mdot
.87949 .45801 Mdot
.87953 .34639 Mdot
.87958 .40474 Mdot
.87963 .43453 Mdot
.87968 .52348 Mdot
.87972 .59462 Mdot
.87977 .50789 Mdot
.87982 .39125 Mdot
.87987 .52324 Mdot
.87991 .4776 Mdot
.87996 .49812 Mdot
.88001 .55821 Mdot
.88006 .51151 Mdot
.8801 .56775 Mdot
.88015 .3549 Mdot
.8802 .43981 Mdot
.88025 .36382 Mdot
.8803 .43939 Mdot
.88034 .57444 Mdot
.88039 .31279 Mdot
.88044 .474 Mdot
.88049 .4464 Mdot
.88053 .50458 Mdot
.88058 .35108 Mdot
.88063 .32455 Mdot
.88068 .40858 Mdot
.88072 .40842 Mdot
.88077 .52 Mdot
.88082 .40452 Mdot
.88087 .41741 Mdot
.88091 .504 Mdot
.88096 .43735 Mdot
.88101 .48475 Mdot
.88106 .54329 Mdot
.8811 .31451 Mdot
.88115 .48263 Mdot
.8812 .57672 Mdot
.88125 .57904 Mdot
.8813 .5631 Mdot
.88134 .35147 Mdot
.88139 .52156 Mdot
.88144 .44829 Mdot
.88149 .59217 Mdot
.88153 .34733 Mdot
.88158 .35622 Mdot
.88163 .31056 Mdot
.88168 .39625 Mdot
.88172 .59977 Mdot
.88177 .34033 Mdot
.88182 .50549 Mdot
.88187 .59134 Mdot
.88191 .38843 Mdot
.88196 .53933 Mdot
.88201 .39674 Mdot
.88206 .396 Mdot
.8821 .55459 Mdot
.88215 .36324 Mdot
.8822 .45696 Mdot
.88225 .39015 Mdot
.8823 .38061 Mdot
.88234 .39002 Mdot
.88239 .48142 Mdot
.88244 .43055 Mdot
.88249 .33778 Mdot
.88253 .47195 Mdot
.88258 .34176 Mdot
.88263 .44186 Mdot
.88268 .59392 Mdot
.88272 .42435 Mdot
.88277 .33981 Mdot
.88282 .35422 Mdot
.88287 .59761 Mdot
.88291 .39261 Mdot
.88296 .43776 Mdot
.88301 .36631 Mdot
.88306 .51775 Mdot
.8831 .4567 Mdot
.88315 .34958 Mdot
.8832 .57371 Mdot
.88325 .56655 Mdot
.8833 .402 Mdot
.88334 .496 Mdot
.88339 .49207 Mdot
.88344 .49445 Mdot
.88349 .32048 Mdot
.88353 .32306 Mdot
.88358 .37 Mdot
.88363 .46514 Mdot
.88368 .45183 Mdot
.88372 .5846 Mdot
.88377 .53143 Mdot
.88382 .47449 Mdot
.88387 .33589 Mdot
.88391 .55318 Mdot
.88396 .4856 Mdot
.88401 .48011 Mdot
.88406 .54649 Mdot
.8841 .42376 Mdot
.88415 .42762 Mdot
.8842 .56553 Mdot
.88425 .39809 Mdot
.88429 .38247 Mdot
.88434 .45704 Mdot
.88439 .60209 Mdot
.88444 .59919 Mdot
.88449 .48955 Mdot
.88453 .56803 Mdot
.88458 .41584 Mdot
.88463 .5869 Mdot
.88468 .47465 Mdot
.88472 .50617 Mdot
.88477 .55369 Mdot
.88482 .44317 Mdot
.88487 .49299 Mdot
.88491 .57767 Mdot
.88496 .38725 Mdot
.88501 .41532 Mdot
.88506 .54268 Mdot
.8851 .40007 Mdot
.88515 .50998 Mdot
.8852 .47164 Mdot
.88525 .42686 Mdot
.88529 .57523 Mdot
.88534 .5472 Mdot
.88539 .38142 Mdot
.88544 .35224 Mdot
.88549 .42603 Mdot
.88553 .54777 Mdot
.88558 .38487 Mdot
.88563 .46531 Mdot
.88568 .4606 Mdot
.88572 .43965 Mdot
.88577 .40053 Mdot
.88582 .59319 Mdot
.88587 .55693 Mdot
.88591 .48844 Mdot
.88596 .55982 Mdot
.88601 .40777 Mdot
.88606 .58166 Mdot
.8861 .40872 Mdot
.88615 .452 Mdot
.8862 .46742 Mdot
.88625 .48904 Mdot
.88629 .50102 Mdot
.88634 .58261 Mdot
.88639 .34793 Mdot
.88644 .516 Mdot
.88649 .55599 Mdot
.88653 .50847 Mdot
.88658 .5978 Mdot
.88663 .3972 Mdot
.88668 .31542 Mdot
.88672 .43077 Mdot
.88677 .43963 Mdot
.88682 .53857 Mdot
.88687 .47771 Mdot
.88691 .33729 Mdot
.88696 .44831 Mdot
.88701 .58349 Mdot
.88706 .59108 Mdot
.8871 .37926 Mdot
.88715 .34743 Mdot
.8872 .30868 Mdot
.88725 .4892 Mdot
.88729 .52891 Mdot
.88734 .48163 Mdot
.88739 .42123 Mdot
.88744 .58973 Mdot
.88749 .54782 Mdot
.88753 .44033 Mdot
.88758 .50668 Mdot
.88763 .34031 Mdot
.88768 .34588 Mdot
.88772 .44388 Mdot
.88777 .41594 Mdot
.88782 .33131 Mdot
.88787 .51635 Mdot
.88791 .3106 Mdot
.88796 .47854 Mdot
.88801 .45473 Mdot
.88806 .4853 Mdot
.8881 .46334 Mdot
.88815 .49608 Mdot
.8882 .46464 Mdot
.88825 .41214 Mdot
.88829 .42196 Mdot
.88834 .4934 Mdot
.88839 .57627 Mdot
.88844 .48401 Mdot
.88848 .54108 Mdot
.88853 .37803 Mdot
.88858 .58721 Mdot
.88863 .53682 Mdot
.88868 .40648 Mdot
.88872 .47189 Mdot
.88877 .55255 Mdot
.88882 .49655 Mdot
.88887 .56302 Mdot
.88891 .36148 Mdot
.88896 .52673 Mdot
.88901 .5805 Mdot
.88906 .55782 Mdot
.8891 .48315 Mdot
.88915 .3773 Mdot
.8892 .40046 Mdot
.88925 .3997 Mdot
.88929 .58711 Mdot
.88934 .51266 Mdot
.88939 .58827 Mdot
.88944 .57764 Mdot
.88948 .3987 Mdot
.88953 .5362 Mdot
.88958 .40917 Mdot
.88963 .34142 Mdot
.88968 .32549 Mdot
.88972 .54861 Mdot
.88977 .47192 Mdot
.88982 .53447 Mdot
.88987 .45308 Mdot
.88991 .59549 Mdot
.88996 .57475 Mdot
.89001 .57079 Mdot
.89006 .39604 Mdot
.8901 .37315 Mdot
.89015 .59345 Mdot
.8902 .31725 Mdot
.89025 .51198 Mdot
.89029 .59489 Mdot
.89034 .49712 Mdot
.89039 .51649 Mdot
.89044 .52376 Mdot
.89048 .38621 Mdot
.89053 .50763 Mdot
.89058 .53758 Mdot
.89063 .42888 Mdot
.89068 .44864 Mdot
.89072 .40218 Mdot
.89077 .49983 Mdot
.89082 .40701 Mdot
.89087 .49845 Mdot
.89091 .52862 Mdot
.89096 .56366 Mdot
.89101 .55218 Mdot
.89106 .50115 Mdot
.8911 .55201 Mdot
.89115 .59096 Mdot
.8912 .45932 Mdot
.89125 .43112 Mdot
.89129 .55648 Mdot
.89134 .57672 Mdot
.89139 .54515 Mdot
.89144 .43398 Mdot
.89148 .36221 Mdot
.89153 .36301 Mdot
.89158 .32411 Mdot
.89163 .35044 Mdot
.89168 .45204 Mdot
.89172 .42284 Mdot
.89177 .49257 Mdot
.89182 .49908 Mdot
.89187 .35223 Mdot
.89191 .52018 Mdot
.89196 .38781 Mdot
.89201 .30282 Mdot
.89206 .42059 Mdot
.8921 .55344 Mdot
.89215 .4325 Mdot
.8922 .39848 Mdot
.89225 .46532 Mdot
.89229 .55916 Mdot
.89234 .5698 Mdot
.89239 .56391 Mdot
.89244 .50533 Mdot
.89248 .57887 Mdot
.89253 .32616 Mdot
.89258 .43138 Mdot
.89263 .44451 Mdot
.89268 .51718 Mdot
.89272 .30331 Mdot
.89277 .38213 Mdot
.89282 .58845 Mdot
.89287 .3954 Mdot
.89291 .40659 Mdot
.89296 .47884 Mdot
.89301 .53709 Mdot
.89306 .47088 Mdot
.8931 .31951 Mdot
.89315 .47668 Mdot
.8932 .4171 Mdot
.89325 .51282 Mdot
.89329 .48234 Mdot
.89334 .3786 Mdot
.89339 .54695 Mdot
.89344 .54878 Mdot
.89348 .50759 Mdot
.89353 .40967 Mdot
.89358 .34167 Mdot
.89363 .56475 Mdot
.89367 .48134 Mdot
.89372 .57299 Mdot
.89377 .49179 Mdot
.89382 .34727 Mdot
.89387 .47766 Mdot
.89391 .49042 Mdot
.89396 .49768 Mdot
.89401 .54614 Mdot
.89406 .37041 Mdot
.8941 .31085 Mdot
.89415 .55465 Mdot
.8942 .37439 Mdot
.89425 .34995 Mdot
.89429 .428 Mdot
.89434 .43646 Mdot
.89439 .45526 Mdot
.89444 .46123 Mdot
.89448 .34809 Mdot
.89453 .48297 Mdot
.89458 .49987 Mdot
.89463 .54696 Mdot
.89467 .53167 Mdot
.89472 .43961 Mdot
.89477 .52822 Mdot
.89482 .36378 Mdot
.89487 .55162 Mdot
.89491 .54068 Mdot
.89496 .47888 Mdot
.89501 .47883 Mdot
.89506 .35898 Mdot
.8951 .34069 Mdot
.89515 .52521 Mdot
.8952 .40596 Mdot
.89525 .34559 Mdot
.89529 .37828 Mdot
.89534 .44812 Mdot
.89539 .35323 Mdot
.89544 .50958 Mdot
.89548 .53374 Mdot
.89553 .5847 Mdot
.89558 .48376 Mdot
.89563 .45832 Mdot
.89567 .34751 Mdot
.89572 .38149 Mdot
.89577 .52824 Mdot
.89582 .518 Mdot
.89587 .49917 Mdot
.89591 .44446 Mdot
.89596 .4607 Mdot
.89601 .55741 Mdot
.89606 .54943 Mdot
.8961 .55644 Mdot
.89615 .57265 Mdot
.8962 .49427 Mdot
.89625 .50449 Mdot
.89629 .3269 Mdot
.89634 .46227 Mdot
.89639 .44418 Mdot
.89644 .42162 Mdot
.89648 .46896 Mdot
.89653 .40428 Mdot
.89658 .5246 Mdot
.89663 .4778 Mdot
.89667 .4741 Mdot
.89672 .51027 Mdot
.89677 .36109 Mdot
.89682 .42501 Mdot
.89687 .38725 Mdot
.89691 .57143 Mdot
.89696 .4324 Mdot
.89701 .51507 Mdot
.89706 .53193 Mdot
.8971 .40492 Mdot
.89715 .46395 Mdot
.8972 .55451 Mdot
.89725 .56427 Mdot
.89729 .42096 Mdot
.89734 .55828 Mdot
.89739 .34367 Mdot
.89744 .53093 Mdot
.89748 .54702 Mdot
.89753 .40749 Mdot
.89758 .5102 Mdot
.89763 .35517 Mdot
.89767 .43584 Mdot
.89772 .47076 Mdot
.89777 .32532 Mdot
.89782 .46875 Mdot
.89786 .51317 Mdot
.89791 .40231 Mdot
.89796 .48772 Mdot
.89801 .37396 Mdot
.89806 .52896 Mdot
.8981 .55702 Mdot
.89815 .55968 Mdot
.8982 .42897 Mdot
.89825 .41602 Mdot
.89829 .38496 Mdot
.89834 .29696 Mdot
.89839 .45125 Mdot
.89844 .58152 Mdot
.89848 .41304 Mdot
.89853 .53956 Mdot
.89858 .50649 Mdot
.89863 .32572 Mdot
.89867 .29666 Mdot
.89872 .32037 Mdot
.89877 .44225 Mdot
.89882 .47555 Mdot
.89886 .41149 Mdot
.89891 .58054 Mdot
.89896 .55888 Mdot
.89901 .54767 Mdot
.89906 .29951 Mdot
.8991 .38305 Mdot
.89915 .47505 Mdot
.8992 .30874 Mdot
.89925 .32727 Mdot
.89929 .40806 Mdot
.89934 .33582 Mdot
.89939 .4772 Mdot
.89944 .5267 Mdot
.89948 .40052 Mdot
.89953 .46874 Mdot
.89958 .47976 Mdot
.89963 .40278 Mdot
.89967 .44484 Mdot
.89972 .54602 Mdot
.89977 .44285 Mdot
.89982 .39482 Mdot
.89986 .41306 Mdot
.89991 .39228 Mdot
.89996 .55055 Mdot
.90001 .56648 Mdot
.90006 .41557 Mdot
.9001 .41634 Mdot
.90015 .29086 Mdot
.9002 .55484 Mdot
.90025 .32029 Mdot
.90029 .5238 Mdot
.90034 .56454 Mdot
.90039 .51502 Mdot
.90044 .49443 Mdot
.90048 .47522 Mdot
.90053 .37446 Mdot
.90058 .5702 Mdot
.90063 .38082 Mdot
.90067 .29328 Mdot
.90072 .47626 Mdot
.90077 .45401 Mdot
.90082 .51733 Mdot
.90086 .32849 Mdot
.90091 .31967 Mdot
.90096 .34534 Mdot
.90101 .39031 Mdot
.90106 .517 Mdot
.9011 .3498 Mdot
.90115 .35943 Mdot
.9012 .55519 Mdot
.90125 .38616 Mdot
.90129 .34431 Mdot
.90134 .38471 Mdot
.90139 .52007 Mdot
.90144 .44226 Mdot
.90148 .35957 Mdot
.90153 .44937 Mdot
.90158 .31035 Mdot
.90163 .5465 Mdot
.90167 .56445 Mdot
.90172 .4584 Mdot
.90177 .50864 Mdot
.90182 .53736 Mdot
.90186 .37223 Mdot
.90191 .28831 Mdot
.90196 .56998 Mdot
.90201 .49257 Mdot
.90206 .33614 Mdot
.9021 .52128 Mdot
.90215 .46302 Mdot
.9022 .55366 Mdot
.90225 .56432 Mdot
.90229 .44485 Mdot
.90234 .48556 Mdot
.90239 .45027 Mdot
.90244 .50265 Mdot
.90248 .34267 Mdot
.90253 .54277 Mdot
.90258 .2903 Mdot
.90263 .42526 Mdot
.90267 .47022 Mdot
.90272 .51436 Mdot
.90277 .32049 Mdot
.90282 .43737 Mdot
.90286 .29341 Mdot
.90291 .28719 Mdot
.90296 .35933 Mdot
.90301 .34637 Mdot
.90305 .28621 Mdot
.9031 .29306 Mdot
.90315 .44249 Mdot
.9032 .29098 Mdot
.90325 .34041 Mdot
.90329 .40541 Mdot
.90334 .46408 Mdot
.90339 .30179 Mdot
.90344 .47056 Mdot
.90348 .49472 Mdot
.90353 .29371 Mdot
.90358 .37377 Mdot
.90363 .40754 Mdot
.90367 .52634 Mdot
.90372 .28282 Mdot
.90377 .52266 Mdot
.90382 .51135 Mdot
.90386 .29102 Mdot
.90391 .53611 Mdot
.90396 .36408 Mdot
.90401 .49661 Mdot
.90405 .28237 Mdot
.9041 .4552 Mdot
.90415 .296 Mdot
.9042 .48856 Mdot
.90425 .56221 Mdot
.90429 .29063 Mdot
.90434 .28281 Mdot
.90439 .42582 Mdot
.90444 .43435 Mdot
.90448 .39883 Mdot
.90453 .55317 Mdot
.90458 .52727 Mdot
.90463 .51152 Mdot
.90467 .38202 Mdot
.90472 .45618 Mdot
.90477 .39638 Mdot
.90482 .55655 Mdot
.90486 .37559 Mdot
.90491 .50464 Mdot
.90496 .45602 Mdot
.90501 .54154 Mdot
.90505 .41021 Mdot
.9051 .41631 Mdot
.90515 .52989 Mdot
.9052 .53465 Mdot
.90525 .52522 Mdot
.90529 .39553 Mdot
.90534 .31642 Mdot
.90539 .54226 Mdot
.90544 .50942 Mdot
.90548 .38742 Mdot
.90553 .46003 Mdot
.90558 .38235 Mdot
.90563 .3849 Mdot
.90567 .40328 Mdot
.90572 .50166 Mdot
.90577 .4396 Mdot
.90582 .27666 Mdot
.90586 .51561 Mdot
.90591 .37879 Mdot
.90596 .45128 Mdot
.90601 .46917 Mdot
.90605 .28408 Mdot
.9061 .49061 Mdot
.90615 .47744 Mdot
.9062 .33167 Mdot
.90625 .4352 Mdot
.90629 .52801 Mdot
.90634 .50995 Mdot
.90639 .37347 Mdot
.90644 .3117 Mdot
.90648 .48348 Mdot
.90653 .53431 Mdot
.90658 .43054 Mdot
.90663 .49062 Mdot
.90667 .2948 Mdot
.90672 .42317 Mdot
.90677 .31671 Mdot
.90682 .35827 Mdot
.90686 .3588 Mdot
.90691 .54909 Mdot
.90696 .31058 Mdot
.90701 .40791 Mdot
.90705 .54511 Mdot
.9071 .36791 Mdot
.90715 .40624 Mdot
.9072 .39366 Mdot
.90724 .32419 Mdot
.90729 .45488 Mdot
.90734 .34399 Mdot
.90739 .52259 Mdot
.90744 .36017 Mdot
.90748 .50878 Mdot
.90753 .53422 Mdot
.90758 .47961 Mdot
.90763 .44012 Mdot
.90767 .53776 Mdot
.90772 .37197 Mdot
.90777 .55199 Mdot
.90782 .41332 Mdot
.90786 .38245 Mdot
.90791 .32297 Mdot
.90796 .46129 Mdot
.90801 .32195 Mdot
.90805 .39551 Mdot
.9081 .27954 Mdot
.90815 .32039 Mdot
.9082 .33856 Mdot
.90824 .29432 Mdot
.90829 .43473 Mdot
.90834 .48801 Mdot
.90839 .28065 Mdot
.90844 .40043 Mdot
.90848 .35674 Mdot
.90853 .52612 Mdot
.90858 .48104 Mdot
.90863 .45207 Mdot
.90867 .38279 Mdot
.90872 .31179 Mdot
.90877 .30605 Mdot
.90882 .47415 Mdot
.90886 .27565 Mdot
.90891 .31934 Mdot
.90896 .45213 Mdot
.90901 .35609 Mdot
.90905 .51178 Mdot
.9091 .417 Mdot
.90915 .39412 Mdot
.9092 .51924 Mdot
.90924 .49589 Mdot
.90929 .36012 Mdot
.90934 .31892 Mdot
.90939 .48813 Mdot
.90944 .32422 Mdot
.90948 .42988 Mdot
.90953 .30102 Mdot
.90958 .35031 Mdot
.90963 .5248 Mdot
.90967 .46092 Mdot
.90972 .377 Mdot
.90977 .45511 Mdot
.90982 .40387 Mdot
.90986 .41085 Mdot
.90991 .33251 Mdot
.90996 .53722 Mdot
.91001 .38948 Mdot
.91005 .35261 Mdot
.9101 .4362 Mdot
.91015 .44193 Mdot
.9102 .43321 Mdot
.91024 .49097 Mdot
.91029 .30242 Mdot
.91034 .47774 Mdot
.91039 .49222 Mdot
.91044 .39074 Mdot
.91048 .5381 Mdot
.91053 .54404 Mdot
.91058 .42743 Mdot
.91063 .51499 Mdot
.91067 .4962 Mdot
.91072 .4527 Mdot
.91077 .4563 Mdot
.91082 .31273 Mdot
.91086 .37771 Mdot
.91091 .25595 Mdot
.91096 .31062 Mdot
.91101 .45478 Mdot
.91105 .30308 Mdot
.9111 .27131 Mdot
.91115 .47358 Mdot
.9112 .35959 Mdot
.91124 .41901 Mdot
.91129 .38135 Mdot
.91134 .29732 Mdot
.91139 .42027 Mdot
.91144 .37322 Mdot
.91148 .45494 Mdot
.91153 .35628 Mdot
.91158 .28569 Mdot
.91163 .38598 Mdot
.91167 .4616 Mdot
.91172 .4794 Mdot
.91177 .32109 Mdot
.91182 .44001 Mdot
.91186 .26412 Mdot
.91191 .27815 Mdot
.91196 .26326 Mdot
.91201 .31705 Mdot
.91205 .26275 Mdot
.9121 .51681 Mdot
.91215 .3576 Mdot
.9122 .26806 Mdot
.91224 .54024 Mdot
.91229 .29702 Mdot
.91234 .25163 Mdot
.91239 .39737 Mdot
.91243 .41219 Mdot
.91248 .25284 Mdot
.91253 .3792 Mdot
.91258 .27697 Mdot
.91263 .50476 Mdot
.91267 .44391 Mdot
.91272 .34584 Mdot
.91277 .43801 Mdot
.91282 .29517 Mdot
.91286 .51122 Mdot
.91291 .27643 Mdot
.91296 .24952 Mdot
.91301 .2824 Mdot
.91305 .48426 Mdot
.9131 .26421 Mdot
.91315 .4782 Mdot
.9132 .27036 Mdot
.91324 .51285 Mdot
.91329 .45184 Mdot
.91334 .46035 Mdot
.91339 .27502 Mdot
.91343 .46572 Mdot
.91348 .44993 Mdot
.91353 .31253 Mdot
.91358 .40708 Mdot
.91363 .46211 Mdot
.91367 .31979 Mdot
.91372 .28445 Mdot
.91377 .44591 Mdot
.91382 .26676 Mdot
.91386 .5172 Mdot
.91391 .38953 Mdot
.91396 .39881 Mdot
.91401 .29829 Mdot
.91405 .4885 Mdot
.9141 .38758 Mdot
.91415 .3638 Mdot
.9142 .35612 Mdot
.91424 .47136 Mdot
.91429 .45114 Mdot
.91434 .34017 Mdot
.91439 .38469 Mdot
.91443 .26591 Mdot
.91448 .53188 Mdot
.91453 .31121 Mdot
.91458 .45971 Mdot
.91463 .35655 Mdot
.91467 .4649 Mdot
.91472 .44437 Mdot
.91477 .24282 Mdot
.91482 .28181 Mdot
.91486 .42532 Mdot
.91491 .24317 Mdot
.91496 .51546 Mdot
.91501 .30383 Mdot
.91505 .27998 Mdot
.9151 .38324 Mdot
.91515 .46102 Mdot
.9152 .35387 Mdot
.91524 .43077 Mdot
.91529 .26278 Mdot
.91534 .34807 Mdot
.91539 .42036 Mdot
.91543 .51732 Mdot
.91548 .46012 Mdot
.91553 .50073 Mdot
.91558 .39677 Mdot
.91563 .52244 Mdot
.91567 .39089 Mdot
.91572 .28281 Mdot
.91577 .28184 Mdot
.91582 .29899 Mdot
.91586 .48266 Mdot
.91591 .2811 Mdot
.91596 .24096 Mdot
.91601 .40929 Mdot
.91605 .48008 Mdot
.9161 .30092 Mdot
.91615 .47223 Mdot
.9162 .36937 Mdot
.91624 .33673 Mdot
.91629 .37447 Mdot
.91634 .35791 Mdot
.91639 .47283 Mdot
.91643 .31314 Mdot
.91648 .26542 Mdot
.91653 .47125 Mdot
.91658 .48904 Mdot
.91663 .38637 Mdot
.91667 .29787 Mdot
.91672 .31263 Mdot
.91677 .49942 Mdot
.91682 .52813 Mdot
.91686 .25267 Mdot
.91691 .26823 Mdot
.91696 .43769 Mdot
.91701 .28256 Mdot
.91705 .50334 Mdot
.9171 .264 Mdot
.91715 .26496 Mdot
.9172 .33371 Mdot
.91724 .43863 Mdot
.91729 .32265 Mdot
.91734 .42629 Mdot
.91739 .23266 Mdot
.91743 .29965 Mdot
.91748 .49491 Mdot
.91753 .48345 Mdot
.91758 .44933 Mdot
.91762 .26901 Mdot
.91767 .25826 Mdot
.91772 .5237 Mdot
.91777 .29721 Mdot
.91782 .50007 Mdot
.91786 .47438 Mdot
.91791 .25799 Mdot
.91796 .29747 Mdot
.91801 .48075 Mdot
.91805 .43932 Mdot
.9181 .34814 Mdot
.91815 .24772 Mdot
.9182 .5049 Mdot
.91824 .40777 Mdot
.91829 .31546 Mdot
.91834 .44095 Mdot
.91839 .29818 Mdot
.91843 .31686 Mdot
.91848 .41557 Mdot
.91853 .43966 Mdot
.91858 .22972 Mdot
.91862 .34781 Mdot
.91867 .4578 Mdot
.91872 .51583 Mdot
.91877 .48602 Mdot
.91882 .31983 Mdot
.91886 .45906 Mdot
.91891 .44853 Mdot
.91896 .51054 Mdot
.91901 .36985 Mdot
.91905 .43044 Mdot
.9191 .38025 Mdot
.91915 .2588 Mdot
.9192 .45421 Mdot
.91924 .31093 Mdot
.91929 .36098 Mdot
.91934 .27703 Mdot
.91939 .27452 Mdot
.91943 .51823 Mdot
.91948 .4426 Mdot
.91953 .50124 Mdot
.91958 .47987 Mdot
.91962 .32982 Mdot
.91967 .22992 Mdot
.91972 .49832 Mdot
.91977 .35867 Mdot
.91982 .39331 Mdot
.91986 .23519 Mdot
.91991 .23836 Mdot
.91996 .26472 Mdot
.92001 .4548 Mdot
.92005 .30702 Mdot
.9201 .24799 Mdot
.92015 .41486 Mdot
.9202 .24931 Mdot
.92024 .44639 Mdot
.92029 .50863 Mdot
.92034 .4799 Mdot
.92039 .45744 Mdot
.92043 .30943 Mdot
.92048 .45543 Mdot
.92053 .42903 Mdot
.92058 .45752 Mdot
.92062 .38496 Mdot
.92067 .47213 Mdot
.92072 .46691 Mdot
.92077 .35041 Mdot
.92082 .37757 Mdot
.92086 .491 Mdot
.92091 .33039 Mdot
.92096 .47392 Mdot
.92101 .36416 Mdot
.92105 .47423 Mdot
.9211 .28707 Mdot
.92115 .24033 Mdot
.9212 .27816 Mdot
.92124 .44707 Mdot
.92129 .38771 Mdot
.92134 .50634 Mdot
.92139 .3469 Mdot
.92143 .45338 Mdot
.92148 .42256 Mdot
.92153 .26861 Mdot
.92158 .25699 Mdot
.92162 .21728 Mdot
.92167 .50753 Mdot
.92172 .32489 Mdot
.92177 .38564 Mdot
.92181 .25857 Mdot
.92186 .25899 Mdot
.92191 .48753 Mdot
.92196 .22607 Mdot
.92201 .28023 Mdot
.92205 .44107 Mdot
.9221 .23104 Mdot
.92215 .37401 Mdot
.9222 .3179 Mdot
.92224 .37086 Mdot
.92229 .50223 Mdot
.92234 .31232 Mdot
.92239 .38197 Mdot
.92243 .4941 Mdot
.92248 .50665 Mdot
.92253 .47599 Mdot
.92258 .43896 Mdot
.92262 .28687 Mdot
.92267 .45318 Mdot
.92272 .43395 Mdot
.92277 .43644 Mdot
.92281 .28876 Mdot
.92286 .34265 Mdot
.92291 .26249 Mdot
.92296 .39185 Mdot
.92301 .24357 Mdot
.92305 .36358 Mdot
.9231 .24983 Mdot
.92315 .32484 Mdot
.9232 .31037 Mdot
.92324 .34537 Mdot
.92329 .38331 Mdot
.92334 .21938 Mdot
.92339 .44662 Mdot
.92343 .35005 Mdot
.92348 .28286 Mdot
.92353 .34394 Mdot
.92358 .45885 Mdot
.92362 .34955 Mdot
.92367 .31282 Mdot
.92372 .41073 Mdot
.92377 .38268 Mdot
.92381 .40174 Mdot
.92386 .38404 Mdot
.92391 .47927 Mdot
.92396 .30385 Mdot
.92401 .26882 Mdot
.92405 .3311 Mdot
.9241 .29676 Mdot
.92415 .26943 Mdot
.9242 .40905 Mdot
.92424 .29003 Mdot
.92429 .47535 Mdot
.92434 .46229 Mdot
.92439 .27186 Mdot
.92443 .40956 Mdot
.92448 .46375 Mdot
.92453 .22326 Mdot
.92458 .42405 Mdot
.92462 .3339 Mdot
.92467 .32681 Mdot
.92472 .26607 Mdot
.92477 .28112 Mdot
.92481 .22749 Mdot
.92486 .41716 Mdot
.92491 .38427 Mdot
.92496 .38006 Mdot
.92501 .34394 Mdot
.92505 .43818 Mdot
.9251 .28566 Mdot
.92515 .31628 Mdot
.9252 .21769 Mdot
.92524 .34606 Mdot
.92529 .22068 Mdot
.92534 .40634 Mdot
.92539 .42657 Mdot
.92543 .36943 Mdot
.92548 .25691 Mdot
.92553 .33795 Mdot
.92558 .22028 Mdot
.92562 .40361 Mdot
.92567 .23653 Mdot
.92572 .41144 Mdot
.92577 .38373 Mdot
.92581 .27908 Mdot
.92586 .4674 Mdot
.92591 .33221 Mdot
.92596 .35792 Mdot
.92601 .35827 Mdot
.92605 .28443 Mdot
.9261 .4481 Mdot
.92615 .21488 Mdot
.9262 .41565 Mdot
.92624 .19927 Mdot
.92629 .33212 Mdot
.92634 .1973 Mdot
.92639 .26949 Mdot
.92643 .47316 Mdot
.92648 .42014 Mdot
.92653 .26489 Mdot
.92658 .39403 Mdot
.92662 .41515 Mdot
.92667 .28089 Mdot
.92672 .24312 Mdot
.92677 .48358 Mdot
.92681 .37674 Mdot
.92686 .36223 Mdot
.92691 .35197 Mdot
.92696 .40201 Mdot
.927 .40151 Mdot
.92705 .22714 Mdot
.9271 .48582 Mdot
.92715 .24046 Mdot
.9272 .31361 Mdot
.92724 .27021 Mdot
.92729 .46706 Mdot
.92734 .31558 Mdot
.92739 .31005 Mdot
.92743 .42847 Mdot
.92748 .46508 Mdot
.92753 .2412 Mdot
.92758 .32667 Mdot
.92762 .20305 Mdot
.92767 .3947 Mdot
.92772 .33635 Mdot
.92777 .40049 Mdot
.92781 .41093 Mdot
.92786 .3453 Mdot
.92791 .34114 Mdot
.92796 .21706 Mdot
.928 .24181 Mdot
.92805 .4811 Mdot
.9281 .42669 Mdot
.92815 .30291 Mdot
.9282 .20698 Mdot
.92824 .48224 Mdot
.92829 .37813 Mdot
.92834 .47586 Mdot
.92839 .42313 Mdot
.92843 .20648 Mdot
.92848 .25365 Mdot
.92853 .35671 Mdot
.92858 .48021 Mdot
.92862 .22676 Mdot
.92867 .20274 Mdot
.92872 .22013 Mdot
.92877 .46704 Mdot
.92881 .3166 Mdot
.92886 .35073 Mdot
.92891 .30378 Mdot
.92896 .2452 Mdot
.929 .45503 Mdot
.92905 .19827 Mdot
.9291 .27519 Mdot
.92915 .19165 Mdot
.9292 .45686 Mdot
.92924 .25431 Mdot
.92929 .4548 Mdot
.92934 .46699 Mdot
.92939 .45674 Mdot
.92943 .35809 Mdot
.92948 .46064 Mdot
.92953 .23051 Mdot
.92958 .4367 Mdot
.92962 .29068 Mdot
.92967 .28998 Mdot
.92972 .231 Mdot
.92977 .39558 Mdot
.92981 .27337 Mdot
.92986 .25508 Mdot
.92991 .24384 Mdot
.92996 .26381 Mdot
.93 .40212 Mdot
.93005 .43058 Mdot
.9301 .18286 Mdot
.93015 .28765 Mdot
.9302 .38766 Mdot
.93024 .339 Mdot
.93029 .46946 Mdot
.93034 .30884 Mdot
.93039 .31635 Mdot
.93043 .36185 Mdot
.93048 .18506 Mdot
.93053 .32934 Mdot
.93058 .4353 Mdot
.93062 .37804 Mdot
.93067 .43117 Mdot
.93072 .36907 Mdot
.93077 .32598 Mdot
.93081 .26922 Mdot
.93086 .38113 Mdot
.93091 .44909 Mdot
.93096 .23315 Mdot
.931 .19448 Mdot
.93105 .31743 Mdot
.9311 .36522 Mdot
.93115 .30562 Mdot
.93119 .23828 Mdot
.93124 .31389 Mdot
.93129 .25669 Mdot
.93134 .39174 Mdot
.93139 .37285 Mdot
.93143 .31779 Mdot
.93148 .42101 Mdot
.93153 .25349 Mdot
.93158 .18889 Mdot
.93162 .31042 Mdot
.93167 .26915 Mdot
.93172 .29033 Mdot
.93177 .28279 Mdot
.93181 .35097 Mdot
.93186 .37161 Mdot
.93191 .43566 Mdot
.93196 .18983 Mdot
.932 .44074 Mdot
.93205 .39322 Mdot
.9321 .37815 Mdot
.93215 .46564 Mdot
.93219 .29855 Mdot
.93224 .20302 Mdot
.93229 .24735 Mdot
.93234 .40198 Mdot
.93239 .45393 Mdot
.93243 .4154 Mdot
.93248 .32447 Mdot
.93253 .20293 Mdot
.93258 .30973 Mdot
.93262 .46263 Mdot
.93267 .24417 Mdot
.93272 .18701 Mdot
.93277 .17208 Mdot
.93281 .36604 Mdot
.93286 .42106 Mdot
.93291 .37123 Mdot
.93296 .28792 Mdot
.933 .46104 Mdot
.93305 .45179 Mdot
.9331 .35274 Mdot
.93315 .31316 Mdot
.93319 .23874 Mdot
.93324 .24436 Mdot
.93329 .35246 Mdot
.93334 .18492 Mdot
.93339 .20582 Mdot
.93343 .16691 Mdot
.93348 .41503 Mdot
.93353 .19534 Mdot
.93358 .25456 Mdot
.93362 .30636 Mdot
.93367 .38098 Mdot
.93372 .34913 Mdot
.93377 .25525 Mdot
.93381 .23045 Mdot
.93386 .36201 Mdot
.93391 .34488 Mdot
.93396 .3517 Mdot
.934 .27168 Mdot
.93405 .45286 Mdot
.9341 .22398 Mdot
.93415 .35233 Mdot
.93419 .28135 Mdot
.93424 .26653 Mdot
.93429 .37187 Mdot
.93434 .27958 Mdot
.93439 .20278 Mdot
.93443 .3745 Mdot
.93448 .35232 Mdot
.93453 .23893 Mdot
.93458 .20084 Mdot
.93462 .41908 Mdot
.93467 .32153 Mdot
.93472 .44357 Mdot
.93477 .35347 Mdot
.93481 .20203 Mdot
.93486 .43099 Mdot
.93491 .35184 Mdot
.93496 .28633 Mdot
.935 .29798 Mdot
.93505 .24901 Mdot
.9351 .16284 Mdot
.93515 .17714 Mdot
.93519 .30226 Mdot
.93524 .18711 Mdot
.93529 .26724 Mdot
.93534 .35231 Mdot
.93539 .1972 Mdot
.93543 .27135 Mdot
.93548 .44357 Mdot
.93553 .31038 Mdot
.93558 .2782 Mdot
.93562 .37433 Mdot
.93567 .36487 Mdot
.93572 .26956 Mdot
.93577 .31379 Mdot
.93581 .21241 Mdot
.93586 .37557 Mdot
.93591 .37015 Mdot
.93596 .27075 Mdot
.936 .23506 Mdot
.93605 .18231 Mdot
.9361 .24219 Mdot
.93615 .4258 Mdot
.93619 .43887 Mdot
.93624 .17723 Mdot
.93629 .2226 Mdot
.93634 .28088 Mdot
.93638 .40891 Mdot
.93643 .36178 Mdot
.93648 .32188 Mdot
.93653 .2402 Mdot
.93658 .29387 Mdot
.93662 .36918 Mdot
.93667 .16741 Mdot
.93672 .41256 Mdot
.93677 .36989 Mdot
.93681 .15959 Mdot
.93686 .34779 Mdot
.93691 .25365 Mdot
.93696 .31216 Mdot
.937 .23335 Mdot
.93705 .42676 Mdot
.9371 .43181 Mdot
.93715 .23095 Mdot
.93719 .20468 Mdot
.93724 .33801 Mdot
.93729 .15925 Mdot
.93734 .23996 Mdot
.93738 .18028 Mdot
.93743 .26802 Mdot
.93748 .32563 Mdot
.93753 .27812 Mdot
.93758 .26536 Mdot
.93762 .39279 Mdot
.93767 .23702 Mdot
.93772 .43049 Mdot
.93777 .34222 Mdot
.93781 .37635 Mdot
.93786 .27008 Mdot
.93791 .21116 Mdot
.93796 .33298 Mdot
.938 .17872 Mdot
.93805 .16638 Mdot
.9381 .3436 Mdot
.93815 .24917 Mdot
.93819 .19615 Mdot
.93824 .17856 Mdot
.93829 .26157 Mdot
.93834 .1932 Mdot
.93838 .30151 Mdot
.93843 .16762 Mdot
.93848 .16971 Mdot
.93853 .16082 Mdot
.93858 .18118 Mdot
.93862 .28433 Mdot
.93867 .33373 Mdot
.93872 .3374 Mdot
.93877 .23012 Mdot
.93881 .19397 Mdot
.93886 .34455 Mdot
.93891 .4363 Mdot
.93896 .29468 Mdot
.939 .3646 Mdot
.93905 .27904 Mdot
.9391 .24875 Mdot
.93915 .26119 Mdot
.93919 .34325 Mdot
.93924 .37512 Mdot
.93929 .14421 Mdot
.93934 .20946 Mdot
.93938 .3089 Mdot
.93943 .25756 Mdot
.93948 .38966 Mdot
.93953 .34641 Mdot
.93958 .28468 Mdot
.93962 .23104 Mdot
.93967 .37183 Mdot
.93972 .30801 Mdot
.93977 .14293 Mdot
.93981 .33455 Mdot
.93986 .1766 Mdot
.93991 .21985 Mdot
.93996 .38557 Mdot
.94 .42641 Mdot
.94005 .17651 Mdot
.9401 .36118 Mdot
.94015 .16192 Mdot
.94019 .28812 Mdot
.94024 .36315 Mdot
.94029 .24032 Mdot
.94034 .25366 Mdot
.94038 .34778 Mdot
.94043 .35867 Mdot
.94048 .17038 Mdot
.94053 .37893 Mdot
.94057 .22933 Mdot
.94062 .40277 Mdot
.94067 .25753 Mdot
.94072 .23276 Mdot
.94077 .13659 Mdot
.94081 .16904 Mdot
.94086 .38227 Mdot
.94091 .22752 Mdot
.94096 .23438 Mdot
.941 .42459 Mdot
.94105 .2995 Mdot
.9411 .27369 Mdot
.94115 .2395 Mdot
.94119 .38455 Mdot
.94124 .36944 Mdot
.94129 .24783 Mdot
.94134 .38211 Mdot
.94138 .15706 Mdot
.94143 .26458 Mdot
.94148 .42428 Mdot
.94153 .16938 Mdot
.94157 .2281 Mdot
.94162 .22885 Mdot
.94167 .17979 Mdot
.94172 .36914 Mdot
.94177 .25422 Mdot
.94181 .40002 Mdot
.94186 .37553 Mdot
.94191 .36599 Mdot
.94196 .21841 Mdot
.942 .15077 Mdot
.94205 .28083 Mdot
.9421 .26423 Mdot
.94215 .22111 Mdot
.94219 .27835 Mdot
.94224 .13917 Mdot
.94229 .15654 Mdot
.94234 .26303 Mdot
.94238 .33518 Mdot
.94243 .31741 Mdot
.94248 .20031 Mdot
.94253 .23679 Mdot
.94257 .20121 Mdot
.94262 .31839 Mdot
.94267 .16114 Mdot
.94272 .1387 Mdot
.94277 .39702 Mdot
.94281 .2682 Mdot
.94286 .21625 Mdot
.94291 .30853 Mdot
.94296 .12601 Mdot
.943 .31633 Mdot
.94305 .27372 Mdot
.9431 .21852 Mdot
.94315 .39829 Mdot
.94319 .16349 Mdot
.94324 .13729 Mdot
.94329 .12501 Mdot
.94334 .24733 Mdot
.94338 .15152 Mdot
.94343 .4026 Mdot
.94348 .28363 Mdot
.94353 .3336 Mdot
.94357 .25537 Mdot
.94362 .32849 Mdot
.94367 .17284 Mdot
.94372 .25819 Mdot
.94377 .35743 Mdot
.94381 .29275 Mdot
.94386 .15934 Mdot
.94391 .28102 Mdot
.94396 .21403 Mdot
.944 .2011 Mdot
.94405 .27007 Mdot
.9441 .27921 Mdot
.94415 .31656 Mdot
.94419 .34603 Mdot
.94424 .17515 Mdot
.94429 .29919 Mdot
.94434 .27627 Mdot
.94438 .33175 Mdot
.94443 .17294 Mdot
.94448 .17446 Mdot
.94453 .24716 Mdot
.94457 .34622 Mdot
.94462 .30618 Mdot
.94467 .25753 Mdot
.94472 .40826 Mdot
.94477 .13915 Mdot
.94481 .25456 Mdot
.94486 .12037 Mdot
.94491 .17165 Mdot
.94496 .26188 Mdot
.945 .21565 Mdot
.94505 .25444 Mdot
.9451 .37251 Mdot
.94515 .18062 Mdot
.94519 .36007 Mdot
.94524 .38952 Mdot
.94529 .17519 Mdot
.94534 .24849 Mdot
.94538 .30377 Mdot
.94543 .20899 Mdot
.94548 .31222 Mdot
.94553 .32985 Mdot
.94557 .24889 Mdot
.94562 .15239 Mdot
.94567 .18273 Mdot
.94572 .39596 Mdot
.94576 .35484 Mdot
.94581 .30679 Mdot
.94586 .18621 Mdot
.94591 .37349 Mdot
.94596 .21677 Mdot
.946 .30272 Mdot
.94605 .13065 Mdot
.9461 .22752 Mdot
.94615 .11683 Mdot
.94619 .16379 Mdot
.94624 .16832 Mdot
.94629 .16202 Mdot
.94634 .16653 Mdot
.94638 .18385 Mdot
.94643 .40252 Mdot
.94648 .32273 Mdot
.94653 .27176 Mdot
.94657 .38367 Mdot
.94662 .20405 Mdot
.94667 .40129 Mdot
.94672 .13623 Mdot
.94676 .34445 Mdot
.94681 .13429 Mdot
.94686 .11812 Mdot
.94691 .18883 Mdot
.94696 .15005 Mdot
.947 .35514 Mdot
.94705 .15148 Mdot
.9471 .37873 Mdot
.94715 .25381 Mdot
.94719 .33591 Mdot
.94724 .33005 Mdot
.94729 .37294 Mdot
.94734 .20086 Mdot
.94738 .27824 Mdot
.94743 .27848 Mdot
.94748 .31667 Mdot
.94753 .12708 Mdot
.94757 .28045 Mdot
.94762 .3603 Mdot
.94767 .1544 Mdot
.94772 .14756 Mdot
.94776 .18551 Mdot
.94781 .36277 Mdot
.94786 .12689 Mdot
.94791 .20649 Mdot
.94796 .15955 Mdot
.948 .3528 Mdot
.94805 .34086 Mdot
.9481 .1642 Mdot
.94815 .20684 Mdot
.94819 .3087 Mdot
.94824 .36417 Mdot
.94829 .31224 Mdot
.94834 .27259 Mdot
.94838 .38012 Mdot
.94843 .39251 Mdot
.94848 .21761 Mdot
.94853 .39525 Mdot
.94857 .20748 Mdot
.94862 .1815 Mdot
.94867 .196 Mdot
.94872 .22008 Mdot
.94876 .24712 Mdot
.94881 .13199 Mdot
.94886 .15315 Mdot
.94891 .13908 Mdot
.94896 .28353 Mdot
.949 .10924 Mdot
.94905 .34545 Mdot
.9491 .37814 Mdot
.94915 .32915 Mdot
.94919 .16661 Mdot
.94924 .28444 Mdot
.94929 .2743 Mdot
.94934 .12327 Mdot
.94938 .19991 Mdot
.94943 .36948 Mdot
.94948 .10395 Mdot
.94953 .14006 Mdot
.94957 .20412 Mdot
.94962 .25355 Mdot
.94967 .10505 Mdot
.94972 .32874 Mdot
.94976 .12374 Mdot
.94981 .15847 Mdot
.94986 .28056 Mdot
.94991 .18217 Mdot
.94996 .38697 Mdot
.95 .1055 Mdot
.95005 .24147 Mdot
.9501 .2933 Mdot
.95015 .37735 Mdot
.95019 .15434 Mdot
.95024 .25742 Mdot
.95029 .35805 Mdot
.95034 .30961 Mdot
.95038 .26343 Mdot
.95043 .37647 Mdot
.95048 .3331 Mdot
.95053 .20782 Mdot
.95057 .28675 Mdot
.95062 .37027 Mdot
.95067 .2906 Mdot
.95072 .10107 Mdot
.95076 .13039 Mdot
.95081 .36223 Mdot
.95086 .35354 Mdot
.95091 .36883 Mdot
.95095 .36323 Mdot
.951 .17794 Mdot
.95105 .26745 Mdot
.9511 .37261 Mdot
.95115 .35344 Mdot
.95119 .32686 Mdot
.95124 .36435 Mdot
.95129 .38529 Mdot
.95134 .29408 Mdot
.95138 .16424 Mdot
.95143 .10091 Mdot
.95148 .17011 Mdot
.95153 .12489 Mdot
.95157 .17668 Mdot
.95162 .15655 Mdot
.95167 .35084 Mdot
.95172 .22652 Mdot
.95176 .1946 Mdot
.95181 .25396 Mdot
.95186 .34273 Mdot
.95191 .18891 Mdot
.95195 .21983 Mdot
.952 .28769 Mdot
.95205 .36099 Mdot
.9521 .21259 Mdot
.95215 .13376 Mdot
.95219 .11194 Mdot
.95224 .37474 Mdot
.95229 .24533 Mdot
.95234 .1929 Mdot
.95238 .13341 Mdot
.95243 .3751 Mdot
.95248 .33671 Mdot
.95253 .11909 Mdot
.95257 .12274 Mdot
.95262 .29506 Mdot
.95267 .3017 Mdot
.95272 .32697 Mdot
.95276 .35057 Mdot
.95281 .32842 Mdot
.95286 .16435 Mdot
.95291 .22135 Mdot
.95295 .18542 Mdot
.953 .36918 Mdot
.95305 .35875 Mdot
.9531 .08979 Mdot
.95315 .28067 Mdot
.95319 .0961 Mdot
.95324 .23389 Mdot
.95329 .33844 Mdot
.95334 .25611 Mdot
.95338 .10341 Mdot
.95343 .37043 Mdot
.95348 .23238 Mdot
.95353 .20937 Mdot
.95357 .10965 Mdot
.95362 .12003 Mdot
.95367 .19943 Mdot
.95372 .17258 Mdot
.95376 .19523 Mdot
.95381 .19878 Mdot
.95386 .25274 Mdot
.95391 .20212 Mdot
.95395 .24674 Mdot
.954 .11933 Mdot
.95405 .11611 Mdot
.9541 .10125 Mdot
.95415 .25679 Mdot
.95419 .13964 Mdot
.95424 .11034 Mdot
.95429 .19929 Mdot
.95434 .24436 Mdot
.95438 .2841 Mdot
.95443 .15006 Mdot
.95448 .32118 Mdot
.95453 .22392 Mdot
.95457 .29132 Mdot
.95462 .29516 Mdot
.95467 .19426 Mdot
.95472 .19655 Mdot
.95476 .25339 Mdot
.95481 .17766 Mdot
.95486 .10343 Mdot
.95491 .0829 Mdot
.95495 .13601 Mdot
.955 .30101 Mdot
.95505 .27722 Mdot
.9551 .21191 Mdot
.95514 .0974 Mdot
.95519 .26544 Mdot
.95524 .25634 Mdot
.95529 .33017 Mdot
.95534 .33264 Mdot
.95538 .23496 Mdot
.95543 .13674 Mdot
.95548 .16533 Mdot
.95553 .12788 Mdot
.95557 .16407 Mdot
.95562 .18941 Mdot
.95567 .31509 Mdot
.95572 .21008 Mdot
.95576 .24225 Mdot
.95581 .36833 Mdot
.95586 .19669 Mdot
.95591 .32952 Mdot
.95595 .1424 Mdot
.956 .34254 Mdot
.95605 .19126 Mdot
.9561 .27081 Mdot
.95614 .21338 Mdot
.95619 .14228 Mdot
.95624 .351 Mdot
.95629 .25003 Mdot
.95634 .31925 Mdot
.95638 .25708 Mdot
.95643 .09695 Mdot
.95648 .2882 Mdot
.95653 .16007 Mdot
.95657 .19596 Mdot
.95662 .30193 Mdot
.95667 .23559 Mdot
.95672 .36598 Mdot
.95676 .0815 Mdot
.95681 .35648 Mdot
.95686 .10013 Mdot
.95691 .19817 Mdot
.95695 .08231 Mdot
.957 .23391 Mdot
.95705 .13942 Mdot
.9571 .12955 Mdot
.95714 .10825 Mdot
.95719 .1161 Mdot
.95724 .23676 Mdot
.95729 .28415 Mdot
.95734 .33378 Mdot
.95738 .13275 Mdot
.95743 .35421 Mdot
.95748 .33222 Mdot
.95753 .149 Mdot
.95757 .10794 Mdot
.95762 .13798 Mdot
.95767 .24395 Mdot
.95772 .31954 Mdot
.95776 .17235 Mdot
.95781 .26856 Mdot
.95786 .24399 Mdot
.95791 .30903 Mdot
.95795 .18156 Mdot
.958 .2391 Mdot
.95805 .11632 Mdot
.9581 .29706 Mdot
.95814 .31269 Mdot
.95819 .1697 Mdot
.95824 .35148 Mdot
.95829 .25851 Mdot
.95834 .26612 Mdot
.95838 .29717 Mdot
.95843 .13655 Mdot
.95848 .28863 Mdot
.95853 .20226 Mdot
.95857 .30656 Mdot
.95862 .16776 Mdot
.95867 .20805 Mdot
.95872 .16257 Mdot
.95876 .23667 Mdot
.95881 .28659 Mdot
.95886 .25114 Mdot
.95891 .35269 Mdot
.95895 .33042 Mdot
.959 .1099 Mdot
.95905 .30411 Mdot
.9591 .23812 Mdot
.95914 .15814 Mdot
.95919 .3551 Mdot
.95924 .07356 Mdot
.95929 .28664 Mdot
.95934 .34949 Mdot
.95938 .06965 Mdot
.95943 .17578 Mdot
.95948 .08624 Mdot
.95953 .11788 Mdot
.95957 .29337 Mdot
.95962 .24725 Mdot
.95967 .24393 Mdot
.95972 .17112 Mdot
.95976 .19039 Mdot
.95981 .10383 Mdot
.95986 .14584 Mdot
.95991 .29363 Mdot
.95995 .26282 Mdot
.96 .21155 Mdot
.96005 .15185 Mdot
.9601 .32176 Mdot
.96014 .21646 Mdot
.96019 .26569 Mdot
.96024 .27183 Mdot
.96029 .2267 Mdot
.96033 .21914 Mdot
.96038 .25491 Mdot
.96043 .34267 Mdot
.96048 .23454 Mdot
.96053 .21181 Mdot
.96057 .1413 Mdot
.96062 .31844 Mdot
.96067 .17851 Mdot
.96072 .275 Mdot
.96076 .25046 Mdot
.96081 .13592 Mdot
.96086 .06865 Mdot
.96091 .14571 Mdot
.96095 .20758 Mdot
.961 .34574 Mdot
.96105 .13053 Mdot
.9611 .23825 Mdot
.96114 .35123 Mdot
.96119 .25408 Mdot
.96124 .16367 Mdot
.96129 .08169 Mdot
.96133 .14529 Mdot
.96138 .33672 Mdot
.96143 .29128 Mdot
.96148 .21671 Mdot
.96153 .24439 Mdot
.96157 .34791 Mdot
.96162 .1156 Mdot
.96167 .06362 Mdot
.96172 .16166 Mdot
.96176 .08788 Mdot
.96181 .29021 Mdot
.96186 .1416 Mdot
.96191 .26403 Mdot
.96195 .30465 Mdot
.962 .27925 Mdot
.96205 .34828 Mdot
.9621 .11385 Mdot
.96214 .31101 Mdot
.96219 .20582 Mdot
.96224 .16698 Mdot
.96229 .11428 Mdot
.96233 .11359 Mdot
.96238 .09867 Mdot
.96243 .14166 Mdot
.96248 .32007 Mdot
.96253 .12782 Mdot
.96257 .15819 Mdot
.96262 .2756 Mdot
.96267 .13133 Mdot
.96272 .13027 Mdot
.96276 .09795 Mdot
.96281 .2672 Mdot
.96286 .3196 Mdot
.96291 .09733 Mdot
.96295 .15739 Mdot
.963 .18026 Mdot
.96305 .11008 Mdot
.9631 .1419 Mdot
.96314 .22722 Mdot
.96319 .18092 Mdot
.96324 .34503 Mdot
.96329 .17955 Mdot
.96333 .07506 Mdot
.96338 .06746 Mdot
.96343 .28414 Mdot
.96348 .1192 Mdot
.96353 .32435 Mdot
.96357 .27362 Mdot
.96362 .31174 Mdot
.96367 .33892 Mdot
.96372 .2187 Mdot
.96376 .05042 Mdot
.96381 .23268 Mdot
.96386 .26077 Mdot
.96391 .17274 Mdot
.96395 .12993 Mdot
.964 .25965 Mdot
.96405 .21502 Mdot
.9641 .06679 Mdot
.96414 .29583 Mdot
.96419 .20073 Mdot
.96424 .12414 Mdot
.96429 .18531 Mdot
.96433 .16567 Mdot
.96438 .20117 Mdot
.96443 .28993 Mdot
.96448 .16059 Mdot
.96452 .14842 Mdot
.96457 .26197 Mdot
.96462 .22068 Mdot
.96467 .1809 Mdot
.96472 .21932 Mdot
.96476 .29462 Mdot
.96481 .22602 Mdot
.96486 .30633 Mdot
.96491 .21804 Mdot
.96495 .11094 Mdot
.965 .30898 Mdot
.96505 .18232 Mdot
.9651 .13671 Mdot
.96514 .19462 Mdot
.96519 .1423 Mdot
.96524 .16374 Mdot
.96529 .18381 Mdot
.96533 .33669 Mdot
.96538 .06597 Mdot
.96543 .32097 Mdot
.96548 .06569 Mdot
.96552 .18294 Mdot
.96557 .11818 Mdot
.96562 .20753 Mdot
.96567 .25916 Mdot
.96572 .26272 Mdot
.96576 .23912 Mdot
.96581 .07327 Mdot
.96586 .08634 Mdot
.96591 .30934 Mdot
.96595 .05935 Mdot
.966 .10792 Mdot
.96605 .20915 Mdot
.9661 .24426 Mdot
.96614 .09097 Mdot
.96619 .26606 Mdot
.96624 .11793 Mdot
.96629 .09499 Mdot
.96633 .28875 Mdot
.96638 .14742 Mdot
.96643 .27395 Mdot
.96648 .098 Mdot
.96652 .2675 Mdot
.96657 .1659 Mdot
.96662 .25273 Mdot
.96667 .25427 Mdot
.96672 .19354 Mdot
.96676 .29732 Mdot
.96681 .3324 Mdot
.96686 .33025 Mdot
.96691 .293 Mdot
.96695 .26764 Mdot
.967 .28953 Mdot
.96705 .06426 Mdot
.9671 .27688 Mdot
.96714 .20283 Mdot
.96719 .12335 Mdot
.96724 .15771 Mdot
.96729 .22864 Mdot
.96733 .27423 Mdot
.96738 .04792 Mdot
.96743 .10508 Mdot
.96748 .27699 Mdot
.96752 .16894 Mdot
.96757 .11083 Mdot
.96762 .04896 Mdot
.96767 .05125 Mdot
.96772 .04468 Mdot
.96776 .19447 Mdot
.96781 .13095 Mdot
.96786 .19385 Mdot
.96791 .08338 Mdot
.96795 .19798 Mdot
.968 .13648 Mdot
.96805 .23651 Mdot
.9681 .15128 Mdot
.96814 .24387 Mdot
.96819 .11268 Mdot
.96824 .29482 Mdot
.96829 .28352 Mdot
.96833 .16061 Mdot
.96838 .28981 Mdot
.96843 .10604 Mdot
.96848 .04904 Mdot
.96852 .15233 Mdot
.96857 .22424 Mdot
.96862 .1633 Mdot
.96867 .21424 Mdot
.96872 .08067 Mdot
.96876 .21433 Mdot
.96881 .15099 Mdot
.96886 .20839 Mdot
.96891 .21976 Mdot
.96895 .12198 Mdot
.969 .29048 Mdot
.96905 .16338 Mdot
.9691 .06003 Mdot
.96914 .31849 Mdot
.96919 .09199 Mdot
.96924 .05001 Mdot
.96929 .14882 Mdot
.96933 .2435 Mdot
.96938 .12961 Mdot
.96943 .09881 Mdot
.96948 .32042 Mdot
.96952 .28579 Mdot
.96957 .06069 Mdot
.96962 .08679 Mdot
.96967 .205 Mdot
.96971 .09835 Mdot
.96976 .22894 Mdot
.96981 .20398 Mdot
.96986 .1608 Mdot
.96991 .21523 Mdot
.96995 .1142 Mdot
.97 .32659 Mdot
.97005 .27193 Mdot
.9701 .12918 Mdot
.97014 .15439 Mdot
.97019 .19892 Mdot
.97024 .24749 Mdot
.97029 .14104 Mdot
.97033 .09778 Mdot
.97038 .18418 Mdot
.97043 .13384 Mdot
.97048 .22746 Mdot
.97052 .29799 Mdot
.97057 .12023 Mdot
.97062 .14303 Mdot
.97067 .27117 Mdot
.97071 .27184 Mdot
.97076 .06787 Mdot
.97081 .26722 Mdot
.97086 .20704 Mdot
.97091 .07702 Mdot
.97095 .19276 Mdot
.971 .14033 Mdot
.97105 .32048 Mdot
.9711 .29138 Mdot
.97114 .19462 Mdot
.97119 .19676 Mdot
.97124 .22469 Mdot
.97129 .17028 Mdot
.97133 .32375 Mdot
.97138 .27721 Mdot
.97143 .11664 Mdot
.97148 .10538 Mdot
.97152 .17235 Mdot
.97157 .17606 Mdot
.97162 .21662 Mdot
.97167 .13472 Mdot
.97171 .08451 Mdot
.97176 .06531 Mdot
.97181 .27249 Mdot
.97186 .18983 Mdot
.97191 .04862 Mdot
.97195 .12483 Mdot
.972 .09724 Mdot
.97205 .1445 Mdot
.9721 .18232 Mdot
.97214 .31085 Mdot
.97219 .10301 Mdot
.97224 .17928 Mdot
.97229 .31375 Mdot
.97233 .1452 Mdot
.97238 .20418 Mdot
.97243 .03991 Mdot
.97248 .31567 Mdot
.97252 .19356 Mdot
.97257 .11816 Mdot
.97262 .25992 Mdot
.97267 .17376 Mdot
.97271 .04785 Mdot
.97276 .22664 Mdot
.97281 .15535 Mdot
.97286 .11931 Mdot
.97291 .30736 Mdot
.97295 .27888 Mdot
.973 .29015 Mdot
.97305 .10037 Mdot
.9731 .21212 Mdot
.97314 .21114 Mdot
.97319 .17506 Mdot
.97324 .24222 Mdot
.97329 .22535 Mdot
.97333 .13726 Mdot
.97338 .31968 Mdot
.97343 .25228 Mdot
.97348 .10901 Mdot
.97352 .25671 Mdot
.97357 .30845 Mdot
.97362 .26006 Mdot
.97367 .2388 Mdot
.97371 .16695 Mdot
.97376 .07686 Mdot
.97381 .11453 Mdot
.97386 .2191 Mdot
.9739 .26322 Mdot
.97395 .24433 Mdot
.974 .31796 Mdot
.97405 .23439 Mdot
.9741 .30691 Mdot
.97414 .27665 Mdot
.97419 .24513 Mdot
.97424 .04971 Mdot
.97429 .12312 Mdot
.97433 .12887 Mdot
.97438 .03009 Mdot
.97443 .14633 Mdot
.97448 .30773 Mdot
.97452 .13097 Mdot
.97457 .09951 Mdot
.97462 .06408 Mdot
.97467 .07771 Mdot
.97471 .14397 Mdot
.97476 .16082 Mdot
.97481 .14657 Mdot
.97486 .23195 Mdot
.9749 .09337 Mdot
.97495 .07247 Mdot
.975 .24842 Mdot
.97505 .2896 Mdot
.9751 .16983 Mdot
.97514 .07522 Mdot
.97519 .03981 Mdot
.97524 .30325 Mdot
.97529 .21364 Mdot
.97533 .15048 Mdot
.97538 .3104 Mdot
.97543 .20549 Mdot
.97548 .11007 Mdot
.97552 .1456 Mdot
.97557 .1892 Mdot
.97562 .21767 Mdot
.97567 .29893 Mdot
.97571 .07098 Mdot
.97576 .14994 Mdot
.97581 .1647 Mdot
.97586 .17962 Mdot
.9759 .2296 Mdot
.97595 .02788 Mdot
.976 .25204 Mdot
.97605 .1106 Mdot
.9761 .18141 Mdot
.97614 .09851 Mdot
.97619 .28141 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX005Cooo]Z1?l0003ooookJ^Wooo]Z000LoookJP03omgIK?oonf[ooo]Z00Go
oo]Z00?ogMU/oookJ_oonfX0;OoonfX4o`000?oooo]ZjOoonfX001;ooo]Z0ol007l6oookJP03omgI
K?l007ooEE=g00Gooo]Z00?oEE=go`00Ooo<b6h01ooonfX3o`00O`Gooo]Z1Ol007lJoookJPCo0000
oooonf[YoookJP004_oonfX3o`00O`Oooo]Z00?oEE=go`00OomEDgL00ooonfX01?mEDgOo001oob4Q
O?o^jV/7oookJP?o001o1?oonfX7o`00OaWooo]Z1?l0003ooookJ^Wooo]Z000BoookJP?o001o2?oo
nfX02?mEDgOo001ooeECMooonf[oEE=go`00OolQ8Gcok^Y[2?oonfX3o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007lIoookJPCo0000oooonf[YoookJP000ooonfX:o`00O`Gooo]Z0ol007l9oook
JP06oeECMol007oo411mo`00OolQ8Gcok^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oo
nfX4o`000?oooo]ZjOoonfX000?ooo]Z2_l007l5oookJP?o001o2_oonfX01?l@47go001oo`00OooM
fF`:oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lHoookJPCo0000oooonf[YoookJP004_oonfX3
o`00O`Wooo]Z00KoEE=go`00Ool@47go001oob4QO?o^jV/9oookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007lHoookJPCo0000oooonf[YoookJP004_oonfX3o`00O`Sooo]Z00SoEE=go`00OomEDgOooo]Z
oeECMol007oo8B5lonkZJ`Sooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z1_l0000`oook
JP?o0000oooonfXcoookJPCo0000OOoonfX001;ooo]Z0ol007l7oookJP03oeECMol007ooEE=g00?o
oo]Z00CoEE=go`00OolQ8Gcok^Y[1ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfX4o`00
02oooo]Z1_l0001PoookJP?o000000?ooo]Zo`000?l000000_l00038oookJPWo0000N_oonfX001;o
oo]Z0ol007l6oookJP03omgIK?l007ooEE=g00Gooo]Z00?oEE=go`00Ooo<b6h01ooonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o6?oonfX4o`0002oooo]Z1_l0001PoookJP?o000000?ooo]Zo`000?l0
00000ol0001QoookJPCo0000H_oonfX9o`0007[ooo]Z000?oookJPKo001o1ooonfX00ooMfFcooo]Z
oookJP05oookJP03omgIK?oonf[ooo]Z00?ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`_ooo]Z
00CoV9Ibo`00Ool007ooIVAf2OoonfX4o`0002oooo]Z1ol0001OoookJP[o0000H?oonfX4o`00063o
oo]Z2ol0001joookJP003ooonfX6o`00OaGooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool007oo
001o2ooonfX00ooMfFco001oo`00O`02o`00O`03ogMeMOoonf[ooo]Z00Kooo]Z1?l0000]oookJP_o
0000G?oonfX5o`000003oookJ_l0003o000000?o0000G?oonfX;o`0005gooo]Z3?l0001ioookJP00
4OoonfX4o`00OaOooo]Z1?l007l4oookJPOo001o2ooonfX01_mEDgOo001ookZhKonj^6oo001ooa0@
O@Sooo]Z1?l0000/oookJPco0000G?oonfX;o`0005cooo]Z1Ol000000ooonf[o0000o`000003o`00
05gooo]Z3ol0001foookJP004_oonfX3o`00OaSooo]Z0ol007l5oookJPGo001o1?oonfX7o`00O`03
oookJ_l@47go001o00;ooo]Z0_l007l8oookJPCo0000:_oonfX>o`0005_ooo]Z2ol0001LoookJPco
0000G?oonfX@o`0005Sooo]Z0ol0000KoookJP00A_oonfX2o`00O`;o^[Q_0_l007l8oookJPCo0000
:_oonfX>o`0005[ooo]Z4?l0001HoookJP?o000000?ooo]Zo`000?l000001_l0001LoookJQ3o0000
EooonfX4o`0001_ooo]Z0016oookJPGo001o00?oEE=goookJ_oonfX01_oonfX4o`0002[ooo]Z4Ol0
001GoookJQ3o0000E_oonfX9o`0000;ooo]Z1ol0001HoookJQ3o0000EooonfX4o`0001_ooo]Z0016
oookJP06oa0@OOl007ooEE=go`00Oolb<W[ok^Y[2?oonfX4o`0002[ooo]Z4Ol0001GoookJQ3o0000
E_oonfX9o`0000;ooo]Z1ol0001IoookJPoo0000EooonfX3o`0001cooo]Z0016oookJP04oeECMol0
07ooQhEcolc8KP;oMgEe2?oonfX4o`0002[ooo]Z1_l00004oookJPSo0000E?oonfXCo`0005Cooo]Z
5?l0001GoookJQ3o0000M_oonfX004Kooo]Z00?oc<Q^o`00Ool007l00_l007l00omEDgOooo]Zoook
JP06oookJPCo0000:_oonfX6o`0000Cooo]Z2?l0001DoookJQGo0000D_oonfXDo`0005Gooo]Z4_l0
001foookJP00AooonfX01OnYYg7o411mo`00OomEDgOok^Y[00Sooo]Z1?l0000ZoookJPKo00000ooo
nfX9o`0005Cooo]Z5Ol0001BoookJPOo000000?ooo]Zo`000?l000002_l0001CoookJQCo0000E_oo
nfX5o`0001_ooo]Z001DoookJPCo0000:?oonfX8o`0000?ooo]Z2_l0001AoookJQOo0000D_oonfX6
o`000003oookJ_l0003o000000_o0000DooonfX@o`0000;ooo]Z0ol0001EoookJPGo00006ooonfX0
05Cooo]Z1Ol0000WoookJQKo0000D?oonfX5o`000004oookJ_l0003o0000o`0000;ooo]Z3?l0001B
oookJPKo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000006o`00057ooo]Z1Ol00000
1Ooonf[o0000o`000?l0003ooo]Z00_o0000EOoonfX5o`0001_ooo]Z001DoookJPCo00009ooonfXG
o`00053ooo]Z1Ol000000ooonf[o0000o`00000?o`0005;ooo]Z3ol00003oookJPGo0000CooonfXI
o`00053ooo]Z0ol0000OoookJP00E?oonfX4o`0002Oooo]Z5ol0001?oookJPKo000000?ooo]Zo`00
0?l000003ol0001AoookJQ3o00000ooonfX5o`0004oooo]Z6Ol0001@oookJPGo00007OoonfX005Co
oo]Z1?l0000VoookJQKo0000DOoonfX6o`000003oookJ_l0003o0000013o0000D?oonfX3o`000003
oookJ_l0003o000000_o00000_oonfX5o`0004oooo]Z6_l0001=oookJPSo00007?oonfX005Cooo]Z
1?l0000VoookJQWo0000C_oonfX6o`000003oookJ_l0003o0000017o0000C_oonfXBo`0000?ooo]Z
1?l0001@oookJPoo00000_oonfX8o`0004gooo]Z2?l0000LoookJP00E?oonfX4o`0002Gooo]Z2?l0
00000ooonf[o0000o`00000?o`0004gooo]Z6ol0001=oookJQ?o00000_oonfX5o`0004oooo]Z2_l0
00000ooonf[o0000o`000003o`0000;ooo]Z2?l0001=oookJPSo00007?oonfX005Cooo]Z1?l0000U
oookJPOo000000?ooo]Zo`000?l000004?l0001=oookJQ_o0000COoonfX=o`0000;ooo]Z2_l0001?
oookJPco000000?ooo]Zo`000?l000003?l0001?oookJP?o00007ooonfX005Cooo]Z1?l0000Uoook
JPOo000000?ooo]Zo`000?l000003?l000001?oonf[o0000o`000?l0001=oookJQco0000C?oonfX>
o`000003oookJ_l0003o000000Oo0000D?oonfXLo`00073ooo]Z001DoookJPCo00009?oonfX3o`00
0003oookJ_l0003o000000;o000000?ooo]Zo`000?l000004Ol0001<oookJQco0000BooonfXHo`00
057ooo]Z5Ol000000ooonf[o0000o`000004o`0004gooo]Z1Ol0000NoookJP00E?oonfX4o`0002Co
oo]Z7?l0001<oookJQco0000BooonfX5o`0000;ooo]Z4_l0001@oookJQGo000000?ooo]Zo`000?l0
00001?l0001=oookJPGo00007_oonfX005Cooo]Z1?l0000SoookJPGo000000?ooo]Zo`000?l00000
5_l0001;oookJPCo000000?ooo]Zo`000?l000005Ol0001:oookJPSo00000_oonfXCo`0004_ooo]Z
5ol000000ooonf[o0000o`000004o`0004_ooo]Z2Ol0000LoookJP00E?oonfX4o`0002?ooo]Z7_l0
001:oookJPGo00000_oonfXFo`0004[ooo]Z7Ol0001;oookJP?o00000_oonfXAo`000003oookJ_l0
003o000000Ko0000B_oonfX9o`0001cooo]Z001DoookJPCo00008ooonfXNo`0004Wooo]Z3?l00000
0ooonf[o0000o`000002o`0000;ooo]Z2Ol0001<oookJQoo0000BOoonfX<o`000003oookJ_l0003o
000000Oo000000?ooo]Zo`000?l000001_l0001:oookJPWo00007?oonfX005Cooo]Z1?l0000Roook
JQoo0000BOoonfX<o`000003oookJ_l0003o000000?o000000?ooo]Zo`000?l000000_l000000ooo
nf[o0000o`000003o`0004_ooo]Z5Ol000001Ooonf[o0000o`000?l0003ooo]Z00Go0000BOoonfX<
o`000003oookJ_l0003o0000013o0000BOoonfX;o`0001_ooo]Z001DoookJPCo00008_oonfXGo`00
0003oookJ_l0003o000000Oo0000AooonfX<o`000003oookJ_l0003o000000?o000000?ooo]Zo`00
0?l000002ol00017oookJP_o000000?ooo]Zo`000?l000002?l000001?oonf[o0000o`000?l00002
oookJPCo0000B_oonfX@o`000003oookJ_l0003o000000_o0000BOoonfX;o`0001_ooo]Z001Doook
JPGo00008OoonfXJo`0000;ooo]Z1Ol00017oookJQ;o000000?ooo]Zo`000?l000002ol00017oook
JPSo000000?ooo]Zo`000?l000005Ol00018oookJPKo000000Cooo]Zo`000?l0003o00000_oonfXD
o`0004Wooo]Z1_l00002oookJP?o00006ooonfX005Cooo]Z1?l0000RoookJQ;o000000?ooo]Zo`00
0?l000003?l00017oookJQco000000Cooo]Zo`000?l0003o0000AooonfX3o`0000;ooo]Z1ol00002
oookJQ7o0000BOoonfX6o`000005oookJ_l0003o0000o`000?oonfX05?l0001:oookJP_o00006ooo
nfX005Cooo]Z1?l0000RoookJR7o0000AooonfXMo`0004[ooo]Z3?l000000ooonf[o0000o`00000A
o`0004Sooo]Z6?l000000ooonf[o0000o`000004o`0004[ooo]Z1Ol000000ooonf[o0000o`000003
o`0001_ooo]Z001DoookJPCo00008?oonfXHo`0000;ooo]Z2Ol00018oookJP[o000000?ooo]Zo`00
0?l000004_l00017oookJPco000000?ooo]Zo`000?l000004_l00017oookJQSo000000?ooo]Zo`00
0?l000001_l00017oookJP_o00007?oonfX005Cooo]Z1?l0000PoookJQWo000000?ooo]Zo`000?l0
00001ol00018oookJP[o000000?ooo]Zo`000?l000004ol00015oookJQ7o000000?ooo]Zo`000?l0
00003ol00018oookJQKo000000?ooo]Zo`000?l000001_l00016oookJPco00007?oonfX005Cooo]Z
1?l0000PoookJQgo000000?ooo]Zo`000?l000000ol00018oookJQSo000000?ooo]Zo`000?l00000
1Ol00015oookJQgo00000_oonfX4o`0004Gooo]Z6Ol000000ooonf[o0000o`000008o`0004Cooo]Z
2ol0000MoookJP00E?oonfX4o`00023ooo]Z3?l000000ooonf[o0000o`00000Eo`0004Oooo]Z8Ol0
0013oookJRCo0000A?oonfX8o`000003oookJ_l0003o0000017o000000?ooo]Zo`000?l000001_l0
0014oookJP_o00007OoonfX005Cooo]Z1?l0000QoookJR?o0000A?oonfXTo`0004?ooo]Z9_l00012
oookJPOo00000_oonfXLo`0004?ooo]Z3?l0000MoookJP00E?oonfX4o`00027ooo]Z1_l000000ooo
nf[o0000o`00000Jo`0004Cooo]Z4?l000000ooonf[o0000o`00000Ao`0004?ooo]Z6ol00002oook
JPWo0000@_oonfX7o`0000;ooo]Z7?l00013oookJP_o00007_oonfX005Cooo]Z1?l0000QoookJPKo
000000?ooo]Zo`000?l000006Ol00015oookJRCo0000AOoonfXDo`000003oookJ_l0003o000000;o
00000_oonfX5o`000004oookJ_l0003o0000o`0004;ooo]Z1ol000000ooonf[o0000o`00000Jo`00
04Cooo]Z0ol00003oookJPOo00007?oonfX005Cooo]Z1?l0000QoookJRGo0000@OoonfX3o`000004
oookJ_l0003o0000o`0000;ooo]Z5?l00002oookJPKo0000@ooonfXMo`0000;ooo]Z1?l00014oook
JQko00000ooonfX5o`0004?ooo]Z0ol00003oookJPOo00007?oonfX005Cooo]Z1?l0000PoookJRKo
0000@OoonfXNo`000004oookJ_l0003o0000o`0004Gooo]Z7_l00002oookJPGo0000@ooonfXFo`00
0003oookJ_l0003o000000;o00001OoonfX7o`0004;ooo]Z3Ol0000LoookJP00E?oonfX4o`0001oo
oo]Z4_l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000Wo0000@OoonfX<o`000003
oookJ_l0003o000001Ko0000@_oonfXNo`0000?ooo]Z1?l00013oookJQko00000_oonfX7o`0004;o
oo]Z3_l0000KoookJP00E?oonfX4o`0001oooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00?o
00000ooonfXGo`0004;ooo]Z3_l000000ooonf[o0000o`00000Eo`00047ooo]Z2?l000000ooonf[o
0000o`00000Co`0000?ooo]Z1ol00011oookJQgo00000_oonfX3o`000004oookJ_l0003o0000o`00
047ooo]Z3ol0000KoookJP00E?oonfX5o`0001kooo]Z1?l00003oookJPOo00000_oonfX>o`0000;o
oo]Z1_l00012oookJRKo0000@OoonfX9o`000003oookJ_l0003o000001;o00000ooonfX7o`0004?o
oo]Z6ol000000ooonf[o0000o`000006o`00043ooo]Z2Ol000000ooonf[o0000o`000004o`0001_o
oo]Z001DoookJPCo00007_oonfX5o`0000?ooo]Z6?l000000ooonf[o0000o`000004o`0004;ooo]Z
9_l00010oookJPco000000?ooo]Zo`000?l000004?l00002oookJPSo0000@_oonfXGo`000004oook
J_l0003o0000o`0000;ooo]Z2Ol0000ooookJPSo000000?ooo]Zo`000?l000001?l0000LoookJP00
E?oonfX4o`0001kooo]Z1Ol00003oookJQoo0000@OoonfXUo`0004;ooo]Z3?l000000ooonf[o0000
o`00000Ao`000003oookJ_l0003o000000Ko0000?_oonfX3o`000003oookJ_l0003o000000_o0000
00?ooo]Zo`000?l000000ol00002oookJQ7o0000?ooonfX>o`0001gooo]Z001DoookJPCo00007Ooo
nfX7o`000003oookJ_l0003o000001Wo000000?ooo]Zo`000?l000001?l0000noookJPCo00000ooo
nfXFo`0004_ooo]Z3?l00002oookJP[o000000?ooo]Zo`000?l000001Ol000000ooonf[o0000o`00
0006o`0003kooo]Z3ol00003oookJQ3o000000?ooo]Zo`000?l000001Ol0000ooookJQ3o00006ooo
nfX005Cooo]Z1?l0000MoookJP?o000000Gooo]Zo`000?l0003o0000oookJP0Ko`000003oookJ_l0
003o000000Co0000?_oonfXPo`0000Oooo]Z0ol00011oookJP?o000000Cooo]Zo`000?l0003o0000
0_oonfXDo`0000Cooo]Z1Ol0000noookJPoo00000ooonfX3o`000003oookJ_l0003o000001?o0000
?_oonfX@o`0001_ooo]Z001DoookJPCo00007OoonfXZo`0003kooo]Z2ol00002oookJQ?o00001?oo
nfX6o`0003oooo]Z8Ol00002oookJPGo0000?_oonfX6o`000003oookJ_l0003o000000Ko00000ooo
nfX3o`000003oookJ_l0003o000001?o0000?_oonfX@o`0001_ooo]Z001DoookJPCo00007OoonfXZ
o`0003gooo]Z5ol000000ooonf[o0000o`00000Ao`0003kooo]Z8_l00002oookJPGo0000?_oonfX?
o`0000?ooo]Z6Ol0000moookJQ3o00007?oonfX005Cooo]Z1?l0000MoookJR[o0000?OoonfXGo`00
0003oookJ_l0003o000000Go000000?ooo]Zo`000?l000001ol00010oookJQGo00000_oonfXBo`00
043ooo]Z6Ol000000ooonf[o0000o`00000<o`0003kooo]Z4?l0000LoookJP00E?oonfX4o`0001_o
oo]Z1?l000000ooonf[o0000o`00000Uo`0003gooo]Z5ol000000ooonf[o0000o`000005o`000003
oookJ_l0003o000000[o0000?OoonfXZo`0003cooo]Z9?l000000ooonf[o0000o`000003o`0003ko
oo]Z4?l0000MoookJP00E?oonfX4o`0001_ooo]Z8?l000001Ooonf[o0000o`000?l0003ooo]Z00Ko
0000?ooonfXGo`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000001_l0000moookJQCo
000000?ooo]Zo`000?l000001_l000000ooonf[o0000o`00000:o`0003cooo]Z;Ol0000koookJQ3o
00007OoonfX005Cooo]Z1?l0000KoookJRko0000>_oonfXSo`000003oookJ_l0003o000000?o0000
00Cooo]Zo`000?l0003o0000?OoonfXMo`000003oookJ_l0003o000000[o0000??oonfX]o`0003[o
oo]Z2?l00002oookJPSo00007?oonfX005Cooo]Z1?l0000NoookJR_o0000>_oonfX>o`000003oook
J_l0003o000000Co000000?ooo]Zo`000?l000002ol000001Ooonf[o0000o`000?l0003ooo]Z00Go
0000>ooonfXHo`0000?ooo]Z3ol0000ooookJQ3o000000?ooo]Zo`000?l000006Ol0000joookJPSo
00000_oonfX8o`0001cooo]Z001DoookJPCo00007_oonfX>o`000003oookJ_l0003o000001[o0000
>_oonfX>o`000003oookJ_l0003o000000?o00000_oonfXGo`0003_ooo]Z1?l000000ooonf[o0000
o`00000So`0003oooo]Z3?l000000ooonf[o0000o`00000No`0003Wooo]Z4_l0000LoookJP00E?oo
nfX4o`0001gooo]Z:ol0000koookJQGo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00
000?o`0003_ooo]Z8ol00004oookJPKo0000?OoonfX]o`0003Wooo]Z4_l0000LoookJP00E?oonfX5
o`0001Wooo]Z;ol0000ioookJQKo000000?ooo]Zo`000?l000005_l0000ioookJRCo00001?oonfX5
o`0003[ooo]Z1_l000000ooonf[o0000o`00000Co`000003oookJ_l0003o000000?o000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`000003o`0003[ooo]Z4Ol0000LoookJP00E?oonfX4o`00
01[ooo]Z6_l00002oookJPSo000000?ooo]Zo`000?l000002?l0000ioookJQoo000000?ooo]Zo`00
0?l000003_l0000goookJPco00000_oonfX?o`000003oookJ_l0003o000000Go00000ooonfX9o`00
03Oooo]Z5?l00002oookJPKo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000<o`00
03Wooo]Z4Ol0000LoookJP00E?oonfX4o`0001[ooo]Z4?l00002oookJPSo00000_oonfXDo`0003So
oo]Z:?l000000ooonf[o0000o`000005o`0003Oooo]Z9ol000000ooonf[o0000o`000007o`0003Oo
oo]Z7?l000000ooonf[o0000o`000003o`000003oookJ_l0003o000000co0000=ooonfXCo`0001co
oo]Z001DoookJPCo00006_oonfXJo`0000Gooo]Z4Ol0000ioookJRoo0000=ooonfX:o`000003oook
J_l0003o000001[o000000?ooo]Zo`000?l000001ol0000joookJQoo000000?ooo]Zo`000?l00000
1ol000000ooonf[o0000o`000002o`0003Oooo]Z4ol0000LoookJP00E?oonfX4o`0001[ooo]Z1_l0
00000ooonf[o0000o`00000>o`0000Gooo]Z5?l0000hoookJQGo00001?oonfXGo`0003Sooo]Z;ol0
000joookJQGo000000?ooo]Zo`000?l000004_l000001?oonf[o0000o`000?l0000hoookJQ?o0000
7?oonfX005Cooo]Z1?l0000JoookJQSo000000?ooo]Zo`000?l000005Ol0000goookJPSo00000_oo
nfX9o`0000;ooo]Z7?l0000goookJPgo000000?ooo]Zo`000?l000006?l00002oookJPKo0000>?oo
nfX:o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000005ol0000goookJQ?o00007Ooo
nfX005Cooo]Z1?l0000JoookJRGo000000?ooo]Zo`000?l000001ol0000hoookJPWo000000?ooo]Z
o`000?l000001ol00002oookJQgo0000=_oonfXbo`0003Kooo]Z2_l000001Ooonf[o0000o`000?l0
003ooo]Z00Go00000ooonfXJo`0003Kooo]Z0ol00002oookJQ3o00006ooonfX005Cooo]Z1?l0000J
oookJS3o0000=ooonfX9o`0000Cooo]Z1Ol000000ooonf[o0000o`000008o`000003oookJ_l0003o
000001;o0000=_oonfX:o`000005oookJ_l0003o0000o`000?oonfX08ol0000eoookJPko00000_oo
nfX;o`000003oookJ_l0003o000001Co0000=_oonfX3o`000005oookJ_l0003o0000o`000?oonfX0
3Ol0000KoookJP007?oonfX00ooMfFcooo]ZoookJP05oookJP03omgIK?oonf[ooo]Z02gooo]Z1?l0
000KoookJP[o00000_oonfXTo`0003Wooo]Z1_l00004oookJQoo000000?ooo]Zo`000?l000001?l0
000eoookJPCo00000_oonfX4o`000005oookJ_l0003o0000o`000?oonfX08ol0000eoookJP[o0000
00?ooo]Zo`000?l000009Ol0000foookJP?o000000Cooo]Zo`000?l0003o00000_oonfX<o`0001_o
oo]Z000@oookJPGo001o1_oonfX00ooMfFco001ooeECM`05oookJP03oeECMol007ooc<Q^00Oooo]Z
0ol007l5oookJPGo001o6_oonfX4o`0001Sooo]Z=?l0000hoookJQKo000000?ooo]Zo`000?l00000
5ol0000eoookJPWo000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`00000Po`0003Kooo]Z
2_l000000ooonf[o0000o`00000Oo`0000;ooo]Z1Ol0000goookJPGo000000?ooo]Zo`000?l00000
2ol0000KoookJP003ooonfX7o`00O`Kooo]Z00?oEE=go`00OomEDgL00ooonfX01?mEDgOo001oob4Q
O?o^jV/7oookJP?o001o1?oonfX7o`00OaWooo]Z1?l0000HoookJQco000000?ooo]Zo`000?l00000
5Ol0000eoookJP?o000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000Go`0000?ooo]Z
2Ol0000doookJPoo000000?ooo]Zo`000?l000007ol0000goookJR;o000000?ooo]Zo`000?l00000
2Ol000000ooonf[o0000o`000002o`0003Oooo]Z4ol0000KoookJP003_oonfX4o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z00SoEE=go`00OomEDgOooo]ZoeECMol007oo8B5lonkZJ`Sooo]Z0ol007l4
oookJP?o001o00Cooo]Zo`00Ool007oo001o6OoonfX4o`0001Sooo]Z6?l000000ooonf[o0000o`00
0003o`000003oookJ_l0003o000001?o0000=OoonfX4o`000003oookJ_l0003o000001oo00000ooo
nfX:o`0003Cooo]Z4Ol000000ooonf[o0000o`00000Lo`0003Oooo]Z5_l00002oookJPOo000000?o
oo]Zo`000?l000004_l0000goookJP_o000000?ooo]Zo`000?l000001Ol0000KoookJP000ooonfX:
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJP06oeECMol007oo411mo`00OolQ8Gco
k^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfX4o`0001Sooo]Z6_l000000ooonf[o
0000o`000002o`000003oookJ_l0003o000001;o0000=?oonfXdo`0003Cooo]Z;ol00002oookJP?o
0000<ooonfXOo`000003oookJ_l0003o000001?o0000=OoonfX8o`0000?ooo]Z1ol0000MoookJP00
0ooonfX:o`00O`Oooo]Z0ol007l8oookJP04oa0@OOl007oo001oomgIK0[ooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00OaSooo]Z1?l0000KoookJQOo000000?ooo]Zo`000?l000006?l0000coookJQoo
00000_oonfXCo`0003Cooo]Z:_l000000ooonf[o0000o`000007o`0003?ooo]Z3?l00002oookJQ7o
000000?ooo]Zo`000?l000005?l0000boookJQCo00007OoonfX001Cooo]Z0ol007l7oookJP06oeEC
Mol007oo411mo`00OolQ8Gcok^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfX4o`00
01Wooo]Z5?l00002oookJQko0000<ooonfX>o`000003oookJ_l0003o000000ko00000_oonfXDo`00
03?ooo]Z:_l000000ooonf[o0000o`000007o`0003Cooo]Z3?l00003oookJPWo00000_oonfXKo`00
03;ooo]Z5Ol0000LoookJP003ooonfX2o`00O`;ooo]Z1?l007l6oookJP08oeECMol007ooEE=goook
J_mEDgOo001oob4QO?o^jV/8oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lHoookJPKo00005ooo
nfX`o`000004oookJ_l0003o0000o`00037ooo]Z0ol000000ooonf[o0000o`00000:o`000003oook
J_l0003o000002Co0000<ooonfX[o`0000;ooo]Z1ol0000doookJPco000000?ooo]Zo`000?l00000
1Ol000000ooonf[o0000o`00000Co`000003oookJ_l0003o000000So0000<OoonfXFo`0001cooo]Z
000?oookJPOo001o1_oonfX00omEDgOo001ooeECM`03oookJP04oeECMol007oo8B5lonkZJ`Oooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z1?l0000IoookJR_o000000?ooo]Zo`000?l00000
1_l0000aoookJSOo0000<OoonfXTo`000003oookJ_l0003o000000Ko00000_oonfX7o`0003Cooo]Z
5?l000000ooonf[o0000o`000009o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l00000
1_l0000coookJQOo00006ooonfX000oooo]Z1_l007l6oookJP03omgIK?l007ooEE=g00Gooo]Z00?o
EE=go`00Ooo<b6h01ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2ooonfX2o`00O`_ooo]Z1?l0
000JoookJPWo000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`00000Io`00037ooo]Z6Ol0
00000ooonf[o0000o`00000Ko`00037ooo]Z:Ol000001?oonf[o0000o`000?l00002oookJPOo0000
<_oonfXHo`0000;ooo]Z4Ol000000ooonf[o0000o`000008o`00037ooo]Z6?l0000KoookJP003ooo
nfX2o`00O`_ooo]Z00?ogMU/oookJ_oonfX01OoonfX00ooMfFcooo]ZoookJP03oookJPKo001o0ooo
nfX3o`00O`?ooo]Z0ol007l;oookJP03ob4QO?l007ooc<Q^00[ooo]Z1?l0000GoookJPoo000000?o
oo]Zo`000?l000009?l0000boookJQSo000000?ooo]Zo`000?l000006ol0000aoookJQGo00000ooo
nfX4o`000003oookJ_l0003o000001Wo0000<?oonfXIo`000003oookJ_l0003o000000[o00000_oo
nfX?o`00033ooo]Z6?l0000KoookJP003ooonfX2o`00OaWooo]Z1_l007l4oookJP?o001o00Cooo]Z
o`00Ool007oo001o3?oonfX00omEDgOo001ooiRFLP0:oookJPCo00005_oonfX:o`000003oookJ_l0
003o000000?o00001?oonfX>o`000003oookJ_l0003o0000013o0000<ooonfXho`00033ooo]Z3?l0
00001Ooonf[o0000o`000?l0003ooo]Z00Co000000?ooo]Zo`000?l000008?l0000`oookJPWo0000
00?ooo]Zo`000?l000006?l00004oookJQ3o0000;ooonfXHo`0001_ooo]Z000@oookJPOo001o5Ooo
nfX4o`00O`Cooo]Z1ol007l3oookJPOo001o0_oonfX00onYYg7o001ooeECM`0:oookJPCo00005_oo
nfX:o`000003oookJ_l0003o000002So000000Cooo]Zo`000?l0003o0000;ooonfXJo`0000;ooo]Z
2_l000001Ooonf[o0000o`000?l0003ooo]Z00Oo000000?ooo]Zo`000?l000000ol0000`oookJQ3o
00000_oonfX3o`000003oookJ_l0003o0000023o0000<?oonfX9o`000003oookJ_l0003o000000So
00000_oonfX?o`0000;ooo]Z4Ol0000_oookJQSo00006ooonfX0013ooo]Z1ol007lFoookJP?o001o
1OoonfX5o`00O`kooo]Z00?o411mo`00OooonfX02OoonfX4o`0001Kooo]Z2Ol00004oookJPoo0000
00?ooo]Zo`000?l000004_l000000ooonf[o0000o`000005o`0002oooo]Z8ol00004oookJP?o0000
00?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000003o`00033ooo]Z3_l000001?oonf[o0000
o`000?l00002oookJPKo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`00000Do`0003?o
oo]Z1ol000000ooonf[o0000o`00000Io`0000;ooo]Z3Ol000001?oonf[o0000o`000?l0000_oook
JQ;o000000?ooo]Zo`000?l000000_l0000LoookJP00B?oonfX00onHUW;o001ooiRFLP09oookJPCo
00005_oonfX8o`000003oookJ_l0003o000001Co00000_oonfX?o`0000;ooo]Z1ol0000_oookJPGo
000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00000Yo`0002oooo]Z3ol000000ooonf[o
0000o`000009o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000003?l000000ooonf[o
0000o`000003o`00037ooo]Z1ol00003oookJRco0000<?oonfXAo`000003oookJ_l0003o000000;o
00007?oonfX004Wooo]Z00?o8B5loa0@OOoonfX02?oonfX4o`0001Kooo]Z1ol00002oookJROo0000
0_oonfX7o`0002kooo]Z3?l000000ooonf[o0000o`00000Po`000003oookJ_l0003o000000Oo0000
;ooonfXjo`0002kooo]Z2_l00002oookJQCo00001OoonfXDo`00033ooo]Z4Ol000000ooonf[o0000
o`000003o`0001_ooo]Z0019oookJP03olc8K_l007ooMgEe00Sooo]Z1?l0000EoookJQ3o00000_oo
nfXXo`0002kooo]Z;Ol00003oookJPWo0000;ooonfX5o`000003oookJ_l0003o000001oo000000?o
oo]Zo`000?l000004?l0000^oookJP[o00000_oonfXDo`0000?ooo]Z5_l0000^oookJQWo00006ooo
nfX004Kooo]Z1_l007l8oookJPCo00005OoonfX=o`0000Gooo]Z8Ol00002oookJPGo0000;_oonfXD
o`000003oookJ_l0003o000001Ko00000_oonfX:o`00033ooo]Z1?l00002oookJQco000000Gooo]Z
o`000?l0003o0000oookJP0@o`00033ooo]Z2Ol000000ooonf[o0000o`00000@o`000005oookJ_l0
003o0000o`000?oonfX01Ol000000ooonf[o0000o`00000Ao`0002gooo]Z3?l000000ooonf[o0000
o`00000:o`0001_ooo]Z0016oookJPKo001o2?oonfX4o`0001Gooo]Z0ol000000ooonf[o0000o`00
0009o`0000;ooo]Z1_l000000ooonf[o0000o`00000Jo`0003?ooo]Z2?l000000ooonf[o0000o`00
000`o`0002gooo]Z1ol000000ooonf[o0000o`00000Bo`000003oookJ_l0003o000000Go000000Go
oo]Zo`000?l0003o0000oookJP0Co`0002kooo]Z1ol00002oookJQ;o000000?ooo]Zo`000?l00000
6ol0000]oookJQWo00006ooonfX005Cooo]Z1?l0000IoookJPOo000000?ooo]Zo`000?l000008Ol0
00000ooonf[o0000o`000006o`0002oooo]Z2ol00002oookJQSo000000?ooo]Zo`000?l000004ol0
000/oookJRSo000000?ooo]Zo`000?l000004_l0000]oookJPSo000000?ooo]Zo`000?l000005?l0
00000ooonf[o0000o`00000Ho`0002gooo]Z1Ol00002oookJPOo00000_oonfX6o`0001kooo]Z001D
oookJPCo00004ooonfX3o`0000;ooo]Z2?l000000ooonf[o0000o`00000Zo`0002oooo]Z2ol00002
oookJQSo000000?ooo]Zo`000?l000004ol0000/oookJQWo000000?ooo]Zo`000?l000003?l00000
0ooonf[o0000o`00000Bo`0002cooo]Z3_l000000ooonf[o0000o`00000Ro`000003oookJ_l0003o
000000Go0000;OoonfX5o`0000;ooo]Z3?l000000ooonf[o0000o`000003o`0001_ooo]Z001Doook
JPGo00004_oonfXjo`0002oooo]Z;?l000000ooonf[o0000o`000009o`000004oookJ_l0003o0000
o`0002_ooo]Z6Ol00002oookJPKo00001?oonfXHo`0002_ooo]Z=?l000000ooonf[o0000o`000005
o`0002cooo]Z1_l00003oookJPWo00000ooonfX5o`0001_ooo]Z001DoookJPCo00004ooonfXjo`00
0004oookJ_l0003o0000o`0002_ooo]Z2_l000000ooonf[o0000o`00000Oo`0000?ooo]Z3_l0000Z
oookJQ_o000000?ooo]Zo`000?l000000ol00004oookJQSo0000:ooonfXIo`000003oookJ_l0003o
0000023o0000;?oonfX8o`0000?ooo]Z3ol0000KoookJP00E?oonfX4o`0001Cooo]Z2?l00002oook
JPSo000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`00000=o`000003oookJ_l0003o0000
00_o0000:ooonfX4o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000006_l000000ooo
nf[o0000o`000003o`000003oookJ_l0003o000000So0000:_oonfX7o`0000;ooo]Z3?l000000ooo
nf[o0000o`00000:o`000003oookJ_l0003o000001;o000000?ooo]Zo`000?l000001?l0000Zoook
JP?o00000_oonfX3o`000003oookJ_l0003o000000ko000000?ooo]Zo`000?l000003_l000000ooo
nf[o0000o`00000?o`0002_ooo]Z2Ol00002oookJPOo000000?ooo]Zo`000?l000001?l0000Moook
JP00E?oonfX4o`0001Cooo]Z1ol000000ooonf[o0000o`00000Jo`000003oookJ_l0003o000000So
000000?ooo]Zo`000?l000002ol0000[oookJP?o00000_oonfX:o`000003oookJ_l0003o000001Co
00000ooonfX9o`0000;ooo]Z2Ol0000ZoookJSOo000000?ooo]Zo`000?l000001?l0000_oookJPCo
000000?ooo]Zo`000?l000002ol000000ooonf[o0000o`000003o`0000;ooo]Z7Ol0000[oookJPWo
00000_oonfX7o`000003oookJ_l0003o000000Co00007OoonfX005Cooo]Z1?l0000DoookJRCo0000
00?ooo]Zo`000?l000005Ol0000/oookJP?o00000_oonfX:o`000003oookJ_l0003o000000co0000
0ooonfX4o`0000?ooo]Z2_l00002oookJPWo0000:_oonfXgo`000003oookJ_l0003o000000Co0000
:OoonfX4o`0000;ooo]Z1?l000001Ooonf[o0000o`000?l0003ooo]Z00Wo000000?ooo]Zo`000?l0
00000ol000000ooonf[o0000o`000002o`0000;ooo]Z6?l0000[oookJQWo00007OoonfX005Cooo]Z
1?l0000BoookJR[o000000?ooo]Zo`000?l000004Ol0000[oookJPCo000000?ooo]Zo`000?l00000
6?l0000:oookJP[o00000_oonfX5o`000004oookJ_l0003o0000o`0002Wooo]Z>?l000000ooonf[o
0000o`000003o`0002[ooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z00_o00000_oonfX6o`00
0003oookJ_l0003o000000;o00000_oonfXKo`0002Sooo]Z1ol000000ooonf[o0000o`00000>o`00
01kooo]Z001DoookJPCo00004_oonfXio`0000;ooo]Z1Ol0000YoookJP?o00000_oonfXLo`0000;o
oo]Z0ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000000?o00000_oonfX4o`000004
oookJ_l0003o0000o`0002Wooo]Z1_l000000ooonf[o0000o`000002o`000003oookJ_l0003o0000
00?o000000?ooo]Zo`000?l00000:_l0000ZoookJQOo000000?ooo]Zo`000?l000005Ol00003oook
JPko0000:OoonfXJo`0001_ooo]Z001DoookJPCo00004_oonfX4o`000003oookJ_l0003o000001_o
000000?ooo]Zo`000?l000006ol0000YoookJR;o000000?ooo]Zo`000?l000003ol00002oookJPOo
0000:_oonfX;o`000004oookJ_l0003o0000o`0000?ooo]Z;?l0000ZoookJQOo000000?ooo]Zo`00
0?l000001Ol00002oookJPko00000ooonfX6o`0000?ooo]Z1Ol0000YoookJPOo00000_oonfXAo`00
01_ooo]Z001DoookJPCo00004_oonfX4o`0000?ooo]Z6_l000000ooonf[o0000o`00000Lo`0002Oo
oo]Z1ol000000ooonf[o0000o`00000@o`000003oookJ_l0003o000001_o000000?ooo]Zo`000?l0
00001_l0000XoookJQ3o00000_oonfX;o`000003oookJ_l0003o000000Go00000_oonfXGo`0002[o
oo]Z0ol00002oookJQ[o00000_oonfX>o`0000?ooo]Z1_l00003oookJP?o0000:ooonfXJo`0001_o
oo]Z001DoookJPCo00004_oonfX3o`0000?ooo]Z>_l0000WoookJPOo000000?ooo]Zo`000?l00000
=ol0000XoookJQgo000000?ooo]Zo`000?l000001Ol00002oookJP[o000000?ooo]Zo`000?l00000
3?l0000XoookJR3o000000?ooo]Zo`000?l000002?l00003oookJP?o000000?ooo]Zo`000?l00000
3?l0000YoookJQWo00007?oonfX005Cooo]Z1?l0000BoookJPGo000000?ooo]Zo`000?l000001ol0
0002oookJPGo000000?ooo]Zo`000?l000000_l00003oookJR;o00009ooonfX7o`000003oookJ_l0
003o000003Oo0000:?oonfXMo`000003oookJ_l0003o0000023o0000:_oonfXYo`0000?ooo]Z0ol0
00000ooonf[o0000o`00000<o`0002gooo]Z5_l0000KoookJP00E?oonfX4o`00017ooo]Z1_l00000
0ooonf[o0000o`00000Eo`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000005ol0000X
oookJPOo00000_oonfXho`0002Sooo]Z7Ol000000ooonf[o0000o`00000Fo`000005oookJ_l0003o
0000o`000?oonfX01Ol0000ZoookJPSo00000_oonfX8o`0000;ooo]Z5?l00004oookJP?o000000?o
oo]Zo`000?l000003?l0000XoookJP?o00000_oonfXFo`0001_ooo]Z001DoookJPCo00004OoonfXO
o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`000002
o`0002Sooo]Z=_l00003oookJPSo0000:OoonfXeo`000005oookJ_l0003o0000o`000?oonfX01Ol0
000YoookJQ?o00000_oonfX5o`0000?ooo]Z3Ol00003oookJQ3o0000:?oonfX6o`000003oookJ_l0
003o000001Co00006ooonfX005Cooo]Z1?l0000AoookJR3o000000?ooo]Zo`000?l000000ol00000
0ooonf[o0000o`00000Ho`0002Oooo]Z;_l000000ooonf[o0000o`000005o`0000;ooo]Z1_l0000Y
oookJSSo00001_oonfX5o`0002Sooo]Z4ol00002oookJPGo00000ooonfX>o`000003oookJ_l0003o
000000oo0000:?oonfX6o`0000?ooo]Z2?l000000ooonf[o0000o`000009o`0001_ooo]Z001Doook
JPGo00004?oonfX3o`000003oookJ_l0003o000003go0000:?oonfXdo`000003oookJ_l0003o0000
00Co0000:OoonfXHo`0000;ooo]Z8_l00002oookJPGo0000:?oonfXCo`0000?ooo]Z1ol00002oook
JPco000000?ooo]Zo`000?l000004?l0000WoookJPKo00000ooonfXDo`0001_ooo]Z001DoookJPCo
00004?oonfXYo`000003oookJ_l0003o000001So00009_oonfXQo`000003oookJ_l0003o000001co
00009_oonfXIo`0000Kooo]Z9?l0000VoookJQGo00000ooonfX7o`000003oookJ_l0003o0000027o
00009?oonfXLo`0001cooo]Z001DoookJPCo00004?oonfY4o`0002Cooo]Z8ol000000ooonf[o0000
o`00000No`0002?ooo]Z1_l000000ooonf[o0000o`00000Eo`0000;ooo]Z9?l0000ToookJPko0000
00Cooo]Zo`000?l0003o00001_oonfX9o`000003oookJ_l0003o000001Co000000?ooo]Zo`000?l0
00002_l0000ToookJQ?o000000?ooo]Zo`000?l000001_l0000LoookJP00E?oonfX4o`00013ooo]Z
>?l000000ooonf[o0000o`00000:o`0002?ooo]Z8_l00002oookJP_o000000?ooo]Zo`000?l00000
4ol0000RoookJQko00000_oonfXIo`0000;ooo]Z2ol0000RoookJQ;o000000Cooo]Zo`000?l0003o
00000_oonfX9o`000003oookJ_l0003o000001Co000000?ooo]Zo`000?l000002_l0000ToookJQco
00007?oonfX005Cooo]Z1?l0000@oookJSSo000000?ooo]Zo`000?l000002_l0000SoookJQCo0000
00?ooo]Zo`000?l000002ol000000ooonf[o0000o`00000Po`0002;ooo]Z7_l000000ooonf[o0000
o`00000Uo`0002;ooo]Z4_l000001Ooonf[o0000o`000?l0003ooo]Z00Wo00000_oonfX>o`0000;o
oo]Z4?l0000UoookJPSo00000_oonfX9o`000003oookJ_l0003o000000Wo00006ooonfX005Cooo]Z
1?l0000?oookJSOo00000_oonfX3o`000003oookJ_l0003o000000Oo00009?oonfXOo`0000;ooo]Z
8ol0000RoookJR;o000000?ooo]Zo`000?l000008Ol0000RoookJPoo00000_oonfX5o`000003oook
J_l0003o000001Oo00000ooonfX>o`000004oookJ_l0003o0000o`0002;ooo]Z7ol0000KoookJP00
E?oonfX4o`0000oooo]ZAOl0000UoookJQoo000000?ooo]Zo`000?l000005_l00005oookJPKo0000
8ooonfX5o`000003oookJ_l0003o000002So00000ooonfXBo`0002?ooo]Z5_l000000ooonf[o0000
o`00000Io`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000001Ol0000RoookJPko0000
0ooonfX>o`0001_ooo]Z001DoookJPCo00003ooonfX4o`000003oookJ_l0003o0000027o00000ooo
nfXFo`0002Oooo]Z4ol000000ooonf[o0000o`00000Io`0000;ooo]Z2Ol00002oookJPWo00009?oo
nfX`o`0000;ooo]Z3?l00003oookJPGo00008OoonfXFo`0000?ooo]Z;?l0000RoookJPko00000ooo
nfX=o`0001cooo]Z001DoookJPCo00004?oonfX3o`000003oookJ_l0003o000000_o000000?ooo]Z
o`000?l000003ol00006oookJPCo000000?ooo]Zo`000?l000000ol00002oookJPko00009?oonfXC
o`0000;ooo]Z2Ol000000ooonf[o0000o`00000?o`0000;ooo]Z2?l000000ooonf[o0000o`000008
o`0002;ooo]Z2ol00004oookJR[o000000?ooo]Zo`000?l000003?l0000OoookJQWo000000?ooo]Z
o`000?l000001_l00005oookJQ3o00000_oonfX?o`00027ooo]Z3ol00002oookJPgo00007?oonfX0
05Cooo]Z1?l0000EoookJQoo000000Gooo]Zo`000?l0003o0000oookJP03o`000003oookJ_l0003o
000000Oo000000?ooo]Zo`000?l000003?l0000RoookJQ3o00000ooonfXNo`000003oookJ_l0003o
000001?o00008?oonfX:o`0000;ooo]Z0ol000000ooonf[o0000o`00000Ro`0000;ooo]Z1Ol00000
0ooonf[o0000o`00000:o`0001oooo]Z3Ol00002oookJS[o00008OoonfX>o`0000?ooo]Z3?l0000L
oookJP00E?oonfX4o`0000kooo]Z2ol000000ooonf[o0000o`00000Ho`000005oookJ_l0003o0000
o`000?oonfX07?l0000SoookJPKo00000_oonfX9o`000003oookJ_l0003o000001Ko000000?ooo]Z
o`000?l000006Ol0000PoookJSCo00000_oonfXBo`0001oooo]Z3Ol00003oookJPko000000?ooo]Z
o`000?l000007?l00003oookJPWo00007ooonfXKo`000004oookJ_l0003o0000o`0001cooo]Z001D
oookJPCo00003_oonfXHo`0000;ooo]Z3?l000001Ooonf[o0000o`000?l0003ooo]Z01Go00000_oo
nfX6o`00027ooo]Z1?l00005oookJSko00007ooonfXUo`0000;ooo]Z3Ol000000ooonf[o0000o`00
000Bo`0002Gooo]Z1_l00002oookJSCo00000_oonfX5o`0001kooo]Z4?l000000ooonf[o0000o`00
000=o`0001cooo]Z001DoookJPCo00003_oonfXHo`000005oookJ_l0003o0000o`000?oonfX00ol0
00000ooonf[o0000o`000003o`0000;ooo]Z6ol000000ooonf[o0000o`000002o`0001oooo]Z7?l0
00001?oonf[o0000o`000?l00002oookJROo00007ooonfXIo`000003oookJ_l0003o000000co0000
00?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000Ao`0002Cooo]Z2?l00002oookJR[o0000
0_oonfX@o`0001gooo]Z3_l00003oookJPoo00007?oonfX005Cooo]Z1?l0000@oookJP?o00000_oo
nfXAo`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l000000_l00003oookJPSo000000?o
oo]Zo`000?l000005Ol0000OoookJQOo00000_oonfX3o`000004oookJ_l0003o0000o`0000;ooo]Z
9ol0000OoookJP?o00000ooonfXCo`000003oookJ_l0003o000001So000000?ooo]Zo`000?l00000
4?l0000RoookJPco000000?ooo]Zo`000?l000005ol000000ooonf[o0000o`00000Po`0001gooo]Z
8Ol0000KoookJP00E?oonfX5o`0000_ooo]Z4Ol000000ooonf[o0000o`000006o`000003oookJ_l0
003o000002go00007ooonfXPo`0000;ooo]Z1Ol000000ooonf[o0000o`00000Oo`0002;ooo]Z5_l0
00000ooonf[o0000o`00000[o`0002;ooo]Z;_l000000ooonf[o0000o`00000Ho`0001cooo]Z6ol0
00000ooonf[o0000o`000004o`0001_ooo]Z001DoookJPCo00003?oonfX:o`0000;ooo]Z?ol0000N
oookJQko00001?oonfXWo`00023ooo]Z:?l00002oookJQco00008_oonfXDo`0000;ooo]Z<_l0000M
oookJPSo00000_oonfXHo`0001_ooo]Z001DoookJPCo00003?oonfX:o`0000;ooo]Z1ol00003oook
JPWo000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`00000Eo`0001_ooo]Z8Ol00003oook
JRSo00007_oonfXBo`000003oookJ_l0003o000003?o00007_oonfX:o`000003oookJ_l0003o0000
00So000000?ooo]Zo`000?l000004ol000000ooonf[o0000o`00000=o`0000;ooo]Z4?l0000Koook
JQgo000000?ooo]Zo`000?l000000_l0000KoookJP00E?oonfX4o`0000_ooo]Z2ol00003oookJPSo
000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000Jo`000003oookJ_l0003o000000go
00006ooonfXRo`0000;ooo]Z:?l0000LoookJT?o000000?ooo]Zo`000?l000001Ol0000MoookJP?o
000000?ooo]Zo`000?l000005_l000000ooonf[o0000o`000008o`000003oookJ_l0003o0000017o
000000?ooo]Zo`000?l000003ol0000JoookJQko000000?ooo]Zo`000?l000000_l0000KoookJP00
E?oonfX4o`0000_ooo]Z3_l000000ooonf[o0000o`00000<o`0000;ooo]Z9Ol000000ooonf[o0000
o`000007o`0001[ooo]Z6ol00002oookJPKo000000?ooo]Zo`000?l000002_l00003oookJQGo0000
00Cooo]Zo`000?l0003o00007?oonfXGo`0000;ooo]Z8_l000000ooonf[o0000o`00000=o`0001go
oo]Z0ol000000ooonf[o0000o`000008o`000003oookJ_l0003o0000023o000000?ooo]Zo`000?l0
00001_l00002oookJPCo000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000005o`0001Wo
oo]Z0ol000000ooonf[o0000o`00000Ho`000004oookJ_l0003o0000o`0001cooo]Z001DoookJPCo
00002ooonfY>o`0001Wooo]Z4_l00004oookJPKo00000_oonfXXo`000004oookJ_l0003o0000o`00
00;ooo]Z0ol0000JoookJQOo00001?oonfX=o`0000;ooo]Z8ol0000KoookJQWo00000_oonfX;o`00
0003oookJ_l0003o0000017o00000_oonfX:o`000003oookJ_l0003o000000Go00006OoonfX3o`00
0003oookJ_l0003o000001co00007?oonfX005Cooo]Z1?l0000;oookJSko000000?ooo]Zo`000?l0
00003Ol0000IoookJPWo000000?ooo]Zo`000?l000001ol00003oookJPKo00000_oonfXQo`0000;o
oo]Z3_l0000LoookJQGo000000?ooo]Zo`000?l000003_l00002oookJPWo000000?ooo]Zo`000?l0
00004Ol00003oookJP?o00006ooonfXVo`000003oookJ_l0003o000001go000000?ooo]Zo`000?l0
00001Ol0000JoookJPSo00001OoonfXDo`0001cooo]Z001DoookJPCo00002ooonfXno`000003oook
J_l0003o000000_o00006ooonfXCo`0000;ooo]Z1?l00005oookJR7o000000?ooo]Zo`000?l00000
3Ol0000IoookJQSo000000?ooo]Zo`000?l000006Ol000000ooonf[o0000o`000002o`000003oook
J_l0003o000000ko000000Cooo]Zo`000?l0003o00006ooonfXUo`0000;ooo]Z9ol0000JoookJQKo
000000?ooo]Zo`000?l000002?l0000LoookJP00E?oonfX4o`0000_ooo]Z7Ol000000ooonf[o0000
o`00000Co`000003oookJ_l0003o000001Ko00006ooonfXXo`0000;ooo]Z2_l000000ooonf[o0000
o`000008o`000003oookJ_l0003o000000go00006OoonfX=o`000003oookJ_l0003o000002Ko0000
00?ooo]Zo`000?l000002_l000000ooonf[o0000o`00000:o`0001Sooo]Z9_l00002oookJR?o0000
00Cooo]Zo`000?l0003o00006_oonfXQo`0001cooo]Z001DoookJPCo00003OoonfXXo`000003oook
J_l0003o000001oo00002?oonfX5o`00O`Gooo]Z1Ol007l3oookJPko00000_l007lIo`0000;ooo]Z
3ol00003oookJP?o000000?ooo]Zo`000?l000000_l00002oookJPWo00003ooonfX3o`00O`Gooo]Z
00?o001oo`000?l000003?l000000ooonf[o0000o`00000Zo`000003oookJ_l0003o000001?o0000
6?oonfXNo`000003o`00Ool0003o000000Ko000000?o001oo`000?l000000ol00004oookJP?o0000
00?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000<o`0001[ooo]Z4_l000000ooonf[o0000
o`00000:o`0000?o001o1OoonfX5o`00O`Gooo]Z1Ol007l7oookJP00E?oonfX4o`0000gooo]Z:?l0
00000ooonf[o0000o`00000Oo`0000Oooo]Z1ol007l3oookJPOo001o0_oonfX3o`000003o`00Ool0
003o000000So000000?o001oo`000?l000005?l000000ooonf[o0000o`000002o`000003oookJ_l0
003o000001Wo00000_oonfX8o`0000oooo]Z0ol007l4oookJP;o001oDOl0000HoookJQ3o000000?o
oo]Zo`000?l000006?l00002o`00O`03oookJ_l0003o000000Co000000?ooo]Zo`000?l000005ol0
000KoookJQoo00001?l007l3oookJPOo001o0ooonfX7o`00O`Kooo]Z001DoookJPCo00002ooonfX;
o`0000;ooo]Z3Ol00002oookJQWo000000?ooo]Zo`000?l000002Ol00002oookJPWo00001_oonfX4
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJP?o0000
00?o001oo`000?l000007ol000000ooonf[o0000o`00000Zo`0000gooo]Z0ol007l4oookJP;o001o
2_l000000ol007oo0000o`000014o`0001Kooo]Z4_l00002oookJP;o001o5ol00002o`00O`Ko0000
0ooonfX9o`000003oookJ_l0003o000000go00006_oonfXPo`0000?o001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP00E?oonfX4o`0000So
oo]Z2_l000001?oonf[o0000o`000?l00002oookJPgo00000_oonfXDo`0000;ooo]Z3ol00002oook
JPWo00001_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`000?l000008_l00002oookJRco00003OoonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000008
o`000003oookJ_l0003o000000go00000_l007l3o`000003oookJ_l0003o000001Ko000000?ooo]Z
o`000?l000005Ol0000FoookJQ?o00000ol007l00ooonf[o0000o`00000Co`000003oookJ_l007oo
001o00Oo00000_oonfX4o`000003oookJ_l0003o000001?o00005ooonfXRo`000005oookJ_l007oo
001oo`00OooonfX00ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z
001DoookJPCo00002?oonfXco`000003oookJ_l0003o000000go000000?ooo]Zo`000?l000002?l0
00001?oonf[o0000o`000?l00009oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03
oookJ_l0003o0000023o00000ooonfXLo`000003oookJ_l0003o000000oo00003?oonfX3o`00O`?o
oo]Z0_l007l<o`000003oookJ_l0003o000001;o000000?ooo]Zo`00Ool007l00ol000000ooonf[o
0000o`00000<o`000003oookJ_l0003o000001So00005ooonfXFo`000003oookJ_l0003o000001?o
000000?ooo]Zo`00Ool000001ol00002oookJQ[o00005_oonfXTo`0000?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00E?oonfX4o`00
00Sooo]Z8ol000000ooonf[o0000o`00000Xo`000004oookJ_l0003o0000o`0000Wooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`000?l00000:?l000000ooonf[o0000o`00
000Do`000003oookJ_l0003o000000oo00003?oonfX3o`00O`?ooo]Z0_l007l8o`000003o`00Ool0
003o000001Ko000000?ooo]Zo`00Ool007l00ol000000ooonf[o0000o`00000Lo`0000Cooo]Z1_l0
000JoookJQCo00000_oonfX8o`0000;ooo]Z2_l000000ooonf[o001oo`000007o`0000;ooo]Z6_l0
000FoookJRCo00000ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z001DoookJPGo00001ooonfXPo`0000Cooo]Z1_l000000ooonf[o0000
o`00000Wo`0000;ooo]Z0_l007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`go
00000_l007ldo`000003oookJ_l0003o000000oo00003?oonfX3o`00O`?ooo]Z0_l007l8o`0000;o
001o3_l000000ol007oo0000o`00000<o`000003oookJ_l0003o000001go00000_oonfX;o`0001Co
oo]Z5_l00002oookJPSo00000_oonfX9o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l0
00002Ol00002oookJPgo00005_oonfX=o`000003oookJ_l0003o000001Go00000_l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z001Doook
JPCo00001ooonfXSo`0000;ooo]Z3?l000000ooonf[o0000o`00000Eo`000003oookJ_l0003o0000
00Go000000Cooo]Zo`000?l0003o00000_oonfX7o`00O`;ooo]Z0ol007l3oookJP;o001o0ol00002
o`00O`So00000_l007l2oookJSgo00000ooonfX3o`0000gooo]Z0ol007l3oookJP;o001o9ol00000
0ooonf[o0000o`00000Zo`0001Cooo]Z5_l000000ooonf[o0000o`000009o`000003oookJ_l0003o
0000023o000000?ooo]Zo`000?l000003?l0000CoookJQ_o000000?o001oo`000?l000002?l00002
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX005Cooo]Z1?l00007oookJS7o000000?ooo]Zo`000?l000008_l000000ooonf[o001oo`00
O`04o`00O`?ooo]Z0ol007l3oookJP;o001o0ol00002o`00O`So00000_l007l2oookJQKo00001?oo
nfXBo`000003oookJ_l0003o000000go00001?oonfX6o`0000[ooo]Z0ol007l3oookJP;o001o<?l0
00000ooonf[o0000o`00000Qo`0001Cooo]Z9ol000000ol007oo0000o`00000Ko`000005oookJ_l0
003o0000o`000?oonfX02_l0000CoookJRKo00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z001DoookJPCo00001ooonfX9o`0000;o
oo]Z9Ol00002oookJPGo000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`000007o`000003
oookJ_l007oo001o00Oooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool007l02Ol000000ol007oo
0000o`00000;o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000001?l000000ooonf[o
0000o`00000Co`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000001_l00004oookJP?o
00001ooonfX6o`00O`?ooo]Z00?o001oo`000?l000007?l000000ol007oo0000o`000002o`000003
o`00Ool0003o000002ko00005?oonfX@o`0000;ooo]Z5_l000000ol007oo0000o`00000Ko`000003
oookJ_l0003o000000;o000000?ooo]Zo`000?l000001ol0000CoookJR?o00000_oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX0
05Cooo]Z1?l00005oookJP_o00001?oonfXSo`0000;ooo]Z1Ol000000ooonf[o0000o`00000>o`00
0003oookJ_l0003o000000_o000000?ooo]Zo`00Ool007l02?oonfX3o`00O`04oookJ_l007oo001o
o`00O`;ooo]Z2ol000000ol007oo0000o`000005o`000003oookJ_l0003o000000?o000000?ooo]Z
o`000?l000001Ol000000ooonf[o0000o`00000Zo`0000Cooo]Z0ol00007oookJPKo001o1?oonfXM
o`000003oookJ_l007oo000000?o00000_l007l_o`0001?ooo]Z7?l000000ol007oooo]ZoookJP0:
o`000003oookJ_l0003o000000?o000000?o001oo`000?l000005Ol000000ooonf[o0000o`00000=
o`00017ooo]Z5_l000000ooonf[o0000o`00000>o`000004o`00Oooonf[ooo]ZoookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z001DoookJPCo0000
1OoonfX;o`0000Cooo]Z3Ol000000ooonf[o0000o`000007o`0000?ooo]Z3ol00002oookJQko0000
0_oonfX7o`00O`;ooo]Z1Ol007l3o`000003oookJ_l0003o000000So000000?ooo]Zo`00Ool00000
1_l00003oookJSWo00003ooonfX4o`00O`;ooo]Z@Ol000000ooonf[o0000o`00000Bo`0001;ooo]Z
7ol000000ooonf[o0000o`000008o`000003oookJ_l0003o000000?o00000_l007l4oookJR?o0000
3ooonfX5o`0000Gooo]Z3Ol000000ooonf[o001oo`00000>o`000004o`00Oooonf[ooo]ZoookJPOo
001o0ooonfX7o`00O`Kooo]Z001DoookJPCo00001OoonfXKo`0000;ooo]Z2?l00004oookJQ3o0000
00?ooo]Zo`000?l000007Ol000000ooonf[o001oo`00O`05o`00O`?ooo]Z1?l007l@o`0000;o001o
1_l00002oookJQgo000000?ooo]Zo`000?l000006Ol00005oookJP?o00002?oonfX3o`00O`;ooo]Z
4_l00003oookJQ_o00000_oonfXAo`0000;ooo]Z5?l0000>oookJR3o000000?ooo]Zo`000?l00000
5ol00002oookJQoo00003_oonfX5o`0000Kooo]Z7Ol00005oookJPGo001o1OoonfX5o`00O`Oooo]Z
001DoookJPCo00002?oonfYHo`0000gooo]Z2_l000000ooonf[o0000o`000003o`0000;ooo]Z=_l0
00000ooonf[o0000o`000009o`0000;ooo]Z1Ol0000=oookJQ;o000000?ooo]Zo`000?l00000;_l0
0002oookJQCo00003_oonfXGo`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000002ol0
0002oookJQKo000000?ooo]Zo`000?l000001_l00004oookJP?o000000?ooo]Zo`000?l000000_l0
000>oookJPWo00001_oonfXGo`0001gooo]Z001DoookJPCo00001?oonfX3o`000003oookJ_l0003o
000005Ko00003_oonfX9o`0000;ooo]Z1Ol00003oookJPWo00001OoonfX@o`000003oookJ_l0003o
000001oo00000_oonfX5o`00013ooo]Z3ol000000ooonf[o0000o`00000Do`000003oookJ_l0003o
000000?o000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`00000Bo`0000kooo]Z5ol00000
0ooonf[o0000o`00000Eo`000003oookJ_l0003o000001ko00000_oonfX4o`000003oookJ_l0003o
000000?o00003?oonfX@o`0000;ooo]Z5?l0000NoookJP00E?oonfX4o`0000?ooo]Z<?l00004oook
JPKo000000Gooo]Zo`000?l0003o0000oookJP0@o`000003oookJ_l0003o000000Oo000000?ooo]Z
o`000?l000000_l0000=oookJPGo00001OoonfXBo`0000;ooo]Z4ol000000ooonf[o0000o`000004
o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000004ol0000;oookJR_o00000_oonfX:
o`0000;ooo]Z4_l000000ooonf[o0000o`00000Ao`0000gooo]Z5Ol000000ooonf[o0000o`000012
o`0000cooo]Z4?l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000co00006ooonfX0
05Cooo]Z1?l00003oookJRKo000000?ooo]Zo`000?l000001ol00003oookJPOo000000?ooo]Zo`00
0?l000007?l000000ooonf[o0000o`000002o`0000kooo]Z6ol00002oookJRGo000000?ooo]Zo`00
0?l000002_l000000ooonf[o0000o`000006o`0000_ooo]Z7Ol000000ooonf[o0000o`00000Jo`00
0003oookJ_l0003o000000ko000000?ooo]Zo`000?l000002_l000000ooonf[o0000o`000004o`00
00Wooo]Z0ol000000ooonf[o0000o`00001Io`0000_ooo]Z4?l000000ooonf[o0000o`000007o`00
0003oookJ_l0003o000000?o00000_oonfX7o`0001_ooo]Z001DoookJPCo00000ooonfX3o`000003
oookJ_l0003o000003?o000000?ooo]Zo`000?l000003Ol00002oookJQ?o00002_oonfXJo`000003
oookJ_l0003o000001_o000000?ooo]Zo`000?l000005Ol000000ooonf[o0000o`00000;o`0000Wo
oo]ZGol00008oookJPCo000000?ooo]Zo`000?l000005Ol000000ooonf[o0000o`000005o`0000;o
oo]Z6Ol000000ooonf[o0000o`00000>o`000003oookJ_l0003o000000go00002?oonfXMo`000003
oookJ_l0003o000000Co00001OoonfX3o`0001_ooo]Z001DoookJPCo000000?ooo]Zo`000?l00000
1?l000000ooonf[o0000o`000007o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l00000
7?l000000ooonf[o0000o`00000=o`0000;ooo]Z5Ol00008oookJQSo00000ooonfXeo`000003oook
J_l0003o000000go00001OoonfXbo`000003oookJ_l0003o000000oo000000?ooo]Zo`000?l00000
7?l00006oookJQco000000?ooo]Zo`000?l000004_l000000ooonf[o0000o`00000To`0000;ooo]Z
1_l00008oookJPCo00000_oonfX9o`000003oookJ_l0003o000000_o000000?ooo]Zo`000?l00000
1ol00002oookJP?o00006ooonfX004Sooo]Zool0003Zo`0000oooo]Z0018oookJ_oo0000j_l0000?
oookJP00B?oonf[oo`000>[o00003ooonfX004Sooo]Zool0003Zo`0000oooo]Z001DoookJQWo0000
0_oonfXFo`0000Wooo]ZHOl00007oookJP?o00001OoonfXMo`000003oookJ_l0003o000000Ko0000
00?ooo]Zo`000?l000001ol00002oookJQ7o000000?ooo]Zo`000?l000004_l00007oookJQko0000
00?ooo]Zo`000?l000003Ol00002oookJQ[o00000ooonfXEo`0000Gooo]Z2Ol00002oookJRko0000
0ooonfXOo`000003oookJ_l0003o000000;o00007?oonfX005Cooo]Z<Ol00009oookJSSo00000ooo
nfXUo`0000Sooo]Z1Ol000000ooonf[o0000o`00000Go`000003oookJ_l0003o000000co000000?o
oo]Zo`000?l000001ol00002oookJP_o00001ooonfX4o`0000;ooo]Z2Ol00002oookJP?o00002?oo
nfXIo`000003oookJ_l0003o000001_o000000?ooo]Zo`000?l000009Ol00008oookJPSo000000?o
oo]Zo`000?l00000:ol00005oookJQOo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`00
0003o`0001cooo]Z001DoookJRKo000000?ooo]Zo`000?l000002?l00009oookJUGo000000?ooo]Z
o`000?l000001_l0000;oookJPCo000000?ooo]Zo`000?l000000_l00002oookJP?o000000?ooo]Z
o`000?l000002?l00002oookJP?o000000?ooo]Zo`000?l000005_l000000ooonf[o0000o`00000;
o`0000?ooo]Z0ol000001Ooonf[o0000o`000?l0003ooo]Z00oo00002_oonfXGo`000003oookJ_l0
003o000000go00000_oonfX]o`000003oookJ_l0003o000000Co00002?oonfXAo`0000;ooo]Z1_l0
00000ooonf[o0000o`00000^o`0000?ooo]Z1Ol000000ooonf[o0000o`00000:o`0001cooo]Z001D
oookJPWo00000_oonfX5o`000003oookJ_l0003o0000017o00000_oonfX;o`0000_ooo]Z7ol00006
oookJRko000000?ooo]Zo`000?l000001Ol0000<oookJPWo00000_oonfX3o`000003oookJ_l0003o
000003Co00000ooonfXEo`0000_ooo]Z3_l000000ooonf[o0000o`000007o`000003oookJ_l0003o
000002Oo000000?ooo]Zo`000?l000006Ol0000:oookJPko00001OoonfX4o`000003oookJ_l0003o
000002[o000000?ooo]Zo`000?l000002Ol000000ooonf[o0000o`00000:o`0001cooo]Z001Doook
JPSo00000ooonfX5o`000003oookJ_l0003o000001go00003?oonfXJo`000004oookJ_l0003o0000
o`0000Gooo]Z3?l000000ooonf[o0000o`00000Yo`0000cooo]Z8?l00003oookJS[o00002ooonfXQ
o`0000?ooo]Z>?l0000>oookJQGo000000?ooo]Zo`000?l000005ol000000ooonf[o0000o`00000@
o`0000;ooo]Z1Ol00002oookJP?o000000?ooo]Zo`000?l000002_l0000LoookJP00E?oonfX6o`00
00;ooo]Z9?l000001?oonf[o0000o`000?l0000<oookJQGo000000?ooo]Zo`000?l000001_l00000
0ooonf[o0000o`00000eo`000003oookJ_l0003o000000;o00003OoonfX>o`0000Gooo]Z3?l00002
oookJS_o00002ooonfX3o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000002_l00000
1Ooonf[o0000o`000?l0003ooo]Z00?o000000?ooo]Zo`000?l000007Ol000000ooonf[o0000o`00
000Do`0000oooo]Z5?l000000ooonf[o0000o`00000Oo`000003oookJ_l0003o000000;o000000?o
oo]Zo`000?l000002_l00002oookJPoo00007OoonfX005Cooo]Z6ol000000ooonf[o0000o`00000>
o`00013ooo]Z1ol00002oookJQGo000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000F
o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l000000ol00002oookJP?o000000Cooo]Z
o`000?l0003o00003ooonfX=o`000003oookJ_l0003o000000So00000_oonfXoo`00017ooo]Z6Ol0
00000ooonf[o0000o`00000Io`0000;ooo]Z8Ol0000?oookJQCo00000_oonfXGo`000003oookJ_l0
003o000000_o00000ooonfXBo`0000;ooo]Z1ol0000MoookJP00E?oonfXXo`000003oookJ_l0003o
000000?o00004OoonfX4o`0000Gooo]Z4Ol00002oookJRKo00000_oonfX3o`000003oookJ_l0003o
000000Ko00005_oonfXJo`000003oookJ_l0003o000001Go00000_oonfXLo`0000;ooo]Z1ol0000@
oookJQ;o00000_oonfY3o`00013ooo]Z1ol000000ooonf[o0000o`00000Lo`0000?ooo]Z0ol00002
oookJP[o00001_oonfXFo`000003oookJ_l0003o000000;o00007_oonfX005Cooo]Z2ol000000ooo
nf[o0000o`00000Po`00017ooo]Z1?l00002oookJSoo00000ooonfX8o`0001Wooo]Z5ol00003oook
JQGo000000?ooo]Zo`000?l000003_l00004oookJQ;o00004?oonfXBo`000003oookJ_l0003o0000
00;o000000?ooo]Zo`000?l000005ol000000ooonf[o0000o`00000=o`000003oookJ_l0003o0000
01?o00004?oonfX6o`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000005_l00002oook
JP?o00001?oonfX7o`0000;ooo]Z2?l000000ooonf[o0000o`00000;o`000004oookJ_l0003o0000
o`0001oooo]Z001DoookJP_o000000?ooo]Zo`000?l000005ol00003oookJPKo00004OoonfXho`00
0003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000ol000000ooonf[o0000o`000006o`00
0003oookJ_l0003o000000?o00004ooonfXGo`000003oookJ_l0003o000000Ko00000_oonfXPo`00
00;ooo]Z4Ol0000AoookJPWo000000?ooo]Zo`000?l000007_l00002oookJR_o00004?oonfX3o`00
00Cooo]Z1_l000000ooonf[o0000o`00000Bo`0000;ooo]Z1Ol00005oookJP?o00001_oonfX5o`00
0003oookJ_l0003o000000Go00000ooonfX=o`000004oookJ_l0003o0000o`0001oooo]Z001Doook
JP_o00000ooonfXEo`000005oookJ_l0003o0000o`000?oonfX01?l0000CoookJQ?o00000_oonfY1
o`0001?ooo]Z=ol000000ooonf[o0000o`000008o`0000;ooo]Z4Ol0000DoookJPKo000000?ooo]Z
o`000?l000004ol000000ooonf[o0000o`000004o`000004oookJ_l0003o0000o`0000;ooo]Z1ol0
0003oookJR7o00005OoonfX8o`000003oookJ_l0003o000001;o00000_oonfX7o`000003oookJ_l0
003o000000?o00000ooonfXAo`0000;ooo]Z4Ol0000OoookJP00E?oonfX:o`0000;ooo]Z5ol00000
0ooonf[o0000o`000006o`0001Gooo]Z4Ol00002oookJT7o00004_oonfXOo`000003oookJ_l0003o
000002go00000_oonfX5o`0001Cooo]Z8ol000000ooonf[o0000o`00000:o`0000?ooo]Z8Ol0000B
oookJP[o00000ooonfXCo`000003oookJ_l0003o000000co00000ooonfX7o`000003oookJ_l0003o
000001Wo00008?oonfX005Cooo]Z2Ol00003oookJP[o000000?ooo]Zo`000?l000001?l000000ooo
nf[o0000o`000003o`000003oookJ_l0003o000000Ko00005OoonfYCo`0001?ooo]Z4?l000000ooo
nf[o0000o`00000Mo`0000?ooo]Z7?l00002oookJP?o00005ooonfXRo`000003oookJ_l0003o0000
00[o000000?ooo]Zo`000?l000008?l0000CoookJP[o00000_oonfXDo`000003oookJ_l0003o0000
01[o00000_oonfX9o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000000ol0000Poook
JP00E?oonfX/o`0001Gooo]Z0ol000000ooonf[o0000o`00000Fo`0000;ooo]Z=?l0000DoookJS3o
00000ooonfX>o`000003oookJ_l0003o0000013o00005ooonfYBo`0001?ooo]Z2_l000000ooonf[o
0000o`00000>o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000006Ol000000ooonf[o
0000o`000009o`000003oookJ_l0003o000000Wo00008OoonfX005Cooo]Z;?l0000EoookJPgo0000
00?ooo]Zo`000?l000005ol000000ooonf[o0000o`00000Bo`000003oookJ_l0003o000001Co0000
5?oonfXSo`000003oookJ_l0003o000002go00006?oonfX5o`0000;ooo]Z1Ol000000ooonf[o0000
o`00000fo`000003oookJ_l0003o000000Oo00005_oonfXKo`000003oookJ_l0003o000001go0000
00?ooo]Zo`000?l000002Ol000000ooonf[o0000o`000009o`00027ooo]Z001DoookJRWo00006?oo
nfXEo`000003oookJ_l0003o000000ko000000?ooo]Zo`000?l00000:_l0000EoookJQko000000?o
oo]Zo`000?l000009Ol000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Co00005_oo
nfX8o`0000;ooo]Z:?l00002oookJPOo00000_oonfXDo`0001Kooo]ZDol0000QoookJP00E?oonfXY
o`0001Sooo]Z5Ol000000ooonf[o0000o`00000>o`000003oookJ_l0003o000000Go00000ooonfXR
o`0001Gooo]Z4?l00002oookJPGo000000?ooo]Zo`000?l00000>?l0000FoookJS;o00000_oonfX7
o`0000;ooo]Z5?l0000GoookJP_o000000?ooo]Zo`000?l00000?Ol00002oookJPGo00008OoonfX0
05Cooo]Z:Ol0000HoookJQoo000000?ooo]Zo`000?l000001?l000000ooonf[o0000o`000006o`00
00Cooo]Z7Ol0000HoookJQ7o000000?ooo]Zo`000?l00000?Ol0000GoookJPgo000000?ooo]Zo`00
0?l000004ol00003oookJPko00000_oonfXKo`0001Oooo]Z8Ol00002oookJRko00008_oonfX005Co
oo]Z:Ol0000HoookJP?o00001?oonfXZo`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l0
00005Ol0000JoookJToo00006?oonfX<o`000003oookJ_l0003o000000Oo000000?ooo]Zo`000?l0
0000<?l000000ooonf[o0000o`000004o`0001Oooo]Z=?l000000ooonf[o0000o`00000=o`0000?o
oo]Z2_l0000RoookJP00E?oonfXMo`000003oookJ_l0003o000000Wo00006ooonfXfo`000003oook
J_l0003o000001Co00006OoonfXMo`000003oookJ_l0003o0000017o000000?ooo]Zo`000?l00000
6ol0000IoookJQKo000000?ooo]Zo`000?l00000=ol0000GoookJPoo000000?ooo]Zo`000?l00000
8?l00003oookJPoo00000_oonfX;o`0002;ooo]Z001DoookJRWo00006_oonfX5o`0000?ooo]Z;ol0
00000ooonf[o0000o`00000Do`0001Wooo]Z4ol000000ooonf[o0000o`000008o`0000;ooo]Z;Ol0
000KoookJPko000000?ooo]Zo`000?l000005Ol000000ooonf[o0000o`00000Wo`0001Wooo]Z3?l0
0002oookJR;o000000?ooo]Zo`000?l000001_l00002oookJPOo000000?ooo]Zo`000?l000002Ol0
000SoookJP00E?oonfXWo`0001cooo]Z9ol000000ooonf[o0000o`00000=o`000003oookJ_l0003o
0000017o00007?oonfXCo`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000001Ol00000
0ooonf[o0000o`00000=o`0000;ooo]Z1?l00002oookJPko00007OoonfXSo`0000;ooo]Z0ol00002
oookJPCo000000Gooo]Zo`000?l0003o0000oookJP0Jo`0001_ooo]Z:?l00003oookJQ?o00000ooo
nfX<o`0002?ooo]Z001DoookJRGo00007_oonfX:o`0000?ooo]Z4Ol000000ooonf[o0000o`000005
o`0000;ooo]Z3ol000000ooonf[o0000o`00000=o`000003oookJ_l0003o000000Co00006OoonfX@
o`0000Cooo]Z2ol000000ooonf[o0000o`00000;o`000003oookJ_l0003o000000Oo000000?ooo]Z
o`000?l000002ol00003oookJPGo00007ooonfXQo`000003oookJ_l0003o000000?o00000_oonfX3
o`000005oookJ_l0003o0000o`000?oonfX06Ol0000KoookJRSo000000?ooo]Zo`000?l000008_l0
000ToookJP00E?oonfXVo`0001oooo]Z2?l00002oookJR_o000000?ooo]Zo`000?l000002ol00000
0ooonf[o0000o`000006o`0001[ooo]Z4_l000000ooonf[o0000o`000009o`0000;ooo]Z2?l00000
0ooonf[o0000o`00000Go`0000Gooo]Z1Ol0000LoookJPCo00000_oonfXAo`000003oookJ_l0003o
000000[o000000?ooo]Zo`000?l000006Ol000000ooonf[o0000o`00000:o`0001_ooo]Z6_l00002
oookJRoo00009_oonfX005Cooo]Z9_l0000OoookJPOo00000_oonfXGo`000003oookJ_l0003o0000
00ko00001_oonfX3o`0000?ooo]Z3ol0000LoookJP[o000000?ooo]Zo`000?l000006Ol000000ooo
nf[o0000o`00000Go`0000Gooo]Z1Ol0000LoookJPGo000000?ooo]Zo`000?l000002Ol00006oook
JP?o00000_oonfXao`0001_ooo]Z0ol000000ooonf[o0000o`00000Do`0000;ooo]Z5ol00002oook
JQSo00009?oonfX005Cooo]Z6Ol000000ooonf[o0000o`00000:o`00023ooo]Z4_l000000ooonf[o
0000o`000009o`0000;ooo]Z3Ol000000ooonf[o0000o`000003o`0000?ooo]Z1?l000000ooonf[o
0000o`00000;o`0001oooo]Z2_l000000ooonf[o0000o`000004o`000003oookJ_l0003o0000013o
000000?ooo]Zo`000?l000006ol00003oookJP?o00007_oonfY:o`0001kooo]Z0ol000000ooonf[o
0000o`00000Do`000003oookJ_l0003o000000co000000?ooo]Zo`000?l000000ol000000ooonf[o
0000o`00000:o`000003oookJ_l0003o000000ko00009?oonfX005Cooo]Z6Ol00002oookJP?o0000
0ooonfX7o`0001oooo]Z4Ol000000ooonf[o0000o`00000No`000003oookJ_l0003o000001?o0000
8?oonfX8o`0000?ooo]Z?Ol0000LoookJS7o00001?oonfXEo`0001kooo]Z:Ol00002oookJP?o0000
1?oonfX3o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000002?l000000ooonf[o0000
o`000005o`0002Cooo]Z001DoookJPKo000000?ooo]Zo`000?l000001ol00002oookJPSo000000?o
oo]Zo`000?l000001?l000000ooonf[o0000o`000004o`0001oooo]Z2ol000001?oonf[o0000o`00
0?l00002oookJR7o000000?ooo]Zo`000?l000004ol0000PoookJPWo00000_oonfX:o`000004oook
J_l0003o0000o`0000;ooo]Z1?l000000ooonf[o0000o`00000Ao`0000?ooo]Z1Ol000000ooonf[o
0000o`00000:o`0001gooo]Z<?l00004oookJPco000000?ooo]Zo`000?l000002?l0000LoookJR7o
000000?ooo]Zo`000?l000001Ol00002oookJP?o000000?ooo]Zo`000?l000001?l000000ooonf[o
0000o`00000Do`0002Gooo]Z001DoookJPKo000000?ooo]Zo`000?l000004Ol000000ooonf[o0000
o`00000;o`0001oooo]Z5_l000000ooonf[o0000o`00000Ho`0000;ooo]Z5Ol0000PoookJPWo0000
0_oonfX:o`0000Kooo]Z1?l000000ooonf[o0000o`00000Io`000003oookJ_l0003o000000[o0000
7OoonfXbo`000003oookJ_l0003o000001Ko00007OoonfX;o`000003oookJ_l0003o000000Oo0000
00?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000Wo`0002Kooo]Z001DoookJP[o000000?o
oo]Zo`000?l000003Ol00004oookJPWo00008ooonfX;o`000003oookJ_l0003o000000Co00000_oo
nfXJo`0000;ooo]Z5Ol0000PoookJQ3o000000?ooo]Zo`000?l000001ol00002oookJR_o00007ooo
nfXHo`000003oookJ_l0003o000001Ko000000?ooo]Zo`000?l000005_l0000OoookJPWo000000?o
oo]Zo`000?l000001ol00003oookJPSo000000?ooo]Zo`000?l000000ol00002oookJR;o00009_oo
nfX005Cooo]Z1ol00002oookJQ7o00001?oonfX9o`0001oooo]Z0ol000000ooonf[o0000o`00000A
o`000003oookJ_l0003o000001oo00000ooonfX=o`00023ooo]Z2?l000000ooonf[o0000o`000004
o`0000?ooo]Z9_l000000ooonf[o0000o`00000<o`0001oooo]Z1Ol000000ooonf[o0000o`00000@
o`0000?ooo]Z0ol000000ooonf[o0000o`00000@o`000003oookJ_l0003o000001?o00008_oonfX9
o`0000;ooo]Z2?l000000ooonf[o0000o`000007o`0000;ooo]Z1Ol00002oookJR;o00009_oonfX0
05Cooo]Z1ol00002oookJPoo00001_oonfX8o`00023ooo]Z1ol000000ooonf[o0000o`00000Lo`00
0003oookJ_l0003o000000So000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000;o`00
023ooo]Z1ol00002oookJPOo00001?oonfXao`0002;ooo]Z1?l00002oookJQ7o00000_oonfXDo`00
00?ooo]Z3?l000000ooonf[o0000o`000008o`00027ooo]Z2?l00003oookJQ;o00000_oonfXYo`00
02Kooo]Z001DoookJPOo00000_oonfX>o`0000Oooo]Z2?l0000PoookJRKo000000?ooo]Zo`000?l0
00001?l000001Ooonf[o0000o`000?l0003ooo]Z01Go00009?oonfX7o`000003oookJ_l0003o0000
00Co00000_oonfXco`0002;ooo]Z1?l00003oookJPCo00000ooonfX]o`0000;ooo]Z2_l0000Roook
JPSo00000_oonfX@o`0000Cooo]Z7ol000000ooonf[o0000o`000005o`0002Sooo]Z001DoookJQOo
00000ooonfX<o`00023ooo]Z7Ol000001Ooonf[o0000o`000?l0003ooo]Z00Wo00000_oonfX4o`00
0003oookJ_l0003o000001?o00008ooonfX8o`000003oookJ_l0003o000000Co000000?ooo]Zo`00
0?l000005Ol000000ooonf[o0000o`00000Do`000003oookJ_l0003o000000Co00008_oonfX:o`00
0003oookJ_l0003o000003Wo00008ooonfX8o`000003oookJ_l0003o000000;o000000?ooo]Zo`00
0?l00000;?l000000ooonf[o0000o`000005o`0002Sooo]Z001DoookJQOo00000ooonfX<o`00023o
oo]Z2ol00004oookJPko00000_oonfXAo`0000;ooo]Z5Ol0000RoookJSoo00000_oonfX5o`0002;o
oo]Z6ol000000ooonf[o0000o`00000Wo`0002?ooo]Z3_l000000ooonf[o0000o`00000/o`000003
oookJ_l0003o000000Ko00009ooonfX005Cooo]Z6?l00002oookJP[o00009?oonfX:o`0000?ooo]Z
1ol00002oookJPCo00000ooonfXKo`000003oookJ_l0003o000000Wo00008ooonfXPo`000003oook
J_l0003o000000co000000?ooo]Zo`000?l000003Ol00002oookJPGo00008_oonfXKo`000003oook
J_l0003o0000017o000000?ooo]Zo`000?l000004ol0000SoookJPCo00000_oonfX8o`0000Cooo]Z
:_l00002oookJPSo00009ooonfX005Cooo]Z6?l00002oookJP[o00009OoonfXIo`0000?ooo]Z4?l0
00000ooonf[o0000o`00000Eo`0002;ooo]Z8?l00002oookJPgo000000?ooo]Zo`000?l000002ol0
00001Ooonf[o0000o`000?l0003ooo]Z00?o00008ooonfXDo`000003oookJ_l0003o000000_o0000
00Cooo]Zo`000?l0003o00000ooonfX7o`0000?ooo]Z4_l0000SoookJPko00001?oonfXVo`000005
oookJ_l0003o0000o`000?oonfX02Ol0000WoookJP00E?oonfXAo`000003oookJ_l0003o000000Co
00000_oonfX8o`0002Oooo]Z5Ol00004oookJPGo000000?ooo]Zo`000?l000002ol000000ooonf[o
0000o`00000Eo`0002Gooo]Z?_l0000WoookJR;o000000?ooo]Zo`000?l000004ol000000ooonf[o
0000o`000009o`0002Gooo]Z3Ol000001Ooonf[o0000o`000?l0003ooo]Z02Go000000?ooo]Zo`00
0?l000002_l0000XoookJP00E?oonfX@o`0000;ooo]Z1ol000001?oonf[o0000o`000?l00002oook
JP?o00009ooonfXHo`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000006?l000000ooo
nf[o0000o`000005o`0002?ooo]ZA?l0000ToookJR7o000000?ooo]Zo`000?l000007ol0000Toook
JQ;o00000_oonfX4o`0000;ooo]Z2ol00002oookJQko0000:?oonfX005Cooo]Z4?l000000ooonf[o
0000o`000006o`000003oookJ_l0003o000000?o0000:_oonfX3o`000003oookJ_l0003o000001;o
000000?ooo]Zo`000?l00000:?l0000ToookJPKo000000?ooo]Zo`000?l000001Ol000000ooonf[o
0000o`00000Bo`000004oookJ_l0003o0000o`0000;ooo]Z5_l000000ooonf[o0000o`000002o`00
02Kooo]Z??l000000ooonf[o0000o`000002o`0002Cooo]Z6?l00002oookJR_o0000:?oonfX005Co
oo]Z4?l000000ooonf[o0000o`000006o`000003oookJ_l0003o000000So00009OoonfX3o`000005
oookJ_l0003o0000o`000?oonfX04?l000000ooonf[o0000o`00000Ko`000003oookJ_l0003o0000
00[o00009?oonfX>o`000003oookJ_l0003o0000017o00000_oonfX3o`000003oookJ_l0003o0000
00_o000000?ooo]Zo`000?l000003?l0000ToookJSKo000000?ooo]Zo`000?l000001Ol000000ooo
nf[o0000o`000002o`0002Cooo]Z=Ol00002oookJPGo00000ooonfX6o`0002Sooo]Z001DoookJRCo
0000:?oonfX4o`000003oookJ_l0003o000000oo000000?ooo]Zo`000?l000004_l00002oookJPCo
000000?ooo]Zo`000?l000003?l0000ToookJP?o000000?ooo]Zo`000?l000001ol00006oookJPGo
000000?ooo]Zo`000?l000003?l000000ooonf[o0000o`000007o`000005oookJ_l0003o0000o`00
0?oonfX03Ol0000UoookJSGo00001OoonfX4o`0000;ooo]Z0ol0000UoookJRSo000000?ooo]Zo`00
0?l000002Ol00002oookJPGo00000_oonfX6o`0002Wooo]Z001DoookJP_o000000?ooo]Zo`000?l0
00003?l000000ooonf[o0000o`000007o`0002Sooo]Z1?l000000ooonf[o0000o`00000Go`000003
oookJ_l0003o000000;o00000_oonfX7o`000003oookJ_l0003o000000Oo00000ooonfX7o`0002Co
oo]Z3Ol000000ooonf[o0000o`000006o`000003oookJ_l0003o000000co00000ooonfX:o`0000Co
oo]Z3?l0000VoookJQCo000000?ooo]Zo`000?l000005?l00003oookJPGo000000?ooo]Zo`000?l0
00002?l00002oookJP?o00009OoonfXco`0000;ooo]Z1ol000000ooonf[o0000o`000004o`0002Wo
oo]Z001DoookJPGo000000?ooo]Zo`000?l000001ol000000ooonf[o0000o`00000@o`0002[ooo]Z
7Ol000001?oonf[o0000o`000?l00004oookJQ_o00009?oonfX9o`000003oookJ_l0003o000001Wo
000000?ooo]Zo`000?l000003Ol00002oookJP_o00009_oonfX:o`000003oookJ_l0003o000000co
000000?ooo]Zo`000?l000005ol000000ooonf[o0000o`000008o`000003oookJ_l0003o000000;o
00009_oonfXEo`000003oookJ_l0003o000001So00001?oonfX7o`000003oookJ_l0003o000000Co
0000:OoonfX005Cooo]Z1Ol000000ooonf[o0000o`000007o`000003oookJ_l0003o0000013o0000
:ooonfXQo`0000;ooo]Z2ol000000ooonf[o0000o`00000=o`0002Kooo]Z6_l000000ooonf[o0000
o`000006o`000003oookJ_l0003o000000Co00000_oonfX8o`000003oookJ_l0003o000000[o0000
9_oonfXIo`0000;ooo]Z1Ol00002oookJQ7o000000?ooo]Zo`000?l000001?l000000ooonf[o0000
o`000005o`0002Oooo]Z4_l00004oookJRGo000000?ooo]Zo`000?l000001?l0000YoookJP00E?oo
nfX4o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l000004?l0000YoookJQSo000000?o
oo]Zo`000?l000002Ol000000ooonf[o0000o`00000Ho`0002Wooo]Z6?l000000ooonf[o0000o`00
000Go`000003oookJ_l0003o000000[o00009_oonfXjo`000003oookJ_l0003o000000Go0000:ooo
nfX<o`0000Kooo]Z8Ol00003oookJP?o000000Cooo]Zo`000?l0003o0000:_oonfX005Cooo]Z4Ol0
0002oookJPko0000:OoonfX:o`000003oookJ_l0003o000003?o0000:_oonfX8o`000003oookJ_l0
003o000000co000000?ooo]Zo`000?l000005ol000000ooonf[o0000o`00000:o`0002Oooo]Z3ol0
00000ooonf[o0000o`00000Ho`000003oookJ_l0003o000000co000000?ooo]Zo`000?l000001?l0
000ZoookJQ3o000000?ooo]Zo`000?l000009?l000001Ooonf[o0000o`000?l0003ooo]Z00?o0000
:_oonfX005Cooo]Z8_l0000XoookJRSo000000?ooo]Zo`000?l000003?l00002oookJPOo0000:_oo
nfX8o`000003oookJ_l0003o000000_o000000?ooo]Zo`000?l000004Ol000000ooonf[o0000o`00
0004o`0000;ooo]Z2ol0000YoookJPOo00000ooonfX3o`000003oookJ_l0003o000001Go00001?oo
nfXFo`0002Oooo]Z4_l000000ooonf[o0000o`00000No`000003oookJ_l0003o000000?o000000Go
oo]Zo`000?l0003o0000oookJP03o`0002[ooo]Z001DoookJP[o00000_oonfXBo`000004oookJ_l0
003o0000o`0002Sooo]Z1ol000000ooonf[o0000o`00000>o`000003oookJ_l0003o000001_o0000
0ooonfX5o`0002[ooo]Z6?l000000ooonf[o0000o`00000Ao`000003oookJ_l0003o0000017o0000
:OoonfX9o`0000Gooo]Z6Ol000000ooonf[o0000o`00000Eo`0002Oooo]Z1_l000000ooonf[o0000
o`000009o`000003oookJ_l0003o000000[o00000_oonfX4o`0000;ooo]Z5_l0000^oookJP00E?oo
nfX:o`0000;ooo]Z2_l000000ooonf[o0000o`000009o`0002Sooo]Z1ol000000ooonf[o0000o`00
000do`0002[ooo]Z;?l00003oookJPco000000?ooo]Zo`000?l000000_l0000YoookJP_o000000?o
oo]Zo`000?l00000<Ol0000WoookJPoo000000?ooo]Zo`000?l00000:ol0000^oookJP00E?oonfX:
o`0000;ooo]Z4ol0000/oookJPOo00000ooonfX:o`000003oookJ_l0003o000000_o00000ooonfXH
o`0002[ooo]Z3_l000000ooonf[o0000o`00000Fo`000003oookJ_l0003o000000;o000000?ooo]Z
o`000?l000001_l00003oookJPSo0000:OoonfX;o`000003oookJ_l0003o000000Go000000?ooo]Z
o`000?l00000:?l0000[oookJQ[o00000_oonfXMo`0002oooo]Z001DoookJP[o00000ooonfXBo`00
02gooo]Z1_l00002oookJQWo000000?ooo]Zo`000?l000002_l00002oookJPco0000;?oonfX7o`00
0003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000007ol000000ooonf[o0000o`000005o`00
02_ooo]Z1_l000001Ooonf[o0000o`000?l0003ooo]Z013o00000_oonfXPo`0002_ooo]Z4_l00000
0ooonf[o0000o`000005o`0000;ooo]Z5?l000000ooonf[o0000o`000006o`0002oooo]Z001Doook
JP[o00000ooonfXAo`00037ooo]Z0ol000000ooonf[o0000o`000006o`0000;ooo]Z:ol0000/oook
JSgo0000:ooonfX6o`0000Cooo]Z3?l000000ooonf[o0000o`000002o`0000;ooo]Z6?l0000eoook
JQ[o000000?ooo]Zo`000?l000002?l000000ooonf[o0000o`00000Bo`0002cooo]Z001DoookJQko
0000;OoonfX7o`000003oookJ_l0003o000000Ko000000?ooo]Zo`000?l00000:_l0000^oookJS_o
0000:ooonfX8o`0000;ooo]Z4?l00003oookJQ3o00000_oonfX6o`0000;ooo]Z1?l0000_oookJS[o
0000;?oonfX005Cooo]Z4_l000000ooonf[o0000o`00000:o`0002cooo]Z1ol000000ooonf[o0000
o`00000co`0002cooo]Z??l0000/oookJPSo00000_oonfX[o`000003oookJ_l0003o000000?o0000
;ooonfXdo`000003oookJ_l0003o000000?o0000;?oonfX005Cooo]Z7ol0000/oookJPOo000000?o
oo]Zo`000?l00000<ol0000/oookJS[o0000;_oonfX9o`0000?ooo]Z0ol00002oookJQoo00000ooo
nfX8o`0002kooo]Z5?l00002oookJQoo000000?ooo]Zo`000?l000000ol0000/oookJP00E?oonfX6
o`000003oookJ_l0003o000001Ko0000;_oonfX_o`0000?ooo]Z2Ol0000/oookJQoo00000_oonfX6
o`0000;ooo]Z4Ol0000^oookJP[o00000_oonfX3o`0000Cooo]Z7Ol00002oookJPSo0000;ooonfXD
o`0000?ooo]Z3ol000000ooonf[o0000o`00000Bo`0002cooo]Z001DoookJPKo000000?ooo]Zo`00
0?l000005_l0000^oookJRSo000000?ooo]Zo`000?l000001?l00003oookJPSo0000;OoonfXXo`00
0003oookJ_l0003o000000Ko000000?ooo]Zo`000?l000000_l000001?oonf[o0000o`000?l0000^
oookJP_o00001ooonfXXo`0002kooo]Z4ol00002oookJRGo0000;_oonfX005Cooo]Z8?l0000]oook
JQgo000000?ooo]Zo`000?l000001ol00004oookJP?o000000?ooo]Zo`000?l000002Ol0000]oook
JS7o000000?ooo]Zo`000?l000000_l00002oookJP?o0000;OoonfX;o`0000Cooo]Z4ol000000ooo
nf[o0000o`000004o`000003oookJ_l0003o000000Wo00000_oonfX3o`0002kooo]Z4_l00003oook
JQko000000?ooo]Zo`000?l000001Ol0000]oookJP00E?oonfXPo`0002gooo]Z3?l00002oookJQ[o
00000ooonfX?o`0002kooo]Z1_l00002oookJPSo000000?ooo]Zo`000?l000002Ol000000ooonf[o
0000o`00000Ko`0002gooo]Z1ol000001?oonf[o0000o`000?l00004oookJPOo000000?ooo]Zo`00
0?l000006Ol00003oookJP?o0000<?oonfXPo`000003oookJ_l0003o000001So0000;OoonfX005Co
oo]Z8?l0000]oookJQ;o00001?oonfXDo`000003oookJ_l0003o000000[o0000<OoonfX6o`000003
oookJ_l0003o000001?o000000?ooo]Zo`000?l000006ol0000^oookJPKo000000Gooo]Zo`000?l0
003o0000oookJP0@o`0000;ooo]Z4?l00004oookJPSo0000<?oonfX:o`0000;ooo]Z1ol00004oook
JR;o0000;OoonfX005Cooo]Z7ol0000^oookJQ;o00000ooonfXEo`000003oookJ_l0003o000000co
0000;ooonfXFo`0000;ooo]Z3_l00002oookJP_o000000?ooo]Zo`000?l000001?l0000_oookJP?o
00000ooonfXMo`0000;ooo]Z1ol000000ooonf[o0000o`000009o`00033ooo]Z2_l000000ooonf[o
0000o`000007o`000003oookJ_l0003o000000Wo000000?ooo]Zo`000?l000005Ol0000^oookJP00
7?oonfX00ooMfFcooo]ZoookJP05oookJP03omgIK?oonf[ooo]Z02gooo]Z7ol0000^oookJS7o0000
0_oonfX7o`0002kooo]Z<ol000000ooonf[o0000o`000004o`0002oooo]Z0ol00004oookJQgo0000
00?ooo]Zo`000?l000001Ol000000ooonf[o0000o`000009o`0003;ooo]Z4_l000000ooonf[o0000
o`00000Jo`0000;ooo]Z1Ol0000^oookJP004OoonfX5o`00O`Gooo]Z00?ogMU/o`00OomEDgL01Ooo
nfX00omEDgOo001oolc8KP07oookJP?o001o1OoonfX5o`00Oa[ooo]Z4?l000000ooonf[o0000o`00
000<o`0002kooo]Z<Ol000000ooonf[o0000o`000006o`0002kooo]Z3ol000000ooonf[o0000o`00
000=o`0000Cooo]Z5ol0000_oookJP?o000000?ooo]Zo`000?l000007_l000000ooonf[o0000o`00
000@o`00033ooo]Z5Ol000000ooonf[o0000o`00000Ko`0000;ooo]Z0ol0000_oookJP004?oonfX7
o`00O`Gooo]Z00?oEE=go`00OomEDgL00ooonfX01?mEDgOo001oob4QO?o^jV/7oookJP?o001o1?oo
nfX7o`00OaWooo]Z7_l0000_oookJS[o0000;_oonfXPo`0000?ooo]Z5?l0000foookJPco00000ooo
nfXAo`000003oookJ_l0003o0000013o0000<?oonfX<o`0000?ooo]Z1ol00002oookJQ3o00000_oo
nfX:o`000004oookJ_l0003o0000o`0002oooo]Z000?oookJPCo001o00Cooo]Zo`00Ool007oo001o
1_oonfX02?mEDgOo001ooeECMooonf[oEE=go`00OolQ8Gcok^Y[2?oonfX3o`00O`Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007lIoookJQko0000<OoonfXfo`00037ooo]Z3ol000000ooonf[o0000o`00
0008o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?l0003o00000ooonfXAo`0003?ooo]Z
4?l000000ooonf[o0000o`00000?o`000003oookJ_l0003o0000013o0000<?oonfXXo`0000?ooo]Z
2ol0000aoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP06oeECMol007oo411mo`00OolQ8Gco
k^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfXNo`00037ooo]Z0ol000000ooonf[o
0000o`00000Go`000003oookJ_l0003o000000go000000?ooo]Zo`000?l000001_l0000foookJQ[o
000000?ooo]Zo`000?l000005Ol0000boookJS;o000000Cooo]Zo`000?l0003o0000<?oonfXho`00
02oooo]Z000EoookJP?o001o1ooonfX01?l@47go001oo`00OooMfF`:oookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007lHoookJQ_o0000=?oonfX3o`000003oookJ_l0003o000001Ko000000?ooo]Zo`00
0?l000005ol0000eoookJRco000000?ooo]Zo`000?l000001?l0000aoookJRWo000000?ooo]Zo`00
0?l000002Ol0000boookJPKo00000_oonfX`o`0002oooo]Z000EoookJP?o001o1_oonfX01_mEDgOo
001ooa0@OOl007oo8B5lonkZJ`Wooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z6_l0000i
oookJQ3o00000_oonfXPo`0003Cooo]Z;Ol00002oookJP?o0000<ooonfXPo`0000;ooo]Z4ol0000e
oookJP?o00000_oonfX3o`000003oookJ_l0003o000002[o0000;ooonfX0013ooo]Z0_l007l2oook
JPCo001o1OoonfX02?mEDgOo001ooeECMooonf[oEE=go`00OolQ8Gcok^Y[2?oonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o6?oonfXKo`0003Gooo]Z5?l000000ooonf[o0000o`00000No`0003?ooo]Z
6_l000000ooonf[o0000o`00000Fo`0003?ooo]Z5ol000000ooonf[o0000o`000009o`000003oook
J_l0003o0000013o0000=?oonfX3o`0000Cooo]Z;Ol0000`oookJP004?oonfX7o`00O`Gooo]Z00?o
EE=go`00OomEDgL00ooonfX01?mEDgOo001oob4QO?o^jV/7oookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007lHoookJQgo0000<_oonfXfo`0003?ooo]Z1?l000000ooonf[o0000o`00000Do`000003oook
J_l0003o000001Go0000=?oonfXZo`000003oookJ_l0003o000000So0000=?oonfX6o`000003oook
J_l0003o000000Wo00000_oonfXPo`00033ooo]Z000@oookJPKo001o1OoonfX00ooMfFco001ooeEC
M`05oookJP03oeECMol007ooc<Q^00Oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l0
07l;oookJQgo0000<_oonfXfo`0003?ooo]Z6ol000000ooonf[o0000o`00000Fo`0003?ooo]Z6?l0
00000ooonf[o0000o`00000Ao`000003oookJ_l0003o000000Ko0000=OoonfX5o`000003oookJ_l0
003o000000[o000000?ooo]Zo`000?l000007_l0000`oookJP004?oonfX2o`00O`[ooo]Z00?ogMU/
oookJ_oonfX01OoonfX00ooMfFcooo]ZoookJP03oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l;
oookJP03ob4QO?l007ooc<Q^00[ooo]Z7Ol0000boookJPKo00000_oonfXHo`000003oookJ_l0003o
0000017o0000=OoonfX<o`000003oookJ_l0003o000002Go0000<ooonfXAo`000003oookJ_l0003o
000001So000000?ooo]Zo`000?l000001Ol0000eoookJQ?o000000Cooo]Zo`000?l0003o00000_oo
nfXCo`000003oookJ_l0003o000000Go0000<?oonfX0013ooo]Z0_l007lHoookJPKo001o1?oonfX3
o`00O`04oookJ_l007oo001oo`00O`cooo]Z00?oEE=go`00OonHUW802_oonfXLo`0003?ooo]Z2_l0
00000ooonf[o0000o`00000Do`000003oookJ_l0003o0000013o0000=OoonfXPo`000003oookJ_l0
003o0000017o0000=OoonfXbo`0003Gooo]Z1ol000000ooonf[o0000o`00000Lo`000003oookJ_l0
003o000000_o0000<?oonfX0017ooo]Z1ol007lDoookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007l2
oookJP03ojVWLOl007ooEE=g00[ooo]Z6_l0000foookJS;o0000=_oonfXEo`0000;ooo]Z2Ol00000
0ooonf[o0000o`00000?o`0003Oooo]Z4?l00002oookJP?o000000?ooo]Zo`000?l000003Ol00003
oookJP[o0000=OoonfXWo`000003oookJ_l0003o000000[o0000<?oonfX0017ooo]Z1ol007lEoook
JP?o001o1OoonfX5o`00O`kooo]Z00?o411mo`00OooonfX02OoonfX<o`000003oookJ_l0003o0000
00Co00000_oonfX5o`0003Kooo]Z5ol000000ooonf[o0000o`00000Ho`0003Kooo]Z5_l000000ooo
nf[o0000o`000002o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l000003ol0000goook
JQGo00000_oonfX3o`000003oookJ_l0003o000000So00000ooonfX:o`0003Gooo]Z7Ol000000ooo
nf[o0000o`000007o`000003oookJ_l0003o000000[o0000<?oonfX004Sooo]Z00?oV9Ibo`00OonH
UW802OoonfX@o`0000Gooo]Z1?l0000goookJS7o0000=ooonfXTo`0000?ooo]Z0ol000000ooonf[o
0000o`000005o`0003Oooo]Z5Ol00002oookJQ7o00000_oonfX8o`0003Gooo]Z<ol0000aoookJP00
BOoonfX00olQ8Gco411moookJP08oookJQ3o00001OoonfX5o`0003Sooo]Z<?l0000foookJRKo0000
00?ooo]Zo`000?l000002?l0000hoookJQGo000000Gooo]Zo`000?l0003o0000oookJP0>o`000003
oookJ_l0003o000000Oo0000=OoonfX:o`000003oookJ_l0003o000000So000000?ooo]Zo`000?l0
00006_l0000boookJP00BOoonfX00oo<b6ko001oogMeM@08oookJPgo000000?ooo]Zo`000?l00000
1Ol00002oookJP?o0000>?oonfX`o`0003Sooo]Z:Ol000000ooonf[o0000o`000004o`0003Oooo]Z
1?l000000ooonf[o0000o`000007o`0000;ooo]Z1Ol000000ooonf[o0000o`000005o`000003oook
J_l0003o000001;o0000=OoonfXbo`0003;ooo]Z0016oookJPKo001o2?oonfXFo`000004oookJ_l0
003o0000o`0003Sooo]Z5_l00004oookJQKo0000>?oonfX9o`0000Cooo]Z8ol0000goookJQGo0000
00?ooo]Zo`000?l000006_l0000ioookJRko0000<_oonfX004Kooo]Z1_l007l8oookJQKo000000Co
oo]Zo`000?l0003o0000>OoonfX6o`000003oookJ_l0003o000000go000000?ooo]Zo`000?l00000
5_l0000hoookJP[o00000ooonfXSo`0003Oooo]Z5Ol000000ooonf[o0000o`00000Ho`0003Sooo]Z
<Ol0000boookJP00E?oonfXFo`0003cooo]Z5ol000000ooonf[o0000o`00000Eo`0003Wooo]Z3?l0
00000ooonf[o0000o`00000Po`0003Sooo]Z5Ol000000ooonf[o0000o`00000Ho`0003Sooo]Z<Ol0
000boookJP00E?oonfX4o`000003oookJ_l0003o0000017o0000>_oonfXQo`000003oookJ_l0003o
000000_o0000>_oonfX^o`0003Sooo]Z1?l00002oookJQko000000?ooo]Zo`000?l000002Ol0000h
oookJRco000000?ooo]Zo`000?l000000_l0000boookJP00E?oonfXJo`0003Sooo]Z8Ol00004oook
JP?o000000?ooo]Zo`000?l000001?l0000joookJQko00000ooonfX<o`0003cooo]Z2?l000000ooo
nf[o0000o`000002o`0000;ooo]Z7_l0000hoookJS7o0000<_oonfX005Cooo]Z5?l000000ooonf[o
0000o`000003o`0003Sooo]Z<?l0000joookJPko000000?ooo]Zo`000?l000003Ol00003oookJPKo
000000?ooo]Zo`000?l000000ol0000koookJPSo000000?ooo]Zo`000?l000008_l0000ioookJP_o
000000?ooo]Zo`000?l000003_l00002oookJQ7o0000<ooonfX005Cooo]Z4ol00002oookJPGo0000
>OoonfX_o`0003[ooo]Z1_l000000ooonf[o0000o`00000No`0000?ooo]Z0ol0000joookJPOo0000
0ooonfX6o`0000;ooo]Z4ol000000ooonf[o0000o`000005o`0003[ooo]Z2_l000000ooonf[o0000
o`00000Po`0003Gooo]Z001DoookJQ?o000000?ooo]Zo`000?l000000_l0000koookJRoo0000>_oo
nfXXo`0000;ooo]Z0ol0000joookJPWo000000?ooo]Zo`000?l000003?l000000ooonf[o0000o`00
000Bo`0003[ooo]Z2Ol000000ooonf[o0000o`000005o`000003oookJ_l0003o000001Wo0000=Ooo
nfX005Cooo]Z6?l0000koookJRko0000>ooonfXHo`0000;ooo]Z4ol0000joookJRgo0000>ooonfX8
o`000003oookJ_l0003o000001_o000000?ooo]Zo`000?l000000ol0000eoookJP00E?oonfXHo`00
03_ooo]Z7?l00003oookJPCo00000_oonfX9o`0003_ooo]Z5ol000000ooonf[o0000o`00000Bo`00
03cooo]Z6Ol000000ooonf[o0000o`00000?o`0003cooo]Z1?l00003oookJQoo000000?ooo]Zo`00
0?l000000ol0000eoookJP00E?oonfXHo`0003cooo]Z4Ol000000ooonf[o0000o`000009o`000003
oookJ_l0003o000000go0000>ooonfX/o`0003cooo]Z3ol000000ooonf[o0000o`000007o`0000;o
oo]Z3ol0000moookJQoo000000?ooo]Zo`000?l000002Ol0000foookJP00E?oonfX=o`000003oook
J_l0003o000000So0000??oonfXNo`000003oookJ_l0003o000000Oo0000@?oonfXBo`000003oook
J_l0003o000001Oo0000??oonfX?o`000003oookJ_l0003o000000;o000000?ooo]Zo`000?l00000
0_l00002oookJPoo0000?ooonfX=o`000003oookJ_l0003o000000Go000000?ooo]Zo`000?l00000
2_l00002oookJPKo0000=OoonfX005Cooo]Z6?l0000loookJPgo00000ooonfXIo`0003oooo]Z2ol0
00000ooonf[o0000o`000003o`0000;ooo]Z6?l0000moookJP?o000000?ooo]Zo`000?l000005?l0
0003oookJPko0000??oonfX/o`0003Gooo]Z001DoookJQ7o000000?ooo]Zo`000?l000001?l0000l
oookJPgo00000ooonfX8o`000003oookJ_l0003o000000ko0000@OoonfX9o`000003oookJ_l0003o
000000?o00000_oonfXCo`000003oookJ_l0003o000000;o0000?_oonfXDo`000003oookJ_l0003o
000001?o0000??oonfX/o`0003Gooo]Z001DoookJQ7o000000?ooo]Zo`000?l000000ol0000moook
JPco00001?oonfXIo`00043ooo]Z2_l000000ooonf[o0000o`000003o`0000?ooo]Z5ol0000noook
JQCo000000?ooo]Zo`000?l000004ol0000loookJPKo00000_oonfXTo`0003Gooo]Z001DoookJPgo
000000Gooo]Zo`000?l0003o0000oookJP03o`0003oooo]Z0ol00002oookJPSo00000ooonfXKo`00
03kooo]Z3_l00006oookJP?o000000?ooo]Zo`000?l000004?l0000noookJQCo000000?ooo]Zo`00
0?l000004_l0000noookJRCo00000_oonfX5o`0003Gooo]Z001DoookJQ7o00000ooonfX3o`00043o
oo]Z1Ol00002oookJPGo000000?ooo]Zo`000?l000006Ol0000noookJQ;o00001_oonfXBo`0003oo
oo]Z5?l000000ooonf[o0000o`00000Ao`0003kooo]Z:ol0000eoookJP00E?oonfXAo`0000;ooo]Z
1?l00010oookJPGo00000_oonfX5o`000003oookJ_l0003o000001Go000000Cooo]Zo`000?l0003o
0000@?oonfXBo`000003oookJ_l0003o000000[o000000?ooo]Zo`000?l000001_l0000ooookJROo
0000@?oonfX6o`0000;ooo]Z8?l0000goookJP00E?oonfXAo`0000;ooo]Z1?l0000ooookJQSo0000
00?ooo]Zo`000?l000003Ol00011oookJQ;o000000?ooo]Zo`000?l000000_l00003oookJPCo0000
00?ooo]Zo`000?l000000ol000001?oonf[o0000o`000?l00010oookJRKo0000@?oonfXXo`0003Oo
oo]Z001DoookJPko00000_oonfX6o`00043ooo]Z4ol000000ooonf[o0000o`00000Bo`00047ooo]Z
0ol000000ooonf[o0000o`00000Ao`000003oookJ_l0003o000000go0000?ooonfXXo`00043ooo]Z
:Ol0000foookJP00E?oonfX>o`0000;ooo]Z1_l00010oookJQOo000000?ooo]Zo`000?l000003_l0
0010oookJP?o00000_oonfXSo`0003oooo]Z7Ol000000ooonf[o0000o`000006o`0004Cooo]Z9ol0
000foookJP00E?oonfXFo`00043ooo]Z7Ol000000ooonf[o0000o`000008o`00043ooo]Z0ol00002
oookJQgo000000?ooo]Zo`000?l000000ol0000ooookJQKo000000?ooo]Zo`000?l000001?l00000
0ooonf[o0000o`000006o`0004Cooo]Z5Ol000000ooonf[o0000o`00000?o`0003Kooo]Z001Doook
JQKo0000@_oonfX?o`000003oookJ_l0003o0000013o0000A?oonfX3o`0000;ooo]Z5ol000000ooo
nf[o0000o`000003o`000003oookJ_l0003o000000;o0000@OoonfXLo`000003oookJ_l0003o0000
00Ko0000A?oonfX6o`000003oookJ_l0003o000000_o00000_oonfX@o`0003Oooo]Z001DoookJQKo
0000@_oonfX6o`000003oookJ_l0003o000001_o0000B?oonfXLo`0000;ooo]Z0ol00011oookJRGo
0000AOoonfXCo`000003oookJ_l0003o000000oo0000=ooonfX005Cooo]Z2?l000000ooonf[o0000
o`000009o`0004Cooo]Z1_l00002oookJPGo00000_oonfXFo`0004?ooo]Z8_l00015oookJRCo0000
AOoonfXBo`000003oookJ_l0003o0000013o0000=ooonfX005Cooo]Z2?l000000ooonf[o0000o`00
0009o`0004Cooo]Z1ol000000ooonf[o0000o`000003o`0000;ooo]Z0ol00002oookJPCo000000?o
oo]Zo`000?l000002_l00013oookJR?o0000A?oonfX;o`000003oookJ_l0003o000001Ko0000AOoo
nfXPo`000004oookJ_l0003o0000o`0003Sooo]Z001DoookJQCo0000A?oonfXBo`000003oookJ_l0
003o0000013o0000@ooonfXTo`0004Cooo]Z5?l000000ooonf[o0000o`00000;o`0004Kooo]Z6ol0
00001Ooonf[o0000o`000?l0003ooo]Z00Co0000>?oonfX005Cooo]Z5?l00014oookJP?o000000?o
oo]Zo`000?l000003?l000000ooonf[o0000o`00000<o`0004Oooo]Z1ol000000ooonf[o0000o`00
000Jo`0004Gooo]Z1Ol000000ooonf[o0000o`00000;o`000003oookJ_l0003o000000[o0000Aooo
nfXKo`000003oookJ_l0003o000000Go0000>OoonfX005Cooo]Z4_l00016oookJP?o00000_oonfX=
o`000003oookJ_l0003o000000Wo0000B_oonfX7o`0000Cooo]Z6Ol00015oookJR3o0000AooonfXB
o`0000;ooo]Z3ol0000ioookJP00E?oonfXBo`0004Kooo]Z0ol00002oookJPKo000000Cooo]Zo`00
0?l0003o00001OoonfX:o`0000;ooo]Z0ol00015oookJPoo000000?ooo]Zo`000?l000004Ol00015
oookJPco000000?ooo]Zo`000?l000003ol0001:oookJR7o0000>ooonfX005Cooo]Z4_l0001=oook
JPCo000000?ooo]Zo`000?l000001?l00002oookJP_o000000Cooo]Zo`000?l0003o0000A_oonfXG
o`000003oookJ_l0003o000000Ko0000AooonfX>o`000003oookJ_l0003o000000Co00001?oonfX5
o`000003oookJ_l0003o000000;o0000AOoonfX6o`000003oookJ_l0003o000001Wo0000>_oonfX0
05Cooo]Z4ol0001<oookJP?o00000_oonfXGo`0004Kooo]Z8?l00017oookJPko000000?ooo]Zo`00
0?l000000ol000000ooonf[o0000o`000007o`000003oookJ_l0003o000000;o0000AOoonfX6o`00
0005oookJ_l0003o0000o`000?oonfX05ol0000joookJP00E?oonfXCo`0004Sooo]Z0ol000000ooo
nf[o0000o`00000Go`0004Wooo]Z8?l0001:oookJP_o000000?ooo]Zo`000?l000000ol000000ooo
nf[o0000o`000007o`000003oookJ_l0003o000000;o0000B?oonfX7o`000003oookJ_l0003o0000
01Go0000>_oonfX005Cooo]Z2?l000000ooonf[o0000o`000008o`0004Oooo]Z8?l00017oookJP[o
000000?ooo]Zo`000?l000000_l000000ooonf[o0000o`000008o`0000;ooo]Z1?l0001:oookJP[o
00000_oonfX>o`0004kooo]Z7_l0000koookJP00E?oonfX7o`000003oookJ_l0003o000000So0000
B?oonfXPo`0004Sooo]Z6Ol00003oookJP?o0000B_oonfX>o`0000;ooo]Z1_l000000ooonf[o0000
o`000003o`0004kooo]Z7?l0000koookJP00E?oonfXBo`0004Sooo]Z8?l00018oookJP_o000000?o
oo]Zo`000?l000002_l00002oookJPGo0000B_oonfXLo`0004_ooo]Z7_l0000loookJP00E?oonfXA
o`0004gooo]Z4?l000000ooonf[o0000o`000007o`0004[ooo]Z1Ol00003oookJP?o000000?ooo]Z
o`000?l000004Ol00019oookJQoo0000BOoonfXNo`0003cooo]Z001DoookJQ7o0000BooonfXMo`00
04Wooo]Z7ol00019oookJQGo000000?ooo]Zo`000?l000001ol00019oookJPgo00000_oonfX?o`00
03cooo]Z001DoookJQ7o0000B_oonfX8o`000003oookJ_l0003o000001?o0000B_oonfXMo`0004[o
oo]Z4?l000000ooonf[o0000o`000002o`000003oookJ_l0003o000000Oo0000B_oonfXLo`0003go
oo]Z001DoookJPCo000000Gooo]Zo`000?l0003o0000oookJP08o`0004[ooo]Z4?l000000ooonf[o
0000o`00000;o`0004[ooo]Z7Ol0001;oookJQCo000000?ooo]Zo`000?l000001_l0001;oookJQco
0000?OoonfX005Cooo]Z1Ol00005oookJPOo0000B_oonfX;o`000003oookJ_l0003o000000Co0000
00?ooo]Zo`000?l000002Ol0001:oookJPKo000000?ooo]Zo`000?l000004ol0001<oookJPOo0000
00?ooo]Zo`000?l000004ol0001;oookJQco0000?OoonfX005Cooo]Z1Ol00005oookJPKo0000COoo
nfX9o`000003oookJ_l0003o000000Co000000?ooo]Zo`000?l000002?l0001>oookJP?o000000?o
oo]Zo`000?l000003ol000001?oonf[o0000o`000?l0001<oookJQgo0000COoonfXIo`0003kooo]Z
001DoookJPKo00000_oonfX8o`0004kooo]Z6?l0001>oookJQOo000000Cooo]Zo`000?l0003o0000
C?oonfX3o`000003oookJ_l0003o000001Oo0000C?oonfXJo`0003kooo]Z001DoookJPoo0000Cooo
nfX5o`0000?ooo]Z4Ol0001=oookJQ_o0000D?oonfXGo`0004kooo]Z6Ol0000ooookJP00E?oonfX?
o`0004oooo]Z1?l00004oookJQ7o0000COoonfXKo`0004oooo]Z1Ol000000ooonf[o0000o`00000@
o`0004kooo]Z1ol000000ooonf[o0000o`00000?o`0003oooo]Z001DoookJPgo0000DOoonfX3o`00
00;ooo]Z1?l00005oookJP_o0000C_oonfXIo`00053ooo]Z1Ol00003oookJPGo000000?ooo]Zo`00
0?l000002?l0001?oookJQSo0000?ooonfX005Cooo]Z3Ol0001BoookJPSo00001_oonfX9o`0004oo
oo]Z6Ol0001?oookJPgo00000_oonfX:o`0004oooo]Z6?l0000ooookJP00E?oonfX8o`000003oook
J_l0003o000000;o0000D_oonfX8o`0000Gooo]Z2?l0001AoookJPGo000000?ooo]Zo`000?l00000
2Ol00002oookJPKo0000CooonfXIo`0004oooo]Z5_l00011oookJP00E?oonfX8o`000004oookJ_l0
003o0000o`0005?ooo]Z2_l00003oookJPWo0000D_oonfX;o`000003oookJ_l0003o000000So0000
D?oonfXGo`0005?ooo]Z4_l00013oookJP00E?oonfX4o`000003oookJ_l0003o000000Go0000Dooo
nfX5o`000003oookJ_l0003o000000ko0000D_oonfX:o`000003oookJ_l0003o000000Go000000Co
oo]Zo`000?l0003o0000D_oonfXEo`0005?ooo]Z5Ol00010oookJP00E?oonfX<o`0005?ooo]Z1Ol0
00000ooonf[o0000o`000009o`000003oookJ_l0003o000000;o0000D_oonfXDo`0005Sooo]Z4Ol0
001EoookJQ?o0000@?oonfX005Cooo]Z3?l0001CoookJPGo000000?ooo]Zo`000?l000003Ol0001C
oookJQGo0000E?oonfXCo`0005Kooo]Z4ol00010oookJP00E?oonfX<o`0005Gooo]Z0ol000000ooo
nf[o0000o`00000;o`0005Gooo]Z5Ol0001DoookJP?o000000?ooo]Zo`000?l000003Ol0001Foook
JP?o00000_oonfX=o`00047ooo]Z001DoookJPco0000EOoonfXAo`0005Kooo]Z5?l0001DoookJQ;o
0000GooonfX9o`0004;ooo]Z000LoookJP03omgIK?oonf[ooo]Z00Gooo]Z00?ogMU/oookJ_oonfX0
;OoonfX;o`0005Oooo]Z4?l0001GoookJP?o000000?ooo]Zo`000?l000002ol0001GoookJQ7o0000
G?oonfX;o`0004?ooo]Z000CoookJP?o001o1OoonfX00ooMfFco001ooeECM`05oookJP03oeECMol0
07ooc<Q^00Oooo]Z0ol007l5oookJPGo001o6_oonfX;o`0005Oooo]Z3ol0001LoookJPco0000F?oo
nfX7o`000003oookJ_l0003o000000Co0000FooonfX?o`0004?ooo]Z000CoookJP?o001o1_oonfX0
0omEDgOo001ooeECM`03oookJP04oeECMol007oo8B5lonkZJ`Oooo]Z0ol007l4oookJPOo001o6Ooo
nfX9o`0005Wooo]Z3ol0001LoookJPco0000F?oonfX=o`0005cooo]Z3_l00014oookJP004ooonfX3
o`00O`Oooo]Z00SoEE=go`00OomEDgOooo]ZoeECMol007oo8B5lonkZJ`Sooo]Z0ol007l4oookJP?o
001o00Cooo]Zo`00Ool007oo001o6OoonfX8o`0005[ooo]Z1_l000000ooonf[o0000o`000006o`00
05cooo]Z3?l0001JoookJPco0000FooonfX=o`0004Gooo]Z000CoookJP?o001o2?oonfX01_mEDgOo
001ooa0@OOl007oo8B5lonkZJ`Wooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z2?l0001K
oookJPgo0000GOoonfX;o`0005cooo]Z2ol0001MoookJP_o0000AOoonfX001?ooo]Z0ol007l9oook
JP04oa0@OOl007oo001oomgIK0[ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OaSooo]Z1_l0001R
oookJPOo0000G_oonfX;o`0005cooo]Z2ol0001NoookJPWo0000A_oonfX001?ooo]Z0ol007l8oook
JP06oeECMol007oo411mo`00OolQ8Gcok^Y[2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oo
nfX6o`0006;ooo]Z1ol0001PoookJPGo0000HOoonfX:o`0005kooo]Z2Ol00016oookJP004ooonfX3
o`00O`Oooo]Z00SoEE=go`00OomEDgOooo]ZoeECMol007oo8B5lonkZJ`Sooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00OaSooo]Z1_l0001RoookJPCo0000HooonfX5o`00067ooo]Z2?l0001SoookJPGo
0000AooonfX001?ooo]Z0ol007l6oookJP03oeECMol007ooEE=g00?ooo]Z00CoEE=go`00OolQ8Gco
k^Y[1ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o6?oonfX4o`0006Gooo]Z0ol0001SoookJP?o
0000IOoonfX6o`0006Gooo]Z0ol00017oookJP004ooonfX3o`00O`Gooo]Z00?ogMU/o`00OomEDgL0
1OoonfX00omEDgOo001oolc8KP07oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lHoookJPCo0000
oooonf[YoookJP004?oonfX6o`00O`Kooo]Z00?ogMU/oookJ_oonfX01OoonfX00ooMfFcooo]Zoook
JP03oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l;oookJP04oiRFL_l007oo001oofITMPWooo]Z
1?l0003ooookJ^Wooo]Z000@oookJPKo001o5?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l;oookJP03omgIK?l007oo001o00;o001o00?oMgEeoookJ_oonfX01_oonfX4o`000?oooo]Z
jOoonfX001;ooo]Z1?l007lFoookJPCo001o1?oonfX7o`00O`_ooo]Z00KoEE=go`00Oonj^6oo^[Q_
o`00Ool@47d8oookJPCo0000oooonf[YoookJP004ooonfX3o`00OaOooo]Z0ol007l5oookJPGo001o
1?oonfX7o`00O`03oookJ_l@47go001o00;ooo]Z0_l007l8oookJPCo0000oooonf[YoookJP00A_oo
nfX2o`00O`;o^[Q_0_l007l8oookJPCo0000oooonf[YoookJP00A_oonfX5o`00O`03oeECMooonf[o
oo]Z00Kooo]Z1?l0003ooookJ^Wooo]Z0016oookJP06oa0@OOl007ooEE=go`00Oolb<W[ok^Y[2?oo
nfX4o`000?oooo]ZjOoonfX004Kooo]Z00CoEE=go`00Oon7QG?oc<Q^0_mgMGGooookJ_Gooo]Z0016
oookJP03olc8K_l007oo001o00;o001o00?oEE=goookJ_oonfX0oooonf[coookJP00AooonfX01OnY
Yg7o411mo`00OomEDgOok^Y[0?oooo]ZmOoonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-3748.55, -1.24197*^-6, \
43.3371, 6.99822*^-9}},
  CellTags->"mmtag:23:noise__periodic_bias"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:23:noise__periodic_bias"]
}, Open  ]],

Cell["Resonance Phenomena by Solution of the ODE", "Subtitle"],

Cell[TextData[{
  "The \"periodic forcing function\" can be any periodic function (i.e., a \
fourier series), but it is a bit simpler to analyze the effect of each mode \
separately.  Below, the forcing function will be assumed to be ",
  Cell[BoxData[
      \(TraditionalForm\`F\_app\)]],
  "cos(",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_app\)]],
  "t)\nSolve problems in terms of the mass and natural frequency--eliminate \
the spring constant in equations by defining it in terms of the mass and \
natural frequency."
}], "Text",
  CellTags->{"mmtag:23:resonance_phenomena", "mmtag:23:natural_frequency"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kspring\  = \ \ M\ \[Omega]char\^2\)], "Input"],

Cell[BoxData[
    \(M\ \[Omega]char\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve the nonhomogeneous ODE with a  forcing function at with an \
applied frequency:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yGeneralSol\  = \ 
      DSolve[M\ \(y''\)[t]\  + \ \[Eta]\ \(y'\)[t]\  + \ 
              Kspring\ y[t]\  \[Equal] \ Fapp\ Cos[\[Omega]app\ t], y[t], t] // 
        Flatten\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"],

Cell[BoxData[
    \({y[t] \[Rule] \[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) - \@\(\[Eta]\^2 - \
4\ M\^2\ \[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[
              1] + \[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) + \@\(\[Eta]\^2 - 4\
\ M\^2\ \[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[
              2] - \(4\ \((\(-Fapp\)\ M\^3\ \[Omega]app\^2\ Cos[t\ \
\[Omega]app] + Fapp\ M\^3\ \[Omega]char\^2\ Cos[t\ \[Omega]app] + Fapp\ M\^2\ \
\[Eta]\ \[Omega]app\ Sin[t\ \[Omega]app])\)\)\/\(\((\[Eta]\^2 + 2\ M\^2\ \
\[Omega]app\^2 - 2\ M\^2\ \[Omega]char\^2 + \[Eta]\ \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\ \((\(-\[Eta]\^2\) - 2\ M\^2\ \[Omega]app\^2 + 2\ M\^2\ \
\[Omega]char\^2 + \[Eta]\ \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\)}\)], "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"]
}, Open  ]],

Cell[TextData[{
  "The general solution of the heterogeneous ODE is the sum of the \
homogeneous solution  (i.e., the one for which the right-hand-side is zero) \
and the particular solution (i.e., the one for the",
  StyleBox[" particular ",
    FontSlant->"Italic"],
  "right-hand-side of the ODE)"
}], "Text",
  CellTags->
  "mmtag:23:harmonic_oscillator__homogeneous_and_particular_solutions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yParticular[
        0]\  = \ \((y[t] /. yGeneralSol)\) /. {C[1] \[Rule] 0, 
          C[2] \[Rule] 0}\)], "Input"],

Cell[BoxData[
    \(\(-\(\(4\ \((\(-Fapp\)\ M\^3\ \[Omega]app\^2\ Cos[t\ \[Omega]app] + 
                Fapp\ M\^3\ \[Omega]char\^2\ Cos[t\ \[Omega]app] + 
                Fapp\ M\^2\ \[Eta]\ \[Omega]app\ Sin[
                    t\ \[Omega]app])\)\)\/\(\((\[Eta]\^2 + 
                2\ M\^2\ \[Omega]app\^2 - 
                2\ M\^2\ \[Omega]char\^2 + \[Eta]\ \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\ \((\(-\[Eta]\^2\) - 2\ M\^2\ \[Omega]app\^2 + 
                2\ M\^2\ \[Omega]char\^2 + \[Eta]\ \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(yParticular[1]\  = \ 
      Collect[FullSimplify[yParticular[0]], {Sin[t\ \[Omega]app], \ 
          Cos[t\ \[Omega]app]}]\)], "Input"],

Cell[BoxData[
    \(\(Fapp\ M\ \((\(-\[Omega]app\^2\) + \[Omega]char\^2)\)\ Cos[t\ \
\[Omega]app]\)\/\(\[Eta]\^2\ \[Omega]app\^2 + M\^2\ \((\[Omega]app\^2 - \
\[Omega]char\^2)\)\^2\) + \(Fapp\ \[Eta]\ \[Omega]app\ Sin[t\ \
\[Omega]app]\)\/\(\[Eta]\^2\ \[Omega]app\^2 + M\^2\ \((\[Omega]app\^2 - \
\[Omega]char\^2)\)\^2\)\)], "Output"]
}, Open  ]],

Cell["\<\
The particular solutions only picks up modes from the forcing \
term\
\>", "Text"],

Cell["The homogeneous solution only has he natural frequencies", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yHomogenous\  = \((y[t] /. yGeneralSol)\)\  - \ 
        yParticular[0]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) - \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[
          1] + \[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) + \@\(\[Eta]\^2 - 4\ \
M\^2\ \[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[2]\)], "Output"]
}, Open  ]],

Cell["\<\
The General Solution is the combination of two different \
frequencies--this should give rise to beats if the driving frequency differs \
from the natural frequency\
\>", "Text"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) - \@\(\[Eta]\^2 - 4\ M\^2\ \
\[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[
          1] + \[ExponentialE]\^\(\(t\ \((\(-\[Eta]\) + \@\(\[Eta]\^2 - 4\ \
M\^2\ \[Omega]char\^2\))\)\)\/\(2\ M\)\)\ C[2]\)], "Output"],

Cell["\<\
The following shows that the solution is unphysical when \
\[Omega]app \[Rule] \[Omega]char AND \[Eta]\[Rule]0\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(singbehav\  = 
      Series[\((yParticular[
                1] /. {\[Eta]\  \[Rule] \ \ \[Delta]\ \[Eta]0\ , \ \
\[Omega]app\  \[Rule] \ \[Omega]char\  + \ \[Epsilon]\ \[Omega]0})\), {\
\[Delta], 0, 1}, {\[Epsilon], 0, 1}] // Normal\)], "Input",
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"],

Cell[BoxData[""], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"],

Cell[BoxData[
    \(\(Fapp\ Cos[t\ \[Omega]char]\)\/\(4\ M\ \[Omega]char\^2\) + \
\(\(-\(\(Fapp\ Cos[t\ \[Omega]char]\)\/\(2\ M\ \[Omega]0\ \[Omega]char\)\)\) \
+ \(Fapp\ t\ \[Delta]\ \[Eta]0\ Cos[t\ \[Omega]char]\)\/\(4\ M\^2\ \[Omega]0\ \
\[Omega]char\)\)\/\[Epsilon] + \(Fapp\ t\ Sin[t\ \[Omega]char]\)\/\(2\ M\ \
\[Omega]char\) + \(Fapp\ \[Delta]\ \[Eta]0\ Sin[t\ \[Omega]char]\)\/\(4\ M\^2\
\ \[Epsilon]\^2\ \[Omega]0\^2\ \[Omega]char\) + \[Delta]\ \((\(-\(\(Fapp\ \
\[Eta]0\ Sin[
                      t\ \[Omega]char]\)\/\(16\ M\^2\ \[Omega]char\^3\)\)\) - \
\(Fapp\ t\^2\ \[Eta]0\ Sin[t\ \[Omega]char]\)\/\(8\ M\^2\ \[Omega]char\))\) + \
\[Epsilon]\ \((\(-\(\(Fapp\ \[Omega]0\ Cos[
                      t\ \[Omega]char]\)\/\(8\ M\ \[Omega]char\^3\)\)\) + \
\(Fapp\ t\^2\ \[Omega]0\ Cos[t\ \[Omega]char]\)\/\(4\ M\ \[Omega]char\) - \
\(Fapp\ t\ \[Omega]0\ Sin[t\ \[Omega]char]\)\/\(4\ M\ \[Omega]char\^2\) + \
\[Delta]\ \((\(-\(\(Fapp\ t\ \[Eta]0\ \[Omega]0\ Cos[
                            t\ \[Omega]char]\)\/\(16\ M\^2\ \[Omega]char\^3\)\
\)\) - \(Fapp\ t\^3\ \[Eta]0\ \[Omega]0\ Cos[t\ \[Omega]char]\)\/\(24\ M\^2\ \
\[Omega]char\) + \(Fapp\ \[Eta]0\ \[Omega]0\ Sin[t\ \[Omega]char]\)\/\(16\ \
M\^2\ \[Omega]char\^4\))\))\)\)], "Output",
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We can determine the behavir near the singularity by looking at the \
effect of each term above:
\t1. If the forcing frequency approaches the resonance frequency (\[Epsilon]\
\[Rule]0), the solution is unbounded because there is no \[Delta] in the \
first part of the second term's numerator
\t2. If the viscosity approaches zero (\[Delta]\[Rule]0), the solution will \
have a linearly growing applitude because of the third term
\t3. Other cases will depend on how the ratio \[Delta]/\[Epsilon] \
scales.\
\>", "Subsubsection"],

Cell["\<\
The following demonstrates the zero viscosity case, needs to be \
analyzed carefully (as above) otherwise one might miss terms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yparticularUndamped\  = \ yParticular[1] /. \[Eta] \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(Fapp\ \((\(-\[Omega]app\^2\) + \[Omega]char\^2)\)\ Cos[t\ \
\[Omega]app]\)\/\(M\ \((\[Omega]app\^2 - \[Omega]char\^2)\)\^2\)\)], "Output"]
}, Open  ]],

Cell["Visualizing Solutions", "Subtitle",
  CellTags->
  "mmtag:23:harmonic_oscillator__visualization_function_for_damped_forced"],

Cell[TextData[{
  "Create a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  function that returns the solution for specified mass, viscous term, \
characteristic and applied frequencies"
}], "Text"],

Cell[BoxData[
    \(y[M_\ , \ \[Eta]_\ , \ \[Omega]char_, \ \[Omega]app_] := \ 
      Chop[y[t] /. 
            DSolve[{M\ \(y''\)[t]\  + \ \[Eta]\ \(y'\)[t]\  + \ 
                    M\ \ \[Omega]char^2\ y[
                        t]\  \[Equal] \ \ Cos[\[Omega]app\ t], 
                y[0] == 1, \(y'\)[0] == 0}, y[t], t] // Flatten]\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example_solution_function_for_damped_forced"],\


Cell["Experiment by plotting for many different values:", "Text"],

Cell["Undamped Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1, 0, 1/2, 1/2]], {t, 0, 200}, 
      PlotPoints \[Rule] 200]\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.313764 0.00151094 [
[.2619 .30126 -12 -20 ]
[.2619 .30126 12 0 ]
[.5 .30126 -17 -20 ]
[.5 .30126 17 0 ]
[.7381 .30126 -17 -20 ]
[.7381 .30126 17 0 ]
[.97619 .30126 -17 -20 ]
[.97619 .30126 17 0 ]
[.01131 .01158 -46.9375 -10 ]
[.01131 .01158 0 10 ]
[.01131 .16267 -46.9375 -10 ]
[.01131 .16267 0 10 ]
[.01131 .46486 -34 -10 ]
[.01131 .46486 0 10 ]
[.01131 .61595 -34 -10 ]
[.01131 .61595 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .31376 m
.2619 .32001 L
s
gsave
.2619 .30126 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .31376 m
.5 .32001 L
s
gsave
.5 .30126 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .31376 m
.7381 .32001 L
s
gsave
.7381 .30126 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .31376 m
.97619 .32001 L
s
gsave
.97619 .30126 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .31376 m
.07143 .31751 L
s
.11905 .31376 m
.11905 .31751 L
s
.16667 .31376 m
.16667 .31751 L
s
.21429 .31376 m
.21429 .31751 L
s
.30952 .31376 m
.30952 .31751 L
s
.35714 .31376 m
.35714 .31751 L
s
.40476 .31376 m
.40476 .31751 L
s
.45238 .31376 m
.45238 .31751 L
s
.54762 .31376 m
.54762 .31751 L
s
.59524 .31376 m
.59524 .31751 L
s
.64286 .31376 m
.64286 .31751 L
s
.69048 .31376 m
.69048 .31751 L
s
.78571 .31376 m
.78571 .31751 L
s
.83333 .31376 m
.83333 .31751 L
s
.88095 .31376 m
.88095 .31751 L
s
.92857 .31376 m
.92857 .31751 L
s
.01 w
0 .31376 m
1 .31376 L
s
.25 Mabswid
.02381 .01158 m
.03006 .01158 L
s
gsave
.01131 .01158 -107.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.02381 .16267 m
.03006 .16267 L
s
gsave
.01131 .16267 -107.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.02381 .46486 m
.03006 .46486 L
s
gsave
.01131 .46486 -95 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.02381 .61595 m
.03006 .61595 L
s
gsave
.01131 .61595 -95 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0418 m
.02756 .0418 L
s
.02381 .07201 m
.02756 .07201 L
s
.02381 .10223 m
.02756 .10223 L
s
.02381 .13245 m
.02756 .13245 L
s
.02381 .19289 m
.02756 .19289 L
s
.02381 .22311 m
.02756 .22311 L
s
.02381 .25333 m
.02756 .25333 L
s
.02381 .28355 m
.02756 .28355 L
s
.02381 .34398 m
.02756 .34398 L
s
.02381 .3742 m
.02756 .3742 L
s
.02381 .40442 m
.02756 .40442 L
s
.02381 .43464 m
.02756 .43464 L
s
.02381 .49508 m
.02756 .49508 L
s
.02381 .5253 m
.02756 .5253 L
s
.02381 .55551 m
.02756 .55551 L
s
.02381 .58573 m
.02756 .58573 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .31528 m
.02395 .31528 L
.02408 .31528 L
.02423 .31528 L
.02437 .31528 L
.02462 .31529 L
.02489 .3153 L
.02519 .31532 L
.02551 .31535 L
.02608 .3154 L
.02722 .31556 L
.02847 .31579 L
.03109 .31645 L
.03355 .31719 L
.03579 .31785 L
.03697 .31815 L
.03823 .31842 L
.03892 .31853 L
.03955 .31862 L
.03985 .31865 L
.04018 .31868 L
.04033 .31869 L
.04049 .3187 L
.04064 .31871 L
.04078 .31871 L
.04093 .31872 L
.04106 .31872 L
.04121 .31872 L
.0413 .31872 L
.04137 .31872 L
.0415 .31872 L
.04164 .31872 L
.04179 .31871 L
.04193 .31871 L
.04209 .3187 L
.04225 .31869 L
.04254 .31866 L
.04285 .31863 L
.0432 .31859 L
.04384 .31847 L
.04444 .31834 L
.04556 .31799 L
.04678 .3175 L
.04809 .31681 L
.05049 .31517 L
.05303 .31294 L
.05759 .30814 L
.06014 .3054 L
.06246 .30311 L
.06361 .30212 L
Mistroke
.06486 .30119 L
.06604 .30047 L
.06714 .29995 L
.06774 .29974 L
.06806 .29966 L
.06839 .29958 L
.06867 .29953 L
.06882 .2995 L
.06898 .29948 L
.06912 .29947 L
.06926 .29946 L
.06939 .29945 L
.06952 .29945 L
.06966 .29945 L
.06975 .29945 L
.06983 .29945 L
.06998 .29945 L
.07007 .29946 L
.07015 .29946 L
.07029 .29948 L
.07043 .29949 L
.07073 .29954 L
.07106 .29961 L
.07142 .2997 L
.07205 .29992 L
.07269 .30022 L
.07329 .30056 L
.07463 .30156 L
.07581 .30269 L
.07706 .30415 L
.08164 .31139 L
.08651 .32109 L
.0912 .33005 L
.09242 .33201 L
.09376 .33387 L
.09491 .33521 L
.09552 .33581 L
.09618 .33637 L
.09682 .33681 L
.09741 .33712 L
.09797 .33734 L
.09825 .33743 L
.0984 .33746 L
.09856 .33749 L
.09873 .33752 L
.09881 .33752 L
.0989 .33753 L
.09905 .33754 L
.0992 .33755 L
.09928 .33755 L
Mistroke
.09936 .33754 L
.09952 .33753 L
.09961 .33752 L
.0997 .33751 L
.09987 .33749 L
.10018 .33742 L
.10046 .33734 L
.1011 .33707 L
.10171 .3367 L
.10237 .33619 L
.10357 .33496 L
.10474 .33339 L
.10582 .33164 L
.11058 .32082 L
.11516 .30744 L
.12004 .2934 L
.12229 .28806 L
.12348 .28572 L
.12474 .28366 L
.12537 .2828 L
.12607 .28201 L
.12671 .28142 L
.1273 .28101 L
.12759 .28084 L
.1279 .28071 L
.12821 .28061 L
.12839 .28056 L
.12847 .28055 L
.12855 .28053 L
.12871 .28051 L
.12885 .2805 L
.12899 .2805 L
.12912 .28051 L
.12926 .28052 L
.12942 .28054 L
.12958 .28057 L
.12973 .28061 L
.13004 .28072 L
.13033 .28085 L
.13098 .28127 L
.13156 .28177 L
.13218 .28243 L
.13335 .2841 L
.13441 .28603 L
.13674 .29159 L
.13925 .29937 L
.14421 .31815 L
.14898 .33667 L
.15138 .34461 L
.15357 .35038 L
Mistroke
.15478 .35284 L
.15593 .35462 L
.15655 .35535 L
.15714 .35587 L
.15744 .35609 L
.15777 .35627 L
.15794 .35634 L
.15812 .35641 L
.15829 .35645 L
.15845 .35649 L
.1586 .3565 L
.15875 .35651 L
.15888 .35651 L
.15902 .3565 L
.15918 .35647 L
.15926 .35646 L
.15934 .35644 L
.15964 .35634 L
.15991 .35621 L
.16021 .35603 L
.16074 .3556 L
.16141 .35487 L
.16205 .35398 L
.16324 .3518 L
.1644 .34906 L
.16564 .34551 L
.16786 .33766 L
.17241 .3172 L
.17726 .29324 L
.17948 .28314 L
.18192 .27371 L
.18309 .27 L
.18434 .26671 L
.18503 .26521 L
.18565 .26406 L
.18625 .26316 L
.18688 .26242 L
.18716 .26216 L
.18745 .26193 L
.18762 .26183 L
.18778 .26174 L
.18794 .26167 L
.18808 .26162 L
.18822 .26158 L
.18836 .26155 L
.18851 .26153 L
.18865 .26153 L
.18879 .26153 L
.18893 .26155 L
.18907 .26158 L
Mistroke
.18919 .26162 L
.18934 .26167 L
.1895 .26174 L
.18978 .2619 L
.19011 .26215 L
.19041 .26244 L
.19108 .26324 L
.1917 .26424 L
.19287 .26669 L
.19411 .2701 L
.19633 .27818 L
.20089 .30098 L
.20574 .32969 L
.21041 .35496 L
.21283 .36498 L
.21405 .36889 L
.21473 .37072 L
.21538 .37218 L
.21597 .37331 L
.21662 .37427 L
.2169 .3746 L
.21721 .3749 L
.21749 .37513 L
.21775 .37529 L
.2179 .37536 L
.21805 .37541 L
.2182 .37546 L
.21829 .37547 L
.21837 .37548 L
.2185 .37549 L
.21865 .37548 L
.21881 .37546 L
.21895 .37543 L
.21903 .3754 L
.21911 .37537 L
.21928 .37529 L
.21959 .3751 L
.21994 .3748 L
.22027 .37444 L
.22088 .37359 L
.22154 .37238 L
.22274 .36944 L
.2239 .3657 L
.22498 .36151 L
.22972 .33599 L
.23429 .30499 L
.23915 .27287 L
.24138 .26072 L
.24382 .25055 L
.24446 .24851 L
Mistroke
.24515 .24666 L
.24574 .24532 L
.24637 .24416 L
.24672 .24367 L
.24703 .24329 L
.24733 .24301 L
.24748 .24289 L
.24765 .24278 L
.24779 .2427 L
.24793 .24264 L
.24807 .24259 L
.24819 .24257 L
.24834 .24255 L
.24848 .24255 L
.24864 .24257 L
.24871 .24258 L
.2488 .24261 L
.24894 .24266 L
.24908 .24272 L
.24939 .24293 L
.24969 .24319 L
.25002 .24356 L
.2506 .24444 L
.25113 .24546 L
.25243 .24887 L
.25365 .25322 L
.25606 .26484 L
.25829 .27859 L
.26304 .31425 L
.26761 .3499 L
.27015 .36721 L
.27248 .38002 L
.27363 .38502 L
.27488 .38934 L
.27545 .3909 L
.27606 .39225 L
.27664 .39324 L
.27716 .39389 L
.27744 .39414 L
.2776 .39425 L
.27775 .39434 L
.27791 .3944 L
.27799 .39443 L
.27807 .39445 L
.27822 .39447 L
.27837 .39447 L
.27851 .39446 L
.27865 .39442 L
.27881 .39436 L
.27895 .39429 L
Mistroke
.27921 .39411 L
.27949 .39385 L
.27981 .39347 L
.28016 .39294 L
.2808 .39171 L
.282 .38842 L
.28324 .38373 L
.28437 .3784 L
.2869 .36308 L
.29173 .32438 L
.29637 .2831 L
.29873 .26382 L
.30132 .24583 L
.3025 .23908 L
.30378 .23307 L
.30498 .22867 L
.3055 .22717 L
.30608 .22581 L
.30665 .22476 L
.30697 .22432 L
.30727 .224 L
.3074 .22388 L
.30755 .22378 L
.30767 .22371 L
.3078 .22365 L
.30794 .2236 L
.30807 .22357 L
.30823 .22356 L
.30837 .22358 L
.30853 .22361 L
.30861 .22364 L
.3087 .22368 L
.30885 .22377 L
.30899 .22387 L
.30931 .22417 L
.30966 .22462 L
.3103 .22574 L
.31088 .22711 L
.31207 .23094 L
.31317 .23568 L
.31567 .25034 L
.32039 .28969 L
.32541 .33911 L
.32793 .36275 L
.33025 .38184 L
.33251 .39688 L
.33365 .4028 L
.33429 .40559 L
.3349 .40787 L
.33549 .40972 L
Mistroke
.33613 .41131 L
.33641 .41188 L
.33671 .41239 L
.337 .41277 L
.33725 .41305 L
.3374 .41318 L
.33755 .41328 L
.33771 .41337 L
.33779 .4134 L
.33787 .41343 L
.33802 .41345 L
.33815 .41346 L
.33831 .41344 L
.33845 .41339 L
.33853 .41336 L
.33861 .41332 L
.33878 .41321 L
.33909 .41293 L
.33944 .41248 L
.33978 .41193 L
.34038 .41063 L
.34103 .40877 L
.34223 .40421 L
.34339 .39838 L
.34446 .3918 L
.34919 .35185 L
.35422 .29814 L
.35674 .27121 L
.35906 .24873 L
.36147 .22911 L
.36372 .21545 L
.36482 .21066 L
.36538 .20872 L
.36599 .20703 L
.36634 .20626 L
.36667 .20568 L
.36697 .20524 L
.36713 .20505 L
.3673 .20489 L
.36745 .20477 L
.36759 .20469 L
.36773 .20463 L
.36787 .20459 L
.36802 .20458 L
.36816 .20459 L
.36832 .20463 L
.36841 .20467 L
.36849 .20471 L
.36877 .20492 L
.36893 .20508 L
Mistroke
.36908 .20525 L
.3694 .20573 L
.3697 .20627 L
.37023 .20753 L
.37081 .20926 L
.3721 .21452 L
.37332 .22123 L
.37572 .23889 L
.37794 .25972 L
.38268 .31323 L
.38723 .36631 L
.38976 .39194 L
.39208 .41095 L
.39326 .41854 L
.39435 .42421 L
.39549 .42859 L
.3961 .43026 L
.39641 .43094 L
.39674 .43152 L
.39705 .43194 L
.39722 .43212 L
.39739 .43225 L
.39753 .43234 L
.39767 .4324 L
.39783 .43244 L
.39798 .43244 L
.39806 .43243 L
.39814 .43241 L
.39823 .43238 L
.39831 .43235 L
.39846 .43226 L
.39862 .43213 L
.3988 .43195 L
.39898 .43172 L
.39932 .43118 L
.39992 .42986 L
.40048 .4282 L
.40175 .42297 L
.40301 .41579 L
.40421 .4073 L
.40645 .38739 L
.41107 .33403 L
.416 .27094 L
.41845 .24222 L
.42074 .21923 L
.42293 .2021 L
.42417 .19495 L
.4253 .19012 L
.42587 .18832 L
.42619 .18752 L
Mistroke
.42648 .18689 L
.42676 .18642 L
.42691 .18621 L
.42706 .18602 L
.42719 .18589 L
.42733 .18577 L
.42746 .18569 L
.42758 .18564 L
.42774 .1856 L
.42783 .18559 L
.42791 .1856 L
.42806 .18563 L
.42821 .18569 L
.42836 .18578 L
.42849 .18589 L
.42879 .18623 L
.42911 .18674 L
.42941 .18734 L
.43008 .18914 L
.43065 .19117 L
.43126 .19383 L
.43236 .19988 L
.43486 .21923 L
.43743 .24619 L
.43986 .27654 L
.44449 .34037 L
.44684 .37179 L
.44942 .40264 L
.45187 .42624 L
.45297 .43456 L
.45417 .44185 L
.45482 .44498 L
.45542 .44734 L
.456 .44911 L
.45629 .44982 L
.45661 .45045 L
.45677 .45069 L
.45693 .45091 L
.45708 .45108 L
.45722 .45121 L
.45735 .4513 L
.45749 .45138 L
.45764 .45142 L
.45779 .45143 L
.45792 .45141 L
.45805 .45136 L
.45818 .45129 L
.45833 .45117 L
.45858 .45091 L
.45885 .45052 L
Mistroke
.45913 .44999 L
.45944 .44926 L
.46007 .44737 L
.46064 .4451 L
.46118 .44255 L
.4624 .43525 L
.4637 .42522 L
.46627 .39922 L
.4687 .36863 L
.47335 .30122 L
.47828 .23159 L
.48074 .20349 L
.48194 .19221 L
.48304 .18355 L
.48417 .17638 L
.48524 .17134 L
.48583 .16933 L
.48637 .16796 L
.48669 .16738 L
.48697 .167 L
.48713 .16684 L
.48721 .16677 L
.4873 .16672 L
.48738 .16668 L
.48746 .16664 L
.48761 .16661 L
.48777 .16662 L
.48791 .16666 L
.48799 .16669 L
.48807 .16674 L
.48824 .16688 L
.48839 .16703 L
.48855 .16724 L
.48884 .16773 L
.48914 .16838 L
.48943 .16913 L
.48997 .1709 L
.49117 .17653 L
.49249 .18523 L
.49486 .20708 L
.49739 .23788 L
.5024 .31329 L
.50723 .38784 L
.50945 .41727 L
.51071 .4317 L
.51188 .4434 L
.51314 .45378 L
.51428 .46117 L
.51487 .46414 L
.51551 .46674 L
Mistroke
.51586 .46787 L
.51618 .46874 L
.51649 .4694 L
.51665 .46967 L
.51682 .46992 L
.51696 .47009 L
.51711 .47022 L
.51727 .47033 L
.51741 .47039 L
.51756 .47041 L
.5177 .4704 L
.51782 .47036 L
.51795 .47029 L
.5181 .47018 L
.51826 .47001 L
.51859 .46954 L
.51889 .46893 L
.51917 .46823 L
.51973 .46644 L
.52023 .46435 L
.52138 .45807 L
.52256 .4493 L
.52367 .43922 L
.52617 .41022 L
.53089 .33845 L
.53591 .25457 L
.53843 .21658 L
.54075 .18728 L
.54301 .1656 L
.54415 .15772 L
.54479 .15424 L
.5454 .15161 L
.54599 .14968 L
.54633 .14887 L
.54663 .1483 L
.54689 .14795 L
.54704 .14781 L
.54718 .14771 L
.54732 .14765 L
.54746 .14762 L
.5476 .14763 L
.54776 .14768 L
.54792 .14778 L
.54806 .14791 L
.54823 .14811 L
.54838 .14834 L
.54866 .14887 L
.54896 .14959 L
.54965 .15186 L
.55028 .1547 L
Mistroke
.55145 .16183 L
.55255 .1706 L
.55504 .19754 L
.55972 .2686 L
.56471 .35693 L
.5672 .39881 L
.56951 .43282 L
.57174 .4594 L
.57287 .46994 L
.57348 .47473 L
.57412 .47907 L
.5747 .48237 L
.57534 .48526 L
.57562 .4863 L
.57591 .48724 L
.57619 .48797 L
.57645 .48851 L
.57661 .48877 L
.57678 .48901 L
.57695 .48919 L
.57704 .48927 L
.57713 .48932 L
.57721 .48936 L
.57729 .48939 L
.57744 .4894 L
.57759 .48937 L
.57768 .48933 L
.57777 .48928 L
.57792 .48915 L
.57807 .48898 L
.57835 .48855 L
.57864 .48793 L
.57896 .48706 L
.57956 .48494 L
.58011 .48236 L
.58137 .47436 L
.5826 .46384 L
.58391 .44974 L
.5889 .37482 L
.5937 .28548 L
.59833 .20454 L
.60071 .17119 L
.60193 .15737 L
.60325 .14529 L
.60384 .14083 L
.60447 .13686 L
.60505 .13387 L
.60559 .13168 L
.6061 .13015 L
.60639 .12953 L
Mistroke
.60665 .1291 L
.6068 .12892 L
.60693 .12879 L
.60708 .1287 L
.60724 .12864 L
.60738 .12864 L
.60751 .12867 L
.60765 .12874 L
.6078 .12886 L
.60796 .12905 L
.60811 .12926 L
.60843 .12989 L
.60874 .13067 L
.60902 .13157 L
.60966 .13419 L
.61035 .13795 L
.61162 .14721 L
.61278 .15834 L
.61505 .18682 L
.61755 .22653 L
.62243 .31968 L
.62713 .40963 L
.62952 .44836 L
.63078 .46562 L
.63212 .48109 L
.63331 .49212 L
.63394 .49687 L
.63462 .5011 L
.63525 .50414 L
.63552 .50522 L
.63582 .50622 L
.63608 .50694 L
.63636 .50756 L
.63652 .50782 L
.63666 .50802 L
.6368 .50818 L
.63694 .50829 L
.63707 .50836 L
.63722 .50839 L
.63737 .50837 L
.6375 .50832 L
.63765 .50821 L
.63773 .50813 L
.63781 .50804 L
.63811 .50758 L
.6384 .50696 L
.63871 .50606 L
.63935 .50361 L
.63991 .5008 L
.6405 .49705 L
Mistroke
.64158 .48844 L
.644 .46112 L
.64654 .42192 L
.65113 .33305 L
.65602 .23267 L
.65828 .19143 L
.66073 .15419 L
.66206 .13803 L
.6633 .12614 L
.66448 .11767 L
.66507 .11452 L
.66538 .11317 L
.66573 .11195 L
.66605 .11102 L
.66621 .11066 L
.66635 .11038 L
.66649 .11015 L
.66664 .10995 L
.6668 .10979 L
.66695 .1097 L
.66709 .10965 L
.66723 .10965 L
.66739 .10971 L
.66753 .10981 L
.66767 .10994 L
.66779 .1101 L
.66807 .11058 L
.66839 .11136 L
.66869 .11228 L
.66936 .11511 L
.66996 .11842 L
.67059 .12279 L
.67172 .13272 L
.67294 .14632 L
.67514 .17785 L
.68011 .27311 L
.68489 .37686 L
.68949 .46356 L
.69186 .49624 L
.69318 .50982 L
.69438 .51891 L
.69497 .52218 L
.69529 .52363 L
.69559 .52478 L
.69586 .52565 L
.69612 .52629 L
.6964 .52683 L
.69655 .52705 L
.6967 .52721 L
.69686 .52732 L
Mistroke
.697 .52737 L
.69708 .52737 L
.69717 .52736 L
.69732 .5273 L
.69747 .52719 L
.69762 .52702 L
.69775 .52683 L
.6979 .52657 L
.69823 .52581 L
.69858 .52472 L
.69921 .52203 L
.69985 .51836 L
.70044 .51414 L
.70178 .50176 L
.7042 .46986 L
.70646 .43086 L
.70895 .38008 L
.71381 .27027 L
.71848 .17332 L
.7197 .15252 L
.72103 .13275 L
.7223 .11708 L
.72345 .10585 L
.72404 .10128 L
.72467 .09723 L
.72527 .09428 L
.72582 .09234 L
.72613 .09158 L
.72627 .0913 L
.72641 .09108 L
.72649 .09097 L
.72657 .09088 L
.72672 .09075 L
.7268 .0907 L
.72689 .09067 L
.72697 .09066 L
.72705 .09067 L
.72714 .09069 L
.72722 .09073 L
.72738 .09084 L
.72746 .09093 L
.72754 .09103 L
.72772 .09132 L
.72803 .09198 L
.72835 .09294 L
.729 .09559 L
.72959 .09892 L
.73093 .1095 L
.73211 .12223 L
.73336 .13895 L
Mistroke
.73793 .22356 L
.74279 .33682 L
.74747 .44204 L
.74985 .48573 L
.75111 .50474 L
.75245 .52139 L
.75312 .52824 L
.75375 .53373 L
.75437 .53815 L
.75493 .54138 L
.75547 .54373 L
.75575 .54463 L
.75604 .5454 L
.7562 .54571 L
.75634 .54595 L
.75642 .54606 L
.75651 .54616 L
.75666 .54628 L
.75681 .54635 L
.75696 .54636 L
.7571 .54632 L
.75724 .54622 L
.75739 .54607 L
.75753 .54587 L
.75784 .54526 L
.75814 .54442 L
.75846 .54328 L
.75905 .54052 L
.75958 .53726 L
.76087 .52643 L
.7621 .51256 L
.76451 .4756 L
.76674 .43207 L
.7715 .32 L
.77607 .20908 L
.77862 .1556 L
.78094 .11623 L
.78209 .10086 L
.78335 .08761 L
.78392 .08283 L
.78453 .07866 L
.78505 .07586 L
.78563 .07359 L
.78591 .07279 L
.78607 .07243 L
.78622 .07217 L
.78638 .07195 L
.78646 .07185 L
.78654 .07178 L
.78669 .0717 L
Mistroke
.78684 .07168 L
.78698 .07171 L
.78713 .07179 L
.78728 .07195 L
.78742 .07215 L
.78768 .07265 L
.78796 .07338 L
.78828 .07449 L
.78863 .07602 L
.78927 .07962 L
.78989 .08416 L
.79047 .08925 L
.79295 .12025 L
.79519 .15986 L
.80003 .27149 L
.80468 .39071 L
.80704 .44649 L
.80962 .49862 L
.81081 .51833 L
.81209 .53597 L
.81329 .54902 L
.81439 .55769 L
.81497 .56098 L
.81528 .5624 L
.81558 .56348 L
.81584 .5642 L
.81611 .56479 L
.81626 .56502 L
.81641 .56519 L
.81654 .56529 L
.81669 .56534 L
.81677 .56535 L
.81686 .56533 L
.81694 .56529 L
.81702 .56524 L
.81716 .5651 L
.81732 .56489 L
.81748 .56459 L
.81764 .56425 L
.81799 .56321 L
.81829 .56203 L
.81857 .56074 L
.81919 .55706 L
.82038 .54714 L
.82149 .53465 L
.82399 .49556 L
.82647 .44418 L
.82872 .38968 L
.83356 .26113 L
.83821 .14823 L
Mistroke
.84062 .1032 L
.84184 .08537 L
.84317 .07004 L
.8438 .06436 L
.8444 .06 L
.84494 .05694 L
.84524 .05559 L
.84552 .05455 L
.84583 .05369 L
.84599 .05334 L
.84616 .05305 L
.84625 .05294 L
.84634 .05284 L
.84643 .05277 L
.84651 .05272 L
.84667 .05269 L
.84676 .0527 L
.84684 .05273 L
.84699 .05285 L
.84714 .05301 L
.84729 .05326 L
.84746 .05361 L
.84774 .05436 L
.84805 .05545 L
.84868 .05853 L
.84928 .0625 L
.8504 .0726 L
.85161 .08724 L
.85292 .10735 L
.85784 .21415 L
.86257 .34324 L
.86712 .46236 L
.86965 .51612 L
.87076 .53549 L
.87197 .55331 L
.87314 .56694 L
.87424 .5762 L
.87484 .57985 L
.87539 .58224 L
.8757 .58318 L
.87587 .58358 L
.87603 .58388 L
.87617 .58408 L
.87632 .58423 L
.87648 .58432 L
.87663 .58433 L
.87678 .58427 L
.87686 .58421 L
.87694 .58414 L
.87709 .58395 L
Mistroke
.87723 .58371 L
.87754 .58295 L
.87788 .5818 L
.8785 .57882 L
.87907 .57509 L
.88016 .56537 L
.88131 .55153 L
.88368 .51216 L
.88589 .46411 L
.89059 .33817 L
.89558 .19713 L
.89808 .13555 L
.90039 .08912 L
.90155 .07056 L
.90263 .05638 L
.90377 .04512 L
.90437 .04067 L
.90468 .03878 L
.90502 .03708 L
.90533 .0358 L
.90562 .0349 L
.90575 .03456 L
.9059 .03425 L
.90604 .03402 L
.90617 .03387 L
.90632 .03375 L
.90647 .0337 L
.90662 .03372 L
.90671 .03377 L
.90679 .03383 L
.90687 .03391 L
.90695 .03401 L
.90712 .0343 L
.90727 .03463 L
.90744 .03506 L
.90777 .03618 L
.90812 .03778 L
.90877 .04166 L
.9094 .04665 L
.90998 .05227 L
.91226 .08361 L
.91355 .10743 L
.91475 .1331 L
.91946 .25743 L
.92445 .40508 L
.92696 .47276 L
.92927 .52594 L
.93152 .56599 L
.93265 .58106 L
.93329 .58792 L
Mistroke
.9339 .59331 L
.93449 .5974 L
.9348 .59914 L
.93513 .60066 L
.93543 .60176 L
.9357 .60251 L
.93584 .60279 L
.93598 .60302 L
.93612 .60318 L
.93624 .60327 L
.93639 .60332 L
.93655 .60329 L
.93669 .6032 L
.93683 .60305 L
.93698 .60281 L
.93716 .60245 L
.93747 .60156 L
.93779 .6003 L
.93814 .59859 L
.93876 .59458 L
.93989 .58422 L
.94111 .56876 L
.94331 .53029 L
.94573 .47468 L
.94828 .40473 L
.95287 .2647 L
.95543 .18884 L
.95776 .12724 L
.96021 .07417 L
.96129 .0556 L
.96247 .03893 L
.9636 .02699 L
.96421 .02212 L
.96479 .01866 L
.96511 .01719 L
.96542 .0161 L
.96569 .01539 L
.96585 .0151 L
.96599 .01491 L
.96608 .01483 L
.96616 .01476 L
.96625 .01473 L
.96632 .01472 L
.96647 .01474 L
.96662 .01485 L
.9667 .01494 L
.96679 .01505 L
.96694 .01532 L
.96713 .01575 L
.96729 .01623 L
Mistroke
.96757 .01723 L
.96787 .01862 L
.96849 .02236 L
.96906 .02692 L
.9696 .03215 L
.97081 .04716 L
.9721 .06815 L
.97619 .16205 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP00<ooonfX5
o`000?oooo]ZoooonfX:oookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP00<ooonfX5o`000?oo
oo]ZoooonfX:oookJP003ooonfX9o`00O`?ooo]Z1Ol007l5oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX:oookJP003ooonfX9o`00O`;ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]Zoooo
nfX:oookJP003ooonfX4o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]ZoooonfX:oookJP000ooonfX:o`00O`?ooo]Z1?l0
07l5oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000
oooonf[ooookJP[ooo]Z0003oookJP[o001o1?oonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1_l0003ooookJ_oooo]Z2OoonfX001?ooo]Z1?l0
07l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000
oooonf[`oookJPCo00005OoonfX001Cooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[`oookJPCo00005OoonfX001Gooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0003ooookJ^oooo]Z1Ol0000EoookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooook
J^oooo]Z1Ol0000EoookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ^oooo]Z1Ol0000E
oookJP003ooonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ^oooo]Z1Ol0000EoookJP004?oonfX7
o`00O`?ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]ZkooonfX6o`0001Cooo]Z000Aoook
JPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000oooonf[_oookJPKo00005?oonfX003?o
oo]Z1Ol0003ooookJ^oooo]Z1_l0000DoookJP00<ooonfX5o`000?oooo]ZkooonfX6o`0001Cooo]Z
000coookJPGo0000oooonf[@oookJPCo00006_oonfX7o`0001Cooo]Z000coookJPGo0000oooonf[@
oookJPCo00006_oonfX7o`0001Cooo]Z000coookJPGo0000oooonf[@oookJPCo00006_oonfX3o`00
0004oookJ_l0003o0000o`0001Cooo]Z000coookJPGo0000oooonf[?oookJPGo00006_oonfX3o`00
0004oookJ_l0003o0000o`0001Cooo]Z000coookJPGo0000oooonf[?oookJPKo00006OoonfX3o`00
0003oookJ_l0003o000000;o00004ooonfX003?ooo]Z1Ol0003ooookJ/oooo]Z1_l0000IoookJP?o
000000?ooo]Zo`000?l000000_l0000CoookJP00<ooonfX5o`000?oooo]ZcooonfX6o`0001Wooo]Z
0ol00002oookJP?o00004ooonfX003?ooo]Z1Ol0003ooookJ/oooo]Z1_l0000IoookJP?o00000_oo
nfX3o`0001?ooo]Z000coookJPGo0000oooonf[?oookJPKo00006OoonfX3o`0000;ooo]Z0ol0000C
oookJP00<ooonfX5o`000?oooo]ZcooonfX6o`0001Wooo]Z0ol00002oookJP?o00004ooonfX003?o
oo]Z1Ol0003ooookJ[3ooo]Z1?l0000KoookJPKo00006OoonfX3o`0000;ooo]Z0ol0000CoookJP00
<ooonfX5o`000?oooo]Z/?oonfX5o`0001[ooo]Z1_l0000IoookJP?o00000_oonfX3o`0001?ooo]Z
000coookJPGo0000oooonfZ`oookJPGo00006_oonfX6o`0001Wooo]Z0ol00002oookJP?o00004ooo
nfX003?ooo]Z1Ol0003ooookJ[3ooo]Z1Ol0000JoookJPKo00006OoonfX3o`0000;ooo]Z0ol0000C
oookJP00<ooonfX5o`000?oooo]Z/?oonfX5o`0001[ooo]Z1_l0000IoookJP?o00000_oonfX3o`00
01?ooo]Z000coookJPGo0000oooonfZ`oookJPGo00006_oonfX7o`0001Sooo]Z0ol00002oookJP?o
00004ooonfX003?ooo]Z1Ol0003ooookJZoooo]Z1_l0000IoookJPSo00006?oonfX3o`0000;ooo]Z
0ol0000CoookJP00<ooonfX5o`000?oooo]Z[ooonfX6o`0001Wooo]Z1?l000001?oonf[o0000o`00
0?l0000GoookJPCo00000_oonfX3o`0001?ooo]Z000coookJPGo0000oooonfZ_oookJPOo00006?oo
nfX3o`0000;ooo]Z0ol0000GoookJPCo00000_oonfX3o`0001?ooo]Z000coookJPGo0000oooonfZ_
oookJPOo00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001?ooo]Z000coook
JPGo0000oooonfZAoookJPCo00006_oonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00002
oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000CoookJP00<ooonfX5o`000?oooo]ZTOoonfX4o`00
01[ooo]Z0ol000001?oonf[o0000o`000?l0000HoookJP?o00000_oonfX3o`0001Oooo]Z0ol00003
oookJP?o00004ooonfX003?ooo]Z1Ol0003ooookJY3ooo]Z1Ol0000JoookJP?o000000Cooo]Zo`00
0?l0003o00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001?ooo]Z000coook
JPGo0000oooonfZ@oookJPGo00006_oonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00002
oookJPCo00005_oonfX3o`0000?ooo]Z0ol0000CoookJP00<ooonfX5o`000?oooo]ZT?oonfX5o`00
01Wooo]Z1?l000001?oonf[o0000o`000?l0000HoookJP?o00000_oonfX4o`0001Kooo]Z0ol00003
oookJP?o00004ooonfX003?ooo]Z1Ol0003ooookJY3ooo]Z1Ol0000IoookJPCo000000?ooo]Zo`00
0?l000000_l0000FoookJPCo00000ooonfX3o`0001Kooo]Z0ol00003oookJP?o00004ooonfX003?o
oo]Z1Ol0003ooookJY3ooo]Z1_l0000HoookJP?o00000_oonfX4o`0001Kooo]Z1?l00003oookJP?o
00005_oonfX3o`0000?ooo]Z0ol0000CoookJP00<ooonfX5o`000?oooo]ZT?oonfX6o`0001Sooo]Z
0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000FoookJP?o00000ooonfX3o`0001?ooo]Z
000coookJPGo0000oooonfZ?oookJPOo00006?oonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oo
nfX3o`0001Kooo]Z0ol00003oookJP?o00004ooonfX003?ooo]Z1Ol0003ooookJXoooo]Z1ol0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000?ooo]Z0ol0000C
oookJP00<ooonfX5o`000?oooo]ZLOoonfX4o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000?ooo]Z0ol0000C
oookJP00<ooonfX5o`000?oooo]ZLOoonfX4o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000?ooo]Z1?l0000B
oookJP00<ooonfX5o`000?oooo]ZLOoonfX5o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000?ooo]Z1?l0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX6o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX6o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX6o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX6o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005OoonfX4o`0000Cooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX6o`0001Wooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005OoonfX4o`0000Cooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZL?oonfX7o`0001Sooo]Z0ol000000ooonf[o0000o`000002o`00
01Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`00
01;ooo]Z000coookJPGo0000oooonfY`oookJPOo00006?oonfX3o`000003oookJ_l0003o000000;o
00005ooonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o
00004_oonfX003?ooo]Z1Ol0003ooookJU7ooo]Z1?l0000KoookJP?o000000Cooo]Zo`000?l0003o
00005ooonfX4o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o
00005OoonfX3o`0000Gooo]Z0ol0000BoookJP00<ooonfX5o`000?oooo]ZDOoonfX5o`0001[ooo]Z
0ol000001?oonf[o0000o`000?l0000GoookJPCo00000_oonfX3o`0001Oooo]Z0ol00003oookJP?o
00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001;ooo]Z000coookJPGo0000
oooonfYAoookJPGo00006OoonfX4o`000004oookJ_l0003o0000o`0001Oooo]Z0ol00003oookJP?o
00005ooonfX3o`0000?ooo]Z0ol0000EoookJPCo00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o
00004_oonfX003?ooo]Z1Ol0003ooookJU7ooo]Z1Ol0000IoookJPCo000000Cooo]Zo`000?l0003o
00005ooonfX3o`0000?ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Gooo]Z1?l00004oookJP?o
00005OoonfX3o`0000Gooo]Z0ol0000BoookJP00<ooonfX5o`000?oooo]ZD?oonfX6o`0001Wooo]Z
0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000FoookJPCo00000ooonfX3o`0001Gooo]Z
0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000BoookJP00<ooonfX5o`000?oooo]ZD?oo
nfX6o`0001Wooo]Z0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000FoookJPCo00000ooo
nfX3o`0001Gooo]Z0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000BoookJP00<ooonfX5
o`000?oooo]ZD?oonfX6o`0001Wooo]Z0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000F
oookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJPCo00005?oonfX3o`0000Gooo]Z0ol0000B
oookJP00<ooonfX5o`000?oooo]ZD?oonfX7o`0001Sooo]Z0ol00002oookJP?o00005ooonfX3o`00
00?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJPCo00005?oonfX3o`00
00Gooo]Z0ol0000BoookJP00<ooonfX5o`000?oooo]ZD?oonfX7o`0001Sooo]Z0ol00002oookJP?o
00005ooonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Gooo]Z0ol00006oookJP?o
00005?oonfX3o`0000Gooo]Z0ol0000BoookJP00<ooonfX5o`000?oooo]ZD?oonfX3o`000004oook
J_l0003o0000o`0001Oooo]Z1?l00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000FoookJP?o
00001?oonfX4o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3o`0000Gooo]Z0ol0000BoookJP00
<ooonfX5o`000?oooo]Z<_oonfX4o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000GoookJPCo
00000_oonfX3o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z1?l0000DoookJP?o
00001_oonfX3o`0001Cooo]Z0ol00005oookJP?o00004_oonfX003?ooo]Z1Ol0003ooookJS7ooo]Z
1Ol0000JoookJP?o000000Cooo]Zo`000?l0003o00005ooonfX3o`0000?ooo]Z0ol0000GoookJP?o
00000ooonfX3o`0001Kooo]Z0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000DoookJP?o
00001OoonfX3o`0001;ooo]Z000coookJPGo0000oooonfXaoookJPGo00006_oonfX3o`000004oook
J_l0003o0000o`0001Oooo]Z0ol00003oookJPCo00005_oonfX3o`0000?ooo]Z1?l0000EoookJP?o
00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3o`0000Gooo]Z0ol0000BoookJP00
<ooonfX5o`000?oooo]Z<OoonfX5o`0001Wooo]Z1?l000001?oonf[o0000o`000?l0000GoookJP?o
00000ooonfX4o`0001Kooo]Z0ol00003oookJPCo00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o
00001_oonfX3o`0001Cooo]Z0ol00005oookJP?o00004_oonfX003?ooo]Z1Ol0003ooookJS7ooo]Z
1Ol0000IoookJPCo000000Cooo]Zo`000?l0003o00005ooonfX3o`0000Cooo]Z0ol0000EoookJPCo
00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000DoookJP?o
00001OoonfX3o`0001;ooo]Z000coookJPGo0000oooonfXaoookJPKo00006?oonfX3o`0000;ooo]Z
0ol0000GoookJP?o00001?oonfX3o`0001Gooo]Z1?l00004oookJP?o00005?oonfX4o`0000Gooo]Z
0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00005oookJP?o00004_oonfX003?ooo]Z1Ol0
003ooookJS3ooo]Z1ol0000HoookJP?o00000_oonfX4o`0001Kooo]Z0ol00004oookJP?o00005Ooo
nfX3o`0000Gooo]Z0ol0000DoookJPCo00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oo
nfX3o`0000Gooo]Z1?l0000AoookJP00<ooonfX5o`000?oooo]Z<?oonfX7o`0001Sooo]Z0ol00002
oookJPCo00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000DoookJP?o00001OoonfX4o`00017ooo]Z000coook
JPGo0000oooonfX`oookJP?o000000Cooo]Zo`000?l0003o00006?oonfX3o`0000?ooo]Z0ol0000F
oookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000D
oookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00004OoonfX003?ooo]Z1Ol0003ooook
JS3ooo]Z0ol000001?oonf[o0000o`000?l0000HoookJP?o00000ooonfX3o`0001Kooo]Z0ol00004
oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00<ooonfX5o`000?oooo]Z4_oonfX4o`00
01[ooo]Z0ol000001?oonf[o0000o`000?l0000GoookJPCo00000ooonfX3o`0001Kooo]Z0ol00004
oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00<ooonfX5o`000?oooo]Z4_oonfX4o`00
01[ooo]Z0ol000001?oonf[o0000o`000?l0000GoookJPCo00000ooonfX3o`0001Kooo]Z0ol00004
oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00<ooonfX5o`000?oooo]Z4OoonfX6o`00
01Wooo]Z0ol000001?oonf[o0000o`000?l0000GoookJP?o00001?oonfX3o`0001Kooo]Z0ol00004
oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00<ooonfX5o`000?oooo]Z4OoonfX6o`00
01Sooo]Z1?l000001?oonf[o0000o`000?l0000GoookJP?o00001?oonfX3o`0001Kooo]Z0ol00004
oookJP?o00005OoonfX3o`0000Gooo]Z1?l0000CoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00<ooonfX5o`000?oooo]Z4OoonfX6o`00
01Sooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`00
00Cooo]Z0ol0000EoookJP?o00001OoonfX4o`0001?ooo]Z0ol00006oookJP?o00005?oonfX3o`00
00Kooo]Z0ol0000DoookJP?o00001_oonfX3o`00017ooo]Z000CoookJP?o001o1OoonfX5o`00O`Go
oo]Z1Ol007l9oookJPGo0000oooonfXAoookJPKo00006?oonfX3o`0000;ooo]Z1?l0000FoookJP?o
00001?oonfX3o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`0000Kooo]Z0ol0000CoookJP?o
00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000AoookJP00
4ooonfX3o`00O`Cooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]Z4OoonfX6o`0001Sooo]Z
0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Gooo]Z
0ol00006oookJP?o00004ooonfX3o`0000Kooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z
1?l00006oookJP?o00004OoonfX001?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJQ7ooo]Z1ol0000GoookJP?o
00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005_oonfX3o`0000Cooo]Z1?l0000DoookJP?o
00001_oonfX3o`0001?ooo]Z0ol00006oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJPCo
00001_oonfX3o`00017ooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJQ3ooo]Z2?l0000GoookJP?o
00000ooonfX3o`0001Kooo]Z0ol00004oookJPCo00005OoonfX3o`0000Cooo]Z1?l0000DoookJP?o
00001_oonfX3o`0001?ooo]Z0ol00006oookJPCo00004ooonfX3o`0000Kooo]Z0ol0000CoookJP?o
00001ooonfX3o`00017ooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1_l0003ooookJPoooo]Z1?l000001?oonf[o
0000o`000?l0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJPCo00005?oonfX4o`00
00Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00006oookJPCo00004ooonfX3o`00
00Kooo]Z1?l0000BoookJP?o00001ooonfX3o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?7ooo]Z1?l0000Joook
JP?o00000_oonfX3o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000Doook
JPCo00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000Coook
JP?o00001_oonfX4o`0001;ooo]Z0ol00007oookJP?o00004OoonfX001?ooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000lOoonfX5o`00
01Wooo]Z0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000FoookJP?o00001OoonfX3o`00
01Cooo]Z0ol00006oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`00
01;ooo]Z1?l00007oookJP?o00004_oonfX3o`0001_ooo]Z000CoookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?7ooo]Z1Ol0000Ioook
JP?o00000_oonfX3o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000Doook
JP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000Boook
JPCo00001ooonfX3o`0001;ooo]Z0ol0000KoookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003`oookJPKo00006OoonfX3o`00
00;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol00005oookJP?o00005?oonfX3o`00
00Kooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`00
00Sooo]Z0ol0000BoookJP?o00006ooonfX0013ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000l?oonfX7o`0001Sooo]Z0ol00002oook
JP?o00005ooonfX3o`0000?ooo]Z1?l0000DoookJPCo00001OoonfX3o`0001Cooo]Z0ol00006oook
JP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oook
JP?o00004_oonfX3o`0001_ooo]Z000@oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000l?oonfX7o`0001Sooo]Z0ol00002
oookJP?o00005ooonfX3o`0000?ooo]Z1?l0000DoookJPCo00001OoonfX3o`0001Cooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008
oookJP?o00004_oonfX3o`0001_ooo]Z000BoookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007l8oook
JPGo0000l?oonfX3o`000004oookJ_l0003o0000o`0001Oooo]Z1?l00002oookJP?o00005ooonfX3
o`0000Cooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3
o`0000Kooo]Z0ol0000BoookJPCo00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3
o`0001_ooo]Z000CoookJP?o001o1OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000l?oonfX3o`00
0004oookJ_l0003o0000o`0001Oooo]Z1?l00002oookJP?o00005ooonfX3o`0000Cooo]Z0ol0000D
oookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000B
oookJPCo00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0001_ooo]Z000coook
JPGo0000kooonfX4o`000004oookJ_l0003o0000o`0001Oooo]Z0ol00003oookJP?o00005_oonfX4
o`0000Cooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oonfX3
o`0000Kooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3
o`0001_ooo]Z000coookJPGo0000kooonfX4o`000004oookJ_l0003o0000o`0001Oooo]Z0ol00003
oookJP?o00005_oonfX4o`0000Cooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006
oookJP?o00004ooonfX4o`0000Kooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008
oookJP?o00004_oonfX3o`0001_ooo]Z000coookJPGo0000d_oonfX4o`0001Wooo]Z0ol00002oook
JP?o00005ooonfX3o`0000?ooo]Z1?l0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00006oook
JP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJPCo00001_oonfX3o`0001;ooo]Z0ol00008oook
JP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00006ooonfX003?ooo]Z1Ol0003AoookJPGo
00006OoonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX4o`0001Gooo]Z0ol00005oookJP?o
00005?oonfX3o`0000Kooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o
00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol0000KoookJP00
<ooonfX5o`000=7ooo]Z1Ol0000IoookJP?o00000_oonfX3o`0001Oooo]Z0ol00004oookJP?o0000
5OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o0000
4ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oookJP?o0000
4_oonfX3o`0001_ooo]Z000coookJPGo0000dOoonfX6o`0001Sooo]Z0ol00002oookJP?o00005ooo
nfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00005?oo
nfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX4o`00017ooo]Z0ol00008oookJP?o00004_oo
nfX3o`0000Sooo]Z0ol0000BoookJP?o00006ooonfX003?ooo]Z1Ol0003AoookJPKo00006?oonfX3
o`0000;ooo]Z1?l0000FoookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3
o`0000Kooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJPCo00004OoonfX3
o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol0000KoookJP00<ooonfX5o`00
0=3ooo]Z1ol0000HoookJP?o00000_oonfX4o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`00
00Gooo]Z0ol0000DoookJP?o00001_oonfX4o`0001?ooo]Z0ol00006oookJP?o00004ooonfX3o`00
00Sooo]Z0ol0000AoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`00
01_ooo]Z000coookJPGo0000d?oonfX7o`0001Sooo]Z0ol00003oookJP?o00005_oonfX3o`0000Co
oo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00006oookJPCo00004ooonfX3o`0000Ko
oo]Z0ol0000CoookJP?o00002?oonfX3o`00017ooo]Z0ol00008oookJP?o00004_oonfX3o`0000So
oo]Z0ol0000BoookJP?o00006ooonfX003?ooo]Z1Ol0003@oookJP?o000000Cooo]Zo`000?l0003o
00006?oonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Cooo]Z1?l00005oookJPCo
00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001_oonfX3o`0001?ooo]Z0ol00008oookJP?o
00004OoonfX3o`0000Sooo]Z1?l0000AoookJP?o00002?oonfX3o`0001;ooo]Z0ol0000KoookJP00
<ooonfX5o`000<oooo]Z1?l000001?oonf[o0000o`000?l0000GoookJPCo00000ooonfX3o`0001Ko
oo]Z0ol00004oookJP?o00005?oonfX4o`0000Gooo]Z1?l0000CoookJP?o00001ooonfX3o`0001;o
oo]Z1?l00006oookJP?o00004ooonfX3o`0000Sooo]Z0ol0000AoookJP?o00002?oonfX4o`00017o
oo]Z0ol00008oookJP?o00004_oonfX3o`0001_ooo]Z000coookJPGo0000cooonfX4o`000004oook
J_l0003o0000o`0001Oooo]Z1?l00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000DoookJP?o
00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX4o`0000Kooo]Z0ol0000CoookJP?o
00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000BoookJP?o
00006ooonfX003?ooo]Z1Ol0002boookJPCo00006OoonfX3o`0000;ooo]Z0ol0000GoookJP?o0000
1?oonfX4o`0001Cooo]Z1?l00004oookJP?o00005?oonfX3o`0000Oooo]Z0ol0000CoookJP?o0000
1ooonfX3o`0001;ooo]Z0ol00007oookJPCo00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o0000
2OoonfX3o`00017ooo]Z0ol00008oookJP?o00004_oonfX3o`0001_ooo]Z000coookJPGo0000/Ooo
nfX5o`0001Wooo]Z0ol00002oookJPCo00005_oonfX3o`0000Cooo]Z1?l0000DoookJPCo00001?oo
nfX3o`0001Cooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooo
nfX4o`0001;ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002?oo
nfX3o`0001;ooo]Z0ol0000KoookJP00<ooonfX5o`000;7ooo]Z1_l0000HoookJP?o00000_oonfX4
o`0001Kooo]Z0ol00005oookJP?o00005?oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3
o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3
o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000BoookJP?o00006ooonfX0
03?ooo]Z1Ol0002aoookJPKo00006?oonfX3o`0000?ooo]Z0ol0000FoookJP?o00001OoonfX3o`00
01Cooo]Z0ol00005oookJPCo00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`00
01;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00
017ooo]Z0ol00008oookJP?o00004OoonfX4o`0001_ooo]Z000coookJPGo0000/OoonfX6o`0001Oo
oo]Z1?l00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001OoonfX4o`0001?o
oo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;o
oo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002?oonfX3o`00017o
oo]Z1?l0000KoookJP00<ooonfX5o`000;3ooo]Z2?l0000FoookJPCo00000ooonfX3o`0001Kooo]Z
0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z
1?l00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`00017ooo]Z
0ol00009oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000AoookJP?o00007?oonfX003?ooo]Z1Ol0
002`oookJPSo00005_oonfX3o`0000Cooo]Z1?l0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol0
0006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJPCo00001ooonfX3o`0001;ooo]Z0ol0
0008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol0
0008oookJP?o00004OoonfX3o`0001cooo]Z000coookJPGo0000/?oonfX3o`0000;ooo]Z0ol0000F
oookJP?o00001?oonfX4o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000C
oookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000B
oookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000A
oookJP?o00007?oonfX003?ooo]Z1Ol0002`oookJP?o00000_oonfX3o`0001Kooo]Z0ol00005oook
JP?o00005?oonfX4o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oook
JPCo00004OoonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oook
JP?o00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002?oonfX3o`00017ooo]Z0ol0000Loook
JP00<ooonfX5o`000;3ooo]Z0ol00002oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJPCo
00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z1?l0000AoookJP?o
00002?oonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o
00002OoonfX3o`00013ooo]Z1?l00008oookJP?o00004OoonfX3o`0001cooo]Z000coookJPGo0000
T_oonfX4o`0001Wooo]Z1?l00002oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o0000
1_oonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Sooo]Z0ol0000AoookJP?o0000
2?oonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o0000
2OoonfX3o`00013ooo]Z1?l00008oookJP?o00004OoonfX3o`0001cooo]Z000coookJPGo0000T_oo
nfX5o`0001Sooo]Z1?l00002oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oo
nfX4o`0001?ooo]Z0ol00006oookJP?o00004ooonfX3o`0000Sooo]Z0ol0000AoookJP?o00002?oo
nfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002Ooo
nfX3o`00013ooo]Z0ol00009oookJP?o00004OoonfX3o`0001cooo]Z000coookJPGo0000TOoonfX6
o`0001Sooo]Z0ol00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX4
o`0001?ooo]Z0ol00006oookJP?o00004_oonfX4o`0000Sooo]Z0ol0000AoookJP?o00002?oonfX4
o`00017ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3
o`00013ooo]Z0ol00009oookJPCo00004?oonfX3o`0001cooo]Z000coookJPGo0000TOoonfX6o`00
01Sooo]Z0ol00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3o`00
01;ooo]Z1?l00006oookJP?o00004_oonfX4o`0000Sooo]Z0ol0000AoookJP?o00002?oonfX4o`00
017ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00
013ooo]Z0ol00009oookJPCo00004?oonfX3o`0001cooo]Z000coookJPGo0000TOoonfX7o`0001Oo
oo]Z0ol00003oookJPCo00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3o`0001;o
oo]Z1?l00006oookJP?o00004_oonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00017o
oo]Z0ol00008oookJP?o00004OoonfX4o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00013o
oo]Z0ol0000:oookJP?o00004?oonfX3o`0001cooo]Z000coookJPGo0000T?oonfX8o`0001Oooo]Z
0ol00003oookJPCo00005?oonfX4o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3o`0001;ooo]Z
0ol00007oookJP?o00004_oonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z
0ol00008oookJP?o00004OoonfX4o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z
0ol0000:oookJP?o00004?oonfX3o`0001cooo]Z000coookJPGo0000T?oonfX4o`000004oookJ_l0
003o0000o`0001Oooo]Z0ol00004oookJP?o00005?oonfX4o`0000Gooo]Z1?l0000CoookJP?o0000
1ooonfX3o`0001;ooo]Z0ol00007oookJPCo00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o0000
2OoonfX3o`00017ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJPCo0000
2OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0001cooo]Z000coookJPGo0000T?oo
nfX3o`0000;ooo]Z0ol0000GoookJP?o00001?oonfX3o`0001Cooo]Z0ol00006oookJPCo00004ooo
nfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooonfX4o`00017ooo]Z0ol00009oookJP?o00004Ooo
nfX3o`0000Wooo]Z0ol0000AoookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004?oo
nfX4o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0000LoookJP00<ooonfX5
o`00093ooo]Z0ol00002oookJP?o00005ooonfX3o`0000Cooo]Z0ol0000DoookJP?o00001ooonfX3
o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3
o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3
o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00007?oonfX0
03?ooo]Z1Ol0002@oookJP?o00000_oonfX3o`0001Kooo]Z1?l00004oookJP?o00005?oonfX3o`00
00Oooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004OoonfX3o`00
00Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00008oookJP?o00004OoonfX3o`00
00Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`00
01cooo]Z000coookJPGo0000LooonfX3o`0001[ooo]Z0ol00002oookJPCo00005OoonfX4o`0000Co
oo]Z0ol0000DoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000So
oo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000So
oo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[o
oo]Z0ol0000@oookJP?o00007?oonfX003?ooo]Z1Ol0001boookJPGo00006?oonfX4o`0000;ooo]Z
1?l0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z
0ol0000BoookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z
0ol0000AoookJP?o00002?oonfX4o`00013ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[ooo]Z
0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0000LoookJP00<ooonfX5o`00077ooo]Z1_l0
000HoookJPCo00000ooonfX3o`0001Gooo]Z0ol00005oookJPCo00004ooonfX3o`0000Oooo]Z0ol0
000BoookJPCo00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0
000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00008oookJPCo00004?oonfX3o`0000Wooo]Z1?l0
000?oookJP?o00002_oonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0001cooo]Z000c
oookJPGo0000LOoonfX6o`0001Sooo]Z0ol00004oookJPCo00005?oonfX3o`0000Gooo]Z1?l0000C
oookJP?o00001ooonfX3o`0001;ooo]Z1?l00007oookJP?o00004OoonfX4o`0000Sooo]Z0ol0000A
oookJP?o00002OoonfX3o`00017ooo]Z0ol00009oookJP?o00004?oonfX4o`0000Wooo]Z0ol0000@
oookJP?o00002OoonfX4o`0000oooo]Z0ol0000:oookJPCo00003ooonfX3o`0000[ooo]Z0ol0000?
oookJPCo00007?oonfX003?ooo]Z1Ol0001aoookJPOo00005ooonfX3o`0000Cooo]Z1?l0000Doook
JP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000Aoook
JPCo00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oook
JPCo00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000[ooo]Z1?l0000?oook
JP?o00002_oonfX3o`0000oooo]Z1?l0000LoookJP00<ooonfX5o`00077ooo]Z1ol0000GoookJP?o
00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o
00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000oooo]Z0ol0000:oookJP?o00003ooonfX3o`0001gooo]Z000coookJPGo0000
LOoonfX3o`000003oookJ_l0003o000000;o00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o0000
1_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z1?l0000@oookJP?o0000
2OoonfX3o`00017ooo]Z0ol00009oookJPCo00003ooonfX4o`0000Wooo]Z0ol0000@oookJP?o0000
2_oonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o0000
2_oonfX3o`0000oooo]Z0ol0000MoookJP00<ooonfX5o`00073ooo]Z1?l000000ooonf[o0000o`00
0002o`0001Kooo]Z0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z1?l0000BoookJP?o00001ooo
nfX3o`0001;ooo]Z0ol00008oookJPCo00004?oonfX3o`0000Wooo]Z0ol0000AoookJP?o00002_oo
nfX3o`0000oooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oo
nfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o00007Ooo
nfX003?ooo]Z1Ol0001`oookJPCo00000_oonfX3o`0001Gooo]Z1?l00005oookJP?o00004ooonfX4
o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX3o`0001;ooo]Z0ol00009oookJP?o00004?oonfX3
o`0000Wooo]Z0ol0000AoookJP?o00002_oonfX3o`0000oooo]Z0ol0000:oookJP?o00004?oonfX3
o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3
o`0000[ooo]Z0ol0000?oookJP?o00007OoonfX003?ooo]Z1Ol0001`oookJP?o00000ooonfX3o`00
01Gooo]Z1?l00005oookJP?o00004ooonfX4o`0000Oooo]Z0ol0000AoookJPCo00001ooonfX3o`00
01;ooo]Z0ol00009oookJP?o00004?oonfX3o`0000Wooo]Z1?l0000@oookJP?o00002_oonfX3o`00
00oooo]Z0ol0000:oookJPCo00003ooonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`00
00oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o00007OoonfX003?o
oo]Z1Ol0001CoookJPCo00006?oonfX4o`0000?ooo]Z1?l0000DoookJP?o00001_oonfX4o`0001;o
oo]Z0ol00008oookJP?o00004OoonfX3o`0000Sooo]Z0ol0000BoookJP?o00002OoonfX3o`00013o
oo]Z0ol00009oookJPCo00004?oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002_oonfX4o`0000oo
oo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oo
oo]Z0ol0000:oookJP?o00003ooonfX3o`0001gooo]Z000coookJPGo0000D_oonfX6o`0001Oooo]Z
1?l00003oookJPCo00005?oonfX3o`0000Kooo]Z1?l0000BoookJP?o00002?oonfX3o`00017ooo]Z
0ol00008oookJPCo00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z
0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002_oonfX3o`00013ooo]Z
0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002_oonfX3o`0000oooo]Z
0ol0000MoookJP00<ooonfX5o`00057ooo]Z1ol0000GoookJP?o00001OoonfX3o`0001Cooo]Z0ol0
0007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002?oonfX4o`00017ooo]Z0ol0
0009oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z0ol0
000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z0ol0
000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o00007OoonfX003?ooo]Z1Ol0001A
oookJPSo00005_oonfX3o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3o`00017ooo]Z1?l00008
oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:
oookJP?o00003ooonfX4o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000:
oookJP?o00003ooonfX4o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000:
oookJP?o00003ooonfX3o`0001gooo]Z000coookJPGo0000DOoonfX8o`0001Gooo]Z1?l00005oook
JP?o00005?oonfX3o`0000Oooo]Z0ol0000AoookJPCo00002?oonfX3o`00017ooo]Z0ol00009oook
JP?o00004?oonfX4o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z1?l0000:oook
JP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002_oonfX3o`0000oooo]Z1?l0000:oook
JP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJPCo00002_oonfX3o`0000oooo]Z0ol0000Moook
JP00<ooonfX5o`00053ooo]Z1?l00002oookJP?o00005OoonfX4o`0000Gooo]Z0ol0000CoookJPCo
00001ooonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJPCo
00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000oooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000kooo]Z1?l0000:oookJP?o00003ooonfX3o`0001gooo]Z000coookJPGo0000
D?oonfX4o`0000;ooo]Z0ol0000EoookJP?o00001_oonfX4o`0001;ooo]Z1?l00007oookJP?o0000
4OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o0000
4?oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o0000
3ooonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o0000
3_oonfX3o`0000_ooo]Z0ol0000?oookJP?o00007OoonfX003?ooo]Z1Ol0001@oookJP?o00000ooo
nfX3o`0001Gooo]Z0ol00006oookJPCo00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002Ooo
nfX4o`00013ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oo
nfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002_oo
nfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o00002ooo
nfX3o`0000oooo]Z0ol0000MoookJP00<ooonfX5o`00053ooo]Z0ol00003oookJPCo00005?oonfX3
o`0000;ooo]Z1Ol007l3o`0000;ooo]Z1Ol007l;oookJP?o00002?oonfX3o`00017ooo]Z0ol00009
oookJPCo00004?oonfX3o`0000Wooo]Z0ol0000@oookJP?o00000ol007l5oookJP;o001o0ol00005
oookJPGo001o1_oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;
oookJP?o00003ooonfX3o`0000;o001o1OoonfX3o`00O`?o00001?oonfX5o`00O`Kooo]Z0ol0000;
oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o00002ooonfX3o`0000gooo]Z0_l007l3
o`0000Co001o0ooonfX5o`00O`Gooo]Z1Ol007l7oookJP00<ooonfX5o`00053ooo]Z0ol00003oook
JPCo00005?oonfX3o`000003oookJ_l007oo001o00Co001o0ol000000ooonf[o001oo`00O`05o`00
O`[ooo]Z0ol00008oookJP?o00004OoonfX3o`0000[ooo]Z0ol0000@oookJP?o00002OoonfX3o`00
013ooo]Z0ol00003o`00O`Cooo]Z0ol007l4o`0000?ooo]Z1ol007l4oookJPCo00002_oonfX3o`00
00oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00000_l007l4oook
JPCo001o0ol00003oookJPOo001o1OoonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`00
00kooo]Z0ol0000;oookJP?o00003OoonfX2o`00O`?o00001?l007l2oookJPOo001o0ooonfX7o`00
O`Kooo]Z000coookJPGo0000<ooonfX4o`0001Sooo]Z1?l00004oookJP?o00005?oonfX3o`0000Co
001o00?ooo]Zo`00Ool007l00ol000001Ooonf[o001oo`00Ool007oooo]Z00?o001o2OoonfX4o`00
00Sooo]Z0ol0000AoookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX3o`00
00?o001o1?oonfX3o`00O`Co00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`Cooo]Z1?l0000:
oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol00002
o`00O`?ooo]Z1?l007l01?oonf[o0000o`000?l00003oookJP?o001o00Cooo]Zo`00Ool007oo001o
1OoonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0000;oookJP?o0000
3OoonfX2o`00O`?o00001_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l6oookJP00<ooonfX5o`0003;ooo]Z1_l0000GoookJPCo00001?oonfX3o`0001?o
oo]Z1?l00003o`00O`?ooo]Z00Co001oo`000?l0003o00000ol007l3oookJP?o001o2?oonfX4o`00
00Sooo]Z1?l0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX3o`00
00?o001o0ooonfX3o`00O`;ooo]Z0ol000000ol007oooo]Zo`00O`02o`00O`?ooo]Z0ol007l3oook
JP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oook
JP?o00000_l007l3oookJP?o001o0_oonfX4o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007l4
oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX3o`0000_ooo]Z0ol0000>
oookJP04o`00Ool0003o0000o`0000Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Gooo]Z000coookJPGo0000<_oonfX7o`0001Kooo]Z0ol00005oookJPCo00004_oo
nfX4o`0000Kooo]Z00Co001oo`000?l0003o00000ol007l3oookJP?o001o2?oonfX3o`0000Wooo]Z
1?l0000@oookJP?o00002_oonfX3o`0000oooo]Z1?l00009oookJP?o00004?oonfX3o`0000?o001o
0ooonfX3o`00O`;ooo]Z0ol000000ol007oooo]Zo`00O`02o`00O`?ooo]Z0ol007l3oookJP?o0000
2ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX4o`0000_ooo]Z0ol0000?oookJP?o0000
0_l007l8oookJPCo000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Cooo]Z0ol0000;oookJP?o
00003_oonfX4o`0000_ooo]Z0ol0000>oookJP?o00002ooonfX4o`0000kooo]Z0ol00002o`00O`?o
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000coookJPGo
0000<OoonfX9o`0001Gooo]Z0ol00005oookJPCo00004_oonfX3o`0000Oooo]Z00?o001oo`000?l0
00000_l00002o`00O`?ooo]Z0ol007l8oookJP?o00002_oonfX3o`0000oooo]Z1?l0000:oookJP?o
00003ooonfX4o`0000Wooo]Z0ol0000@oookJP?o00000ol007l3oookJP?o001o0_oonfX3o`000003
o`00Oooonf[o001o00;o001o0ooonfX3o`00O`?ooo]Z0ol0000;oookJPCo00003_oonfX3o`0000_o
oo]Z0ol0000>oookJPCo00002ooonfX3o`0000oooo]Z0ol00002o`00O`Wooo]Z0ol000001?oonf[o
001oo`00Ool007l3oookJP?o001o1?oonfX3o`0000_ooo]Z0ol0000>oookJPCo00002ooonfX3o`00
00kooo]Z0ol0000;oookJPCo00003_oonfX3o`0000?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o1OoonfX003?ooo]Z1Ol0000`oookJPGo000000?ooo]Zo`00
0?l000000_l0000DoookJPCo00001_oonfX3o`0001;ooo]Z0ol00002oookJP;o001o0_oonfX2o`00
O`Co00000_l007l3oookJP?o001o2?oonfX3o`0000[ooo]Z0ol0000?oookJPCo00002_oonfX3o`00
00oooo]Z0ol0000:oookJP?o00004?oonfX3o`0000?o001o0ooonfX3o`00O`;ooo]Z0ol000000ol0
07oooo]Zo`00O`02o`00O`?ooo]Z0ol007l3oookJP?o00002ooonfX4o`0000kooo]Z0ol0000;oook
JP?o00003_oonfX3o`0000cooo]Z0ol0000?oookJP?o00000_l007l4oookJP;o001o0_oonfX01Ol0
07oo0000o`000?l0003ooo]Z00?o001o0ooonfX3o`00O`Cooo]Z0ol0000;oookJP?o00003_oonfX3
o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z0ol00003o`00O`;ooo]Z0ol007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000coookJPGo0000<?oonfX4
o`0000?ooo]Z1?l0000CoookJPCo00001_oonfX3o`0001;ooo]Z0ol00002oookJPOo001o0ol00002
o`00O`?ooo]Z0ol007l8oookJP?o00002_oonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3
o`0000[ooo]Z1?l0000?oookJP?o00000ol007l3oookJP?o001o0_oonfX3o`000003o`00Oooonf[o
001o00;o001o0ooonfX3o`00O`?ooo]Z0ol0000<oookJP?o00003_oonfX3o`0000_ooo]Z0ol0000>
oookJP?o00003?oonfX3o`0000oooo]Z0ol00002o`00O`Cooo]Z1Ol007l3o`000004oookJ_l007oo
001oo`00O`?ooo]Z0ol007l4oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oo
nfX3o`0000cooo]Z0ol0000>oookJP?o000000Gooo]Zo`00Ool007oo001ooookJP03o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX003?ooo]Z1Ol0000_oookJPCo0000
1?oonfX4o`0001?ooo]Z0ol00007oookJPCo00004OoonfX3o`0000;ooo]Z1_l007l01?oonf[o0000
o`000?l00002o`00O`?ooo]Z0ol007l8oookJP?o00002_oonfX3o`0000oooo]Z0ol0000;oookJP?o
00003ooonfX3o`0000[ooo]Z1?l0000>oookJPCo00000ol007l3oookJP?o001o0_oonfX3o`000003
o`00Oooonf[o001o00;o001o0ooonfX3o`00O`?ooo]Z0ol0000<oookJP?o00003_oonfX3o`0000_o
oo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z1?l00002o`00O`Cooo]Z1Ol007l3o`000004
oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oook
JP?o00003_oonfX3o`0000cooo]Z0ol0000<oookJP;o001o0ol000001Ooonf[o001oo`00Ool007oo
oo]Z00?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00<ooonfX5
o`0002oooo]Z1?l00005oookJP?o00004_oonfX4o`0000Oooo]Z1?l0000AoookJP?o00000_oonfX2
o`00O`Gooo]Z0ol00002o`00O`?ooo]Z0ol007l8oookJP?o00002_oonfX3o`0000oooo]Z0ol0000;
oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJPCo00000ol007l3oookJP?o001o0_oonfX3
o`000003o`00Oooonf[o001o00;o001o0ooonfX3o`00O`?ooo]Z0ol0000<oookJP?o00003_oonfX3
o`0000_ooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z1?l00002o`00O`Cooo]Z0_l007l3
oookJP?o000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Cooo]Z0ol0000;oookJPCo00003Ooo
nfX3o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000cooo]Z0_l007l3o`000005oookJ_l0
07oo001oo`00OooonfX00ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Go
oo]Z000coookJPGo0000;ooonfX3o`0000Kooo]Z0ol0000BoookJPCo00002?oonfX3o`00017ooo]Z
0ol00002oookJP;o001o1OoonfX3o`0000?o001o00Cooo]Zo`00Ool007oo001o2?oonfX4o`0000[o
oo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX3o`0000Co
001o1?oonfX3o`00O`04oookJ_l0003o0000o`0000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4
oookJP?o00003?oonfX3o`0000kooo]Z0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>
oookJP?o00000ol007l4oookJP;o001o0ooonfX3o`0000;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l5oookJP?o00002ooonfX4o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0
000<oookJP;o001o0ol000001?oonf[o001oo`00Ool007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000coookJPGo0000;_oonfX4o`0000Ko
oo]Z1?l0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00003oookJPKo001o1?l00006o`00O`So
oo]Z1?l0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000ko
oo]Z0ol00004o`00O`Cooo]Z1?l007l3o`0000?ooo]Z1ol007l4oookJP?o00003?oonfX3o`0000ko
oo]Z0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00000ol007l5oookJPCo
001o0ol00002oookJPOo001o1OoonfX3o`0000cooo]Z0ol0000=oookJP?o00003?oonfX3o`0000ko
oo]Z0ol0000<oookJP?o00003OoonfX01?l007oo0000o`000?l00003o`00O`?ooo]Z1ol007l3oook
JPOo001o1_oonfX003?ooo]Z1Ol0000DoookJPCo00005_oonfX4o`0000Kooo]Z1?l0000AoookJP?o
00002OoonfX4o`0000oooo]Z1?l00003oookJPKo001o1?l00005o`00O`Wooo]Z0ol0000;oookJPCo
00003_oonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000kooo]Z0ol000001?oonf[o
001oo`00Ool007l5oookJP?o001o0ol00004oookJPGo001o1OoonfX3o`0000cooo]Z0ol0000>oook
JP?o00002ooonfX4o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000?o001o1OoonfX4o`00
O`?o00000ooonfX5o`00O`Kooo]Z0ol0000<oookJP?o00003OoonfX3o`0000cooo]Z0ol0000>oook
JP?o00003?oonfX3o`0000kooo]Z0ol00002o`00O`Gooo]Z1Ol007l5oookJPGo001o1ooonfX003?o
oo]Z1Ol0000BoookJPOo00005OoonfX3o`0000Sooo]Z0ol0000@oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000>oookJP?o00002ooonfX3o`0000oo
oo]Z0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000ko
oo]Z0ol0000;oookJPCo00003OoonfX3o`0000cooo]Z1?l0000=oookJP?o00003?oonfX3o`0000ko
oo]Z0ol0000<oookJP?o00003OoonfX3o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000go
oo]Z1?l0000MoookJP00<ooonfX5o`00017ooo]Z2_l0000BoookJPCo00002?oonfX3o`00013ooo]Z
1?l0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z
0ol0000;oookJPCo00003_oonfX3o`0000_ooo]Z0ol0000>oookJP?o00003?oonfX4o`0000gooo]Z
0ol0000<oookJP?o00003OoonfX4o`0000cooo]Z0ol0000=oookJP?o00003?oonfX4o`0000gooo]Z
0ol0000<oookJP?o00003OoonfX4o`0000cooo]Z0ol0000=oookJP?o00003?oonfX3o`0000kooo]Z
0ol0000<oookJP?o00003OoonfX4o`0001gooo]Z000coookJPGo00004?oonfX;o`0001;ooo]Z1?l0
0008oookJPCo00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0
000<oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX3o`0000kooo]Z0ol0
000<oookJPCo00003OoonfX3o`0000cooo]Z0ol0000=oookJPCo00003?oonfX3o`0000gooo]Z0ol0
000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJPCo00003?oonfX3o`0000gooo]Z0ol0
000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o00007_oonfX003?ooo]Z1Ol0000?
oookJPGo00000ooonfX4o`0001;ooo]Z0ol00009oookJPCo00003ooonfX3o`0000_ooo]Z0ol0000?
oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=
oookJPCo00002ooonfX3o`0000kooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=
oookJP?o00003OoonfX3o`0000gooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=
oookJP?o00003OoonfX3o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=
oookJP?o00007_oonfX003?ooo]Z1Ol0000>oookJPGo00001OoonfX4o`00013ooo]Z1?l0000:oook
JP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oook
JP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o00003?oonfX3o`0000kooo]Z0ol0000=oook
JP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJP?o00003OoonfX3o`0000gooo]Z0ol0000=oook
JP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJP?o00003OoonfX3o`0000gooo]Z0ol0000<oook
JP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o00007_oonfX003?ooo]Z1Ol0000>oookJPCo
00001_oonfX5o`0000oooo]Z1?l0000:oookJPCo00003_oonfX3o`0000_ooo]Z1?l0000>oookJP?o
00002ooonfX4o`0000gooo]Z0ol0000<oookJP?o00003OoonfX4o`0000cooo]Z0ol0000=oookJP?o
00003?oonfX4o`0000gooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJP?o
00003OoonfX3o`0000gooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJP?o
00003OoonfX3o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o
00007_oonfX002Kooo]Zool0003oo`0001Wo00000ooonfX002Kooo]Zool0003oo`0001Wo00000ooo
nfX002Kooo]Zool0003oo`0001Wo00000ooonfX002Kooo]Zool0003oo`0001Wo00000ooonfX002Ko
oo]Zool0003oo`0001Wo00000ooonfX003?ooo]Z1Ol000000ooonf[o0000o`000009o`00013ooo]Z
1?l0000:oookJPCo00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o00003?oonfX4o`0000gooo]Z
0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o00003OoonfX3o`0000gooo]Z
0ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJP?o00003?oonfX3o`0000gooo]Z
0ol0000<oookJP?o00003_oonfX3o`0000gooo]Z0ol0000;oookJPGo00003?oonfX3o`0000gooo]Z
0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=oookJP?o00003OoonfX3o`0000_ooo]Z
00?o0000oookJ_oonfX04?oonfX003?ooo]Z1Ol00004oookJPKo00004_oonfX4o`0000[ooo]Z0ol0
000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX3o`0000cooo]Z0ol0
000>oookJP?o00003?oonfX3o`0000gooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0
000>oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003OoonfX3o`0000cooo]Z0ol0
000>oookJP?o00003OoonfX3o`0000gooo]Z0ol0000<oookJP?o00003OoonfX3o`0000gooo]Z0ol0
000=oookJP?o00003?oonfX3o`0000gooo]Z0ol0000=oookJP?o00007_oonfX003?ooo]Z1Ol0000M
oookJPCo00002?oonfX4o`0000oooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z0ol0000>
oookJPCo00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003OoonfX4o`0000_ooo]Z1?l0000=
oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=
oookJP?o00003?oonfX3o`0000kooo]Z0ol0000=oookJP?o00003OoonfX3o`0000cooo]Z0ol0000=
oookJP?o00003OoonfX3o`0000gooo]Z0ol0000<oookJP?o00003OoonfX3o`0000gooo]Z0ol0000N
oookJP00<ooonfX5o`0001gooo]Z1Ol00007oookJPCo00004?oonfX3o`0000[ooo]Z0ol0000?oook
JP?o00002ooonfX3o`0000kooo]Z1?l0000;oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oook
JP?o00003?oonfX3o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z1?l0000=oook
JP?o00003?oonfX3o`0000gooo]Z0ol0000<oookJPCo00003OoonfX3o`0000cooo]Z0ol0000=oook
JP?o00003OoonfX3o`0001kooo]Z000coookJPGo00007_oonfX4o`0000Oooo]Z0ol0000AoookJP?o
00002OoonfX4o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o
00002ooonfX4o`0000kooo]Z0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o
00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003OoonfX3o`0000cooo]Z0ol0000>oookJP?o
00003?oonfX4o`0000gooo]Z0ol0000<oookJP?o00003OoonfX3o`0000cooo]Z1?l0000=oookJP?o
00003?oonfX3o`0000gooo]Z0ol0000=oookJP?o00007_oonfX003?ooo]Z1Ol0000OoookJPCo0000
1OoonfX4o`00017ooo]Z0ol00009oookJPCo00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o0000
2ooonfX3o`0000kooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJPCo0000
2ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000=oookJP?o0000
3?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJP?o0000
3?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003OoonfX3o`0000gooo]Z0ol0000NoookJP00<ooo
nfX5o`0001oooo]Z1?l00004oookJPGo00004OoonfX4o`0000Sooo]Z0ol0000@oookJP?o00002_oo
nfX4o`0000oooo]Z0ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z0ol0000?oookJP?o00002ooo
nfX3o`0000kooo]Z1?l0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00002ooo
nfX4o`0000gooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00003?oo
nfX3o`0000gooo]Z1?l0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000=oookJPCo00003?oo
nfX3o`0001kooo]Z000coookJPGo00008?oonfX5o`000003oookJ_l0003o000000?o00004_oonfX4
o`0000Sooo]Z0ol0000@oookJPCo00002OoonfX4o`0000oooo]Z0ol0000:oookJPCo00003_oonfX4
o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX4
o`0000_ooo]Z0ol0000>oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3
o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000gooo]Z1?l0000;oookJP?o00003_oonfX3
o`0000cooo]Z0ol0000=oookJPCo00003?oonfX3o`0001kooo]Z000coookJPGo00008?oonfX:o`00
01Cooo]Z0ol00007oookJPCo00004?oonfX4o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00
013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`00
00kooo]Z1?l0000;oookJP?o00003_oonfX3o`0000_ooo]Z0ol0000>oookJPCo00002ooonfX3o`00
00kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00002ooonfX3o`00
00kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00<ooonfX5o`00027o
oo]Z2?l0000EoookJP?o00001ooonfX4o`00017ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[o
oo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_o
oo]Z0ol0000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0000;oookJP?o00003_oonfX4o`0000_o
oo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000_o
oo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00007_oonfX003?ooo]Z
1Ol0000RoookJPOo00005OoonfX4o`0000Kooo]Z0ol0000BoookJP?o00002OoonfX3o`00013ooo]Z
0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`0000oooo]Z
0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o00002ooonfX3o`0000oooo]Z
0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z
0ol0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o00003?oonfX3o`0001kooo]Z
000coookJPGo00008ooonfX5o`0001Kooo]Z1?l00006oookJP?o00004_oonfX3o`0000Wooo]Z0ol0
000@oookJPCo00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX4o`0000[ooo]Z0ol0
000?oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX3o`0000_ooo]Z0ol0
000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0
000>oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0
000NoookJP00<ooonfX5o`0003oooo]Z1?l00004oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@
oookJPCo00002OoonfX3o`00013ooo]Z0ol00009oookJPCo00003ooonfX4o`0000[ooo]Z0ol0000?
oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX4o`0000[ooo]Z0ol0000?
oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>
oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000N
oookJP00<ooonfX5o`0003oooo]Z1?l00004oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000Aoook
JP?o00002?oonfX4o`00013ooo]Z0ol00009oookJPCo00004?oonfX3o`0000[ooo]Z0ol0000?oook
JP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX4o`0000[ooo]Z0ol0000?oook
JP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oook
JP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000Noook
JP00<ooonfX5o`00043ooo]Z1?l00003oookJP?o00005?oonfX3o`0000Oooo]Z0ol0000BoookJP?o
00002?oonfX4o`00013ooo]Z0ol00009oookJP?o00004OoonfX3o`0000[ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000>oookJP?o
00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00
<ooonfX5o`00043ooo]Z1?l00003oookJP?o00005?oonfX3o`0000Oooo]Z0ol0000BoookJP?o0000
2?oonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z1?l0000?oookJP?o0000
2ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o0000
2ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000>oookJP?o0000
2ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00<ooo
nfX5o`00047ooo]Z0ol00002oookJPCo00005?oonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oo
nfX3o`00017ooo]Z1?l00008oookJP?o00004OoonfX3o`0000Wooo]Z1?l0000?oookJP?o00002ooo
nfX3o`0000oooo]Z0ol0000:oookJPCo00003ooonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooo
nfX3o`0000kooo]Z1?l0000;oookJP?o00003_oonfX3o`0000_ooo]Z1?l0000>oookJP?o00002ooo
nfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00<ooonfX5
o`00047ooo]Z0ol000000ooonf[o0000o`000003o`0001Cooo]Z1?l00006oookJP?o00004_oonfX3
o`0000Sooo]Z0ol0000AoookJPCo00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004?oonfX3
o`0000[ooo]Z1?l0000?oookJP?o00002_oonfX4o`0000oooo]Z0ol0000:oookJP?o00003ooonfX3
o`0000_ooo]Z0ol0000>oookJPCo00002ooonfX3o`0000kooo]Z0ol0000;oookJP?o00003ooonfX3
o`0000_ooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00007_oonfX0
03?ooo]Z1Ol00011oookJPSo00005OoonfX4o`0000Kooo]Z0ol0000BoookJPCo00001ooonfX3o`00
01;ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX4o`00
00oooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJP?o00002ooonfX3o`00
00oooo]Z0ol0000;oookJP?o00003_oonfX3o`0000_ooo]Z0ol0000?oookJP?o00002ooonfX3o`00
00kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00<ooonfX5o`00047o
oo]Z1ol0000GoookJP?o00001OoonfX4o`0001;ooo]Z1?l00007oookJP?o00004_oonfX3o`0000So
oo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z1?l00009oookJP?o00004?oonfX3o`0000[o
oo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z0ol0000:oookJPCo00003ooonfX3o`0000_o
oo]Z0ol0000>oookJP?o00002ooonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX3o`0000co
oo]Z0ol0000>oookJP?o00003?oonfX3o`0001kooo]Z000coookJPGo0000@_oonfX6o`0001Oooo]Z
0ol00005oookJPCo00004ooonfX3o`0000Kooo]Z1?l0000BoookJP?o00002?oonfX3o`00017ooo]Z
1?l00008oookJP?o00004?oonfX4o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z
0ol0000:oookJP?o00003ooonfX3o`0000[ooo]Z1?l0000?oookJP?o00002ooonfX3o`0000kooo]Z
0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>oookJP?o00003?oonfX3o`0000kooo]Z
0ol0000<oookJP?o00007_oonfX003?ooo]Z1Ol00013oookJPCo00006?oonfX4o`0000Cooo]Z0ol0
000DoookJP?o00001_oonfX4o`0001;ooo]Z0ol00008oookJP?o00004OoonfX4o`0000Sooo]Z0ol0
000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000Wooo]Z1?l0
000?oookJP?o00002_oonfX3o`00013ooo]Z0ol0000;oookJP?o00003_oonfX3o`0000_ooo]Z0ol0
000?oookJP?o00002ooonfX3o`0000kooo]Z0ol0000<oookJP?o00003_oonfX3o`0000cooo]Z0ol0
000NoookJP00<ooonfX5o`0005oooo]Z1?l00004oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000C
oookJP?o00001ooonfX4o`0001;ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@
oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJPCo00003ooonfX3o`0000[ooo]Z0ol0000@
oookJP?o00002_oonfX4o`0000kooo]Z0ol0000;oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000>
oookJP?o00003?oonfX3o`0000kooo]Z0ol0000<oookJP?o00007_oonfX003?ooo]Z1Ol0001Poook
JP?o00000ooonfX4o`0001Cooo]Z1?l00005oookJP?o00004ooonfX3o`0000Oooo]Z1?l0000Boook
JP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oook
JP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z1?l0000>oook
JPCo00002_oonfX3o`0000oooo]Z0ol0000;oookJP?o00003_oonfX4o`0000_ooo]Z0ol0000>oook
JP?o00003?oonfX3o`0001kooo]Z000coookJPGo0000H?oonfX3o`0000?ooo]Z1?l0000DoookJPCo
00001OoonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Sooo]Z0ol0000AoookJP?o
00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000@oookJPCo
00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX4o`0000[ooo]Z0ol0000?oookJP?o
00002ooonfX3o`0000kooo]Z1?l0000;oookJP?o00003_oonfX3o`0000cooo]Z0ol0000NoookJP00
<ooonfX5o`00063ooo]Z1?l00002oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000CoookJP?o0000
1ooonfX3o`0001?ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o0000
2_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX4o`0000Wooo]Z0ol0000@oookJP?o0000
2_oonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000?oookJP?o0000
2ooonfX3o`0000kooo]Z0ol0000<oookJP?o00007_oonfX003?ooo]Z1Ol0001PoookJPCo000000?o
oo]Zo`000?l000000_l0000FoookJP?o00001OoonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooo
nfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z1?l00009oookJP?o00004?oo
nfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oo
nfX3o`0000[ooo]Z0ol0000?oookJP?o00002_oonfX4o`0000oooo]Z0ol0000;oookJP?o00003_oo
nfX3o`0000_ooo]Z1?l0000NoookJP00<ooonfX5o`00067ooo]Z2?l0000FoookJP?o00001?oonfX4
o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3
o`00013ooo]Z1?l00009oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3
o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJPCo00002OoonfX4
o`0000oooo]Z0ol0000:oookJPCo00003_oonfX3o`0000_ooo]Z1?l0000NoookJP00<ooonfX5o`00
067ooo]Z1ol0000GoookJPCo00000ooonfX4o`0001?ooo]Z1?l00006oookJP?o00004ooonfX3o`00
00Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00009oookJP?o00004?oonfX3o`00
00Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`00
00[ooo]Z0ol0000?oookJPCo00002OoonfX3o`00013ooo]Z0ol0000:oookJPCo00003_oonfX3o`00
00_ooo]Z0ol0000OoookJP00<ooonfX5o`0006;ooo]Z1_l0000GoookJPCo00000ooonfX3o`0001Co
oo]Z1?l00006oookJP?o00004ooonfX3o`0000Oooo]Z1?l0000AoookJP?o00002OoonfX3o`00017o
oo]Z0ol00008oookJPCo00004?oonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013o
oo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002OoonfX3o`00013o
oo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000OoookJP00<ooonfX5o`0006;ooo]Z
1Ol0000IoookJP?o00000ooonfX3o`0001Gooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z
1?l0000AoookJP?o00002?oonfX4o`00017ooo]Z0ol00008oookJPCo00004?oonfX3o`0000Wooo]Z
0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z
0ol0000@oookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00003ooonfX3o`0000_ooo]Z
0ol0000OoookJP00<ooonfX5o`0006?ooo]Z1?l0000IoookJP?o00000ooonfX3o`0001Gooo]Z0ol0
0006oookJP?o00004ooonfX4o`0000Kooo]Z0ol0000BoookJP?o00002?oonfX4o`00017ooo]Z0ol0
0008oookJP?o00004OoonfX4o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0
000:oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002OoonfX3o`00013ooo]Z0ol0
000:oookJP?o00003ooonfX3o`0000_ooo]Z0ol0000OoookJP00<ooonfX5o`00083ooo]Z0ol00002
oookJPCo00005OoonfX3o`0000Kooo]Z0ol0000CoookJPCo00001_oonfX3o`0001;ooo]Z0ol00008
oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJPCo00002?oonfX3o`00017ooo]Z0ol00009
oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009
oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000?oookJPCo00002_oonfX3o`0001oooo]Z000coook
JPGo0000P?oonfX3o`0000;ooo]Z1?l0000EoookJP?o00001OoonfX4o`0001Cooo]Z0ol00006oook
JP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oook
JP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0000:oook
JP?o00004?oonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`0000oooo]Z1?l0000:oook
JP?o00007ooonfX003?ooo]Z1Ol00020oookJP?o00000_oonfX3o`0001Kooo]Z0ol00005oookJPCo
00005?oonfX3o`0000Kooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00008oookJP?o
00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o
00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o
00004?oonfX3o`0000[ooo]Z0ol0000OoookJP00<ooonfX5o`00083ooo]Z0ol00002oookJP?o0000
5_oonfX4o`0000Cooo]Z0ol0000EoookJP?o00001_oonfX3o`0001;ooo]Z0ol00008oookJP?o0000
4_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o0000
4?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o0000
4?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000P?oo
nfX4o`000004oookJ_l0003o0000o`0001Kooo]Z1?l00004oookJP?o00005OoonfX3o`0000Kooo]Z
0ol0000BoookJPCo00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Sooo]Z
0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z
0ol0000@oookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000[ooo]Z
0ol0000OoookJP00<ooonfX5o`00083ooo]Z2?l0000GoookJP?o00001?oonfX3o`0001Gooo]Z0ol0
0006oookJP?o00004_oonfX4o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol0
0008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0
000:oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol0
000:oookJP?o00007ooonfX003?ooo]Z1Ol00021oookJPOo00005ooonfX3o`0000Cooo]Z0ol0000E
oookJP?o00001_oonfX3o`0001?ooo]Z0ol00006oookJPCo00004_oonfX3o`0000Sooo]Z0ol0000B
oookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004?oonfX4o`0000Wooo]Z0ol0000@
oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000@
oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000POoonfX6o`0001Sooo]Z1?l00003oook
JP?o00005OoonfX3o`0000Kooo]Z0ol0000CoookJP?o00001_oonfX4o`0001;ooo]Z0ol00008oook
JP?o00004_oonfX3o`0000Oooo]Z1?l0000AoookJP?o00002OoonfX3o`00013ooo]Z1?l00009oook
JP?o00004?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oook
JP?o00004?oonfX3o`0000[ooo]Z0ol0000OoookJP00<ooonfX5o`0008;ooo]Z1Ol0000HoookJPCo
00000_oonfX4o`0001Gooo]Z0ol00006oookJP?o00004ooonfX3o`0000Kooo]Z0ol0000CoookJP?o
00002?oonfX3o`0001;ooo]Z0ol00007oookJPCo00004OoonfX4o`0000Sooo]Z0ol0000AoookJP?o
00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000@oookJP?o
00002_oonfX3o`00013ooo]Z0ol0000:oookJP?o00007ooonfX003?ooo]Z1Ol00022oookJPCo0000
6_oonfX3o`0000;ooo]Z1?l0000EoookJP?o00001OoonfX4o`0001?ooo]Z0ol00006oookJP?o0000
4ooonfX3o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z1?l00008oookJP?o0000
4OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o0000
4?oonfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000X?oo
nfX3o`0000;ooo]Z0ol0000FoookJP?o00001OoonfX4o`0001?ooo]Z0ol00006oookJP?o00004ooo
nfX3o`0000Oooo]Z1?l0000BoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJPCo00004Ooo
nfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oo
nfX3o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000X?oonfX3
o`0000;ooo]Z0ol0000FoookJPCo00001?oonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3
o`0000Oooo]Z1?l0000BoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJPCo00004OoonfX3
o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX3
o`0000[ooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000X?oonfX3o`00
00;ooo]Z0ol0000FoookJPCo00001?oonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX4o`00
00Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`00
00Wooo]Z0ol0000@oookJP?o00002_oonfX3o`00013ooo]Z0ol00009oookJP?o00004?oonfX4o`00
00Wooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000X?oonfX4o`000004
oookJ_l0003o0000o`0001Oooo]Z0ol00004oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000Coook
JPCo00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000Boook
JP?o00002?oonfX4o`00013ooo]Z0ol00009oookJPCo00004?oonfX3o`0000Wooo]Z0ol0000@oook
JPCo00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00007ooonfX003?ooo]Z1Ol0002PoookJPSo
00005ooonfX3o`0000Cooo]Z0ol0000DoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o
00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJPCo
00004?oonfX3o`0000Wooo]Z1?l0000@oookJP?o00002OoonfX3o`00017ooo]Z0ol00009oookJP?o
00004?oonfX3o`0000[ooo]Z0ol0000OoookJP00<ooonfX5o`000:7ooo]Z1ol0000GoookJP?o0000
1?oonfX3o`0001Cooo]Z1?l00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o0000
1ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJP?o0000
2OoonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o0000
2_oonfX3o`0001oooo]Z000coookJPGo0000XOoonfX6o`0001Sooo]Z0ol00004oookJP?o00005?oo
nfX4o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooo
nfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`00017ooo]Z0ol00009oookJP?o00004Ooo
nfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00007ooo
nfX003?ooo]Z1Ol0002QoookJPKo00006?oonfX3o`0000?ooo]Z1?l0000EoookJP?o00001?oonfX4
o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3
o`0001;ooo]Z0ol00008oookJP?o00004OoonfX3o`0000Wooo]Z0ol0000AoookJP?o00002OoonfX3
o`00017ooo]Z0ol00009oookJP?o00004?oonfX3o`0000[ooo]Z0ol0000OoookJP00<ooonfX5o`00
0:7ooo]Z1Ol0000IoookJP?o00000ooonfX4o`0001Gooo]Z0ol00004oookJPCo00005?oonfX3o`00
00Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`00
00Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00017ooo]Z0ol00009oookJP?o00004OoonfX3o`00
00Wooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z000coookJPGo0000X_oonfX4o`0001Wo
oo]Z1?l00002oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o00001_oonfX3o`0001?o
oo]Z1?l00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`00017o
oo]Z1?l00008oookJP?o00004OoonfX3o`0000Sooo]Z1?l0000AoookJP?o00002OoonfX3o`00013o
oo]Z0ol0000:oookJP?o00007ooonfX003?ooo]Z1Ol0002ooookJPCo00000_oonfX3o`0001Kooo]Z
0ol00004oookJP?o00005OoonfX3o`0000Kooo]Z0ol0000CoookJPCo00001_oonfX3o`0001?ooo]Z
0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000AoookJPCo00002?oonfX3o`00017ooo]Z
1?l00007oookJPCo00004OoonfX3o`0000Wooo]Z0ol0000@oookJP?o00002_oonfX3o`0001oooo]Z
000coookJPGo0000`?oonfX3o`000003oookJ_l0003o000000;o00005_oonfX3o`0000Cooo]Z0ol0
000EoookJP?o00001_oonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0
000BoookJPCo00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004OoonfX4o`0000Oooo]Z0ol0
000BoookJP?o00002OoonfX3o`00013ooo]Z0ol0000:oookJP?o00007ooonfX003?ooo]Z1Ol00030
oookJP?o000000?ooo]Zo`000?l000000_l0000FoookJPCo00000ooonfX3o`0001Gooo]Z0ol00006
oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z1?l00007
oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z0ol00009
oookJP?o00004?oonfX3o`0000Wooo]Z1?l0000OoookJP00<ooonfX5o`000<3ooo]Z0ol000001?oo
nf[o0000o`000?l0000GoookJPCo00000ooonfX3o`0001Gooo]Z1?l00004oookJPCo00005?oonfX3
o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3
o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z0ol00009oookJP?o00004?oonfX3
o`0000Wooo]Z1?l0000OoookJP00<ooonfX5o`000<3ooo]Z0ol000001?oonf[o0000o`000?l0000H
oookJP?o00000ooonfX3o`0001Gooo]Z1?l00004oookJPCo00005?oonfX3o`0000Kooo]Z0ol0000C
oookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000B
oookJP?o00001ooonfX3o`0001;ooo]Z0ol00009oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000P
oookJP00<ooonfX5o`000<3ooo]Z1ol0000HoookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oook
JP?o00005OoonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oook
JP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z0ol00009oook
JP?o00004?oonfX3o`0000Wooo]Z0ol0000PoookJP00<ooonfX5o`000<3ooo]Z1ol0000HoookJP?o
00000_oonfX4o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`0000Kooo]Z0ol0000CoookJPCo
00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o
00001ooonfX3o`0001;ooo]Z0ol00009oookJP?o00004?oonfX3o`0000Wooo]Z0ol0000PoookJP00
<ooonfX5o`000<7ooo]Z1_l0000HoookJP?o00000_oonfX4o`0001Kooo]Z0ol00004oookJP?o0000
5OoonfX3o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o0000
4_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z0ol00009oookJP?o0000
4?oonfX3o`0000Wooo]Z0ol0000PoookJP00<ooonfX5o`000<7ooo]Z1Ol0000IoookJP?o00000_oo
nfX3o`0001Oooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z1?l0000DoookJP?o00001_oo
nfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000BoookJP?o00001ooo
nfX3o`0001;ooo]Z0ol00008oookJPCo00004?oonfX3o`0000Wooo]Z0ol0000PoookJP00<ooonfX5
o`000<;ooo]Z1?l0000IoookJP?o00000_oonfX3o`0001Oooo]Z0ol00004oookJP?o00005OoonfX3
o`0000Gooo]Z0ol0000EoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3
o`0000Sooo]Z0ol0000BoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJPCo00004?oonfX3
o`0000Wooo]Z0ol0000PoookJP00<ooonfX5o`000=oooo]Z0ol00002oookJP?o00005ooonfX4o`00
00?ooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Gooo]Z0ol00006oookJP?o00004ooonfX3o`00
00Oooo]Z0ol0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00007oookJP?o00004_oonfX3o`00
00Sooo]Z0ol0000AoookJP?o00002OoonfX3o`00023ooo]Z000coookJPGo0000gooonfX4o`000004
oookJ_l0003o0000o`0001Oooo]Z1?l00003oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000Eoook
JP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000Boook
JP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o00004OoonfX4o`0000Sooo]Z0ol0000Poook
JP00<ooonfX5o`000=oooo]Z1?l000001?oonf[o0000o`000?l0000HoookJP?o00000ooonfX3o`00
01Gooo]Z0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z1?l0000CoookJP?o00001_oonfX4o`00
01;ooo]Z0ol00008oookJP?o00004_oonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`00
017ooo]Z1?l00008oookJP?o00008?oonfX003?ooo]Z1Ol0003PoookJP?o000000Cooo]Zo`000?l0
003o00006?oonfX3o`0000?ooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Gooo]Z0ol00005oook
JPCo00004ooonfX3o`0000Kooo]Z1?l0000BoookJP?o00002?oonfX3o`0001;ooo]Z0ol00007oook
JP?o00004_oonfX4o`0000Oooo]Z0ol0000BoookJP?o00002?oonfX3o`00023ooo]Z000coookJPGo
0000h?oonfX7o`0001Sooo]Z0ol00002oookJPCo00005OoonfX3o`0000Gooo]Z0ol0000EoookJP?o
00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z1?l0000BoookJP?o
00001ooonfX3o`0001;ooo]Z1?l00007oookJP?o00004_oonfX3o`0000Sooo]Z0ol0000PoookJP00
<ooonfX5o`000>3ooo]Z1ol0000HoookJP?o00000_oonfX4o`0001Gooo]Z1?l00004oookJP?o0000
5OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`0001?ooo]Z0ol00007oookJPCo0000
4_oonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00008oookJP?o0000
8?oonfX003?ooo]Z1Ol0003PoookJPKo00006OoonfX3o`0000;ooo]Z0ol0000FoookJPCo00001?oo
nfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX4o`0000Gooo]Z0ol0000CoookJP?o00001ooo
nfX3o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00002?oo
nfX3o`00023ooo]Z000coookJPGo0000hOoonfX5o`0001Wooo]Z0ol00002oookJP?o00005ooonfX3
o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z1?l00005oookJP?o00004ooonfX3
o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3
o`0000Sooo]Z0ol0000PoookJP00<ooonfX5o`000>7ooo]Z1Ol0000IoookJP?o00000_oonfX3o`00
01Oooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000EoookJP?o00001OoonfX3o`00
01?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`00
01;ooo]Z0ol00008oookJP?o00008?oonfX003?ooo]Z1Ol0003QoookJPCo00006_oonfX3o`0000;o
oo]Z0ol0000GoookJP?o00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005OoonfX3o`0000Go
oo]Z0ol0000CoookJPCo00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oo
oo]Z0ol0000BoookJP?o00002?oonfX3o`00023ooo]Z000coookJPGo0000oooonfX3o`0000;ooo]Z
0ol0000GoookJP?o00001?oonfX3o`0001Gooo]Z1?l00004oookJP?o00005OoonfX3o`0000Gooo]Z
0ol0000CoookJPCo00001_oonfX3o`0001?ooo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z
0ol0000BoookJP?o00002?oonfX3o`00023ooo]Z000CoookJP?o001o1OoonfX5o`00O`Gooo]Z1Ol0
07l9oookJPGo0000oooonfX4o`000004oookJ_l0003o0000o`0001Oooo]Z0ol00003oookJPCo0000
5OoonfX4o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00006oookJP?o0000
4ooonfX3o`0000Oooo]Z0ol0000CoookJP?o00001ooonfX3o`0001;ooo]Z0ol00007oookJPCo0000
8?oonfX001?ooo]Z0ol007l4oookJPOo001o0ooonfX7o`00O`Sooo]Z1Ol0003ooookJPCo000000Co
oo]Zo`000?l0003o00005ooonfX3o`0000?ooo]Z1?l0000FoookJP?o00001?oonfX3o`0001Gooo]Z
0ol00005oookJP?o00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z
0ol00007oookJP?o00004_oonfX3o`0000Oooo]Z1?l0000PoookJP004ooonfX3o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oo
oo]Z0OoonfX7o`0001Oooo]Z0ol00003oookJP?o00005ooonfX3o`0000Cooo]Z0ol0000EoookJP?o
00001?oonfX4o`0001Cooo]Z0ol00006oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000CoookJP?o
00001ooonfX3o`0001;ooo]Z0ol00007oookJP?o00008OoonfX001?ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000oooonfX1oookJPOo
00005ooonfX3o`0000?ooo]Z0ol0000GoookJP?o00001?oonfX3o`0001Gooo]Z0ol00004oookJPCo
00005?oonfX3o`0000Kooo]Z0ol0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o
00004_oonfX3o`0000Oooo]Z0ol0000QoookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1_l0003ooookJPKo00006?oonfX4o`0000;o
oo]Z0ol0000GoookJP?o00001?oonfX3o`0001Gooo]Z0ol00004oookJP?o00005OoonfX3o`0000Go
oo]Z1?l0000CoookJP?o00001ooonfX3o`0001?ooo]Z0ol00007oookJP?o00004_oonfX3o`0000Oo
oo]Z0ol0000QoookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJP7ooo]Z1_l0000HoookJPCo00000_oonfX3o`0001Oo
oo]Z0ol00004oookJP?o00005OoonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX4o`0001?o
oo]Z0ol00007oookJP?o00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooonfX3o`00027o
oo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1ooonfX5o`000?oooo]Z0OoonfX6o`0001Wooo]Z0ol000000ooonf[o0000o`000002o`0001Oo
oo]Z0ol00003oookJPCo00005OoonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Co
oo]Z0ol00006oookJPCo00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooonfX3o`00027o
oo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1ooonfX5o`000?oooo]Z0_oonfX4o`0001[ooo]Z0ol000000ooonf[o0000o`000002o`0001Oo
oo]Z0ol00003oookJPCo00005OoonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Co
oo]Z0ol00006oookJPCo00004ooonfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooonfX3o`00027o
oo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1ooonfX5o`000?oooo]Z0_oonfX4o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000Hoook
JP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000Doook
JPCo00001OoonfX3o`0001Cooo]Z0ol00007oookJP?o00004_oonfX3o`0000Oooo]Z0ol0000Qoook
JP004?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Oooo]Z1Ol0003ooookJR3ooo]Z0ol000001?oonf[o0000o`000?l0000HoookJP?o00000ooonfX3
o`0001Kooo]Z0ol00004oookJP?o00005OoonfX4o`0000Cooo]Z0ol0000DoookJPCo00001OoonfX3
o`0001Cooo]Z0ol00007oookJP?o00004_oonfX3o`0000Oooo]Z0ol0000QoookJP004?oonfX6o`00
O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX5o`000?oooo]Z8?oonfX7o`0001Sooo]Z0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0
000EoookJPCo00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Oooo]Z0ol0
000BoookJP?o00001ooonfX3o`00027ooo]Z000BoookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007l8
oookJPGo0000oooonfXPoookJPOo00006?oonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3
o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001ooonfX3
o`0001;ooo]Z0ol00007oookJP?o00008OoonfX001?ooo]Z0ol007l5oookJPGo001o1OoonfX5o`00
O`Wooo]Z1Ol0003ooookJR7ooo]Z1_l0000HoookJP?o00000ooonfX3o`0001Kooo]Z1?l00003oook
JP?o00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00007oook
JP?o00004_oonfX3o`0000Oooo]Z0ol0000QoookJP00<ooonfX5o`000?oooo]Z8OoonfX6o`0001So
oo]Z0ol00002oookJPCo00005_oonfX4o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0001Go
oo]Z0ol00005oookJP?o00005?oonfX3o`0000Oooo]Z0ol0000BoookJP?o00001ooonfX3o`00027o
oo]Z000coookJPGo0000oooonfXQoookJPKo00006?oonfX3o`0000;ooo]Z1?l0000GoookJP?o0000
0ooonfX3o`0001Kooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o0000
1ooonfX3o`0001;ooo]Z0ol00007oookJP?o00008OoonfX003?ooo]Z1Ol0003ooookJR7ooo]Z1_l0
000HoookJPCo000000Cooo]Zo`000?l0003o00006?oonfX3o`0000;ooo]Z1?l0000FoookJP?o0000
1?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Oooo]Z0ol0000BoookJPCo0000
1_oonfX3o`00027ooo]Z000coookJPGo0000oooonfXQoookJPGo00006OoonfX4o`000004oookJ_l0
003o0000o`0001Sooo]Z0ol00002oookJPCo00005_oonfX3o`0000Cooo]Z0ol0000EoookJP?o0000
1OoonfX3o`0001Cooo]Z0ol00006oookJPCo00004_oonfX4o`0000Kooo]Z0ol0000QoookJP00<ooo
nfX5o`000?oooo]Z8OoonfX5o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000HoookJP?o0000
0_oonfX3o`0001Oooo]Z0ol00004oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJPCo0000
1OoonfX4o`0001?ooo]Z0ol00006oookJP?o00008OoonfX003?ooo]Z1Ol0003ooookJR;ooo]Z1?l0
000JoookJP?o000000Cooo]Zo`000?l0003o00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o0000
1?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX4o`0000Gooo]Z0ol0000DoookJP?o0000
1_oonfX3o`00027ooo]Z000coookJPGo0000oooonfY0oookJP?o000000Cooo]Zo`000?l0003o0000
6?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX4o`0001Gooo]Z0ol00005oookJP?o0000
5OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`00027ooo]Z000coookJPGo0000oooo
nfY0oookJP?o000000Cooo]Zo`000?l0003o00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o0000
0ooonfX4o`0001Gooo]Z0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o0000
1_oonfX3o`00027ooo]Z000coookJPGo0000oooonfY0oookJP?o000000Cooo]Zo`000?l0003o0000
6?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol00005oookJP?o0000
5OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`00027ooo]Z000coookJPGo0000oooo
nfY0oookJPOo00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol0
0005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3o`00027ooo]Z000c
oookJPGo0000oooonfY0oookJPOo00006?oonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3
o`0001Kooo]Z0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001_oonfX3
o`00027ooo]Z000coookJPGo0000oooonfY1oookJPGo00006OoonfX4o`000004oookJ_l0003o0000
o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Gooo]Z0ol0000EoookJP?o00001OoonfX3
o`0001Cooo]Z0ol00005oookJPCo00008OoonfX003?ooo]Z1Ol0003ooookJT7ooo]Z1Ol0000Ioook
JPCo000000Cooo]Zo`000?l0003o00005ooonfX3o`0000?ooo]Z0ol0000FoookJP?o00001OoonfX3
o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Gooo]Z1?l0000QoookJP00<ooonfX5o`00
0?oooo]Z@OoonfX5o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000GoookJP?o00000ooonfX3
o`0001Kooo]Z0ol00005oookJP?o00005OoonfX3o`0000Gooo]Z0ol0000DoookJP?o00001OoonfX3
o`0002;ooo]Z000coookJPGo0000oooonfY1oookJPGo00006_oonfX7o`0001Oooo]Z0ol00003oook
JP?o00005_oonfX4o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z0ol00005oook
JP?o00008_oonfX003?ooo]Z1Ol0003ooookJT;ooo]Z0ol0000KoookJPOo00005ooonfX3o`0000?o
oo]Z0ol0000FoookJPCo00001?oonfX3o`0001Gooo]Z0ol00005oookJP?o00005?oonfX3o`0000Go
oo]Z0ol0000RoookJP00<ooonfX5o`000?oooo]ZH?oonfX6o`0001Sooo]Z1?l00002oookJP?o0000
5ooonfX3o`0000Cooo]Z0ol0000EoookJP?o00001OoonfX3o`0001Cooo]Z1?l00004oookJP?o0000
8_oonfX003?ooo]Z1Ol0003ooookJV3ooo]Z1_l0000HoookJPCo00000_oonfX3o`0001Oooo]Z0ol0
0003oookJPCo00005OoonfX3o`0000Gooo]Z0ol0000DoookJPCo00001?oonfX3o`0002;ooo]Z000c
oookJPGo0000oooonfYPoookJPKo00006OoonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX4
o`0001Gooo]Z0ol00005oookJP?o00005OoonfX3o`0000Cooo]Z0ol0000RoookJP00<ooonfX5o`00
0?oooo]ZH?oonfX6o`0001Wooo]Z0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000Foook
JP?o00001OoonfX3o`0001Gooo]Z0ol00004oookJP?o00008_oonfX003?ooo]Z1Ol0003ooookJV3o
oo]Z1_l0000IoookJP?o000000?ooo]Zo`000?l000000_l0000GoookJP?o00000ooonfX3o`0001Ko
oo]Z0ol00005oookJP?o00005OoonfX3o`0000Cooo]Z0ol0000RoookJP00<ooonfX5o`000?oooo]Z
H?oonfX6o`0001Wooo]Z0ol000000ooonf[o0000o`000002o`0001Oooo]Z0ol00003oookJP?o0000
5_oonfX3o`0000Cooo]Z1?l0000EoookJP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooo
nfYQoookJPGo00006OoonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00003oookJP?o0000
5_oonfX3o`0000Cooo]Z1?l0000EoookJP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooo
nfYQoookJPGo00006OoonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00003oookJP?o0000
5_oonfX4o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooo
nfYQoookJPCo00006_oonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z1?l00002oookJP?o0000
5_oonfX4o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooo
nfYQoookJPCo00006_oonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z1?l00002oookJP?o0000
5ooonfX3o`0000?ooo]Z0ol0000FoookJP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooo
nfYooookJPOo00006OoonfX3o`0000;ooo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol0
0004oookJP?o00008_oonfX003?ooo]Z1Ol0003ooookJWoooo]Z1ol0000IoookJP?o00000_oonfX3
o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0000RoookJP00<ooonfX5o`00
0?oooo]ZP?oonfX6o`0001Wooo]Z0ol00002oookJP?o00005ooonfX3o`0000?ooo]Z0ol0000Foook
JP?o00001?oonfX3o`0002;ooo]Z000coookJPGo0000oooonfZ0oookJPKo00006OoonfX3o`0000;o
oo]Z0ol0000GoookJP?o00000ooonfX3o`0001Kooo]Z0ol00004oookJP?o00008_oonfX003?ooo]Z
1Ol0003ooookJX3ooo]Z1_l0000IoookJP?o00000_oonfX3o`0001Oooo]Z0ol00003oookJP?o0000
5_oonfX3o`0000Cooo]Z0ol0000RoookJP00<ooonfX5o`000?oooo]ZP?oonfX6o`0001Wooo]Z0ol0
00000ooonf[o0000o`000002o`0001Oooo]Z0ol00003oookJP?o00005_oonfX3o`0000Cooo]Z0ol0
000RoookJP00<ooonfX5o`000?oooo]ZP?oonfX5o`0001[ooo]Z0ol000000ooonf[o0000o`000002
o`0001Oooo]Z0ol00002oookJPCo00005_oonfX3o`0000Cooo]Z0ol0000RoookJP00<ooonfX5o`00
0?oooo]ZP?oonfX5o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0000HoookJP?o00000_oonfX4
o`0001Kooo]Z0ol00004oookJP?o00008_oonfX003?ooo]Z1Ol0003ooookJX7ooo]Z1?l0000Joook
JP?o000000Cooo]Zo`000?l0003o00006?oonfX3o`0000;ooo]Z0ol0000GoookJPCo00000ooonfX3
o`0002;ooo]Z000coookJPGo0000oooonfZ1oookJPCo00006_oonfX3o`000004oookJ_l0003o0000
o`0001Sooo]Z0ol00002oookJP?o00005ooonfX4o`0000?ooo]Z0ol0000RoookJP00<ooonfX5o`00
0?oooo]ZWooonfX3o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00002oookJP?o00006?oonfX3
o`0000;ooo]Z1?l0000RoookJP00<ooonfX5o`000?oooo]ZWooonfX7o`0001Sooo]Z0ol00002oook
JP?o00006?oonfX3o`0000;ooo]Z1?l0000RoookJP00<ooonfX5o`000?oooo]ZWooonfX7o`0001So
oo]Z0ol00002oookJP?o00006?oonfX3o`0000;ooo]Z0ol0000SoookJP00<ooonfX5o`000?oooo]Z
WooonfX6o`0001Wooo]Z0ol00002oookJP?o00006?oonfX3o`0000;ooo]Z0ol0000SoookJP00<ooo
nfX5o`000?oooo]ZX?oonfX5o`0001Wooo]Z0ol00002oookJP?o00006?oonfX3o`0000;ooo]Z0ol0
000SoookJP00<ooonfX5o`000?oooo]ZX?oonfX5o`0001Wooo]Z1?l000001?oonf[o0000o`000?l0
000HoookJP?o00000_oonfX3o`0002?ooo]Z000coookJPGo0000oooonfZPoookJPGo00006OoonfX4
o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00002oookJP?o00008ooonfX003?ooo]Z1Ol0003o
oookJZ3ooo]Z1Ol0000JoookJP?o000000Cooo]Zo`000?l0003o00006?oonfX3o`0000;ooo]Z0ol0
000SoookJP00<ooonfX5o`000?oooo]ZX?oonfX5o`0001[ooo]Z0ol000001?oonf[o0000o`000?l0
000HoookJP?o00000_oonfX3o`0002?ooo]Z000coookJPGo0000oooonfZQoookJPCo00006_oonfX3
o`000004oookJ_l0003o0000o`0001Sooo]Z0ol00002oookJP?o00008ooonfX003?ooo]Z1Ol0003o
oookJZ7ooo]Z0ol0000KoookJPOo00006?oonfX3o`0000;ooo]Z0ol0000SoookJP00<ooonfX5o`00
0?oooo]Z_ooonfX7o`0001Sooo]Z0ol00002oookJP?o00008ooonfX003?ooo]Z1Ol0003ooookJ[oo
oo]Z1_l0000IoookJP?o00000_oonfX3o`0002?ooo]Z000coookJPGo0000oooonf[0oookJPGo0000
6OoonfX3o`0000;ooo]Z0ol0000SoookJP00<ooonfX5o`000?oooo]Z`?oonfX5o`0001Wooo]Z0ol0
00000ooonf[o0000o`000002o`0002?ooo]Z000coookJPGo0000oooonf[0oookJPGo00006OoonfX3
o`000003oookJ_l0003o000000;o00008ooonfX003?ooo]Z1Ol0003ooookJ/3ooo]Z1Ol0000Ioook
JP?o000000Cooo]Zo`000?l0003o00009?oonfX003?ooo]Z1Ol0003ooookJ/3ooo]Z1Ol0000Ioook
JP?o000000Cooo]Zo`000?l0003o00009?oonfX003?ooo]Z1Ol0003ooookJ/3ooo]Z1?l0000Joook
JPOo00009?oonfX003?ooo]Z1Ol0003ooookJ/3ooo]Z1?l0000JoookJPOo00009?oonfX003?ooo]Z
1Ol0003ooookJ]oooo]Z1_l0000ToookJP00<ooonfX5o`000?oooo]ZgooonfX6o`0002Cooo]Z000c
oookJPGo0000oooonf[OoookJPKo00009?oonfX003?ooo]Z1Ol0003ooookJ]oooo]Z1_l0000Toook
JP00<ooonfX5o`000?oooo]ZgooonfX6o`0002Cooo]Z000coookJPGo0000oooonf[OoookJPKo0000
9?oonfX003?ooo]Z1Ol0003ooookJ]oooo]Z1_l0000ToookJP00<ooonfX5o`000?oooo]Zh?oonfX4
o`0002Gooo]Z000coookJPGo0000oooonf[PoookJPCo00009OoonfX003?ooo]Z1Ol0003ooookJ^3o
oo]Z1?l0000UoookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP003ooonfX9o`00O`?ooo]Z1Ol0
07l5oookJPGo001o2OoonfX5o`000?oooo]ZoooonfX:oookJP003ooonfX9o`00O`;ooo]Z1ol007l3
oookJPOo001o2?oonfX5o`000?oooo]ZoooonfX:oookJP003ooonfX4o`00O`Oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Zoooo
nfX:oookJP004?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z2_oonfX0017ooo]Z1Ol007l3oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPKo0000oooonf[ooookJPWooo]Z000C
oookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooo
nfX5o`000?oooo]ZoooonfX:oookJP005?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z2_oonfX001Gooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z
1Ol0003ooookJ_oooo]Z2_oonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007oooookJ_oooo]Z5_oonfX000oooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007oooookJ_oooo]Z5_oonfX000oooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJ_oooo]Z5ooonfX0
013ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00Oooooo]ZoooonfXGoookJP004OoonfX5o`00O`Go
oo]Z1Ol007l5oookJPGo001ooooonf[ooookJQSooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-21.2358, -221.757, \
0.396482, 1.24956}},
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"]
}, Open  ]],

Cell["Undamped Near Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1, 0, 1/2\  + \ \ 0.05, 1/2]], {t, 0, 200}, 
      PlotPoints \[Rule] 200]\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.307366 0.00797824 [
[.2619 .29487 -12 -20 ]
[.2619 .29487 12 0 ]
[.5 .29487 -17 -20 ]
[.5 .29487 17 0 ]
[.7381 .29487 -17 -20 ]
[.7381 .29487 17 0 ]
[.97619 .29487 -17 -20 ]
[.97619 .29487 17 0 ]
[.01131 .06802 -36.9375 -10 ]
[.01131 .06802 0 10 ]
[.01131 .1478 -36.9375 -10 ]
[.01131 .1478 0 10 ]
[.01131 .22758 -36.9375 -10 ]
[.01131 .22758 0 10 ]
[.01131 .38715 -24 -10 ]
[.01131 .38715 0 10 ]
[.01131 .46693 -24 -10 ]
[.01131 .46693 0 10 ]
[.01131 .54671 -24 -10 ]
[.01131 .54671 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30737 m
.2619 .31362 L
s
gsave
.2619 .29487 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .30737 m
.5 .31362 L
s
gsave
.5 .29487 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .30737 m
.7381 .31362 L
s
gsave
.7381 .29487 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .30737 m
.97619 .31362 L
s
gsave
.97619 .29487 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30737 m
.07143 .31112 L
s
.11905 .30737 m
.11905 .31112 L
s
.16667 .30737 m
.16667 .31112 L
s
.21429 .30737 m
.21429 .31112 L
s
.30952 .30737 m
.30952 .31112 L
s
.35714 .30737 m
.35714 .31112 L
s
.40476 .30737 m
.40476 .31112 L
s
.45238 .30737 m
.45238 .31112 L
s
.54762 .30737 m
.54762 .31112 L
s
.59524 .30737 m
.59524 .31112 L
s
.64286 .30737 m
.64286 .31112 L
s
.69048 .30737 m
.69048 .31112 L
s
.78571 .30737 m
.78571 .31112 L
s
.83333 .30737 m
.83333 .31112 L
s
.88095 .30737 m
.88095 .31112 L
s
.92857 .30737 m
.92857 .31112 L
s
.01 w
0 .30737 m
1 .30737 L
s
.25 Mabswid
.02381 .06802 m
.03006 .06802 L
s
gsave
.01131 .06802 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.02381 .1478 m
.03006 .1478 L
s
gsave
.01131 .1478 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02381 .22758 m
.03006 .22758 L
s
gsave
.01131 .22758 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .38715 m
.03006 .38715 L
s
gsave
.01131 .38715 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .46693 m
.03006 .46693 L
s
gsave
.01131 .46693 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02381 .54671 m
.03006 .54671 L
s
gsave
.01131 .54671 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .08397 m
.02756 .08397 L
s
.02381 .09993 m
.02756 .09993 L
s
.02381 .11589 m
.02756 .11589 L
s
.02381 .13184 m
.02756 .13184 L
s
.02381 .16376 m
.02756 .16376 L
s
.02381 .17971 m
.02756 .17971 L
s
.02381 .19567 m
.02756 .19567 L
s
.02381 .21163 m
.02756 .21163 L
s
.02381 .24354 m
.02756 .24354 L
s
.02381 .2595 m
.02756 .2595 L
s
.02381 .27545 m
.02756 .27545 L
s
.02381 .29141 m
.02756 .29141 L
s
.02381 .32332 m
.02756 .32332 L
s
.02381 .33928 m
.02756 .33928 L
s
.02381 .35523 m
.02756 .35523 L
s
.02381 .37119 m
.02756 .37119 L
s
.02381 .4031 m
.02756 .4031 L
s
.02381 .41906 m
.02756 .41906 L
s
.02381 .43502 m
.02756 .43502 L
s
.02381 .45097 m
.02756 .45097 L
s
.02381 .48289 m
.02756 .48289 L
s
.02381 .49884 m
.02756 .49884 L
s
.02381 .5148 m
.02756 .5148 L
s
.02381 .53076 m
.02756 .53076 L
s
.02381 .05206 m
.02756 .05206 L
s
.02381 .03611 m
.02756 .03611 L
s
.02381 .02015 m
.02756 .02015 L
s
.02381 .00419 m
.02756 .00419 L
s
.02381 .56267 m
.02756 .56267 L
s
.02381 .57863 m
.02756 .57863 L
s
.02381 .59458 m
.02756 .59458 L
s
.02381 .61054 m
.02756 .61054 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .31534 m
.02395 .31535 L
.02408 .31535 L
.02423 .31537 L
.02437 .31538 L
.02462 .31542 L
.02489 .31549 L
.02519 .31558 L
.02551 .3157 L
.02608 .31597 L
.02722 .31673 L
.02847 .31787 L
.03109 .32104 L
.03355 .32446 L
.03579 .32736 L
.03697 .3286 L
.03762 .32916 L
.03823 .32959 L
.03856 .32979 L
.03892 .32996 L
.03925 .33008 L
.0394 .33013 L
.03955 .33016 L
.0397 .33019 L
.03983 .33021 L
.03998 .33023 L
.04007 .33023 L
.04015 .33023 L
.0403 .33023 L
.04045 .33022 L
.04061 .3302 L
.04069 .33019 L
.04078 .33017 L
.04093 .33013 L
.04109 .33009 L
.04138 .32997 L
.04169 .32982 L
.04203 .3296 L
.04263 .32909 L
.0432 .32847 L
.04447 .32658 L
.04567 .32412 L
.04791 .31777 L
.05032 .30856 L
.05255 .29829 L
.0573 .27359 L
.05969 .2617 L
.06187 .25242 L
.06299 .24853 L
.06421 .24513 L
Mistroke
.06488 .24368 L
.06551 .24263 L
.0661 .24189 L
.06643 .24159 L
.06659 .24149 L
.06673 .2414 L
.06687 .24134 L
.06701 .24129 L
.0671 .24127 L
.06718 .24126 L
.06732 .24124 L
.06748 .24125 L
.06762 .24127 L
.06778 .24132 L
.06786 .24135 L
.06795 .24139 L
.06822 .24156 L
.06852 .24182 L
.0688 .24213 L
.06906 .24248 L
.06964 .24348 L
.07028 .24493 L
.07157 .24895 L
.07281 .25422 L
.07394 .26014 L
.07647 .27706 L
.0813 .3198 L
.08594 .36468 L
.0883 .38478 L
.08955 .39391 L
.09088 .4022 L
.09217 .40846 L
.09278 .41079 L
.09334 .41256 L
.09391 .41394 L
.09421 .4145 L
.09452 .41498 L
.09466 .41514 L
.0948 .41529 L
.09492 .4154 L
.09506 .4155 L
.0952 .41557 L
.09536 .41562 L
.09551 .41564 L
.09564 .41563 L
.0958 .41559 L
.09587 .41556 L
.09596 .41551 L
.09611 .41541 L
.09625 .41528 L
Mistroke
.09657 .4149 L
.09691 .41434 L
.09754 .4129 L
.09811 .41112 L
.09926 .40618 L
.10035 .39985 L
.10274 .38072 L
.10496 .35721 L
.10968 .29475 L
.1147 .22527 L
.11721 .19603 L
.11832 .18538 L
.11953 .17555 L
.1207 .1681 L
.12126 .1653 L
.12179 .16312 L
.12208 .16214 L
.1224 .16123 L
.12266 .1606 L
.12295 .16006 L
.1231 .15983 L
.12326 .15963 L
.12335 .15954 L
.12343 .15947 L
.12351 .15941 L
.12359 .15936 L
.12373 .15931 L
.12388 .15929 L
.12402 .15932 L
.12418 .15938 L
.12433 .15949 L
.12449 .15965 L
.12467 .15987 L
.12483 .16013 L
.12511 .1607 L
.12542 .16149 L
.12612 .16392 L
.12676 .16693 L
.12801 .1749 L
.12919 .18499 L
.13158 .2123 L
.1338 .24467 L
.13853 .32761 L
.14095 .37173 L
.14356 .41588 L
.14587 .44891 L
.14718 .46412 L
.1484 .47559 L
.14956 .48384 L
.15021 .48725 L
Mistroke
.15081 .48956 L
.15113 .4905 L
.15143 .49116 L
.15159 .49143 L
.15176 .49166 L
.15185 .49175 L
.15194 .49183 L
.15203 .49189 L
.15211 .49192 L
.15227 .49195 L
.15242 .49193 L
.1525 .49189 L
.15258 .49185 L
.15266 .49178 L
.15275 .4917 L
.1529 .49151 L
.15304 .49129 L
.15335 .49064 L
.15365 .48982 L
.15392 .4889 L
.15452 .48623 L
.15509 .48301 L
.15562 .47931 L
.15681 .4688 L
.15811 .45399 L
.16049 .41852 L
.16303 .37124 L
.16758 .27279 L
.17011 .21803 L
.17243 .17252 L
.17484 .13339 L
.17602 .11831 L
.17709 .10722 L
.17819 .0986 L
.1788 .09513 L
.17937 .09271 L
.17967 .09178 L
.17984 .09136 L
.17999 .09104 L
.18014 .0908 L
.18027 .09063 L
.18041 .09049 L
.18057 .0904 L
.18065 .09038 L
.18073 .09038 L
.18089 .09042 L
.18098 .09048 L
.18107 .09055 L
.18124 .09075 L
.18139 .091 L
Mistroke
.18154 .09129 L
.18187 .09216 L
.18217 .09319 L
.18244 .09433 L
.18304 .09761 L
.18414 .10594 L
.18542 .11952 L
.18664 .13599 L
.18904 .17801 L
.19126 .22587 L
.196 .3435 L
.20056 .45215 L
.2029 .49679 L
.2041 .51533 L
.20541 .53157 L
.20602 .53756 L
.20667 .54283 L
.20728 .54673 L
.20783 .54934 L
.20816 .55045 L
.20846 .55121 L
.20862 .55149 L
.20879 .55173 L
.20888 .55181 L
.20898 .55187 L
.20906 .55191 L
.20914 .55192 L
.2093 .55189 L
.20945 .55179 L
.20952 .55172 L
.20961 .55161 L
.20978 .55134 L
.20993 .55103 L
.21009 .55062 L
.21038 .54969 L
.21098 .54698 L
.21153 .54352 L
.21214 .53869 L
.21279 .53234 L
.21413 .51569 L
.21534 .49649 L
.22015 .38918 L
.22479 .26079 L
.22713 .1969 L
.22972 .13427 L
.2309 .10973 L
.23217 .08692 L
.23336 .06931 L
.23446 .05655 L
.23505 .05121 L
Mistroke
.23568 .04671 L
.23604 .04469 L
.23638 .04316 L
.23668 .0421 L
.23685 .04164 L
.23701 .04129 L
.23715 .04105 L
.23731 .04086 L
.23739 .04079 L
.23747 .04074 L
.23763 .04071 L
.2377 .04072 L
.23779 .04076 L
.23794 .04088 L
.23802 .04097 L
.2381 .04109 L
.23827 .04142 L
.23857 .04218 L
.23883 .04312 L
.23944 .04609 L
.24001 .04998 L
.24062 .05528 L
.24172 .06774 L
.24303 .08722 L
.24422 .10901 L
.24904 .22898 L
.25368 .36788 L
.25603 .43552 L
.25861 .50053 L
.2598 .52557 L
.26107 .54843 L
.26226 .56565 L
.26337 .5777 L
.26396 .58253 L
.26459 .58639 L
.26495 .588 L
.26513 .58863 L
.26529 .58911 L
.26543 .58947 L
.26559 .58978 L
.26567 .58989 L
.26575 .59 L
.26584 .59008 L
.26592 .59014 L
.266 .59017 L
.26608 .59018 L
.26623 .59013 L
.26632 .59008 L
.2664 .59 L
.26648 .58989 L
Mistroke
.26657 .58975 L
.26674 .58942 L
.2669 .58902 L
.26719 .58804 L
.26748 .58681 L
.26774 .58541 L
.26835 .58135 L
.26896 .57599 L
.26962 .5688 L
.27082 .5522 L
.27306 .5098 L
.27547 .45047 L
.278 .37655 L
.28258 .23269 L
.28513 .15781 L
.28745 .09925 L
.28861 .07495 L
.28986 .05272 L
.29105 .03614 L
.29214 .02487 L
.2927 .02071 L
.29299 .01896 L
.2933 .01744 L
.29357 .01638 L
.29372 .01592 L
.29387 .01552 L
.29401 .01521 L
.29414 .015 L
.29427 .01485 L
.29439 .01475 L
.29454 .01472 L
.29469 .01476 L
.29477 .01481 L
.29486 .01489 L
.29501 .01511 L
.29516 .01541 L
.29531 .01576 L
.29558 .01664 L
.2959 .01801 L
.2962 .0196 L
.29688 .02436 L
.29749 .03005 L
.29815 .03763 L
.29935 .05502 L
.3016 .09915 L
.30655 .23676 L
.31131 .38983 L
.3159 .51694 L
.31825 .56354 L
.31957 .58232 L
Mistroke
.32015 .58879 L
.32077 .59438 L
.32134 .59835 L
.32167 .60009 L
.32197 .60139 L
.32225 .60228 L
.32238 .60261 L
.3225 .60286 L
.32264 .60307 L
.32278 .60323 L
.32293 .60331 L
.32308 .60331 L
.32316 .60328 L
.32325 .60322 L
.3234 .60304 L
.32349 .60291 L
.32357 .60276 L
.32375 .60232 L
.32406 .60133 L
.32439 .59989 L
.32501 .59612 L
.32558 .59149 L
.32677 .57819 L
.32788 .56169 L
.33038 .51089 L
.33511 .3771 L
.34013 .21608 L
.34266 .1429 L
.34498 .08689 L
.34724 .04605 L
.34839 .03156 L
.34903 .02528 L
.34964 .02072 L
.34993 .01896 L
.35024 .01742 L
.35041 .01675 L
.35058 .01613 L
.35075 .01565 L
.3509 .0153 L
.35105 .01503 L
.3512 .01485 L
.35135 .01474 L
.35144 .01472 L
.35152 .01472 L
.35167 .01478 L
.3518 .0149 L
.35195 .01512 L
.3521 .0154 L
.35237 .01613 L
.35266 .01719 L
Mistroke
.35317 .01982 L
.35373 .02368 L
.35434 .02913 L
.35557 .04392 L
.35669 .0616 L
.35921 .11439 L
.36402 .25074 L
.36864 .39556 L
.37098 .46183 L
.37356 .52254 L
.37473 .54457 L
.376 .56378 L
.37658 .57093 L
.3772 .57728 L
.37776 .58202 L
.37829 .58551 L
.37858 .587 L
.3789 .5883 L
.37903 .58876 L
.37918 .58918 L
.37932 .58951 L
.37944 .58975 L
.37959 .58996 L
.37975 .59011 L
.37989 .59017 L
.38003 .59016 L
.38011 .59013 L
.38019 .59007 L
.38034 .58991 L
.38043 .58977 L
.38051 .58962 L
.38067 .58926 L
.38094 .58846 L
.38123 .58734 L
.38174 .58466 L
.38229 .58081 L
.38289 .57544 L
.38412 .56082 L
.38524 .54348 L
.38777 .49214 L
.39258 .36069 L
.39721 .22243 L
.39955 .15963 L
.40213 .10258 L
.40331 .082 L
.40458 .06422 L
.40516 .05764 L
.40578 .05186 L
.40634 .0476 L
.40687 .0445 L
Mistroke
.40716 .0432 L
.40748 .0421 L
.40762 .04171 L
.40776 .04137 L
.4079 .04112 L
.40803 .04094 L
.40817 .04079 L
.40833 .04072 L
.40848 .04071 L
.40861 .04078 L
.40869 .04084 L
.40877 .04093 L
.40892 .04114 L
.40908 .04145 L
.40926 .04189 L
.40955 .04281 L
.40981 .04389 L
.4104 .04713 L
.41092 .05089 L
.41148 .05577 L
.41262 .06885 L
.41385 .08696 L
.41607 .12917 L
.42107 .25621 L
.42588 .38971 L
.42809 .44406 L
.43052 .49366 L
.43167 .51249 L
.43291 .52888 L
.4336 .53612 L
.43422 .54157 L
.43485 .54591 L
.43545 .54895 L
.43576 .55012 L
.43606 .55095 L
.43619 .55124 L
.43632 .55148 L
.43647 .55169 L
.43661 .55182 L
.43675 .5519 L
.43691 .55192 L
.43706 .55186 L
.43719 .55175 L
.43735 .55156 L
.43753 .55126 L
.43784 .5505 L
.43811 .54963 L
.4384 .54843 L
.43899 .54523 L
.43954 .54138 L
Mistroke
.44006 .537 L
.44124 .5242 L
.44249 .50687 L
.44473 .46722 L
.44932 .36101 L
.45422 .23845 L
.45648 .18812 L
.45893 .14303 L
.46027 .12362 L
.4615 .10947 L
.46268 .0995 L
.46328 .09584 L
.46359 .09428 L
.46393 .09288 L
.46426 .09183 L
.46442 .09143 L
.46456 .09111 L
.4647 .09086 L
.46485 .09065 L
.46501 .09049 L
.46516 .09041 L
.4653 .09038 L
.46545 .0904 L
.4656 .09049 L
.46574 .09062 L
.46588 .0908 L
.466 .09101 L
.46628 .09161 L
.4666 .09257 L
.4669 .09369 L
.46758 .09707 L
.46817 .10099 L
.4688 .10609 L
.47116 .13312 L
.47336 .16839 L
.47804 .26389 L
.48301 .37157 L
.48549 .41792 L
.48779 .45253 L
.48894 .46605 L
.49002 .47632 L
.49062 .48092 L
.49127 .48501 L
.49186 .48792 L
.4924 .4899 L
.49269 .4907 L
.49296 .49126 L
.49311 .4915 L
.49327 .4917 L
.49343 .49184 L
Mistroke
.49357 .49192 L
.4937 .49195 L
.49382 .49195 L
.49396 .4919 L
.4941 .49181 L
.49424 .49167 L
.4944 .49148 L
.49467 .491 L
.49496 .49029 L
.49528 .48932 L
.49586 .48701 L
.49654 .48336 L
.49716 .4792 L
.49947 .4572 L
.50198 .42339 L
.50691 .33823 L
.51166 .2536 L
.51405 .21751 L
.51623 .191 L
.51743 .17957 L
.51857 .17099 L
.51915 .16749 L
.51978 .16444 L
.52013 .16301 L
.52046 .16191 L
.52076 .16106 L
.52109 .16032 L
.52124 .16005 L
.5214 .15981 L
.52153 .15964 L
.52168 .1595 L
.52177 .15943 L
.52185 .15938 L
.52201 .15931 L
.52215 .15929 L
.5223 .15931 L
.52243 .15937 L
.52257 .15946 L
.52271 .15957 L
.52283 .15971 L
.52312 .16013 L
.52341 .16072 L
.52404 .16246 L
.52461 .16467 L
.52593 .17172 L
.5272 .18107 L
.5284 .19194 L
.53064 .21677 L
.53528 .27969 L
.54022 .34712 L
Mistroke
.54268 .37488 L
.54388 .38619 L
.54498 .39505 L
.54603 .40215 L
.54718 .40821 L
.54782 .41078 L
.5484 .41267 L
.54896 .41405 L
.54924 .41458 L
.54955 .41504 L
.54983 .41535 L
.54999 .41547 L
.55014 .41556 L
.5503 .41561 L
.55044 .41564 L
.55052 .41564 L
.55061 .41563 L
.55077 .41559 L
.5509 .41553 L
.55105 .41544 L
.5512 .41531 L
.55135 .41516 L
.5516 .41483 L
.55188 .41438 L
.55255 .41288 L
.55319 .41094 L
.5544 .40601 L
.55555 .39979 L
.55678 .39174 L
.559 .37423 L
.56402 .32666 L
.56653 .30259 L
.56885 .28253 L
.57125 .26511 L
.5735 .25284 L
.57459 .24841 L
.57577 .24484 L
.57644 .24336 L
.57677 .24277 L
.57707 .24231 L
.57734 .24198 L
.57764 .24168 L
.57794 .24146 L
.57811 .24137 L
.57826 .24131 L
.5784 .24127 L
.57856 .24125 L
.5787 .24124 L
.57883 .24125 L
.57898 .24129 L
Mistroke
.57907 .24131 L
.57915 .24134 L
.5793 .24141 L
.57945 .2415 L
.57974 .24172 L
.58005 .24203 L
.5807 .24291 L
.58126 .24393 L
.58177 .24505 L
.58293 .24822 L
.58522 .25674 L
.58772 .26848 L
.59263 .2941 L
.5949 .30507 L
.59736 .31514 L
.59871 .31967 L
.59995 .32313 L
.60113 .32579 L
.60178 .32698 L
.60238 .3279 L
.60293 .3286 L
.60353 .32922 L
.60385 .3295 L
.60416 .32971 L
.60446 .32989 L
.60475 .33002 L
.605 .33011 L
.60513 .33014 L
.60526 .33018 L
.60541 .3302 L
.60556 .33022 L
.6057 .33023 L
.60583 .33023 L
.60598 .33023 L
.60612 .33022 L
.60624 .3302 L
.60638 .33018 L
.60653 .33015 L
.60668 .33011 L
.60697 .33001 L
.60756 .32973 L
.60811 .32938 L
.60933 .32833 L
.61154 .32572 L
.61404 .32227 L
.61634 .31922 L
.6175 .31792 L
.61858 .31691 L
.61971 .3161 L
.62031 .31578 L
Mistroke
.62063 .31565 L
.62096 .31553 L
.62128 .31545 L
.62156 .3154 L
.6217 .31538 L
.62185 .31536 L
.62199 .31535 L
.62212 .31534 L
.62227 .31534 L
.62241 .31535 L
.62256 .31536 L
.62265 .31537 L
.62273 .31538 L
.62289 .3154 L
.62306 .31543 L
.62338 .31551 L
.62371 .31562 L
.62402 .31574 L
.6247 .31609 L
.62592 .31698 L
.62713 .31815 L
.62824 .31943 L
.63076 .32279 L
.63322 .32617 L
.63442 .32763 L
.63552 .32874 L
.63607 .3292 L
.63666 .32961 L
.63693 .32977 L
.63722 .32991 L
.63749 .33002 L
.63773 .33011 L
.63801 .33018 L
.63816 .3302 L
.63831 .33022 L
.63845 .33023 L
.63857 .33023 L
.63871 .33023 L
.63886 .33022 L
.63894 .33021 L
.63902 .3302 L
.6392 .33017 L
.63935 .33013 L
.63951 .33008 L
.63979 .32997 L
.6401 .32981 L
.64073 .32936 L
.64133 .32878 L
.64245 .32728 L
.64366 .32503 L
Mistroke
.64497 .32182 L
.64735 .31406 L
.64988 .30338 L
.65491 .27774 L
.65743 .26483 L
.65975 .25445 L
.66092 .25007 L
.66201 .24667 L
.66316 .24393 L
.66376 .24285 L
.66407 .24239 L
.66441 .24199 L
.66471 .24169 L
.66487 .24156 L
.66505 .24145 L
.66521 .24137 L
.66535 .24131 L
.6655 .24127 L
.66564 .24125 L
.66572 .24124 L
.6658 .24124 L
.66589 .24125 L
.66597 .24126 L
.66612 .2413 L
.6662 .24133 L
.66628 .24136 L
.66644 .24144 L
.66662 .24156 L
.66697 .24187 L
.66729 .24225 L
.66758 .24266 L
.66823 .24387 L
.66883 .24532 L
.6694 .247 L
.67057 .25131 L
.6718 .25719 L
.67402 .27089 L
.67858 .30906 L
.68342 .35612 L
.68565 .37625 L
.68809 .39488 L
.68926 .40205 L
.6905 .40819 L
.69119 .41085 L
.69182 .41277 L
.69212 .41353 L
.69245 .41423 L
.69274 .41472 L
.6929 .41495 L
.69305 .41514 L
Mistroke
.6932 .41529 L
.69336 .41543 L
.6935 .41552 L
.69364 .41559 L
.69378 .41563 L
.69391 .41564 L
.69405 .41563 L
.69419 .41559 L
.69434 .41552 L
.69442 .41547 L
.6945 .41541 L
.69479 .41513 L
.69496 .41492 L
.69513 .41465 L
.69544 .41407 L
.69613 .41235 L
.69677 .41013 L
.69798 .40445 L
.69915 .39713 L
.70039 .38746 L
.70261 .36565 L
.70717 .30757 L
.71202 .23931 L
.71425 .21105 L
.71552 .19701 L
.71669 .1856 L
.71796 .17531 L
.71911 .16802 L
.71975 .1649 L
.72035 .16258 L
.72065 .16162 L
.72098 .16078 L
.72115 .16042 L
.72133 .16008 L
.7215 .15982 L
.72166 .15962 L
.72181 .15948 L
.72196 .15938 L
.72212 .15931 L
.72221 .1593 L
.72229 .15929 L
.72244 .15932 L
.72258 .15938 L
.72273 .15949 L
.72289 .15965 L
.72317 .16003 L
.72342 .16051 L
.72401 .16207 L
.72434 .16321 L
.72465 .16447 L
Mistroke
.72523 .1673 L
.72653 .17586 L
.7277 .18607 L
.72894 .19933 L
.73116 .22879 L
.73573 .30553 L
.74059 .39345 L
.74283 .42916 L
.74527 .4608 L
.74659 .47385 L
.74723 .479 L
.74782 .48297 L
.74838 .48613 L
.74899 .4888 L
.74932 .48993 L
.74963 .49075 L
.74993 .49133 L
.75008 .49155 L
.75015 .49165 L
.75024 .49174 L
.7504 .49187 L
.75054 .49193 L
.7507 .49195 L
.75079 .49194 L
.75087 .49191 L
.75102 .49181 L
.75116 .49168 L
.75131 .49149 L
.75147 .49123 L
.75175 .49064 L
.75201 .48994 L
.75259 .48778 L
.75323 .48454 L
.75381 .48081 L
.75512 .46976 L
.75632 .45636 L
.75743 .44149 L
.75994 .40003 L
.76469 .30134 L
.76926 .20251 L
.77181 .15543 L
.77413 .12175 L
.77528 .10919 L
.77589 .10378 L
.77653 .09899 L
.77715 .09536 L
.77772 .09291 L
.77799 .09202 L
.77828 .09127 L
.77842 .091 L
Mistroke
.77856 .09077 L
.77868 .09061 L
.77881 .09049 L
.77897 .0904 L
.77912 .09038 L
.77919 .09039 L
.77928 .09041 L
.77936 .09046 L
.77945 .09053 L
.7796 .0907 L
.77974 .0909 L
.78005 .09155 L
.78032 .09234 L
.78062 .09343 L
.78117 .09602 L
.7818 .10001 L
.78248 .1054 L
.7837 .11801 L
.78493 .13452 L
.78628 .15625 L
.78871 .20445 L
.79365 .32435 L
.79841 .44027 L
.8008 .48827 L
.80299 .52188 L
.80419 .53545 L
.80475 .54038 L
.80534 .54469 L
.80564 .54649 L
.80596 .54818 L
.80627 .54947 L
.80655 .55041 L
.80687 .55123 L
.80704 .55153 L
.80713 .55165 L
.80722 .55176 L
.80738 .55187 L
.80753 .55192 L
.80762 .55191 L
.8077 .55189 L
.80786 .55178 L
.808 .55163 L
.80815 .5514 L
.80842 .55081 L
.80874 .54983 L
.80903 .54867 L
.80967 .54528 L
.81027 .54096 L
.81134 .53078 L
.8125 .51609 L
Mistroke
.81487 .47527 L
.8174 .41846 L
.82242 .28232 L
.82494 .21257 L
.82726 .15388 L
.82966 .10273 L
.83191 .06734 L
.83301 .05514 L
.83362 .04988 L
.83418 .0461 L
.83448 .04449 L
.8348 .0431 L
.83496 .04249 L
.83514 .04193 L
.83531 .04151 L
.83546 .0412 L
.83561 .04097 L
.83576 .04081 L
.83592 .04072 L
.83601 .04071 L
.83609 .04072 L
.83624 .04079 L
.83637 .04092 L
.83653 .04114 L
.83668 .04142 L
.83696 .04218 L
.83723 .04313 L
.83785 .04617 L
.83845 .05031 L
.83909 .05601 L
.84026 .06956 L
.84132 .08543 L
.84361 .1301 L
.84612 .19212 L
.85103 .33634 L
.85576 .47053 L
.85835 .5285 L
.85953 .54946 L
.86078 .56717 L
.86194 .57925 L
.8626 .58417 L
.86291 .58601 L
.86321 .58744 L
.86348 .58849 L
.86362 .58894 L
.86378 .58934 L
.8639 .58962 L
.86404 .58986 L
.86417 .59002 L
.86429 .59012 L
Mistroke
.86444 .59018 L
.86458 .59016 L
.86471 .59009 L
.86484 .58994 L
.86499 .58971 L
.86515 .58938 L
.86544 .58857 L
.86576 .58736 L
.86609 .58571 L
.86668 .58182 L
.86732 .57632 L
.86802 .56872 L
.86928 .55119 L
.87046 .53052 L
.87515 .41417 L
.88014 .25896 L
.88263 .1831 L
.88494 .12078 L
.88718 .07151 L
.88832 .05184 L
.88956 .03471 L
.89016 .02836 L
.89078 .02295 L
.89131 .0194 L
.89161 .01783 L
.8919 .01664 L
.89206 .0161 L
.89223 .01562 L
.89237 .01529 L
.89253 .01502 L
.89262 .0149 L
.8927 .01482 L
.89278 .01476 L
.89288 .01472 L
.89296 .01472 L
.89305 .01474 L
.8932 .01484 L
.89335 .01501 L
.8935 .01528 L
.89365 .01561 L
.89378 .01597 L
.89411 .01713 L
.89441 .01857 L
.89498 .02206 L
.89559 .02716 L
.89684 .04138 L
.89799 .05905 L
.89907 .07917 L
.90377 .20038 L
.90876 .35976 L
Mistroke
.91126 .43691 L
.91357 .49971 L
.91582 .54893 L
.91695 .56835 L
.91756 .57712 L
.9182 .58504 L
.91879 .59104 L
.91942 .59626 L
.9197 .59811 L
.92 .59977 L
.92028 .60104 L
.92054 .60197 L
.9207 .60241 L
.92087 .60279 L
.92104 .60307 L
.92113 .60318 L
.92122 .60326 L
.9213 .6033 L
.92138 .60332 L
.92153 .60329 L
.92169 .60318 L
.92178 .60308 L
.92186 .60295 L
.922 .60269 L
.92213 .60237 L
.92244 .60141 L
.92274 .60015 L
.92306 .59844 L
.92365 .5943 L
.92421 .58932 L
.92547 .57413 L
.9267 .55438 L
.92801 .52827 L
.93301 .39261 L
.93783 .23793 L
.94247 .10727 L
.94486 .05837 L
.94607 .04014 L
.94675 .03192 L
.9474 .02556 L
.94798 .02106 L
.94829 .01916 L
.94862 .0175 L
.94893 .01631 L
.9492 .01552 L
.94934 .01523 L
.94948 .01499 L
.94962 .01483 L
.94974 .01475 L
.94989 .01472 L
Mistroke
.95004 .01477 L
.95019 .01489 L
.95032 .01508 L
.95048 .01537 L
.95065 .01579 L
.95097 .01683 L
.95129 .01828 L
.95164 .02022 L
.95226 .02476 L
.95339 .03638 L
.95461 .05358 L
.95681 .09593 L
.96178 .23094 L
.96656 .38107 L
.97116 .50545 L
.97352 .55105 L
.97485 .56941 L
.97605 .5812 L
.97619 .58226 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wo
oo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0
003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooook
J_oooo]Z5?oonfX002Wooo]Z1Ol0002=oookJPGo00006_oonfX4o`000?oooo]Z8OoonfX5o`0001[o
oo]Z1Ol0000NoookJP00:OoonfX5o`0008gooo]Z1Ol0000JoookJPGo0000oooonfXPoookJPGo0000
6_oonfX5o`0001kooo]Z000YoookJPGo0000SOoonfX5o`0001Wooo]Z1_l0003ooookJR3ooo]Z1Ol0
000JoookJPGo00007_oonfX002Wooo]Z1Ol0002<oookJPKo00006OoonfX6o`000?oooo]Z8?oonfX5
o`0001Wooo]Z1_l0000NoookJP00:OoonfX5o`0008cooo]Z1_l0000IoookJPKo0000oooonfXPoook
JPKo00006?oonfX6o`0001kooo]Z000YoookJPGo0000S?oonfX7o`0001Sooo]Z1_l0003ooookJQoo
oo]Z1ol0000HoookJPOo00007OoonfX002Wooo]Z1Ol0002<oookJPOo00006?oonfX6o`000?oooo]Z
7ooonfX7o`0001Sooo]Z1ol0000MoookJP00:OoonfX5o`0008cooo]Z1ol0000HoookJPOo0000oooo
nfXNoookJPOo00006?oonfX7o`0001gooo]Z000YoookJPGo0000S?oonfX7o`0001Oooo]Z2?l0003o
oookJQkooo]Z1ol0000HoookJPOo00007OoonfX002Wooo]Z1Ol0002<oookJPOo00005ooonfX8o`00
0?oooo]Z7_oonfX7o`0001Sooo]Z1ol0000MoookJP00:OoonfX5o`0008cooo]Z1ol0000GoookJPSo
0000oooonfXNoookJPOo00006?oonfX7o`0001gooo]Z000YoookJPGo0000S?oonfX7o`0001Oooo]Z
2?l0003ooookJQkooo]Z1ol0000HoookJPOo00007OoonfX002Wooo]Z1Ol0002<oookJPOo00005ooo
nfX8o`000?oooo]Z7_oonfX8o`0001Kooo]Z2?l0000MoookJP00:OoonfX5o`0008cooo]Z1ol0000G
oookJPSo0000oooonfXNoookJPSo00005_oonfX8o`0001gooo]Z000YoookJPGo0000K_oonfX5o`00
01Wooo]Z1ol0000GoookJPSo00006OoonfX4o`000>?ooo]Z1?l0000IoookJPSo00005_oonfX8o`00
01gooo]Z000YoookJPGo0000K_oonfX5o`0001Wooo]Z1ol0000GoookJPSo00006?oonfX6o`000>7o
oo]Z1Ol0000IoookJPSo00005_oonfX8o`0001gooo]Z000YoookJPGo0000K_oonfX5o`0001Wooo]Z
1ol0000GoookJPSo00006?oonfX6o`000>7ooo]Z1Ol0000HoookJPWo00005_oonfX8o`0001gooo]Z
000YoookJPGo0000K_oonfX6o`0001Oooo]Z2?l0000GoookJPSo00006?oonfX6o`000>7ooo]Z1_l0
000GoookJPWo00005_oonfX9o`0001cooo]Z000YoookJPGo0000K_oonfX6o`0001Oooo]Z2Ol0000F
oookJPSo00006?oonfX6o`000>7ooo]Z1_l0000GoookJPWo00005_oonfX9o`0001cooo]Z000Yoook
JPGo0000KOoonfX7o`0001Oooo]Z2Ol0000FoookJPSo00006?oonfX6o`000>7ooo]Z1_l0000Goook
JPCo000000?ooo]Zo`000?l000000_l0000FoookJPWo00007?oonfX002Wooo]Z1Ol0001]oookJPOo
00005ooonfX9o`0001Kooo]Z2?l0000GoookJPOo0000hOoonfX6o`0001Oooo]Z1?l000000ooonf[o
0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001cooo]Z000YoookJPGo0000
KOoonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z2Ol0000FoookJPOo0000
h?oonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000
o`000002o`0001cooo]Z000YoookJPGo0000KOoonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`00
0002o`0001Kooo]Z2Ol0000FoookJPSo0000gooonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`00
0002o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001cooo]Z000YoookJPGo0000KOoonfX7
o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z2Ol0000FoookJPSo0000gooonfX7
o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000002
o`0001cooo]Z000YoookJPGo0000KOoonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`00
01Kooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z2?l0003OoookJPOo00005ooonfX4o`00
0003oookJ_l0003o000000;o00005_oonfX4o`000003oookJ_l0003o000000;o00007?oonfX002Wo
oo]Z1Ol0001]oookJPOo00005ooonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`000003
oookJ_l0003o000000;o00005_oonfX8o`000=oooo]Z1ol0000GoookJPCo000000?ooo]Zo`000?l0
00000_l0000FoookJPCo000000?ooo]Zo`000?l000000_l0000LoookJP004OoonfX5o`00O`Gooo]Z
1Ol007l9oookJPGo0000KOoonfX8o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z
1?l000000ooonf[o0000o`000002o`0001Kooo]Z2?l0003OoookJPOo00005_oonfX5o`000003oook
J_l0003o000000;o00005_oonfX4o`000003oookJ_l0003o000000;o00007?oonfX0013ooo]Z1ol0
07l3oookJPOo001o2?oonfX5o`0006cooo]Z2Ol0000FoookJPCo000000?ooo]Zo`000?l000000_l0
000FoookJPCo000000?ooo]Zo`000?l000000_l0000FoookJPSo0000gooonfX8o`0001Gooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001cooo]Z000?
oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000K?oo
nfX9o`0001Gooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`00
0002o`0001Kooo]Z2?l0003OoookJPSo00005OoonfX5o`000003oookJ_l0003o000000;o00005_oo
nfX4o`000003oookJ_l0003o000000;o00007?oonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000K?oonfX9o`0001Gooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Gooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z2?l0
003OoookJPSo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo000000?ooo]Zo`000?l000000_l0
000LoookJP000ooonfX:o`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooo
nfX7o`0006[ooo]Z1?l000000ooonf[o0000o`000002o`0001Gooo]Z1Ol000000ooonf[o0000o`00
0002o`0001Gooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z2?l0003OoookJPSo00005Ooo
nfX4o`0000;ooo]Z1Ol0000EoookJPCo000000?ooo]Zo`000?l000000_l0000LoookJP005OoonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000K?oonfX4o`000003oookJ_l0
003o000000;o00005OoonfX4o`0000;ooo]Z1?l0000EoookJPGo000000?ooo]Zo`000?l000000_l0
000FoookJPSo0000gooonfX8o`0001Gooo]Z1?l00002oookJPGo00005?oonfX5o`000003oookJ_l0
003o000000;o00007?oonfX001?ooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001/
oookJPCo000000?ooo]Zo`000?l000000_l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l00002
oookJPCo00005OoonfX9o`000=oooo]Z2?l0000EoookJPCo00000_oonfX5o`0001Cooo]Z1Ol00000
0ooonf[o0000o`000002o`0001cooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000K?oonfX4o`000003oookJ_l0003o000000;o00005OoonfX4o`0000;ooo]Z1?l0000Eoook
JPCo00000_oonfX4o`0001Gooo]Z2Ol0003OoookJPSo00005OoonfX4o`0000?ooo]Z1?l0000Doook
JPGo000000?ooo]Zo`000?l000000ol0000KoookJP005OoonfX2o`00O`;ooo]Z0ol007l3oookJP?o
001o1ooonfX5o`0006cooo]Z1?l000000ooonf[o0000o`000002o`0001Gooo]Z1?l00002oookJPCo
00005OoonfX4o`0000;ooo]Z1?l0000EoookJPWo0000gooonfX8o`0001Gooo]Z1?l00003oookJPCo
00005?oonfX4o`0000;ooo]Z1Ol0000KoookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`0006cooo]Z1?l000000ooonf[o0000o`000003o`0001Co
oo]Z1?l00002oookJPGo00005?oonfX4o`0000;ooo]Z1?l0000EoookJPCo000000?ooo]Zo`000?l0
00000ol0003MoookJP[o00005?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00000_oonfX5o`0001_o
oo]Z000?oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000K?oonfX4o`000003oookJ_l0003o000000?o00005?oonfX4o`0000;ooo]Z1Ol0000DoookJPCo
00000_oonfX4o`0001Gooo]Z1?l000000ooonf[o0000o`000003o`000=gooo]Z2_l0000DoookJPCo
00000ooonfX4o`0001Cooo]Z1?l00003oookJPCo00006ooonfX0013ooo]Z1ol007l3oookJPOo001o
2?oonfX5o`0006cooo]Z1?l000000ooonf[o0000o`000003o`0001Cooo]Z1?l00002oookJPGo0000
5?oonfX4o`0000;ooo]Z1?l0000EoookJPCo000000?ooo]Zo`000?l000000ol0003MoookJP[o0000
5?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001_ooo]Z000AoookJPGo001o1Ooo
nfX5o`00O`Wooo]Z1Ol0001/oookJPCo00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oo
nfX4o`0000;ooo]Z1?l0000EoookJPCo00000_oonfX4o`000=gooo]Z1?l00002oookJPCo00005?oo
nfX4o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001_ooo]Z000YoookJPGo0000K?oonfX4
o`0000;ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Cooo]Z1?l00002oookJPCo00005OoonfX4
o`0000;ooo]Z1?l0003MoookJPCo00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oonfX4
o`0000?ooo]Z1?l0000KoookJP00:OoonfX5o`00057ooo]Z0_l0000IoookJPCo00000_oonfX4o`00
01Cooo]Z1?l00003oookJPCo00005?oonfX4o`0000;ooo]Z1Ol0000DoookJPCo00000_oonfX4o`00
0<?ooo]Z0_l0000HoookJPCo00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oonfX4o`00
00?ooo]Z1?l0000KoookJP00:OoonfX5o`0004oooo]Z1Ol0000HoookJPCo00000_oonfX4o`0001Co
oo]Z1?l00003oookJPCo00005?oonfX4o`0000;ooo]Z1Ol0000DoookJPCo00000_oonfX4o`0001Oo
oo]Z1Ol0002UoookJPGo00005ooonfX4o`0000;ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Co
oo]Z1?l00003oookJPCo00006ooonfX002Wooo]Z1Ol0001?oookJPKo00005ooonfX4o`0000;ooo]Z
1?l0000DoookJPCo00000ooonfX4o`0001Cooo]Z1?l00002oookJPGo00005?oonfX4o`0000;ooo]Z
1?l0000GoookJPGo0000Y?oonfX6o`0001Oooo]Z1?l00002oookJPCo00005?oonfX4o`0000?ooo]Z
1?l0000DoookJPCo00000ooonfX4o`0001_ooo]Z000YoookJPGo0000CooonfX6o`0001Oooo]Z1?l0
0002oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001?ooo]Z1Ol0
0002oookJPCo00005ooonfX5o`000:Cooo]Z1_l0000GoookJPCo00000_oonfX4o`0001Cooo]Z1?l0
0003oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000KoookJP00:OoonfX5o`0004oooo]Z1_l0000G
oookJPCo00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000C
oookJPGo00000_oonfX4o`0001Oooo]Z1Ol0002ToookJPKo00005_oonfX5o`0000;ooo]Z1?l0000D
oookJPCo00000ooonfX4o`0001?ooo]Z1Ol00003oookJPCo00006ooonfX002Wooo]Z1Ol0001?oook
JPKo00005ooonfX4o`0000;ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Cooo]Z1?l00003oook
JPCo00004ooonfX5o`0000;ooo]Z1?l0000GoookJPKo0000XooonfX6o`0001Kooo]Z1Ol00002oook
JPCo00004ooonfX5o`0000?ooo]Z1?l0000CoookJPGo00000ooonfX4o`0001_ooo]Z000YoookJPGo
0000CooonfX6o`0001Kooo]Z1Ol00002oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000DoookJPCo
00000ooonfX4o`0001?ooo]Z1?l00003oookJPCo00005_oonfX7o`000:?ooo]Z1ol0000EoookJPGo
00000_oonfX4o`0001?ooo]Z1Ol00003oookJPCo00004ooonfX5o`0000?ooo]Z1?l0000KoookJP00
:OoonfX5o`0004oooo]Z1_l0000FoookJPGo00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo0000
4ooonfX5o`0000?ooo]Z1?l0000CoookJPCo00000ooonfX4o`0001Kooo]Z1ol0002SoookJPOo0000
5OoonfX4o`0000?ooo]Z1?l0000CoookJPGo00000ooonfX4o`0001?ooo]Z1?l00004oookJPCo0000
6ooonfX002Wooo]Z1Ol0001>oookJPSo00005OoonfX5o`0000;ooo]Z1?l0000DoookJPCo00000ooo
nfX4o`0001?ooo]Z1Ol00003oookJPCo00004ooonfX4o`0000?ooo]Z1?l0000FoookJPOo0000X_oo
nfX8o`0001Gooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oo
nfX4o`0001_ooo]Z000YoookJPGo0000C_oonfX8o`0001Gooo]Z1?l00003oookJPCo00005?oonfX4
o`0000?ooo]Z1?l0000CoookJPGo00000ooonfX4o`0001?ooo]Z1?l00003oookJPCo00005_oonfX7
o`000:;ooo]Z2?l0000EoookJPCo00000ooonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4
o`0000Cooo]Z1?l0000KoookJP00:OoonfX5o`0004kooo]Z2?l0000EoookJPCo00000ooonfX4o`00
01Cooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00000ooonfX4o`00
01Kooo]Z1ol0002RoookJPSo00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`00
01?ooo]Z1?l00004oookJPCo00006ooonfX002Wooo]Z1Ol0001>oookJPSo00005OoonfX4o`0000?o
oo]Z1?l0000DoookJPCo00000ooonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4o`0000?o
oo]Z1Ol0000EoookJPOo0000X_oonfX8o`0001Gooo]Z1?l00003oookJPGo00004_oonfX4o`0000Co
oo]Z1?l0000CoookJPCo00001?oonfX4o`0001_ooo]Z000YoookJPGo0000C_oonfX8o`0001Gooo]Z
1?l00003oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z
1?l00003oookJPGo00005OoonfX7o`000:;ooo]Z2?l0000EoookJPCo00000ooonfX5o`0001;ooo]Z
1?l00004oookJPGo00004_oonfX4o`0000Cooo]Z1?l0000KoookJP00:OoonfX5o`0004kooo]Z2?l0
000EoookJPCo00000ooonfX4o`0001Cooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0
000CoookJPCo00000ooonfX5o`0001Gooo]Z1ol0002RoookJPWo00005?oonfX4o`0000?ooo]Z1Ol0
000BoookJPCo00001?oonfX5o`0001;ooo]Z1?l00004oookJPCo00006ooonfX002Wooo]Z1Ol0001=
oookJPWo00005OoonfX4o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001?ooo]Z1?l00004
oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000EoookJPSo0000XOoonfX9o`0001Cooo]Z1?l00004
oookJPCo00004_oonfX4o`0000Cooo]Z1Ol0000BoookJPCo00001?oonfX4o`0001_ooo]Z000Yoook
JPGo0000COoonfX9o`0001Gooo]Z1?l00003oookJPCo00004ooonfX5o`0000?ooo]Z1?l0000Coook
JPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005OoonfX8o`000:3ooo]Z2_l0000Doook
JPCo00001?oonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Cooo]Z1?l0000Koook
JP00:OoonfX5o`0004gooo]Z2Ol0000EoookJPCo00000ooonfX4o`0001?ooo]Z1Ol00003oookJPCo
00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z2Ol0002PoookJPGo
000000?ooo]Zo`000?l000000_l0000DoookJPCo00001?oonfX4o`0001;ooo]Z1?l00005oookJPCo
00004_oonfX4o`0000Cooo]Z1?l0000KoookJP00:OoonfX5o`0004gooo]Z1?l000000ooonf[o0000
o`000002o`0001Gooo]Z1?l00003oookJPCo00004ooonfX5o`0000?ooo]Z1?l0000CoookJPCo0000
1?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX9o`000:3ooo]Z1Ol000000ooonf[o0000
o`000002o`0001Cooo]Z1?l00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPCo0000
1?oonfX5o`0001[ooo]Z000YoookJPGo0000COoonfX4o`000003oookJ_l0003o000000;o00005Ooo
nfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooo
nfX4o`0000Cooo]Z1?l0000DoookJPWo0000X?oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oo
nfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Cooo]Z1Ol0000JoookJP00:OoonfX5
o`0004gooo]Z1?l000000ooonf[o0000o`000002o`0001Cooo]Z1Ol00003oookJPCo00004ooonfX4
o`0000Cooo]Z1Ol0000BoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4
o`000003oookJ_l0003o000000;o0000X?oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Cooo]Z1Ol0000JoookJP00:OoonfX5o`00
04gooo]Z1?l000000ooonf[o0000o`000002o`0001Cooo]Z1Ol00003oookJPCo00004ooonfX4o`00
00Cooo]Z1Ol0000BoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`00
0003oookJ_l0003o000000;o0000X?oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`00
01;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000JoookJP00:OoonfX5o`0004go
oo]Z1?l000000ooonf[o0000o`000002o`0001Cooo]Z1Ol00003oookJPCo00004ooonfX4o`0000Co
oo]Z1Ol0000BoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`000003
oookJ_l0003o000000?o0000WooonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001;o
oo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000JoookJP00:OoonfX5o`0004gooo]Z
1?l000000ooonf[o0000o`000003o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4o`0000Gooo]Z
1?l0000AoookJPGo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`000003oook
J_l0003o000000?o0000WooonfX4o`0000;ooo]Z1?l0000CoookJPGo00001?oonfX4o`0001;ooo]Z
1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000JoookJP00:OoonfX5o`0004gooo]Z1?l0
00000ooonf[o0000o`000003o`0001?ooo]Z1?l00004oookJPGo00004_oonfX4o`0000Gooo]Z1?l0
000AoookJPGo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`000003oookJ_l0
003o000000?o0000WooonfX4o`0000;ooo]Z1?l0000CoookJPGo00001?oonfX4o`0001;ooo]Z1?l0
0005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000JoookJP00:OoonfX5o`0004gooo]Z1?l00000
0ooonf[o0000o`000003o`0001?ooo]Z1?l00004oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000A
oookJPGo00001?oonfX4o`0001;ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000;ooo]Z1?l0002O
oookJPCo00000_oonfX4o`0001?ooo]Z1Ol00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000B
oookJPCo00001OoonfX4o`0001[ooo]Z000YoookJPGo0000COoonfX4o`0000;ooo]Z1?l0000Coook
JPCo00001?oonfX5o`0001;ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000Boook
JPGo00001?oonfX4o`0001?ooo]Z1Ol00002oookJPCo0000WooonfX4o`0000;ooo]Z1?l0000Coook
JPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000Joook
JP00:OoonfX5o`0004gooo]Z1?l00002oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000BoookJPCo
00001OoonfX4o`00017ooo]Z1?l00005oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000CoookJPGo
00000_oonfX4o`0009oooo]Z1?l00002oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000BoookJPCo
00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00006_oonfX002Wooo]Z1Ol0001=oookJPCo0000
0_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000AoookJPCo0000
1OoonfX5o`00017ooo]Z1?l00005oookJPCo00004ooonfX5o`0000;ooo]Z1?l0002OoookJPCo0000
0_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPCo0000
1OoonfX4o`0001[ooo]Z000YoookJPGo0000COoonfX4o`0000;ooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001;ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0000AoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00003oookJPCo0000W_oonfX5o`0000;ooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000JoookJP003ooonfX9
o`00O`?ooo]Z1Ol007l9oookJPGo0000COoonfX4o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001;ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0000AoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00003oookJPCo0000W_oonfX5o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001;ooo]Z1?l00005oookJPCo00004OoonfX5o`0000Gooo]Z1?l0000JoookJP003ooonfX9o`00
O`;ooo]Z1ol007l8oookJPGo0000C?oonfX5o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX4o`00
017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00003oookJPCo0000W_oonfX5o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01;ooo]Z1?l00005oookJPCo00004OoonfX5o`0000Gooo]Z1?l0000JoookJP003ooonfX4o`00O`Oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000C?oonfX5o`0000;ooo]Z1?l0000Coook
JPCo00001OoonfX4o`00017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000Aoook
JPCo00001OoonfX4o`0001?ooo]Z1?l00003oookJPCo0000W_oonfX4o`0000?ooo]Z1?l0000Coook
JPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004OoonfX5o`0000Gooo]Z1?l0000Joook
JP000ooonfX:o`00O`?ooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001<oookJPGo
00000_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004OoonfX5o`0000Gooo]Z1?l0000AoookJPCo
00001_oonfX4o`00017ooo]Z1?l00005oookJPCo00004ooonfX4o`0000?ooo]Z1?l0002NoookJPCo
00000ooonfX5o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000AoookJPCo
00001_oonfX4o`0001[ooo]Z0003oookJP[o001o1?oonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o
1ooonfX7o`0004[ooo]Z1?l00003oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000AoookJPCo0000
1_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
0ooonfX4o`0009kooo]Z1?l00003oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPCo0000
1OoonfX4o`00017ooo]Z1?l00006oookJPCo00006_oonfX001?ooo]Z1?l007l2oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0001<oookJPCo00000ooonfX4o`0001?ooo]Z1?l00005oookJPCo00004Ooo
nfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPGo00004_oo
nfX4o`0000?ooo]Z1Ol0002MoookJPCo00000ooonfX5o`0001;ooo]Z1?l00005oookJPCo00004_oo
nfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`0001[ooo]Z000DoookJP?o001o0_oonfX3
o`00O`?ooo]Z0ol007l7oookJPGo0000C?oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001OoonfX4
o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX5
o`0001;ooo]Z1?l00003oookJPGo0000WOoonfX4o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX4
o`00017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000JoookJP005OoonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000C?oonfX4o`0000?ooo]Z1?l0000C
oookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00003oookJPGo0000WOoonfX4o`0000Cooo]Z1?l0000B
oookJPCo00001OoonfX4o`00017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000J
oookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5
o`0004cooo]Z1?l00003oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4
o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001?oonfX4
o`0009gooo]Z1?l00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000AoookJPGo00001OoonfX4
o`00017ooo]Z1?l00006oookJPCo00006_oonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0000aoookJPGo00005_oonfX4o`0000?ooo]Z1Ol0000B
oookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00004oookJPCo00005_oonfX5o`0006Oooo]Z1Ol0000F
oookJPCo00001?oonfX4o`0001;ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001_oonfX4o`0001[ooo]Z000?oookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJPGo0000<?oonfX6o`0001Kooo]Z1?l00003oookJPGo00004_oonfX4
o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001?oonfX4o`0001Kooo]Z1Ol0001WoookJPGo00005_oonfX4
o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4
o`0000Kooo]Z1?l0000JoookJP004?oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000<?oonfX6o`00
01Kooo]Z1?l00003oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00
017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001?oonfX4o`00
01Gooo]Z1_l0001VoookJPKo00005_oonfX4o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX5o`00
013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000JoookJP004OoonfX5o`00O`Go
oo]Z1Ol007l9oookJPGo0000<?oonfX6o`0001Gooo]Z1Ol00004oookJPCo00004_oonfX4o`0000Go
oo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001?oonfX4o`0001Gooo]Z1ol0001UoookJPOo00005OoonfX4o`0000Co
oo]Z1?l0000BoookJPCo00001OoonfX5o`00013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Ko
oo]Z1Ol0000IoookJP00:OoonfX5o`00033ooo]Z1ol0000DoookJPGo00001?oonfX4o`00017ooo]Z
1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z
1?l00006oookJPCo00004OoonfX5o`0000Cooo]Z1?l0000EoookJPOo0000IOoonfX7o`0001Gooo]Z
1?l00004oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000@oookJPCo00001_oonfX4o`00017ooo]Z
1?l00006oookJPGo00006OoonfX002Wooo]Z1Ol0000`oookJPOo00005?oonfX5o`0000Cooo]Z1?l0
000AoookJPGo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0
000AoookJPCo00001_oonfX4o`00017ooo]Z1Ol00004oookJPCo00005OoonfX7o`0006Gooo]Z1ol0
000EoookJPCo00001?oonfX4o`0001;ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Kooo]Z1?l0
000AoookJPCo00001_oonfX5o`0001Wooo]Z000YoookJPGo0000<?oonfX7o`0001Cooo]Z1?l00005
oookJPCo00004OoonfX5o`0000Gooo]Z1Ol0000@oookJPCo00001_oonfX5o`00013ooo]Z1?l00006
oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPGo00001?oonfX4o`0001Cooo]Z2?l0001U
oookJPOo00005OoonfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00006
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000IoookJP00:OoonfX5o`00033ooo]Z1ol0000Doook
JPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPGo00004?oonfX4o`0000Kooo]Z1Ol0000@oook
JPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000Doook
JPSo0000IOoonfX8o`0001Cooo]Z1?l00004oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000@oook
JPCo00001_oonfX5o`00013ooo]Z1?l00007oookJPCo00006OoonfX002Wooo]Z1Ol0000_oookJPSo
00005?oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX5o`00013ooo]Z1?l00006oookJPGo
00004?oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPCo
00005?oonfX8o`0006Cooo]Z2Ol0000DoookJPCo00001?oonfX4o`0001;ooo]Z1?l00006oookJPCo
00004?oonfX4o`0000Kooo]Z1Ol0000@oookJPCo00001ooonfX4o`0001Wooo]Z000YoookJPGo0000
;ooonfX8o`0001Cooo]Z1?l00005oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPCo0000
1ooonfX4o`00013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo0000
1OoonfX4o`0001Cooo]Z2?l0001ToookJPWo00005?oonfX4o`0000Cooo]Z1?l0000BoookJPCo0000
1_oonfX4o`00013ooo]Z1?l00006oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000IoookJP00:Ooo
nfX5o`0002oooo]Z2?l0000DoookJPCo00001OoonfX4o`00017ooo]Z1?l00007oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000@oookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004Ooo
nfX4o`0000Gooo]Z1?l0000DoookJPWo0000HooonfX9o`0001Cooo]Z1?l00004oookJPCo00004_oo
nfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00006Ooo
nfX002Wooo]Z1Ol0000_oookJPSo00005?oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001ooonfX4
o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4
o`00017ooo]Z1?l00005oookJPCo00005?oonfX9o`0006?ooo]Z1?l000000ooonf[o0000o`000002
o`0001Cooo]Z1?l00004oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4
o`00013ooo]Z1?l00007oookJPCo00006OoonfX002Wooo]Z1Ol0000^oookJP[o00004ooonfX4o`00
00Gooo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX5o`00
00Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPCo00005?oonfX9o`00
06;ooo]Z1Ol000000ooonf[o0000o`000002o`0001?ooo]Z1Ol00004oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00006OoonfX002Wo
oo]Z1Ol0000^oookJP[o00004ooonfX4o`0000Gooo]Z1?l0000AoookJPCo00001ooonfX4o`00013o
oo]Z1?l00007oookJPCo00003ooonfX5o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017o
oo]Z1?l00005oookJPCo00005?oonfX4o`000003oookJ_l0003o000000;o0000H_oonfX5o`000003
oookJ_l0003o000000;o00004ooonfX5o`0000Cooo]Z1Ol0000AoookJPCo00001_oonfX4o`00013o
oo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000IoookJP00:OoonfX5o`0002kooo]Z
2_l0000CoookJPCo00001OoonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z
1?l0000?oookJPGo00001_oonfX5o`00013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z
1?l0000DoookJPCo000000?ooo]Zo`000?l000000_l0001RoookJPGo000000?ooo]Zo`000?l00000
0_l0000CoookJPGo00001?oonfX5o`00013ooo]Z1Ol00006oookJPCo00004?oonfX4o`0000Oooo]Z
1?l0000@oookJPCo00001ooonfX4o`0001Wooo]Z000YoookJPGo0000;_oonfX4o`0000;ooo]Z1?l0
000CoookJPCo00001OoonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0
000?oookJPCo00001ooonfX5o`00013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0
000CoookJPGo000000?ooo]Zo`000?l000000_l0001RoookJPCo00000_oonfX4o`0001?ooo]Z1?l0
0005oookJPGo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l0
0007oookJPCo00006OoonfX002Wooo]Z1Ol0000^oookJPCo00000_oonfX4o`0001?ooo]Z1?l00005
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`0000oooo]Z1?l00007
oookJPGo00004?oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00000
0ooonf[o0000o`000003o`00067ooo]Z1?l00002oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000@
oookJPGo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000I
oookJP00:OoonfX5o`0002kooo]Z1?l00002oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000@oook
JPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oook
JPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPCo00004ooonfX5o`000003oookJ_l0003o0000
00?o0000HOoonfX4o`0000;ooo]Z1?l0000CoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oook
JPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`0001Wooo]Z000YoookJPGo
0000;_oonfX4o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX5o`00013ooo]Z1?l00007oookJPCo
00004?oonfX4o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1Ol00006oookJPCo
00004OoonfX4o`0000Gooo]Z1?l0000CoookJPCo00000_oonfX5o`00067ooo]Z1?l00002oookJPCo
00004ooonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo
00004?oonfX4o`0000Oooo]Z1?l0000IoookJP00:OoonfX5o`0002kooo]Z1?l00002oookJPCo0000
4ooonfX4o`0000Gooo]Z1Ol0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo0000
3ooonfX4o`0000Sooo]Z1?l0000?oookJPGo00001_oonfX5o`00013ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000?ooo]Z1?l0001QoookJPCo00000_oonfX5o`0001;ooo]Z1?l00006oookJPCo0000
4?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo0000
6OoonfX002Wooo]Z1Ol0000^oookJPCo00000_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000?oookJPGo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooo
nfX5o`0000Kooo]Z1Ol0000@oookJPCo00001OoonfX5o`0001;ooo]Z1?l00003oookJPCo0000HOoo
nfX4o`0000;ooo]Z1Ol0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`0001Wooo]Z000YoookJPGo0000;_oonfX4
o`0000;ooo]Z1?l0000BoookJPGo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX5
o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPGo00004?oonfX4
o`0000Gooo]Z1Ol0000BoookJPCo00000ooonfX4o`00067ooo]Z1?l00002oookJPGo00004_oonfX4
o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4
o`0000Oooo]Z1?l0000IoookJP00:OoonfX5o`0002kooo]Z1?l00002oookJPGo00004OoonfX5o`00
00Kooo]Z1?l0000@oookJPCo00001ooonfX4o`0000oooo]Z1Ol00007oookJPCo00003ooonfX4o`00
00Sooo]Z1?l0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00?ooo]Z1?l0001QoookJPCo00000ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004?oonfX4o`00
00Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00006OoonfX002Wo
oo]Z1Ol0000^oookJPCo00000_oonfX5o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oo
oo]Z1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000So
oo]Z1?l0000@oookJPCo00001_oonfX4o`0001;ooo]Z1?l00003oookJPCo0000HOoonfX4o`0000?o
oo]Z1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oo
oo]Z1?l0000@oookJPCo00001ooonfX4o`0001Wooo]Z000YoookJPGo0000;_oonfX4o`0000;ooo]Z
1Ol0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z
1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00000ooonfX4o`00067ooo]Z1?l00003oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z
1?l0000IoookJP00:OoonfX5o`0002gooo]Z1Ol00003oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000@oookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0
000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004OoonfX5o`0000?ooo]Z1Ol0
001OoookJPGo00000ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0
000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00006OoonfX002Wooo]Z1Ol0000]
oookJPGo00000ooonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@
oookJPCo00001_oonfX4o`00017ooo]Z1Ol00003oookJPGo0000GooonfX5o`0000?ooo]Z1?l0000B
oookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000?
oookJPGo00001ooonfX4o`0001Wooo]Z000YoookJPGo0000;OoonfX5o`0000?ooo]Z1?l0000Aoook
JPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oook
JPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000Aoook
JPGo00000ooonfX5o`0005oooo]Z1Ol00003oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000@oook
JPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX5o`0000Oooo]Z1?l0000Ioook
JP00:OoonfX5o`0002gooo]Z1?l00004oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPCo
00001ooonfX5o`0000kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo
00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0001OoookJPCo
00001?oonfX4o`0001;ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo
00001ooonfX4o`0000oooo]Z1Ol00007oookJPGo00006?oonfX002Wooo]Z1Ol0000]oookJPCo0000
1?oonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000>oookJPCo0000
2?oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
1_oonfX4o`00017ooo]Z1?l00005oookJPCo0000GooonfX4o`0000Cooo]Z1?l0000BoookJPCo0000
1_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000?oookJPCo0000
2?oonfX5o`0001Sooo]Z000YoookJPGo0000;OoonfX4o`0000Cooo]Z1?l0000AoookJPCo00001ooo
nfX5o`0000oooo]Z1?l00007oookJPGo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oo
nfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX5o`0000Kooo]Z1?l0000AoookJPCo00001Ooo
nfX4o`0005oooo]Z1?l00004oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooo
nfX4o`00013ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0000HoookJP00:OoonfX5
o`0002gooo]Z1?l00004oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000?oookJPCo00002?oonfX4
o`0000kooo]Z1?l00008oookJPGo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oonfX4
o`0000oooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0001OoookJPCo00001?oonfX5
o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4
o`0000oooo]Z1?l00009oookJPCo00006?oonfX002Wooo]Z1Ol0000]oookJPCo00001?oonfX4o`00
017ooo]Z1?l00007oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002?oonfX5o`00
00kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPGo00001_oonfX4o`00
017ooo]Z1?l00005oookJPCo0000GooonfX4o`0000Cooo]Z1Ol0000AoookJPCo00001_oonfX4o`00
013ooo]Z1?l00007oookJPGo00003ooonfX4o`0000Oooo]Z1?l0000?oookJPCo00002OoonfX4o`00
01Sooo]Z000YoookJPGo0000;?oonfX5o`0000Cooo]Z1?l0000AoookJPCo00002?oonfX4o`0000oo
oo]Z1?l00008oookJPCo00003_oonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002?oonfX4o`0000oo
oo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000AoookJPCo00001OoonfX4o`0005oo
oo]Z1?l00004oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX5o`0000oo
oo]Z1?l00007oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000HoookJP004ooonfX3o`00O`Gooo]Z
1Ol007l9oookJPGo0000;?oonfX5o`0000Cooo]Z1Ol0000@oookJPCo00002?oonfX4o`0000oooo]Z
1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX4o`0000oooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000AoookJPCo00001OoonfX4o`0005oooo]Z
1?l00005oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX5o`0000kooo]Z
1Ol00007oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000HoookJP004ooonfX3o`00O`Cooo]Z1ol0
07l8oookJPGo0000;?oonfX5o`0000Cooo]Z1Ol0000@oookJPCo00002?oonfX4o`0000oooo]Z1?l0
0008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX4o`0000oooo]Z1?l0
0008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000AoookJPCo00001OoonfX4o`0005oooo]Z1?l0
0005oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1Ol0
0007oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000HoookJP004ooonfX3o`00O`Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJPGo0000;?oonfX4o`0000Gooo]Z1Ol0000@oookJPCo00002?oo
nfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oo
nfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000AoookJPCo00001Ooo
nfX4o`0005kooo]Z1Ol00005oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00002?oo
nfX4o`0000kooo]Z1Ol00007oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000HoookJP000ooonfX:
o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000/oookJPCo00001_oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4
o`0000kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00001ooonfX4
o`00017ooo]Z1?l00005oookJPCo0000G_oonfX5o`0000Gooo]Z1?l0000@oookJPCo00001ooonfX5
o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002OoonfX4
o`0001Sooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
02[ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000>oookJPGo00002?oonfX4o`00
00kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oonfX4o`00
00oooo]Z1?l00007oookJPCo00004OoonfX4o`0000Gooo]Z1?l0001NoookJPGo00001OoonfX4o`00
013ooo]Z1?l00007oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002?oonfX5o`00
00kooo]Z1?l00009oookJPCo00006?oonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1Ol0000/oookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003_oonfX5o`0000So
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00008oookJPGo00003_oonfX4o`0000So
oo]Z1?l0000?oookJPCo00001ooonfX4o`00017ooo]Z1?l00005oookJPCo0000G_oonfX4o`0000Ko
oo]Z1?l0000@oookJPCo00001ooonfX5o`0000kooo]Z1Ol00008oookJPCo00003_oonfX4o`0000So
oo]Z1Ol0000>oookJPCo00002OoonfX4o`0001Sooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l7oookJPGo0000;?oonfX4o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z
1Ol00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX5o`0000kooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000AoookJPCo00001OoonfX5o`0005gooo]Z
1?l00006oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000>oookJPGo00002?oonfX4o`0000kooo]Z
1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000HoookJP004ooonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`0002cooo]Z1?l00006oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1Ol0
000>oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0
001MoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003_oonfX5o`0000Sooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00006?oonfX001?ooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000/oookJPCo00001_oonfX4o`00013ooo]Z1?l00008
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Sooo]Z1Ol0000>oookJPCo00001ooonfX4o`00013ooo]Z1Ol00005
oookJPGo0000GOoonfX4o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0001Sooo]Z000@oook
JPKo001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000;?oonfX4o`0000Kooo]Z1Ol0000?oook
JPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000kooo]Z1?l00008oookJPGo00003_oonfX4o`0000Oooo]Z1?l0000@oook
JPGo00001_oonfX4o`0005gooo]Z1?l00006oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000Hoook
JP004?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo00004_oonfX5o`00
01Gooo]Z1?l00006oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`00
00kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX5o`00
00kooo]Z1?l00007oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000EoookJPCo0000:ooonfX4o`00
01Gooo]Z1?l00006oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`00
00kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000HoookJP004_oonfX4o`00O`Co
oo]Z1ol007l8oookJPGo00004_oonfX6o`0001Cooo]Z1?l00006oookJPGo00003ooonfX4o`0000So
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00007oookJPGo00003ooonfX4o`0000Oo
oo]Z1?l0000DoookJPKo0000:OoonfX6o`0001Cooo]Z1?l00006oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000HoookJP004ooonfX3o`00O`Gooo]Z1Ol007l9oookJPGo00004OoonfX7o`0001?ooo]Z
1Ol00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l00009oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l00007oookJPGo00003ooonfX4o`0000Oooo]Z1?l0000CoookJPSo00009ooonfX7o`0001Cooo]Z
1?l00006oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000HoookJP00:OoonfX5o`00017ooo]Z1ol0
000CoookJPGo00001ooonfX4o`0000kooo]Z1Ol00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000gooo]Z1Ol00009oookJPCo00003OoonfX5o`0000Wooo]Z1?l0
000>oookJPCo00001ooonfX5o`0000oooo]Z1?l00007oookJPCo00004ooonfX8o`0002Oooo]Z2?l0
000CoookJPCo00001_oonfX5o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00006?oonfX002Wooo]Z1Ol0000@
oookJPWo00004_oonfX5o`0000Oooo]Z1?l0000>oookJPGo00002?oonfX4o`0000kooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000=oookJPGo00002OoonfX4o`0000gooo]Z1Ol00009
oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPCo00001ooonfX4o`0001?ooo]Z2?l0000W
oookJPSo00004ooonfX4o`0000Kooo]Z1Ol0000?oookJPCo00002?oonfX4o`0000kooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0001Sooo]Z000Yoook
JPGo00004?oonfX9o`0001;ooo]Z1?l00008oookJPCo00003_oonfX5o`0000Sooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oook
JPGo00002OoonfX4o`0000kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000Coook
JPSo00009_oonfX9o`0001?ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000Hoook
JP00:OoonfX5o`00013ooo]Z2Ol0000BoookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo
00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo
00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPCo
00004_oonfX9o`0002Kooo]Z2Ol0000BoookJPGo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo
00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo
00006?oonfX002Wooo]Z1Ol0000@oookJPCo000000?ooo]Zo`000?l000000ol0000AoookJPCo0000
2?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo0000
2OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo0000
2?oonfX4o`0000oooo]Z1?l00007oookJPCo00004_oonfX:o`0002Gooo]Z2Ol0000BoookJPGo0000
1ooonfX4o`0000kooo]Z1Ol00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo0000
2OoonfX4o`0000kooo]Z1?l00009oookJPCo00006?oonfX002Wooo]Z1Ol0000@oookJPCo000000?o
oo]Zo`000?l000000ol0000AoookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oo
nfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000[ooo]Z1?l0000>oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPCo00004_oo
nfX:o`0002Gooo]Z1?l000000ooonf[o0000o`000003o`00017ooo]Z1Ol00007oookJPCo00003_oo
nfX5o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oo
nfX4o`0000Wooo]Z1?l0000HoookJP00:OoonfX5o`0000oooo]Z1Ol000000ooonf[o0000o`000003
o`00017ooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000=oookJPCo00002OoonfX4
o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4
o`0000kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000BoookJPCo000000?ooo]Z
o`000?l000000ol0000UoookJPCo000000?ooo]Zo`000?l000000ol0000AoookJPCo00002?oonfX4
o`0000kooo]Z1Ol00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4
o`0000kooo]Z1?l00009oookJPCo00006?oonfX002Wooo]Z1Ol0000?oookJPGo00000_oonfX4o`00
017ooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000=oookJPCo00002OoonfX4o`00
00gooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`00
00kooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000BoookJPCo00000_oonfX4o`00
02Cooo]Z1Ol000000ooonf[o0000o`000003o`00017ooo]Z1?l00008oookJPCo00003_oonfX4o`00
00Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`00
00Wooo]Z1?l0000HoookJP00:OoonfX5o`0000oooo]Z1Ol00002oookJPCo00004OoonfX4o`0000So
oo]Z1?l0000>oookJPCo00002OoonfX5o`0000gooo]Z1?l00009oookJPCo00003OoonfX5o`0000Wo
oo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000So
oo]Z1?l0000?oookJPCo00001ooonfX4o`00017ooo]Z1Ol00002oookJPGo00008ooonfX5o`0000;o
oo]Z1?l0000AoookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00006?oonfX002Wooo]Z
1Ol0000?oookJPCo00000ooonfX4o`00017ooo]Z1?l00008oookJPCo00003_oonfX4o`0000[ooo]Z
1?l0000=oookJPCo00002OoonfX4o`0000gooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z
1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Oooo]Z
1?l0000AoookJPGo00000_oonfX5o`0002?ooo]Z1Ol00002oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z
1?l0000>oookJPCo00002OoonfX4o`0001Sooo]Z000YoookJPGo00003ooonfX4o`0000?ooo]Z1?l0
000AoookJPCo00002?oonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z1?l0
000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0
000=oookJPGo00002?oonfX4o`0000oooo]Z1?l00007oookJPGo00004?oonfX5o`0000;ooo]Z1Ol0
000RoookJPGo00000ooonfX5o`00013ooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000HoookJP00:OoonfX5o`0000kooo]Z1Ol00003oookJPGo00004?oonfX4o`0000Sooo]Z1Ol0000=
oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000=
oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000?
oookJPCo00001ooonfX5o`00013ooo]Z1?l00004oookJPGo00008OoonfX5o`0000?ooo]Z1Ol0000@
oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPGo00003?oonfX5o`0000Wooo]Z1Ol0000=
oookJPCo00002OoonfX4o`0000gooo]Z1Ol00009oookJPCo00006?oonfX002Wooo]Z1Ol0000>oook
JPGo00000ooonfX5o`00013ooo]Z1?l00008oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002OoonfX5o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPCo00003ooonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00001?oonfX5o`00027ooo]Z1Ol00003oookJPGo00004?oonfX4o`0000Sooo]Z1Ol0000=oook
JPCo00002OoonfX5o`0000cooo]Z1Ol00009oookJPGo00003OoonfX4o`0000Wooo]Z1?l0000=oook
JPGo00002OoonfX4o`0001Sooo]Z000YoookJPGo00003_oonfX5o`0000?ooo]Z1Ol0000@oookJPCo
00002?oonfX5o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z1Ol000000ol007oo
oo]ZoookJP03oookJPGo001o00?ooo]Zo`000?l000000_l0000:oookJPCo00003OoonfX4o`0000[o
oo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPCo00000_l007l5oookJPGo
001o0_oonfX5o`0000?o001o1OoonfX4o`00013ooo]Z1?l00004oookJPGo00008OoonfX4o`0000Go
oo]Z1?l0000@oookJPCo00000_oonfX3o`00O`?ooo]Z1Ol00002o`00O`Gooo]Z1Ol007l00ooonf[o
0000o`000002o`0000Wooo]Z1Ol0000<oookJPGo00002OoonfX5o`0000gooo]Z1?l00009oookJPCo
00003OoonfX5o`0000?ooo]Z1_l007l5o`000003oookJ_l007oo001o00?o001o1OoonfX5o`00O`Oo
oo]Z000YoookJPGo00003OoonfX5o`0000Gooo]Z1?l0000@oookJPCo00002OoonfX4o`0000gooo]Z
1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z00?o001oo`000?l000000_l00002o`00O`?ooo]Z
1ol007l4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo0000
3OoonfX4o`0000Wooo]Z1?l00002o`00O`Cooo]Z1ol007l00ooonf[o0000o`000003o`0000Co001o
1?oonfX4o`00013ooo]Z1?l00005oookJPCo00008?oonfX5o`0000Gooo]Z1?l0000@oookJPCo0000
0_oonfX3o`00O`?ooo]Z1Ol00003o`00O`?ooo]Z1ol007l4o`0000[ooo]Z1?l0000<oookJPCo0000
2ooonfX4o`0000gooo]Z1?l00009oookJPCo00003OoonfX4o`0000Cooo]Z1_l007l5o`0000Oo001o
0ooonfX7o`00O`Kooo]Z000YoookJPGo00003OoonfX5o`0000Gooo]Z1?l0000@oookJPCo00002Ooo
nfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Sooo]Z0_l007l4o`0000;o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Co00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo0000
3OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX4o`0000;o001o1?oonfX3o`00O`05oook
J_l007oo001oo`00OooonfX01Ol000001?oonf[o001oo`00Ool007l4oookJPCo00004?oonfX4o`00
00Gooo]Z1?l0000PoookJPGo00001OoonfX4o`0000oooo]Z1Ol00002oookJP?o001o0ooonfX00ol0
07oo0000o`000002o`0000?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Co00002_oonfX4
o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000=oookJPCo00001?oonfX4
o`00O`;ooo]Z1Ol00003o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l6oookJP00:OoonfX5o`0000gooo]Z1Ol00005oookJPGo00003ooonfX4o`0000Wooo]Z1?l0
000=oookJPCo00002_oonfX4o`0000gooo]Z1?l00008oookJP;o001o1?l00003o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0_l007l4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z
1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z1?l00002o`00O`?ooo]Z0ol007l3oookJP?o001o
1?l00003oookJP?o001o0ooonfX4o`0000oooo]Z1Ol00005oookJPGo00007ooonfX5o`0000Gooo]Z
1?l0000?oookJPGo00000_oonfX3o`00O`?ooo]Z00?o001oo`000?l000000_l000001Ooonf[o001o
o`00Ool007oooo]Z00?o001o0ooonfX2o`00O`Co00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo
00003OoonfX4o`0000Wooo]Z1?l0000=oookJPCo00001OoonfX4o`00O`;ooo]Z1?l00002o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002Wooo]Z1Ol0000=oookJPCo
00001_oonfX5o`0000oooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo
00002_oonfX4o`0000?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`Co00002_oonfX5o`00
00cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX4o`00
00;o001o0ooonfX3o`00O`?ooo]Z0ol007l4o`0000?ooo]Z0ol007l3oookJPCo00003ooonfX5o`00
00Gooo]Z1Ol0000OoookJPCo00001_oonfX5o`0000kooo]Z1Ol00002oookJP?o001o1?oonfX4o`00
0005oookJ_l007oo001oo`00OooonfX00ol007l3oookJP;o001o1?l0000:oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l00006oookJPGo001o1?l00002
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002Wooo]Z1Ol0000=
oookJPCo00001_oonfX5o`0000kooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=
oookJPCo00002_oonfX4o`0000?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`Co00002_oo
nfX5o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002Ooo
nfX4o`0000;o001o0ooonfX3o`00O`?ooo]Z0ol007l4o`0000?ooo]Z0ol007l3oookJPCo00003ooo
nfX5o`0000Gooo]Z1Ol0000OoookJPCo00001_oonfX5o`0000kooo]Z1?l00003oookJP?o001o1?oo
nfX4o`000005oookJ_l007oo001oo`00OooonfX00ol007l3oookJP;o001o1?l0000:oookJPCo0000
3?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l00008oookJP?o001o
1?l00002o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002Wooo]Z
1Ol0000<oookJPGo00001ooonfX4o`0000kooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z
1?l0000=oookJPCo00002OoonfX00ol007oo0000o`000002o`0000?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX2o`00O`Co00002_oonfX5o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[o
oo]Z1?l0000=oookJPCo00002OoonfX4o`0000;o001o0ooonfX3o`00O`?ooo]Z0ol007l4o`0000?o
oo]Z0ol007l3oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000OoookJPCo00001_oonfX5o`0000ko
oo]Z1?l00003oookJP?o001o1?oonfX4o`0000Co001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00
O`Co00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Wooo]Z1Ol0000<oook
JPCo00002OoonfX2o`00O`Co00000_l007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Gooo]Z000YoookJPGo00003?oonfX5o`0000Oooo]Z1?l0000>oookJPGo00002OoonfX4o`00
00gooo]Z1?l0000:oookJPCo00003?oonfX5o`0000Wooo]Z00?o001oo`000?l000000_l00002o`00
O`;ooo]Z0ol007l3oookJP;o001o1?l0000;oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPCo00000_l007l3oookJP?o001o0ooonfX3o`00
O`Co00000ooonfX3o`00O`?ooo]Z1?l0000?oookJPCo00001ooonfX4o`0001kooo]Z1Ol00007oook
JPCo00003_oonfX4o`0000?ooo]Z0ol007l4oookJPCo00000ol007l2oookJP?o001o0ooonfX2o`00
O`Co00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Wooo]Z1Ol0000<oook
JPCo00002_oonfX00ol007oo0000o`000002o`0000;o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l5oookJP00:OoonfX5o`0000cooo]Z1Ol00007oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000cooo]Z1Ol00009oookJP03o`00Ool0003o0000
00;o000000Co001ooookJ_oonf[ooo]Z0ol007l3oookJP;o001o1?l0000;oookJPCo00003?oonfX4
o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPGo000000Co001o
oookJ_oonf[ooo]Z0ol007l3oookJP?o001o1?l00003oookJP?o001o0ooonfX4o`0000oooo]Z1?l0
0007oookJPCo00007_oonfX5o`0000Oooo]Z1?l0000>oookJPCo00000ooonfX3o`00O`Cooo]Z1?l0
0002o`00O`?ooo]Z0ol007l3oookJP;o001o1?l0000:oookJPCo00003?oonfX4o`0000_ooo]Z1?l0
000=oookJPCo00002OoonfX5o`0000cooo]Z1?l00004oookJP?o001o0ooonfX00ol007oo0000o`00
0002o`0000;o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00:Ooo
nfX5o`0000cooo]Z1?l00008oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oo
nfX4o`0000cooo]Z1Ol00009oookJP03o`00Ool0003o000000;o00001?oonfX3o`00O`?ooo]Z0_l0
07l4o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000Wooo]Z1Ol000001?l007oooo]ZoookJ_oonfX3o`00O`?ooo]Z0ol007l4o`0000?ooo]Z
0ol007l3oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000NoookJPGo00001ooonfX4o`0000kooo]Z
1?l00006o`00O`Cooo]Z1?l00005oookJP?o001o0ooonfX00ol007oo0000o`000003o`0000[ooo]Z
1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000Cooo]Z
0ol007l3oookJP03o`00Ool0003o000000;o00000_l007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z000YoookJPGo00003?oonfX4o`0000Sooo]Z1?l0000>oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003?oonfX4o`0000[ooo]Z00?o001oo`000?l00000
0_l00005oookJP?o001o00Cooo]Zo`00Ool007oo001o1?l0000;oookJPCo00003?oonfX4o`0000[o
oo]Z1Ol0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPGo000000?o001ooookJ_oo
nfX00_oonfX3o`00O`05oookJ_l007oo001oo`00OooonfX01?l000000ol007oooo]Zo`00O`02o`00
O`Cooo]Z1?l0000?oookJPCo00001ooonfX5o`0001gooo]Z1?l00008oookJPCo00003_oonfX4o`00
00Ko001o1?oonfX4o`0000Kooo]Z0ol007l00ooonf[o001oo`00O`05o`0000[ooo]Z1?l0000<oook
JPCo00002ooonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000Cooo]Z1?l007l2oook
JP03o`00Ool0003o000000;o00000ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o1_oonfX002Wooo]Z1Ol0000<oookJPCo00002?oonfX5o`0000gooo]Z1?l0000:
oookJPCo00003?oonfX5o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000?o001o0_oonfX7
o`00O`Co00002ooonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000=
oookJPCo00002_oonfX4o`000003o`00Oooonf[ooo]Z00;ooo]Z1ol007l00ooonf[o0000o`000002
o`0000Go001o1?oonfX4o`0000kooo]Z1Ol00007oookJPGo00007OoonfX4o`0000Sooo]Z1Ol0000=
oookJPCo00000_oonfX4o`00O`Cooo]Z1?l00004o`00O`;ooo]Z1_l007l5o`0000[ooo]Z1?l0000<
oookJPCo00002ooonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000Gooo]Z1_l007l4
o`0000Oo001o0ooonfX7o`00O`Kooo]Z000YoookJPGo00003?oonfX4o`0000Sooo]Z1Ol0000=oook
JPCo00002_oonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000_ooo]Z1?l00003o`00
O`?ooo]Z1Ol007l00ooonf[o0000o`000002o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX5o`00
00_ooo]Z1Ol0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l000000ol007oooo]ZoookJP03oook
JPGo001o0_oonfX4o`0000Co001o1OoonfX5o`0000gooo]Z1Ol00007oookJPGo00007?oonfX5o`00
00Sooo]Z1Ol0000=oookJPCo00000ooonfX3o`00O`Cooo]Z1?l00004o`00O`?ooo]Z1Ol007l4o`00
00_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`00
00Kooo]Z1Ol007l4o`000003oookJ_l007oo001o00?o001o1OoonfX5o`00O`Oooo]Z000YoookJPGo
00002ooonfX5o`0000Sooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000cooo]Z1Ol0000:oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo
00002ooonfX5o`0000[ooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPGo
00003OoonfX5o`0000Sooo]Z1?l0000LoookJPGo00002?oonfX5o`0000gooo]Z1?l0000:oookJPGo
00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000GoookJP00:OoonfX5o`0000_ooo]Z1Ol00009oookJPCo0000
3OoonfX4o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000_ooo]Z1Ol0000:oookJPGo0000
3?oonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX5o`0000gooo]Z1?l00009oookJPCo0000
7?oonfX5o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX5o`0000_ooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo0000
5ooonfX002Wooo]Z1Ol0000;oookJPGo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003?oo
nfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00002ooo
nfX5o`0000_ooo]Z1?l0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0000:oookJPCo00003?oo
nfX5o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX5o`0001_ooo]Z1?l0000:oookJPCo00003?oo
nfX5o`0000[ooo]Z1Ol0000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oo
nfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0001Oooo]Z000YoookJPGo00002ooonfX4
o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000_ooo]Z1Ol0000;oookJPCo00002ooonfX4
o`0000cooo]Z1?l0000<oookJPCo00002_oonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX5
o`0000Wooo]Z1Ol0000KoookJPCo00002_oonfX4o`0000cooo]Z1Ol0000;oookJPCo00002ooonfX4
o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000GoookJP00:OoonfX5o`0000_ooo]Z1?l0000:oookJPCo00003OoonfX4o`00
00[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`00
00_ooo]Z1?l0000;oookJPGo00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX5o`00
00[ooo]Z1?l0000<oookJPGo00002_oonfX4o`0000cooo]Z1Ol00009oookJPGo00006_oonfX5o`00
00[ooo]Z1?l0000<oookJPGo00002ooonfX4o`0000_ooo]Z1?l0000;oookJPCo00003?oonfX4o`00
00_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00005ooonfX002Wo
oo]Z1Ol0000;oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00002ooonfX4o`0000co
oo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000<oookJPGo00002_oonfX5o`0001Wooo]Z1Ol0000:oookJPGo00002ooonfX4o`0000co
oo]Z1?l0000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000<oookJPCo00002ooonfX4o`0001Oooo]Z000LoookJ_oo0000ool0000So`0000?ooo]Z
000LoookJ_oo0000ool0000So`0000?ooo]Z000LoookJ_oo0000ool0000So`0000?ooo]Z000Loook
J_oo0000ool0000So`0000?ooo]Z000LoookJ_oo0000ool0000So`0000?ooo]Z000YoookJPGo0000
2OoonfX5o`0000_ooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000_ooo]Z1?l00004oookJP03o`000?oonf[ooo]Z00Cooo]Z1?l0000<oookJPCo0000
2ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000;oookJPCo0000
2OoonfX00ol0003ooo]ZoookJP04o`0000_ooo]Z1Ol0000;oookJPCo00003?oonfX5o`0000Wooo]Z
1Ol00009oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z
1?l0000;oookJPCo00002ooonfX5o`0000_ooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z
1?l00004oookJP03o`000?oonf[ooo]Z013ooo]Z000YoookJPKo00002?oonfX5o`0000cooo]Z1?l0
000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000;oookJPGo00002ooonfX4o`0000_ooo]Z1?l0
0004oookJP03o`000?oonf[ooo]Z00Cooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0
000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000;oookJPCo00002OoonfX00ol0003ooo]Zoook
JP04o`0000_ooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000Oooo]Z2?l00008oookJPCo00003Ooo
nfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00002ooo
nfX5o`0000_ooo]Z1?l0000;oookJPCo00002ooonfX5o`0000_ooo]Z1?l00004oookJP03o`000?oo
nf[ooo]Z013ooo]Z000YoookJPOo00001_oonfX5o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000;oookJPGo00002ooonfX4o`0000_ooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00002ooonfX4
o`0000cooo]Z1?l0000;oookJPGo00002_oonfX5o`0000gooo]Z1Ol00006oookJPWo00001ooonfX4
o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX5
o`0000_ooo]Z1Ol0000;oookJPCo00002ooonfX4o`0000_ooo]Z1Ol0000;oookJPCo00005ooonfX0
02Wooo]Z1ol00006oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`00
00_ooo]Z1Ol0000;oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`00
00cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000;oookJPGo00002ooonfX4o`00
00cooo]Z1?l0000:oookJPGo00003OoonfX5o`0000Gooo]Z2ol00005oookJPGo00003OoonfX4o`00
00_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`00
00_ooo]Z1?l0000;oookJPCo00002ooonfX5o`0000_ooo]Z1?l0000GoookJP00:OoonfX8o`0000Co
oo]Z1_l0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000<oookJPCo00002ooonfX4o`0000_ooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000[o
oo]Z1?l0000>oookJPGo00001?oonfX=o`0000Cooo]Z1Ol0000=oookJPGo00002_oonfX4o`0000co
oo]Z1?l0000;oookJPCo00003?oonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_o
oo]Z1?l0000;oookJPCo00003?oonfX4o`0001Oooo]Z000YoookJPWo00000ooonfX5o`0000kooo]Z
1?l0000;oookJPCo00003?oonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z
1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z
1?l0000;oookJPCo00002ooonfX5o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX4o`0000oooo]Z
1?l00004oookJPKo000000?ooo]Zo`000?l000001?l00004oookJPGo00003OoonfX5o`0000Wooo]Z
1Ol0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000GoookJP00:OoonfX:o`0000;ooo]Z1Ol0
000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1Ol0
000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0
000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l0
000?oookJPGo000000?ooo]Zo`000?l000001Ol00003oookJPKo00000_oonfX5o`0000kooo]Z1Ol0
0009oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l0
000;oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo00005ooonfX002Wooo]Z4?l0000?
oookJPCo00002_oonfX5o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1Ol0000;
oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<
oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000?
oookJPco00001OoonfX<o`0000oooo]Z1?l00009oookJPGo00003?oonfX4o`0000[ooo]Z1Ol0000<
oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000<
oookJPCo00005ooonfX002Wooo]Z4?l0000?oookJPGo00002OoonfX5o`0000cooo]Z1?l0000:oook
JPCo00003OoonfX4o`0000[ooo]Z1Ol0000;oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oook
JPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oook
JPGo00003?oonfX4o`0000[ooo]Z1?l0000?oookJPco00001OoonfX<o`0000oooo]Z1?l00009oook
JPCo00003OoonfX5o`0000Wooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oook
JPCo00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo00005ooonfX002Wooo]Z1Ol000000ooonf[o
0000o`000008o`0000oooo]Z1Ol00009oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000=oookJPCo
00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo
00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000=oookJPCo
00002_oonfX4o`00013ooo]Z2_l00007oookJP[o00004?oonfX4o`0000Wooo]Z1?l0000=oookJPGo
00002OoonfX5o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000;oookJPCo
00002ooonfX4o`0000cooo]Z1?l0000GoookJP00:OoonfX5o`0000;ooo]Z2?l0000@oookJPGo0000
2OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000<oookJPCo0000
2ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo0000
2ooonfX4o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000@oookJPSo0000
2_oonfX8o`00017ooo]Z1?l00009oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000;oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000<oookJPCo0000
5ooonfX002Wooo]Z1Ol00002oookJPSo00004OoonfX4o`0000Wooo]Z1?l0000=oookJPCo00002_oo
nfX4o`0000gooo]Z1?l0000:oookJPCo00003?oonfX5o`0000[ooo]Z1?l0000<oookJPCo00002ooo
nfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002_oo
nfX4o`0000gooo]Z1?l0000:oookJPCo00004OoonfX7o`0000_ooo]Z1ol0000AoookJPCo00002Ooo
nfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002ooo
nfX4o`0000_ooo]Z1Ol0000:oookJPCo00003?oonfX4o`0001Oooo]Z000YoookJPGo00006ooonfX4
o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003?oonfX5
o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPGo0000>ooonfX4
o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000;oookJPGo00002_oonfX4o`0000cooo]Z1?l0000GoookJP00:OoonfX5o`00
01_ooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`00
00cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX5o`00
00cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000=oookJPGo00002?oonfX5o`00
03_ooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`00
00gooo]Z1?l0000:oookJPGo00002ooonfX5o`0000[ooo]Z1?l0000<oookJPCo00005ooonfX002Wo
oo]Z1Ol0000KoookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[o
oo]Z1?l0000=oookJPCo00002_oonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000[o
oo]Z1Ol0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPCo00003OoonfX5o`0000So
oo]Z1Ol0000koookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[o
oo]Z1?l0000=oookJPCo00002_oonfX5o`0000cooo]Z1?l0000:oookJPCo00003?oonfX4o`0001Oo
oo]Z000YoookJPGo00006ooonfX4o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z
1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z
1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000gooo]Z
1Ol00008oookJPCo0000??oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z
1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000cooo]Z
1?l0000GoookJP00:OoonfX5o`0001_ooo]Z1Ol00008oookJPCo00003OoonfX4o`0000[ooo]Z1?l0
000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003?oonfX4o`0000_ooo]Z1?l0
000<oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002?oonfX4o`0003cooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0
000<oookJPCo00005ooonfX002Wooo]Z1Ol0000KoookJPGo00002?oonfX4o`0000gooo]Z1?l0000:
oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000cooo]Z1?l0000;
oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX5o`0000cooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000loookJPGo00002?oonfX4o`0000kooo]Z1?l00009
oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:
oookJPCo00003?oonfX5o`0001Kooo]Z000YoookJPGo00006ooonfX5o`0000Oooo]Z1Ol0000=oook
JPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000<oook
JPCo00002ooonfX4o`0000cooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002_oonfX4o`0000kooo]Z1?l00008oookJPCo0000??oonfX5o`0000Sooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002_oonfX4o`0000cooo]Z1Ol0000FoookJP00:OoonfX5o`0001cooo]Z1?l00007oookJPGo
00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo
00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002?oonfX4o`0003cooo]Z1Ol00008oookJPCo
00003_oonfX4o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo
00003OoonfX4o`0000[ooo]Z1?l0000<oookJPGo00005_oonfX002Wooo]Z1Ol0000LoookJPCo0000
1ooonfX5o`0000gooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000cooo]Z1?l0000:oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Oooo]Z1Ol0000moookJPCo0000
2?oonfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0001Kooo]Z000YoookJPGo00007?oo
nfX4o`0000Oooo]Z1?l0000>oookJPGo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000Wooo]Z1Ol0000<oookJPGo00002OoonfX5o`0000cooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l00007oookJPGo0000?Ooo
nfX4o`0000Oooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000FoookJP00:OoonfX5
o`0001cooo]Z1?l00007oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4
o`0000gooo]Z1?l00009oookJPGo00003?oonfX5o`0000Wooo]Z1Ol0000<oookJPCo00002_oonfX4
o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000Sooo]Z1Ol0000>oookJPCo00001ooonfX5
o`0003gooo]Z1?l00007oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000=oookJPGo00002OoonfX4
o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00005_oonfX0
02Wooo]Z1Ol0000LoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPGo00003OoonfX4o`00
00[ooo]Z1?l0000=oookJPCo00002OoonfX5o`0000cooo]Z1Ol00009oookJPCo00003OoonfX4o`00
00[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1Ol00008oookJPGo00003_oonfX4o`00
00Oooo]Z1?l0000noookJPCo00001ooonfX5o`0000kooo]Z1?l00009oookJPCo00003OoonfX5o`00
00Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`00
01Kooo]Z000YoookJPGo00007?oonfX5o`0000Kooo]Z1?l0000?oookJPCo00002?oonfX5o`0000go
oo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000go
oo]Z1?l0000:oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000=oookJPGo00002?oonfX5o`0000ko
oo]Z1?l00007oookJPCo0000?_oonfX4o`0000Oooo]Z1?l0000?oookJPCo00002OoonfX4o`0000go
oo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000go
oo]Z1?l0000FoookJP00:OoonfX5o`0001cooo]Z1Ol00006oookJPCo00003ooonfX4o`0000Sooo]Z
1Ol0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z
1?l0000=oookJPGo00002OoonfX4o`0000gooo]Z1Ol00009oookJPCo00003_oonfX4o`0000Sooo]Z
1?l0000?oookJPCo00001ooonfX4o`0003kooo]Z1?l00007oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z
1?l0000=oookJPCo00005_oonfX002Wooo]Z1Ol0000LoookJPGo00001_oonfX4o`0000oooo]Z1?l0
0008oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX4o`0000kooo]Z1?l0
0009oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000=oookJPGo00002OoonfX4o`0000kooo]Z1?l0
0008oookJPCo00003ooonfX5o`0000Kooo]Z1?l0000noookJPGo00001_oonfX4o`0000oooo]Z1?l0
0009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0
000:oookJPCo00003OoonfX4o`0001Kooo]Z000YoookJPGo00007OoonfX4o`0000Kooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000kooo]Z1Ol00009oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002OoonfX4o`0000gooo]Z1Ol00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002?oonfX4o`0000oooo]Z1Ol00006oookJPCo0000?_oonfX5o`0000Kooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=
oookJPCo00002_oonfX4o`0000gooo]Z1?l0000FoookJP00:OoonfX5o`0001gooo]Z1?l00006oook
JPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPGo00002OoonfX4o`0000gooo]Z1?l00009oook
JPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oook
JPCo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPGo00001_oonfX4o`0003kooo]Z1Ol00006oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l0000:oook
JPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00005_oonfX002Wooo]Z1Ol0000MoookJPCo
00001_oonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX5o`0000Sooo]Z1Ol0000=oookJPCo
00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo
00002OoonfX4o`0000kooo]Z1?l00008oookJPCo00004?oonfX4o`0000Gooo]Z1Ol0000ooookJPCo
00001_oonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000=oookJPCo
00002_oonfX4o`0000gooo]Z1?l00009oookJPGo00003OoonfX4o`0001Kooo]Z000YoookJPGo0000
7OoonfX4o`0000Gooo]Z1Ol0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPGo0000
3OoonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo0000
3_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX4o`00013ooo]Z1?l00005oookJPGo0000
?ooonfX4o`0000Kooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo0000
3OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX5o`0000gooo]Z1?l0000FoookJP00:Ooo
nfX5o`0001gooo]Z1?l00005oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oo
nfX5o`0000gooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000@oookJPCo00001Ooo
nfX5o`0003oooo]Z1Ol00005oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000gooo]Z1Ol00009oookJPCo00003OoonfX4o`0000Wooo]Z1Ol0000=oookJPCo00005_oo
nfX002Wooo]Z1Ol0000MoookJPCo00001OoonfX5o`0000oooo]Z1?l00008oookJPCo00003ooonfX4
o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4
o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Gooo]Z1?l00010oookJPGo00001OoonfX4o`0000oooo]Z1Ol00008oookJPCo00003_oonfX4
o`0000Wooo]Z1?l0000=oookJPGo00002OoonfX4o`0000gooo]Z1?l00009oookJPCo00003_oonfX4
o`0001Kooo]Z000YoookJPGo00007OoonfX5o`0000Cooo]Z1?l0000@oookJPCo00002?oonfX4o`00
00oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`00
00kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX4o`00
013ooo]Z1?l00005oookJPCo0000@?oonfX5o`0000Gooo]Z1?l0000?oookJPGo00002?oonfX4o`00
00kooo]Z1?l00009oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000=oookJPCo00002OoonfX4o`00
00kooo]Z1?l0000FoookJP00:OoonfX5o`0001gooo]Z1Ol00004oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000?oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000So
oo]Z1?l0000@oookJPCo00001OoonfX4o`00047ooo]Z1?l00004oookJPGo00003ooonfX5o`0000Oo
oo]Z1Ol0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00005_oonfX002Wooo]Z1Ol0000MoookJPGo00001?oonfX4o`00013ooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX5o`0000kooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Gooo]Z1?l00011oookJPCo00001?oonfX5o`00013ooo]Z
1?l00007oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z
1?l00009oookJPCo00003_oonfX4o`0001Kooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0
000NoookJPCo00001?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002?oonfX5o`0000kooo]Z1?l00008oookJPCo00004?oonfX4o`0000Gooo]Z1?l0
0011oookJPCo00001?oonfX5o`00013ooo]Z1?l00007oookJPGo00003_oonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000gooo]Z1?l00009oookJPCo00003_oonfX4o`0001Kooo]Z000C
oookJP?o001o1?oonfX7o`00O`Sooo]Z1Ol0000NoookJPCo00001?oonfX4o`00013ooo]Z1?l00008
oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX5o`0000kooo]Z1?l00007
oookJPGo00004?oonfX5o`0000Cooo]Z1?l00011oookJPCo00001?oonfX4o`00017ooo]Z1?l00007
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l00009
oookJPCo00003_oonfX4o`0001Kooo]Z000CoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol0000NoookJPCo00001?oonfX4o`00013ooo]Z1Ol00007oookJPCo00003ooonfX4
o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4
o`0000Wooo]Z1?l0000>oookJPCo00002?oonfX4o`0000oooo]Z1Ol00006oookJPGo00004?oonfX5
o`0000?ooo]Z1Ol00011oookJPCo00001?oonfX4o`00017ooo]Z1?l00007oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000gooo]Z1?l00009oookJPCo00003_oonfX4
o`0001Kooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007_oonfX4o`00
00Cooo]Z1?l0000@oookJPGo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX5o`00
00Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`00
00Sooo]Z1?l0000?oookJPGo00001_oonfX5o`00013ooo]Z1Ol00003oookJPGo0000@OoonfX5o`00
00?ooo]Z1?l0000AoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPGo00003_oonfX4o`00
00Wooo]Z1?l0000=oookJPCo00002OoonfX4o`0000kooo]Z1?l0000FoookJP004ooonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o1ooonfX7o`0001cooo]Z1?l00004oookJPCo00004?oonfX5o`0000Oo
oo]Z1?l0000?oookJPCo00002?oonfX4o`0000kooo]Z1Ol00008oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00008oookJPCo00003ooonfX5o`0000Ko
oo]Z1?l0000BoookJPCo00000ooonfX5o`00047ooo]Z1Ol00003oookJPCo00004OoonfX4o`0000Oo
oo]Z1?l0000?oookJPCo00002?oonfX5o`0000kooo]Z1?l00009oookJPCo00003OoonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00005_oonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z
1Ol0000NoookJPGo00000ooonfX4o`00017ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z
1?l0000>oookJPGo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z
1?l0000>oookJPCo00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004_oonfX4o`0000?ooo]Z
1?l00012oookJPGo00000ooonfX4o`00017ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z
1Ol0000>oookJPCo00002?oonfX5o`0000gooo]Z1?l00009oookJPCo00003_oonfX4o`0001Kooo]Z
000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007_oonfX5o`0000;ooo]Z1Ol0
000AoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00001_oonfX4o`0001;ooo]Z1Ol00002oookJPCo0000@ooonfX4o`0000?ooo]Z1?l0
000AoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0
000=oookJPCo00002OoonfX4o`0000kooo]Z1?l0000FoookJP004ooonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o1ooonfX5o`0001kooo]Z1Ol00002oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002OoonfX4o`0000kooo]Z1?l00008oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000B
oookJPGo00000_oonfX4o`0004?ooo]Z1?l00002oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPGo00003OoonfX4o`0000Wooo]Z1?l0000>
oookJPCo00005_oonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000Ooook
JPCo00000_oonfX5o`00017ooo]Z1?l00006oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000?oook
JPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1Ol0000>oook
JPCo00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004_oonfX5o`0000;ooo]Z1?l00013oook
JPCo00000_oonfX5o`00017ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oook
JPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0001Kooo]Z000@oookJPKo
001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007ooonfX4o`0000;ooo]Z1?l0000BoookJPCo
00001_oonfX5o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo
00002OoonfX4o`0000kooo]Z1?l00008oookJPGo00003_oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00001_oonfX4o`0001?ooo]Z1?l000000ooonf[o0000o`000003o`0004?ooo]Z1?l00002oookJPGo
00004OoonfX4o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo
00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00005_oonfX0013ooo]Z1_l007l4oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0001oooo]Z1?l00002oookJPCo00004_oonfX4o`0000Ko
oo]Z1Ol0000?oookJPGo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002?oonfX5o`0000kooo]Z1?l00008oookJPCo00004?oonfX4o`0000Ko
oo]Z1?l0000CoookJPCo000000?ooo]Zo`000?l000000ol00013oookJPGo000000?ooo]Zo`000?l0
00000_l0000BoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000So
oo]Z1?l0000>oookJPGo00002?oonfX4o`0000kooo]Z1?l0000FoookJP004_oonfX4o`00O`Cooo]Z
1ol007l8oookJPGo00007ooonfX4o`0000;ooo]Z1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z
1Ol00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00001_oonfX4o`0001?ooo]Z
1?l000000ooonf[o0000o`000003o`0004?ooo]Z1Ol000000ooonf[o0000o`000002o`0001;ooo]Z
1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oonfX4o`0000kooo]Z
1Ol00008oookJPCo00003_oonfX4o`0001Kooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0
000OoookJPCo00000_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004?oonfX5o`0000Oooo]Z1?l0
000?oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1?l0
000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00006oookJPCo00004ooonfX4o`000003oookJ_l0
003o000000;o0000A?oonfX:o`0001;ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0
000?oookJPCo00002?oonfX4o`0000kooo]Z1Ol00008oookJPCo00003_oonfX5o`0001Gooo]Z000Y
oookJPGo00007ooonfX4o`000003oookJ_l0003o000000?o00004_oonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002?oonfX4o`0000oooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000C
oookJPCo000000?ooo]Zo`000?l000000_l00015oookJPWo00004_oonfX4o`0000Oooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>
oookJPGo00005OoonfX002Wooo]Z1Ol0000OoookJP[o00004_oonfX5o`0000Gooo]Z1?l0000Aoook
JPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oook
JPCo00002?oonfX4o`0000oooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000Coook
JPWo0000AOoonfX9o`0001;ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oook
JPCo00002?oonfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX5o`0001Gooo]Z000YoookJPGo
00007ooonfX:o`0001;ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000?oookJPCo
00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000?oookJPGo
00001ooonfX4o`00013ooo]Z1Ol00005oookJPCo00004ooonfX9o`0004Gooo]Z2?l0000CoookJPCo
00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo
00002?oonfX4o`0000oooo]Z1?l0000EoookJP00:OoonfX5o`0001oooo]Z2Ol0000CoookJPGo0000
1OoonfX4o`00017ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo0000
2OoonfX4o`0000kooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPGo0000
1?oonfX5o`0001?ooo]Z2Ol00015oookJPSo00004ooonfX4o`0000Oooo]Z1?l0000?oookJPCo0000
2?oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo0000
5OoonfX002Wooo]Z1Ol0000PoookJPSo00005?oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001ooo
nfX4o`0000oooo]Z1?l00008oookJPCo00003_oonfX5o`0000Oooo]Z1Ol0000>oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX5o`0000Cooo]Z1Ol0000DoookJPSo0000AOoo
nfX8o`0001?ooo]Z1Ol00005oookJPGo00003ooonfX5o`0000Oooo]Z1?l0000?oookJPCo00002?oo
nfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0001Gooo]Z000YoookJPGo00008?oonfX8
o`0001Cooo]Z1?l00005oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000?oookJPCo00001ooonfX5
o`0000kooo]Z1Ol00007oookJPGo00003_oonfX5o`0000Oooo]Z1?l0000@oookJPCo00001_oonfX5
o`00017ooo]Z1?l00004oookJPGo00005?oonfX7o`0004Kooo]Z2?l0000CoookJPGo00001OoonfX5
o`0000oooo]Z1Ol00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00002?oonfX4
o`0000oooo]Z1?l0000EoookJP00:OoonfX5o`00023ooo]Z1ol0000EoookJPCo00001OoonfX4o`00
017ooo]Z1?l00006oookJPGo00003ooonfX4o`0000Oooo]Z1Ol0000>oookJPGo00001ooonfX5o`00
00kooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001?oonfX4o`00
01Gooo]Z1ol00017oookJPOo00004ooonfX5o`0000Gooo]Z1Ol0000?oookJPGo00001ooonfX4o`00
00oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1Ol0000?oookJPCo00005OoonfX002Wo
oo]Z1Ol0000QoookJPKo00005OoonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX5o`0000oo
oo]Z1?l00007oookJPGo00003ooonfX4o`0000Oooo]Z1?l0000?oookJPGo00001ooonfX4o`00013o
oo]Z1?l00006oookJPGo00004OoonfX4o`0000Cooo]Z1?l0000EoookJPOo0000AooonfX6o`0001Go
oo]Z1?l00005oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX4o`0000oo
oo]Z1?l00007oookJPGo00003ooonfX4o`0001Gooo]Z000YoookJPGo00008OoonfX6o`0001Gooo]Z
1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000?oookJPGo00001_oonfX4o`00013ooo]Z
1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001_oonfX4o`0001;ooo]Z
1?l00004oookJPCo00005_oonfX5o`0004Sooo]Z1_l0000EoookJPCo00001OoonfX4o`00017ooo]Z
1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00001ooonfX5o`0000oooo]Z
1?l0000EoookJP00:OoonfX5o`0002;ooo]Z1?l0000FoookJPCo00001OoonfX4o`00017ooo]Z1?l0
0006oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l0
0007oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001?oonfX4o`0001Kooo]Z1Ol0
0019oookJPCo00005_oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001ooonfX4o`0000oooo]Z1?l0
0008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000@oookJPCo00005OoonfX002Wooo]Z1Ol0000l
oookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@
oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001?oonfX4o`0007kooo]Z1?l00005oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000?
oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPCo00004?oonfX4o`0001Gooo]Z000Yoook
JPGo0000??oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oook
JPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Cooo]Z1?l0001noookJPCo00001OoonfX4o`00017ooo]Z1?l00007oook
JPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00001ooonfX4o`00013ooo]Z1?l0000Eoook
JP00:OoonfX5o`0003cooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo
00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo
00001_oonfX4o`0001;ooo]Z1?l00004oookJPCo0000O_oonfX4o`0000Gooo]Z1?l0000AoookJPCo
00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000@oookJPCo
00005OoonfX002Wooo]Z1Ol0000loookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo0000
4OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo0000
4?oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001?oonfX4o`0007kooo]Z1?l00005oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX4o`0000oooo]Z1?l00007oookJPCo0000
4?oonfX4o`0001Gooo]Z000YoookJPGo0000??oonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oo
nfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooo
nfX4o`00013ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Cooo]Z1?l0001noookJPCo00001Ooo
nfX4o`00017ooo]Z1?l00007oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000?oookJPCo00001ooo
nfX4o`00013ooo]Z1?l0000EoookJP00:OoonfX5o`0003cooo]Z1?l00005oookJPCo00004OoonfX4
o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4
o`0000Oooo]Z1?l0000@oookJPGo00001OoonfX4o`0001;ooo]Z1?l00004oookJPCo0000O_oonfX4
o`0000Cooo]Z1Ol0000AoookJPCo00001ooonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX4
o`0000Oooo]Z1?l0000@oookJPCo00005OoonfX002Wooo]Z1Ol0000loookJPGo00001?oonfX4o`00
017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00
013ooo]Z1?l00007oookJPCo00004?oonfX5o`0000Gooo]Z1?l0000BoookJPCo00001?oonfX4o`00
07kooo]Z1?l00004oookJPGo00004OoonfX4o`0000Kooo]Z1Ol0000?oookJPCo00001ooonfX5o`00
00oooo]Z1?l00007oookJPCo00004?oonfX4o`0001Gooo]Z000YoookJPGo0000??oonfX5o`0000?o
oo]Z1Ol0000AoookJPGo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oo
oo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1Ol00005oookJPCo00004_oonfX5o`0000?o
oo]Z1?l0001noookJPCo00001?oonfX5o`00017ooo]Z1?l00006oookJPGo00003ooonfX4o`0000Oo
oo]Z1Ol0000?oookJPCo00001ooonfX4o`00013ooo]Z1?l0000EoookJP00:OoonfX5o`0003cooo]Z
1Ol00003oookJPGo00004OoonfX5o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00013ooo]Z
1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001OoonfX4o`0001;ooo]Z
1Ol00003oookJPCo0000O_oonfX5o`0000?ooo]Z1?l0000BoookJPCo00001_oonfX5o`0000oooo]Z
1Ol00006oookJPGo00003ooonfX4o`0000Oooo]Z1?l0000@oookJPCo00005OoonfX002Wooo]Z1Ol0
000moookJPCo00000ooonfX5o`0001;ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0
000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Gooo]Z1?l0
000BoookJPGo00000ooonfX4o`0007kooo]Z1Ol00003oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000@oookJPGo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0001Gooo]Z000Y
oookJPGo0000?OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00001OoonfX4o`00017ooo]Z1?l00006
oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00005
oookJPCo00004ooonfX4o`0000;ooo]Z1Ol0001noookJPGo00000ooonfX4o`0001;ooo]Z1?l00006
oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l0000E
oookJP00:OoonfX5o`0003gooo]Z1?l00003oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000Aoook
JPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00001OoonfX4o`0001?ooo]Z1?l00002oookJPGo0000OooonfX4o`0000?ooo]Z1?l0000Boook
JPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oook
JPGo00005?oonfX002Wooo]Z1Ol0000moookJPCo00000ooonfX4o`0001?ooo]Z1?l00005oookJPCo
00004OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Gooo]Z1?l0000CoookJPCo00000_oonfX5o`0007oooo]Z1?l00003oookJPCo
00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo
00004?oonfX5o`0001Cooo]Z000YoookJPGo0000?OoonfX4o`0000?ooo]Z1?l0000CoookJPCo0000
1OoonfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPGo0000
1_oonfX4o`00017ooo]Z1?l00005oookJPCo00004ooonfX4o`0000;ooo]Z1?l00020oookJPCo0000
0ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000@oookJPCo0000
1ooonfX4o`00013ooo]Z1Ol0000DoookJP00:OoonfX5o`0003gooo]Z1?l00003oookJPCo00004ooo
nfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004?oo
nfX5o`0000Kooo]Z1?l0000AoookJPCo00001?oonfX5o`0001?ooo]Z1?l00002oookJPCo0000P?oo
nfX4o`0000?ooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00005?oonfX002Wooo]Z1Ol0000moookJPCo00000ooonfX4
o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX4
o`00013ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Cooo]Z1Ol0000CoookJPCo00000_oonfX4
o`00083ooo]Z1?l00003oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4
o`00013ooo]Z1?l00007oookJPCo00004OoonfX4o`0001Cooo]Z000YoookJPGo0000?OoonfX4o`00
00?ooo]Z1?l0000CoookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004?oonfX4o`00
00Oooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00004oookJPGo00004ooonfX4o`00
00;ooo]Z1?l00020oookJPCo00000ooonfX4o`0001;ooo]Z1Ol00005oookJPCo00004OoonfX4o`00
00Kooo]Z1?l0000@oookJPGo00001_oonfX4o`00017ooo]Z1?l0000DoookJP00:OoonfX5o`0003go
oo]Z1?l00003oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00013o
oo]Z1Ol00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00002oookJPCo0000P?oonfX5o`0000;ooo]Z1?l0000BoookJPGo00001OoonfX4o`00017o
oo]Z1?l00006oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000AoookJPCo00005?oonfX002Wooo]Z
1Ol0000moookJPCo00000ooonfX4o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z
1?l0000@oookJPGo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000_oonfX4o`00083ooo]Z1Ol00002oookJPCo00004_oonfX5o`0000Gooo]Z
1?l0000AoookJPCo00001_oonfX4o`00013ooo]Z1Ol00006oookJPCo00004OoonfX4o`0001Cooo]Z
000YoookJPGo0000?OoonfX5o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX4o`00017ooo]Z1?l0
0006oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000;ooo]Z1?l00020oookJPGo00000_oonfX4o`0001?ooo]Z1?l0
0005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l0
000DoookJP003ooonfX9o`00O`?ooo]Z1Ol007l9oookJPGo0000?OoonfX5o`0000;ooo]Z1?l0000C
oookJPCo00001OoonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001OoonfX5o`00017ooo]Z1?l00004oookJPCo00005?oonfX4o`0000;ooo]Z1?l00021
oookJPCo00000_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPCo00001OoonfX5o`00017ooo]Z1?l0000DoookJP003ooonfX9o`00O`;ooo]Z1ol007l8oook
JPGo0000?OoonfX5o`000003oookJ_l0003o000000?o00004ooonfX4o`0000Gooo]Z1?l0000Aoook
JPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0000Aoook
JPCo00001?oonfX4o`0001Cooo]Z1?l00002oookJPCo0000POoonfX4o`0000;ooo]Z1?l0000Coook
JPCo00001?oonfX5o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0000Aoook
JPCo00005?oonfX000oooo]Z1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
03kooo]Z1?l000000ooonf[o0000o`000003o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4o`00
00Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPGo00004OoonfX4o`00
00Cooo]Z1?l0000DoookJPCo00000_oonfX4o`00087ooo]Z1?l000000ooonf[o0000o`000003o`00
01?ooo]Z1?l00004oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX5o`00
017ooo]Z1?l0000DoookJP004?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1ooonfX5o`0003ko
oo]Z1?l000000ooonf[o0000o`000003o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4o`0000Ko
oo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Co
oo]Z1?l0000DoookJPCo00000_oonfX4o`00087ooo]Z1?l000000ooonf[o0000o`000003o`0001?o
oo]Z1?l00004oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX4o`0001;o
oo]Z1?l0000DoookJP004OoonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`0003cooo]Z
1?l000000ooonf[o0000o`000002o`0001Cooo]Z1?l00005oookJPCo00004OoonfX5o`0000Gooo]Z
1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000_oonfX4o`00087ooo]Z2_l0000CoookJPCo00001?oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000BoookJPCo00005?oonfX001?ooo]Z1?l0
07l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000noookJPCo000000?ooo]Zo`000?l000000_l0
000DoookJPCo00001?oonfX5o`00017ooo]Z1Ol00005oookJPCo00004OoonfX4o`0000Kooo]Z1?l0
000AoookJPCo00001OoonfX4o`0001;ooo]Z1Ol00003oookJPCo00005?oonfX4o`000003oookJ_l0
003o000000?o0000POoonfX9o`0001Cooo]Z1?l00004oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000AoookJPCo00001OoonfX4o`0001;ooo]Z1?l0000DoookJP005?oonfX3o`00O`;ooo]Z0ol007l3
oookJP?o001o1ooonfX5o`0003kooo]Z1?l000000ooonf[o0000o`000002o`0001Cooo]Z1?l00004
oookJPGo00004OoonfX5o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005
oookJPCo00004_oonfX5o`0000?ooo]Z1?l0000DoookJP[o0000POoonfX9o`0001Cooo]Z1?l00004
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX4o`0001;ooo]Z1?l0000D
oookJP005OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000?_oonfX4
o`000003oookJ_l0003o000000;o00005?oonfX4o`0000Cooo]Z1Ol0000BoookJPCo00001OoonfX4
o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000BoookJPGo00000ooonfX4
o`0001Cooo]Z2_l00022oookJPSo00005?oonfX4o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX5
o`00017ooo]Z1?l00005oookJPCo00004_oonfX4o`0001Cooo]Z000?oookJP?o001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000?_oonfX9o`0001Cooo]Z1Ol00003
oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00005
oookJPCo00004ooonfX4o`0000?ooo]Z1?l0000DoookJPWo0000PooonfX8o`0001Cooo]Z1?l00004
oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000AoookJPCo00001OoonfX4o`0001;ooo]Z1?l0000D
oookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5
o`0003kooo]Z2Ol0000DoookJPGo00000ooonfX4o`0001?ooo]Z1?l00005oookJPCo00004OoonfX4
o`0000Kooo]Z1?l0000AoookJPCo00001OoonfX4o`0001?ooo]Z1?l00003oookJPCo00005OoonfX8
o`0008?ooo]Z2?l0000DoookJPGo00000ooonfX4o`0001;ooo]Z1?l00005oookJPGo00004OoonfX4
o`0000Gooo]Z1?l0000BoookJPCo00005?oonfX000oooo]Z1?l007l2oookJP?o001o0_oonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0000noookJPWo00005?oonfX5o`0000?ooo]Z1?l0000C
oookJPCo00001OoonfX4o`00017ooo]Z1?l00005oookJPGo00004OoonfX4o`0000Gooo]Z1?l0000C
oookJPCo00000ooonfX4o`0001Gooo]Z2?l00023oookJPSo00005?oonfX5o`0000?ooo]Z1?l0000B
oookJPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0001Cooo]Z000@oook
JPOo001o0ooonfX7o`00O`Sooo]Z1Ol0000noookJPSo00005_oonfX4o`0000?ooo]Z1?l0000Coook
JPCo00001?oonfX5o`00017ooo]Z1?l00005oookJPGo00004OoonfX4o`0000Gooo]Z1?l0000Coook
JPCo00000ooonfX4o`0001Gooo]Z2?l00023oookJPSo00005?oonfX5o`0000?ooo]Z1?l0000Boook
JPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0001Cooo]Z000AoookJPGo
001o1OoonfX5o`00O`Wooo]Z1Ol0000noookJPSo00005_oonfX4o`0000?ooo]Z1?l0000CoookJPCo
00001?oonfX5o`00017ooo]Z1?l00005oookJPGo00004OoonfX4o`0000Gooo]Z1?l0000CoookJPCo
00000ooonfX4o`0001Gooo]Z2?l00023oookJPOo00005_oonfX4o`0000?ooo]Z1?l0000BoookJPCo
00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0001Cooo]Z000YoookJPGo0000
?_oonfX8o`0001Kooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1Ol0000AoookJPCo0000
1OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004ooonfX4o`0000?ooo]Z1?l0000EoookJPSo0000
PooonfX7o`0001Kooo]Z1?l00003oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPGo0000
1?oonfX4o`0001;ooo]Z1?l0000DoookJP00:OoonfX5o`0003oooo]Z1ol0000FoookJPCo00000ooo
nfX4o`0001?ooo]Z1?l00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00003oookJPCo00005OoonfX8o`0008?ooo]Z1ol0000FoookJPCo00000ooo
nfX4o`0001;ooo]Z1Ol00004oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000BoookJPGo00004ooo
nfX002Wooo]Z1Ol0000ooookJPOo00005_oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4
o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00000_oonfX5
o`0001Gooo]Z1ol00024oookJPOo00005_oonfX4o`0000?ooo]Z1?l0000BoookJPGo00001?oonfX4
o`0001;ooo]Z1Ol00004oookJPCo00004_oonfX5o`0001?ooo]Z000YoookJPGo0000?ooonfX7o`00
01Kooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX4o`00
01;ooo]Z1?l00005oookJPCo00004ooonfX4o`0000;ooo]Z1Ol0000FoookJPKo0000Q?oonfX7o`00
01Kooo]Z1?l00003oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`00
01;ooo]Z1Ol0000CoookJP00:OoonfX5o`0003oooo]Z1ol0000FoookJPCo00000ooonfX4o`0001?o
oo]Z1?l00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00002oookJPGo00005_oonfX6o`0008Cooo]Z1ol0000FoookJPCo00000ooonfX4o`0001?o
oo]Z1?l00004oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00004ooonfX002Wooo]Z
1Ol0000ooookJPKo00005ooonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001;ooo]Z
1?l00005oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000CoookJPCo00000_oonfX4o`0001Oooo]Z
1_l00025oookJPKo00005_oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z
1?l00004oookJPCo00004ooonfX4o`0001?ooo]Z000YoookJPGo0000@?oonfX5o`0001Oooo]Z1?l0
0003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00001OoonfX4o`0001;ooo]Z1Ol0
0004oookJPCo00004ooonfX4o`0000;ooo]Z1?l0000GoookJPKo0000QOoonfX5o`0001Oooo]Z1?l0
0003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l0
000CoookJP00:OoonfX5o`00043ooo]Z1Ol0000GoookJPCo00000ooonfX4o`0001?ooo]Z1?l00004
oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000BoookJPGo00001?oonfX4o`0001?ooo]Z1?l00002
oookJPCo00006?oonfX4o`0008Kooo]Z1Ol0000GoookJPCo00000_oonfX5o`0001?ooo]Z1?l00004
oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00004ooonfX002Wooo]Z1Ol0001Loook
JPCo00000ooonfX4o`0001?ooo]Z1?l00004oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000Coook
JPCo00001?oonfX4o`0001?ooo]Z1?l00002oookJPCo0000__oonfX4o`0000;ooo]Z1Ol0000Coook
JPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4o`0001?ooo]Z000YoookJPGo
0000G?oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001;ooo]Z1Ol00004oookJPCo
00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00000_oonfX4o`000;kooo]Z1?l00002oookJPGo
00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l0000CoookJP00
:OoonfX5o`0005cooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo0000
1?oonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4o`0000;ooo]Z1?l0002noookJPCo0000
0_oonfX4o`0001Cooo]Z1?l00004oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo0000
4ooonfX002Wooo]Z1Ol0001LoookJPCo00000ooonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooo
nfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00002oookJPCo0000__oo
nfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00004ooo
nfX4o`0001?ooo]Z000YoookJPGo0000G?oonfX5o`000003oookJ_l0003o000000?o00004ooonfX4
o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPGo00004ooonfX4
o`0000;ooo]Z1?l0002noookJPGo000000?ooo]Zo`000?l000000_l0000DoookJPCo00001?oonfX4
o`0001?ooo]Z1?l00003oookJPGo00004ooonfX4o`0001?ooo]Z000YoookJPGo0000G?oonfX5o`00
0003oookJ_l0003o000000?o00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`00
01?ooo]Z1?l00003oookJPGo00004ooonfX4o`0000;ooo]Z1?l0002noookJPGo000000?ooo]Zo`00
0?l000000_l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPGo00004ooonfX4o`00
01?ooo]Z000YoookJPGo0000G?oonfX5o`000003oookJ_l0003o000000?o00004ooonfX4o`0000Co
oo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPGo00004ooonfX4o`0000;o
oo]Z1?l0002noookJPGo000000?ooo]Zo`000?l000000_l0000DoookJPCo00001?oonfX4o`0001?o
oo]Z1?l00003oookJPGo00004ooonfX4o`0001?ooo]Z000YoookJPGo0000GOoonfX4o`000003oook
J_l0003o000000;o00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z
1?l00003oookJPCo00005?oonfX4o`0000;ooo]Z1?l0002ooookJPCo000000?ooo]Zo`000?l00000
0_l0000DoookJPCo00000ooonfX5o`0001?ooo]Z1?l00003oookJPCo00005?oonfX4o`0001?ooo]Z
000YoookJPGo0000GOoonfX4o`000003oookJ_l0003o000000;o00005?oonfX5o`0000?ooo]Z1?l0
000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPCo00005?oonfX4o`0000;ooo]Z1?l0
002ooookJPCo000000?ooo]Zo`000?l000000_l0000DoookJPCo00000ooonfX5o`0001?ooo]Z1?l0
0003oookJPCo00005?oonfX4o`0001?ooo]Z000YoookJPGo0000GOoonfX4o`000003oookJ_l0003o
000000;o00005?oonfX5o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003
oookJPCo00005?oonfX4o`0000;ooo]Z1?l0002ooookJPCo000000?ooo]Zo`000?l000000_l0000D
oookJPGo00000_oonfX5o`0001?ooo]Z1?l00003oookJPCo00005?oonfX4o`0001?ooo]Z000Yoook
JPGo0000GOoonfX4o`000003oookJ_l0003o000000;o00005?oonfX5o`0000?ooo]Z1?l0000Coook
JPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPCo00005?oonfX4o`0000;ooo]Z1?l0002ooook
JPCo000000?ooo]Zo`000?l000000_l0000DoookJPGo00000_oonfX4o`0001Cooo]Z1?l00003oook
JPCo00005?oonfX4o`0001?ooo]Z000YoookJPGo0000GOoonfX4o`000003oookJ_l0003o000000;o
00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00001?oonfX4o`0001?ooo]Z1?l00003oookJPCo
00005?oonfX4o`0000;ooo]Z1?l0002ooookJPCo000000?ooo]Zo`000?l000000_l0000DoookJPGo
00000_oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oonfX4o`0001?ooo]Z000YoookJPGo0000
GOoonfX4o`000003oookJ_l0003o000000;o00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo0000
1?oonfX4o`0001?ooo]Z1?l00003oookJPCo00005?oonfX5o`000003oookJ_l0003o000000;o0000
_ooonfX4o`000003oookJ_l0003o000000;o00005OoonfX4o`0000;ooo]Z1?l0000DoookJPCo0000
0ooonfX4o`0001Cooo]Z1?l0000CoookJP00:OoonfX5o`0005gooo]Z1?l000000ooonf[o0000o`00
0002o`0001Gooo]Z1?l00003oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPCo00000ooo
nfX4o`0001Cooo]Z1Ol000000ooonf[o0000o`000002o`000;oooo]Z1?l000000ooonf[o0000o`00
0002o`0001Gooo]Z1?l00002oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00004ooo
nfX002Wooo]Z1Ol0001MoookJPWo00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00000ooonfX5
o`0001?ooo]Z1?l00003oookJPCo00005?oonfX5o`000003oookJ_l0003o000000;o0000_ooonfX9
o`0001Gooo]Z1?l00002oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000DoookJPCo00004ooonfX0
02Wooo]Z1Ol0001MoookJPWo00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00000ooonfX5o`00
01?ooo]Z1?l00003oookJPCo00005OoonfX4o`000003oookJ_l0003o000000;o0000_ooonfX9o`00
01Gooo]Z1?l00002oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000DoookJPCo00004ooonfX002Wo
oo]Z1Ol0001MoookJPWo00005OoonfX4o`0000?ooo]Z1?l0000CoookJPCo00000ooonfX5o`0001?o
oo]Z1?l00003oookJPCo00005OoonfX4o`000003oookJ_l0003o000000;o0000_ooonfX9o`0001Go
oo]Z1?l00002oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000DoookJPGo00004_oonfX002Wooo]Z
1Ol0001MoookJPSo00005_oonfX4o`0000;ooo]Z1Ol0000CoookJPCo00000ooonfX4o`0001Cooo]Z
1?l00003oookJPCo00005OoonfX9o`000;oooo]Z2?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z
1?l00002oookJPCo00005?oonfX5o`0001;ooo]Z000YoookJPGo0000GOoonfX8o`0001Kooo]Z1?l0
0002oookJPGo00004ooonfX4o`0000?ooo]Z1?l0000DoookJPCo00000_oonfX5o`0001Gooo]Z2Ol0
002ooookJPSo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Cooo]Z1Ol0
000BoookJP00:OoonfX5o`0005gooo]Z2?l0000FoookJPCo00000_oonfX5o`0001?ooo]Z1?l00003
oookJPCo00005?oonfX5o`000003oookJ_l0003o000000?o00005OoonfX9o`000<3ooo]Z1ol0000F
oookJPCo00000_oonfX4o`0001Gooo]Z1?l00002oookJPCo00005OoonfX4o`0001;ooo]Z000Yoook
JPGo0000GOoonfX8o`0001Kooo]Z1?l00002oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000Doook
JPGo000000?ooo]Zo`000?l000000ol0000EoookJPSo0000`OoonfX7o`0001Kooo]Z1?l00002oook
JPCo00005OoonfX4o`0000;ooo]Z1?l0000EoookJPCo00004_oonfX002Wooo]Z1Ol0001MoookJPSo
00005_oonfX4o`0000;ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Cooo]Z1Ol000000ooonf[o
0000o`000002o`0001Kooo]Z2?l00031oookJPOo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo
00000_oonfX4o`0001Gooo]Z1?l0000BoookJP004OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000
G_oonfX7o`0001Kooo]Z1?l00002oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000EoookJPCo0000
00?ooo]Zo`000?l000000_l0000FoookJPSo0000`OoonfX7o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0001Gooo]Z1?l00002oookJPCo00005OoonfX4o`0001;ooo]Z000@oookJPOo001o0ooo
nfX7o`00O`Sooo]Z1Ol0001NoookJPOo00005_oonfX4o`0000;ooo]Z1?l0000DoookJPGo00000_oo
nfX4o`0001Gooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z2?l00031oookJPOo00005_oo
nfX5o`000003oookJ_l0003o000000;o00005OoonfX4o`0000;ooo]Z1?l0000EoookJPCo00004_oo
nfX000oooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0
001NoookJPOo00005_oonfX4o`0000;ooo]Z1?l0000DoookJPGo00000_oonfX4o`0001Gooo]Z1?l0
00000ooonf[o0000o`000002o`0001Kooo]Z2?l00031oookJPOo00005_oonfX5o`000003oookJ_l0
003o000000;o00005OoonfX4o`0000;ooo]Z1?l0000EoookJPCo00004_oonfX000oooo]Z0ol007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0001NoookJPOo00005_oo
nfX4o`0000;ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l000000ooonf[o0000o`00
0002o`0001Oooo]Z1ol00031oookJPOo00005ooonfX4o`000003oookJ_l0003o000000;o00005Ooo
nfX4o`0000;ooo]Z1?l0000EoookJPCo00004_oonfX001Gooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1ooonfX7o`0005cooo]Z1ol0000FoookJPCo00000_oonfX4o`0001Gooo]Z1?l0
0002oookJPCo00005OoonfX4o`000003oookJ_l0003o000000;o00005ooonfX7o`000<7ooo]Z1ol0
000GoookJPCo000000?ooo]Zo`000?l000000_l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l0
000BoookJP005OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000G_oo
nfX7o`0001Kooo]Z1?l00002oookJPCo00005OoonfX4o`000003oookJ_l0003o000000?o00005Ooo
nfX4o`000003oookJ_l0003o000000;o00005ooonfX7o`000<7ooo]Z1ol0000GoookJPCo000000?o
oo]Zo`000?l000000_l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l0000BoookJP004ooonfX4
o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX5o`0005kooo]Z1ol0000FoookJPCo00000_oonfX4
o`0001Gooo]Z1?l000000ooonf[o0000o`000003o`0001Gooo]Z1?l000000ooonf[o0000o`000002
o`0001Oooo]Z1_l00032oookJPOo00005ooonfX4o`000003oookJ_l0003o000000;o00005OoonfX4
o`0000;ooo]Z1?l0000EoookJPCo00004_oonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol0001NoookJPKo00005ooonfX4o`0000;ooo]Z1?l0000EoookJPCo000000?ooo]Zo`00
0?l000000ol0000EoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPKo0000`ooonfX5o`00
01Sooo]Z1?l000000ooonf[o0000o`000002o`0001Gooo]Z1?l00002oookJPCo00005OoonfX4o`00
01;ooo]Z000EoookJP;o001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000GooonfX5o`0001Oo
oo]Z1?l00002oookJPCo00005OoonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`000003
oookJ_l0003o000000;o00005ooonfX6o`000<?ooo]Z1Ol0000HoookJPCo000000?ooo]Zo`000?l0
00000_l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l0000BoookJP003ooonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`0005oooo]Z1Ol0000GoookJPCo
00000_oonfX4o`0001Gooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o
0000o`000002o`0001Sooo]Z1Ol00033oookJPGo00006?oonfX4o`000003oookJ_l0003o000000;o
00005OoonfX4o`0000;ooo]Z1?l0000EoookJPCo00004_oonfX000oooo]Z0ol007l3oookJP?o001o
0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0001koookJPGo000000?ooo]Zo`000?l0
00000_l0000EoookJPCo000000?ooo]Zo`000?l000000_l0000FoookJPCo000000?ooo]Zo`000?l0
00000_l0003moookJPCo000000?ooo]Zo`000?l000000_l0000EoookJPCo00000_oonfX4o`0001Go
oo]Z1?l0000BoookJP004?oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000NooonfX:o`0001Gooo]Z
1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`000?gooo]Z
2Ol0000EoookJPGo000000?ooo]Zo`000?l000000_l0000EoookJPCo00004_oonfX0017ooo]Z1Ol0
07l5oookJPGo001o2OoonfX5o`0007_ooo]Z2_l0000EoookJPCo000000?ooo]Zo`000?l000000_l0
000FoookJPCo000000?ooo]Zo`000?l000000_l0003moookJPWo00005OoonfX5o`000003oookJ_l0
003o000000;o00005OoonfX5o`00017ooo]Z000YoookJPGo0000O?oonfX9o`0001Gooo]Z1?l00000
0ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`000?gooo]Z2Ol0000E
oookJPGo000000?ooo]Zo`000?l000000_l0000EoookJPGo00004OoonfX002Wooo]Z1Ol0001loook
JPSo00005_oonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`000003oookJ_l0003o0000
00;o0000oOoonfX8o`0001Oooo]Z2Ol0000EoookJPGo00004OoonfX002Wooo]Z1Ol0001loookJPSo
00005_oonfX4o`000003oookJ_l0003o000000;o00005_oonfX9o`000?gooo]Z2?l0000GoookJPWo
00005_oonfX4o`00017ooo]Z000YoookJPGo0000O?oonfX8o`0001Kooo]Z1?l000000ooonf[o0000
o`000002o`0001Kooo]Z2Ol0003moookJPSo00005ooonfX9o`0001Kooo]Z1?l0000AoookJP00:Ooo
nfX5o`0007cooo]Z2?l0000FoookJPCo000000?ooo]Zo`000?l000000_l0000FoookJPWo0000oOoo
nfX8o`0001Oooo]Z2?l0000GoookJPCo00004OoonfX002Wooo]Z1Ol0001loookJPSo00005_oonfX9
o`0001Oooo]Z2?l0003moookJPSo00005ooonfX8o`0001Oooo]Z1?l0000AoookJP00:OoonfX5o`00
07cooo]Z2?l0000FoookJPWo00005ooonfX7o`000?kooo]Z2?l0000GoookJPSo00005ooonfX4o`00
017ooo]Z000YoookJPGo0000O?oonfX8o`0001Kooo]Z2Ol0000GoookJPOo0000o_oonfX8o`0001Oo
oo]Z2?l0000GoookJPCo00004OoonfX002Wooo]Z1Ol0001moookJPOo00005ooonfX8o`0001Oooo]Z
1ol0003ooookJPOo00005ooonfX8o`0001Oooo]Z1?l0000AoookJP00:OoonfX5o`0007gooo]Z1ol0
000GoookJPSo00005ooonfX7o`000?oooo]Z1ol0000GoookJPSo00005ooonfX4o`00017ooo]Z000Y
oookJPGo0000OOoonfX7o`0001Oooo]Z2?l0000GoookJPOo0000oooonfX7o`0001Oooo]Z2?l0000G
oookJPCo00004OoonfX002Wooo]Z1Ol0001moookJPKo00006?oonfX8o`0001Oooo]Z1ol0003ooook
JPKo00006?oonfX8o`0001Oooo]Z1?l0000AoookJP00:OoonfX5o`0007gooo]Z1_l0000HoookJPSo
00005ooonfX7o`000?oooo]Z1_l0000HoookJPSo00005ooonfX4o`00017ooo]Z000YoookJPGo0000
OOoonfX6o`0001Sooo]Z2?l0000GoookJPOo0000oooonfX6o`0001Sooo]Z1ol0000HoookJPCo0000
4OoonfX002Wooo]Z1Ol0001moookJPKo00006?oonfX8o`0001Sooo]Z1Ol0003ooookJP7ooo]Z1_l0
000HoookJPOo0000;OoonfX002Wooo]Z1Ol0001moookJPKo00006?oonfX7o`0001Wooo]Z1Ol0003o
oookJP7ooo]Z1_l0000HoookJPOo0000;OoonfX002Wooo]Z1Ol0001moookJPKo00006?oonfX7o`00
01Wooo]Z1Ol0003ooookJP;ooo]Z1Ol0000IoookJPKo0000;OoonfX002Wooo]Z1Ol0001noookJPCo
00006OoonfX7o`0001Wooo]Z1Ol0003ooookJP;ooo]Z1?l0000JoookJPKo0000;OoonfX002Wooo]Z
1Ol0002LoookJPKo0000oooonfXnoookJPKo0000;OoonfX002Wooo]Z1Ol0002LoookJPKo0000oooo
nfXnoookJPKo0000;OoonfX002Wooo]Z1Ol0002LoookJPKo0000oooonfXnoookJPKo0000;OoonfX0
02Wooo]Z1Ol0002LoookJPKo0000oooonfXnoookJPKo0000;OoonfX002Wooo]Z1Ol0002LoookJPKo
0000oooonfXnoookJPKo0000;OoonfX002Wooo]Z1Ol0002LoookJPGo0000oooonfXooookJPGo0000
;_oonfX002Wooo]Z1Ol0002LoookJPGo0000oooonfY0oookJPCo0000;_oonfX002Wooo]Z1Ol0003o
oookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oo
oo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wo
oo]Z1Ol0003ooookJ_oooo]Z5?oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-16.9899, -40.9843, \
0.388873, 0.232103}},
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"]
}, Open  ]],

Cell["Damped Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1, 1/10, 1/2, 1/2]], {t, 0, 200}]\)], "Input",
  CellTags->"mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],\


Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.309016 0.0147196 [
[.2619 .29652 -12 -20 ]
[.2619 .29652 12 0 ]
[.5 .29652 -17 -20 ]
[.5 .29652 17 0 ]
[.7381 .29652 -17 -20 ]
[.7381 .29652 17 0 ]
[.97619 .29652 -17 -20 ]
[.97619 .29652 17 0 ]
[.01131 .01462 -36.9375 -10 ]
[.01131 .01462 0 10 ]
[.01131 .16182 -36.9375 -10 ]
[.01131 .16182 0 10 ]
[.01131 .45621 -24 -10 ]
[.01131 .45621 0 10 ]
[.01131 .60341 -24 -10 ]
[.01131 .60341 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .30902 m
.5 .31527 L
s
gsave
.5 .29652 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.02381 .01462 m
.03006 .01462 L
s
gsave
.01131 .01462 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02381 .16182 m
.03006 .16182 L
s
gsave
.01131 .16182 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .45621 m
.03006 .45621 L
s
gsave
.01131 .45621 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .60341 m
.03006 .60341 L
s
gsave
.01131 .60341 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04406 m
.02756 .04406 L
s
.02381 .0735 m
.02756 .0735 L
s
.02381 .10294 m
.02756 .10294 L
s
.02381 .13238 m
.02756 .13238 L
s
.02381 .19126 m
.02756 .19126 L
s
.02381 .2207 m
.02756 .2207 L
s
.02381 .25014 m
.02756 .25014 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33846 m
.02756 .33846 L
s
.02381 .36789 m
.02756 .36789 L
s
.02381 .39733 m
.02756 .39733 L
s
.02381 .42677 m
.02756 .42677 L
s
.02381 .48565 m
.02756 .48565 L
s
.02381 .51509 m
.02756 .51509 L
s
.02381 .54453 m
.02756 .54453 L
s
.02381 .57397 m
.02756 .57397 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .32374 m
.03279 .33911 L
.03543 .34588 L
.03673 .34871 L
.03793 .35081 L
.03902 .35218 L
.04018 .35297 L
.04134 .35297 L
.04262 .35195 L
.04385 .34989 L
.04454 .34824 L
.04518 .34642 L
.04758 .33681 L
.04888 .32984 L
.0503 .32095 L
.05288 .30181 L
.05781 .25952 L
.06244 .2226 L
.06374 .21447 L
.06511 .20741 L
.06582 .20443 L
.06661 .20178 L
.06732 .19995 L
.06799 .19878 L
.06926 .19804 L
.07042 .19912 L
.07106 .20046 L
.07175 .20252 L
.07302 .20789 L
.07437 .2159 L
.07586 .22737 L
.07888 .2582 L
.08429 .33114 L
.08933 .40179 L
.09197 .43262 L
.09342 .44619 L
.09476 .4563 L
.09594 .46297 L
.0972 .4676 L
.09793 .46903 L
.09861 .46955 L
.09988 .4683 L
.10105 .46458 L
.10214 .45896 L
.10332 .45043 L
.10458 .4388 L
.10711 .40798 L
.10951 .37103 L
.11402 .28943 L
.11928 .19474 L
Mistroke
.12184 .15742 L
.12295 .14412 L
.12415 .13211 L
.12529 .1232 L
.12634 .11727 L
.12734 .11371 L
.1284 .11226 L
.12951 .11335 L
.13055 .1168 L
.13169 .12328 L
.13292 .13326 L
.13415 .14637 L
.13548 .16389 L
.13791 .20336 L
.14247 .29596 L
.14701 .39491 L
.14939 .44187 L
.15189 .48315 L
.15323 .50074 L
.15394 .5086 L
.15469 .51581 L
.15539 .52136 L
.15602 .52543 L
.15725 .53067 L
.1585 .53222 L
.1592 .53143 L
.15984 .52964 L
.16103 .52368 L
.16228 .51371 L
.16359 .49947 L
.16478 .48323 L
.16746 .43674 L
.1723 .32828 L
.17763 .20077 L
.18055 .14122 L
.18199 .11717 L
.1833 .09875 L
.18438 .08652 L
.18556 .07634 L
.18675 .06966 L
.188 .06661 L
.1893 .06786 L
.19003 .07053 L
.19069 .07417 L
.19198 .08451 L
.1932 .09812 L
.19548 .13296 L
.19759 .17444 L
.20236 .29018 L
.20757 .42314 L
Mistroke
.21011 .4791 L
.21244 .5202 L
.21369 .53743 L
.21489 .55019 L
.21615 .5596 L
.21686 .56302 L
.21752 .56493 L
.21825 .56561 L
.21894 .56487 L
.22023 .55989 L
.22095 .55508 L
.22162 .5494 L
.22311 .53229 L
.22438 .51349 L
.22558 .4923 L
.22782 .4449 L
.23286 .31449 L
.23727 .19643 L
.23969 .13982 L
.24195 .0962 L
.24323 .07668 L
.2444 .0624 L
.2457 .05086 L
.24638 .0467 L
.2471 .04376 L
.24828 .04219 L
.24937 .04438 L
.25057 .05081 L
.25186 .06222 L
.25325 .07971 L
.25476 .10422 L
.2575 .16151 L
.26262 .29766 L
.26719 .42413 L
.26971 .4848 L
.2721 .53137 L
.27344 .55173 L
.27415 .56056 L
.27491 .56843 L
.27561 .57427 L
.27624 .57833 L
.27748 .58283 L
.27873 .5827 L
.27943 .58057 L
.28007 .57731 L
.28126 .56809 L
.28251 .55401 L
.28383 .53465 L
.28502 .51325 L
.28771 .45392 L
Mistroke
.29256 .32118 L
.2979 .17169 L
.30082 .10471 L
.30225 .07848 L
.30356 .05898 L
.30473 .04551 L
.30584 .03636 L
.30701 .03072 L
.30829 .02936 L
.3096 .03319 L
.31033 .0376 L
.311 .043 L
.31229 .05719 L
.31351 .07483 L
.31581 .11829 L
.31792 .16822 L
.3227 .30245 L
.32792 .45061 L
.33047 .51048 L
.3328 .55276 L
.33406 .56978 L
.33526 .58172 L
.33652 .58968 L
.33723 .59202 L
.33789 .59277 L
.33918 .59033 L
.33991 .58664 L
.3406 .58168 L
.34132 .57494 L
.34198 .56741 L
.34348 .5459 L
.34596 .49759 L
.34821 .44246 L
.35328 .29659 L
.35802 .16175 L
.3601 .11201 L
.36239 .06813 L
.36367 .04949 L
.36487 .03627 L
.36614 .02699 L
.36685 .02395 L
.3675 .02256 L
.3682 .02256 L
.36886 .02395 L
.36958 .02703 L
.37034 .03207 L
.37107 .03854 L
.37176 .04608 L
.37304 .06379 L
.37556 .11114 L
Mistroke
.37787 .16693 L
.38309 .31791 L
.3878 .45351 L
.39039 .51529 L
.39167 .54038 L
.39285 .55991 L
.39393 .57453 L
.39513 .58665 L
.39633 .59444 L
.39761 .59773 L
.39868 .59648 L
.39984 .59103 L
.40094 .58204 L
.40194 .57063 L
.40315 .55307 L
.40444 .53002 L
.40676 .47863 L
.41202 .33051 L
.41754 .16886 L
.41996 .10951 L
.42124 .08302 L
.42262 .05914 L
.42397 .04081 L
.4252 .02874 L
.42643 .02131 L
.4276 .01874 L
.42892 .02106 L
.43013 .02807 L
.43076 .03354 L
.43146 .04101 L
.43288 .06052 L
.43564 .11369 L
.43861 .18917 L
.44399 .34972 L
.44911 .49153 L
.45169 .54554 L
.45315 .56874 L
.4538 .57717 L
.45451 .5849 L
.45576 .59484 L
.45695 .59968 L
.4581 .60007 L
.45917 .59664 L
.46032 .58889 L
.46159 .57562 L
.46291 .55673 L
.46415 .53468 L
.47454 .24953 L
.47702 .17801 L
.47966 .11156 L
Mistroke
.48094 .08442 L
.48215 .06258 L
.48325 .04615 L
.48441 .03258 L
.48546 .02379 L
.48662 .01818 L
.48768 .01681 L
.48866 .01877 L
.48983 .02506 L
.49089 .03448 L
.49211 .04957 L
.49327 .0678 L
.49567 .11669 L
.4979 .17289 L
.50293 .32206 L
.50757 .45725 L
.51 .51624 L
.51133 .54296 L
.51256 .56376 L
.51375 .57965 L
.51482 .59049 L
.51601 .59836 L
.51728 .60177 L
.51835 .60061 L
.51951 .59522 L
.5206 .58626 L
.5216 .57477 L
.52279 .55741 L
.52407 .53448 L
.52637 .48315 L
.53161 .33423 L
.53711 .17079 L
.53979 .10454 L
.54221 .05825 L
.54342 .04093 L
.54474 .02714 L
.54598 .01903 L
.54712 .0159 L
.54833 .01717 L
.54902 .02 L
.54966 .02399 L
.55096 .03598 L
.55168 .04492 L
.55234 .05439 L
.55506 .10572 L
.55802 .17998 L
.56339 .34073 L
.56846 .48444 L
.57102 .54062 L
.57247 .56538 L
Mistroke
.57313 .57456 L
.57384 .58317 L
.57508 .59451 L
.57627 .60078 L
.57742 .60256 L
.57849 .60038 L
.57976 .59303 L
.58091 .58199 L
.58224 .5643 L
.58349 .54308 L
.58814 .43268 L
.59324 .27935 L
.59822 .13755 L
.59965 .10375 L
.60101 .07598 L
.60224 .05483 L
.60355 .03701 L
.60468 .0258 L
.60593 .01803 L
.60706 .01528 L
.60812 .01648 L
.60937 .02254 L
.61052 .03242 L
.61177 .04786 L
.6131 .06905 L
.61736 .16593 L
.62202 .30337 L
.6273 .45882 L
.62989 .5213 L
.63103 .54404 L
.63228 .56517 L
.63333 .57945 L
.63445 .59115 L
.63564 .59923 L
.63676 .6027 L
.63806 .60168 L
.63929 .59566 L
.6404 .58615 L
.64161 .5715 L
.64303 .54891 L
.64437 .52275 L
.64687 .46304 L
.65248 .29814 L
.65728 .15742 L
.65983 .09625 L
.66123 .0688 L
.66255 .04758 L
.66382 .03202 L
.66454 .02538 L
.6652 .02067 L
Mistroke
.66637 .01577 L
.66761 .01539 L
.66877 .01954 L
.66986 .02731 L
.67105 .04004 L
.67233 .05846 L
.67496 .10981 L
.67772 .17998 L
.68265 .32783 L
.68692 .45321 L
.68927 .51137 L
.69148 .55509 L
.69274 .57418 L
.6934 .58238 L
.6941 .58963 L
.69534 .5987 L
.69648 .60274 L
.69763 .60255 L
.6987 .59854 L
.69987 .58995 L
.70113 .57598 L
.70247 .55603 L
.70368 .53376 L
.7064 .47132 L
.71128 .33022 L
.71659 .17164 L
.71938 .1023 L
.72091 .07158 L
.72233 .0484 L
.72357 .03282 L
.72427 .02614 L
.72491 .02137 L
.7256 .01762 L
.72636 .01531 L
.72707 .01483 L
.72773 .01584 L
.72888 .02095 L
.73014 .03139 L
.73146 .04748 L
.73269 .06711 L
.73514 .11771 L
.73739 .17515 L
.74244 .32605 L
.7472 .46485 L
.74982 .52669 L
.7511 .55132 L
.75228 .57011 L
.7534 .58423 L
.75458 .59501 L
.75577 .60141 L
Mistroke
.75707 .6032 L
.75816 .6005 L
.75932 .59341 L
.76042 .58283 L
.76142 .57001 L
.76407 .5227 L
.76652 .46421 L
.77206 .30118 L
.77691 .15872 L
.77946 .09718 L
.78085 .06973 L
.78214 .04874 L
.7833 .03399 L
.78454 .02273 L
.78525 .01846 L
.78591 .01589 L
.78716 .01497 L
.78831 .01857 L
.78937 .02565 L
.79053 .03744 L
.79177 .05433 L
.79399 .09535 L
.79607 .14428 L
.8008 .2805 L
.8059 .4338 L
.80841 .49893 L
.81073 .54768 L
.81202 .56878 L
.8134 .58599 L
.81419 .59326 L
.81493 .59833 L
.81559 .6014 L
.81631 .60311 L
.8176 .60199 L
.81825 .59939 L
.81896 .59498 L
.82023 .58326 L
.8214 .56799 L
.82401 .52048 L
.82642 .46246 L
.83188 .30184 L
.83659 .16291 L
.8391 .10155 L
.84041 .07481 L
.84179 .0515 L
.84295 .03609 L
.84422 .02388 L
.84537 .01715 L
.84644 .01472 L
.84755 .0161 L
Mistroke
.84855 .02077 L
.84971 .03013 L
.8508 .04274 L
.85196 .05998 L
.85319 .08222 L
.85539 .13121 L
.86036 .27178 L
.86521 .41902 L
.86761 .48338 L
.86982 .53332 L
.87103 .55562 L
.87236 .57564 L
.8737 .5905 L
.87444 .5963 L
.87513 .60019 L
.87634 .60332 L
.87746 .60198 L
.87868 .59589 L
.87997 .58436 L
.88112 .56987 L
.88216 .55341 L
.8845 .50615 L
.88872 .39345 L
.89327 .25408 L
.89587 .17837 L
.89829 .11609 L
.90062 .06797 L
.90193 .04709 L
.90313 .03231 L
.90439 .0215 L
.9051 .01759 L
.90576 .01542 L
.90697 .01509 L
.90826 .01995 L
.90945 .02916 L
.91074 .04406 L
.91196 .06259 L
.91308 .0832 L
.91745 .19024 L
.92264 .34708 L
.9255 .43164 L
.9282 .50172 L
.93072 .55313 L
.93214 .57487 L
.93345 .58973 L
.93456 .59809 L
.93577 .60282 L
.93705 .60264 L
.93824 .59772 L
.9393 .58958 L
Mistroke
.94045 .57671 L
.94166 .55908 L
.94278 .53907 L
.94695 .43963 L
.95633 .16126 L
.95892 .09833 L
.96019 .07284 L
.96137 .05306 L
.96241 .03868 L
.96356 .02662 L
.96471 .01864 L
.96594 .01484 L
.96662 .01482 L
.96727 .01621 L
.96849 .02249 L
.9698 .03449 L
.97055 .0436 L
.97124 .05348 L
.97364 .09801 L
.97619 .15996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wo
oo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX000oooo]Z2Ol0
07l3oookJPGo001o2OoonfX5o`000?oooo]ZoooonfXDoookJP003ooonfX9o`00O`;ooo]Z1ol007l8
oookJPGo0000oooonf[ooookJQCooo]Z000?oookJPCo001o1ooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z5?oonfX000?ooo]Z2_l007l3oookJPCo001o1OoonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000oooonfXgoookJPCo00007OoonfX4o`0001cooo]Z1?l0000Loook
JPCo00007?oonfX4o`0001cooo]Z1Ol0000LoookJPCo00005_oonfX000?ooo]Z2_l007l4oookJPGo
001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo0000m?oonfX4o`0001cooo]Z1?l0000LoookJPGo
00006ooonfX5o`0001cooo]Z1?l0000LoookJPCo00007?oonfX5o`0001_ooo]Z1Ol0000LoookJPGo
00005OoonfX001?ooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003EoookJPCo0000
7?oonfX5o`0001_ooo]Z1Ol0000LoookJPGo00006ooonfX5o`0001_ooo]Z1Ol0000KoookJPKo0000
6ooonfX5o`0001_ooo]Z1_l0000JoookJPKo00005OoonfX001Cooo]Z0ol007l2oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0003EoookJPCo00007?oonfX5o`0001_ooo]Z1_l0000KoookJPGo00006ooo
nfX5o`0001_ooo]Z1_l0000JoookJPKo00006ooonfX6o`0001[ooo]Z1_l0000JoookJPKo00005Ooo
nfX001Gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000;Gooo]Z1?l0
000LoookJPGo00006_oonfX6o`0001_ooo]Z1_l0000KoookJPGo00006ooonfX5o`0001_ooo]Z1_l0
000JoookJPKo00006_oonfX7o`0001[ooo]Z1_l0000JoookJPKo00005OoonfX000oooo]Z0ol007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0002doookJPKo00006ooo
nfX5o`0001[ooo]Z1ol0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000KoookJPKo00006_oo
nfX7o`0001Wooo]Z1ol0000JoookJPKo00006_oonfX6o`0001Gooo]Z000?oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000]?oonfX6o`0001_ooo]Z1_l0
000IoookJPOo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001[ooo]Z1ol0
000IoookJPOo00006_oonfX6o`0001[ooo]Z1_l0000EoookJP003ooonfX4o`00O`;ooo]Z0ol007l2
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000;Cooo]Z1_l0000JoookJPOo00006Ooo
nfX7o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX7o`0001Wooo]Z2?l0000IoookJPOo00006Ooo
nfX7o`0001[ooo]Z1_l0000JoookJPKo00005OoonfX0013ooo]Z1ol007l3oookJPOo001o2?oonfX5
o`0009Gooo]Z1?l0000KoookJPKo00006_oonfX7o`0001Wooo]Z1ol0000JoookJPKo00006_oonfX7
o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0001Wooo]Z1ol0000IoookJPOo00006_oonfX7
o`0001Cooo]Z000AoookJPGo001o1OoonfX5o`00O`Wooo]Z1Ol0002DoookJPGo00006ooonfX6o`00
01[ooo]Z1ol0000IoookJPOo00006_oonfX7o`0001Wooo]Z1ol0000IoookJPOo00006OoonfX8o`00
01Sooo]Z2?l0000IoookJPOo00006OoonfX7o`0001[ooo]Z1ol0000DoookJP00:OoonfX5o`0009Co
oo]Z1_l0000IoookJPOo00006_oonfX7o`0001Wooo]Z1ol0000JoookJPOo00006?oonfX8o`0001Wo
oo]Z1ol0000IoookJPSo00006?oonfX8o`0001Wooo]Z1ol0000IoookJPOo00006_oonfX7o`0001Co
oo]Z000YoookJPGo0000TooonfX7o`0001Wooo]Z1ol0000JoookJPOo00006OoonfX7o`0001Wooo]Z
2?l0000HoookJPSo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPSo00006OoonfX7o`0001Wooo]Z
1ol0000IoookJPSo00005?oonfX002Wooo]Z1Ol0002CoookJPOo00006OoonfX8o`0001Sooo]Z2?l0
000IoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0
000IoookJPSo00006?oonfX7o`0001Wooo]Z2?l0000DoookJP00:OoonfX5o`0009?ooo]Z1ol0000I
oookJPSo00006?oonfX8o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0001Wooo]Z2?l0000H
oookJPSo00006?oonfX8o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Cooo]Z000Yoook
JPGo0000TooonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Wooo]Z2?l0000Hoook
JPSo00006?oonfX9o`0001Sooo]Z2?l0000HoookJPSo00006OoonfX8o`0001Sooo]Z2?l0000Hoook
JPSo00005?oonfX002Wooo]Z1Ol0001doookJPCo00006ooonfX7o`0001Wooo]Z2?l0000HoookJPSo
00006?oonfX8o`0001Wooo]Z2?l0000HoookJPWo00005ooonfX9o`0001Oooo]Z2Ol0000HoookJPSo
00006OoonfX8o`0001Oooo]Z2Ol0000HoookJPSo00005?oonfX002Wooo]Z1Ol0001doookJPGo0000
6_oonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX9o`0001Sooo]Z2?l0000HoookJPWo0000
5ooonfX9o`0001Oooo]Z2Ol0000HoookJPSo00006OoonfX8o`0001Oooo]Z2Ol0000HoookJPSo0000
5?oonfX002Wooo]Z1Ol0001coookJPKo00006_oonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oo
nfX9o`0001Sooo]Z2?l0000HoookJPWo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX9o`0001Sooo]Z2Ol0000GoookJPWo00005ooonfX9o`0001Sooo]Z2?l0000DoookJP00:OoonfX5
o`0007?ooo]Z1_l0000JoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPWo00006?oonfX8
o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002
o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z2Ol0000GoookJPWo00005ooonfX4
o`000003oookJ_l0003o000000;o00005ooonfX9o`0001Cooo]Z000YoookJPGo0000LooonfX7o`00
01Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`00
01Sooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`00
0?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000HoookJPWo00005ooonfX9o`00
01Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z2_l0000CoookJP00:OoonfX5o`0007?o
oo]Z1ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l0
00000_l0000GoookJP[o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003
oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX4o`000003
oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003
oookJ_l0003o000000;o00005ooonfX:o`0001?ooo]Z000YoookJPGo0000LooonfX7o`0001Sooo]Z
2Ol0000HoookJPSo00006?oonfX9o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z
2_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000HoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000CoookJP00:OoonfX5o`0007?ooo]Z1ol0
000HoookJPWo00006?oonfX8o`0001Sooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l000000_l0
000GoookJP[o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0
003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX4o`000003oookJ_l0
003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0
003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0007?ooo]Z1ol0000H
oookJPWo00006?oonfX9o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00000
0ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005ooonfX4o`000003oookJ_l0003o
000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o
000000;o00006?oonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o
000000;o00005ooonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000C
oookJP00:OoonfX5o`0007;ooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000Hoook
JPWo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o0000
00;o00005ooonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000Foook
JPGo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000Goook
JPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000Goook
JPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001?ooo]Z000YoookJPGo
0000L_oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z2_l0000GoookJPCo
000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo
00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1Ol000000ooonf[o
0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol000000ooonf[o
0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo
00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0007;ooo]Z2?l0000HoookJPCo0000
00?ooo]Zo`000?l000000_l0000GoookJPGo000000?ooo]Zo`000?l000000_l0000GoookJPCo0000
00?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo0000
0_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0007;ooo]Z2?l0000HoookJPCo000000?o
oo]Zo`000?l000000_l0000GoookJPGo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?o
oo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oo
nfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l00002oookJPCo00005ooo
nfX4o`0000;ooo]Z1?l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPGo000000?o
oo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00004ooo
nfX002Wooo]Z1Ol0001DoookJPCo00006_oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002
o`0001Oooo]Z1?l00002oookJPCo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`000002
o`0001Kooo]Z1?l00002oookJPCo00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4
o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0005Cooo]Z1Ol0000IoookJPSo00006?oonfX4o`00
0003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`00
0?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX5o`00
0003oookJ_l0003o000000;o00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`00
00;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001?ooo]Z000YoookJPGo0000DooonfX6o`0001Wo
oo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Oo
oo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`0000;o
oo]Z1?l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPCo00000_oonfX4o`0001Oo
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oo
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0005?ooo]Z
1_l0000IoookJPWo00005ooonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z
1?l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00:OoonfX5o`0005?ooo]Z1_l0
000IoookJPWo00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001?ooo]Z000YoookJPGo0000DooonfX6o`0001Wooo]Z2Ol0000G
oookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o
000000?o00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPGo00005OoonfX4o`0000;ooo]Z1Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00004ooonfX002Wooo]Z1Ol0001CoookJPKo00006OoonfX4o`000003oookJ_l0003o0000
00;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oook
JPGo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oook
JPCo00005_oonfX4o`0000;ooo]Z1Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oook
JPGo00005OoonfX4o`0000;ooo]Z1Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oook
JPGo00004_oonfX002Wooo]Z1Ol0001CoookJPKo00006OoonfX4o`000003oookJ_l0003o000000;o
00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo
00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo
00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo
00004_oonfX002Wooo]Z1Ol0001CoookJPOo00006?oonfX4o`000003oookJ_l0003o000000;o0000
5ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo0000
5OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo0000
5OoonfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo0000
4_oonfX002Wooo]Z1Ol0001BoookJPSo00006?oonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005Ooo
nfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005Ooo
nfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00004_oo
nfX002Wooo]Z1Ol0001BoookJPSo00006?oonfX4o`000003oookJ_l0003o000000;o00005ooonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4
o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo00005_oonfX4
o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4
o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00004_oonfX0
02Wooo]Z1Ol0001BoookJPSo00006?oonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`00
00;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`00
00?ooo]Z1?l0000EoookJPGo00000ooonfX4o`0001Gooo]Z1?l00002oookJPGo00005OoonfX4o`00
00?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4o`00
00?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00003oookJPCo00004_oonfX002Wo
oo]Z1Ol0001BoookJPSo00005ooonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;o
oo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?o
oo]Z1?l0000EoookJPCo00001?oonfX4o`0001Gooo]Z1?l00002oookJPGo00005OoonfX4o`0000?o
oo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4o`0000?o
oo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00003oookJPCo00004_oonfX002Wooo]Z
1Ol0001BoookJPSo00005ooonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z
1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z
1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00002oookJPGo00005OoonfX4o`0000?ooo]Z
1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z
1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00003oookJPCo00004_oonfX002Wooo]Z1Ol0
001BoookJPWo00005_oonfX5o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0
000EoookJPGo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0
000EoookJPGo00000_oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00004_oonfX002Wooo]Z1Ol0001A
oookJP[o00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00003
oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z2_l0000Foook
JPCo00000_oonfX5o`0001Gooo]Z1Ol00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000Eoook
JPCo00001?oonfX4o`0001;ooo]Z000YoookJPGo0000DOoonfX5o`000003oookJ_l0003o000000;o
00005_oonfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX5o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPGo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo
00005OoonfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX5o`0000?ooo]Z1?l0000DoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo0000
5OoonfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX5o`0000?ooo]Z1?l0000DoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005Ooo
nfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oonfX4
o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Cooo]Z1Ol0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4
o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oonfX4o`00
00?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPGo00005?oonfX4o`00
00Cooo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oonfX4o`0000?o
oo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Co
oo]Z1Ol0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Co
oo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Co
oo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPGo00005?oonfX4o`0000Co
oo]Z1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z
1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000BoookJP00:OoonfX5o`00057ooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0
000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000BoookJP00:OoonfX5o`0003Cooo]Z1?l0000IoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003
oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005
oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004
oookJPCo00004_oonfX002Wooo]Z1Ol0000coookJPGo00006OoonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001;ooo]Z000YoookJPGo0000<ooonfX6o`0001Sooo]Z1?l00002oookJPGo
00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`0003?ooo]Z1_l0000HoookJPCo0000
0_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
1OoonfX4o`0001Cooo]Z1?l00004oookJPCo00004_oonfX002Wooo]Z1Ol0000coookJPKo00006?oo
nfX4o`0000;ooo]Z1Ol0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooo
nfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooo
nfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001;ooo]Z000YoookJPGo0000<_oonfX7
o`0001Sooo]Z1?l00003oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001Cooo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000BoookJP00:OoonfX5o`00
03;ooo]Z1ol0000HoookJPCo00000ooonfX4o`0001Cooo]Z1Ol00003oookJPCo00005?oonfX5o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Gooo]Z1?l0000CoookJPGo00001?oonfX4o`0001?ooo]Z1Ol00005oookJPCo00004ooonfX4o`00
00Gooo]Z1?l0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00004_oonfX002Wo
oo]Z1Ol0000boookJPOo00006?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPCo00004ooonfX5o`0000Cooo]Z1Ol0000BoookJPGo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5o`0001?o
oo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001;o
oo]Z000YoookJPGo0000<_oonfX7o`0001Sooo]Z1?l00003oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPGo00004_oonfX4o`0000Kooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000BoookJP00:OoonfX5o`00037ooo]Z2Ol0000FoookJPGo00000ooonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l0
0006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1Ol0
0005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l0
0004oookJPCo00004_oonfX002Wooo]Z1Ol0000aoookJPWo00005_oonfX5o`0000?ooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000C
oookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000C
oookJPGo00001?oonfX5o`00017ooo]Z000YoookJPGo0000<OoonfX9o`0001Kooo]Z1Ol00003oook
JPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oook
JPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00004ooonfX5o`0000Gooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00004ooonfX5o`0000Cooo]Z1Ol0000AoookJP00:OoonfX5o`00037ooo]Z1?l000000ooonf[o
0000o`000002o`0001Kooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo
00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo
00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo
00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo
00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX5o`0000Cooo]Z1Ol0000AoookJP00
:OoonfX5o`00037ooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo0000
4ooonfX4o`0000Kooo]Z1?l0000AoookJP00:OoonfX5o`00037ooo]Z1?l000000ooonf[o0000o`00
0002o`0001Kooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000AoookJP00:OoonfX5
o`00037ooo]Z1?l000000ooonf[o0000o`000003o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPGo00004_oonfX5
o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4
o`0000Kooo]Z1?l0000AoookJP00:OoonfX5o`00037ooo]Z1?l000000ooonf[o0000o`000003o`00
01Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1Ol00004oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000AoookJP00:OoonfX5o`00037o
oo]Z1?l000000ooonf[o0000o`000003o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Go
oo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Go
oo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000AoookJP00:OoonfX5o`00037ooo]Z1?l00002oookJPCo00005OoonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oookJPGo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oookJPGo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z000YoookJPGo0000<OoonfX4o`0000;ooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z1Ol0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z1Ol0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000BoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX002Wooo]Z1Ol0000a
oookJPCo00000_oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000C
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPGo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000A
oookJP00:OoonfX5o`00033ooo]Z1Ol00002oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX4o`00017ooo]Z000YoookJPGo0000<?oonfX5o`0000;ooo]Z1?l0000EoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX002Wooo]Z1Ol0000`oookJPGo0000
0_oonfX4o`0001Gooo]Z1?l00004oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo0000
1ooonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo0000
1ooonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJP004ooo
nfX3o`00O`Gooo]Z1Ol007l9oookJPGo0000<?oonfX4o`0000?ooo]Z1?l0000DoookJPGo00001?oo
nfX5o`0001;ooo]Z1Ol00005oookJPCo00004_oonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001_oo
nfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX001?ooo]Z0ol007l4oookJPOo001o2?oonfX5
o`00033ooo]Z1?l00003oookJPCo00005?oonfX5o`0000Cooo]Z1Ol0000BoookJPGo00001OoonfX4
o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4
o`00017ooo]Z000CoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0000`
oookJPCo00000ooonfX4o`0001Cooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000A
oookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000A
oookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000A
oookJP000ooonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000`oook
JPCo00000ooonfX4o`0001Cooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Aoook
JP000ooonfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0000^oookJPCo
00000ooonfX4o`0001Cooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo
00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo
00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJP00
4ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX5o`00033ooo]Z1?l00003oookJPCo0000
5?oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1Ol0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1Ol0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z000CoookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000<?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oo
nfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oo
nfX4o`00017ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l0000KoookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX5
o`00033ooo]Z1?l00003oookJPCo00005?oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX5
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00006ooonfX0
01?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000`oookJPCo00000ooonfX4o`00
01Cooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00
017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00
017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001ooonfX4o`00
017ooo]Z1?l00007oookJPCo00004_oonfX4o`0001_ooo]Z000@oookJPKo001o0ooonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000<?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013o
oo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017o
oo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00017o
oo]Z1?l0000KoookJP004?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000<?oonfX4o`0000?ooo]Z1Ol0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo
00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z1?l0000KoookJP00
4_oonfX4o`00O`Cooo]Z1ol007l8oookJPGo0000;ooonfX5o`0000?ooo]Z1Ol0000CoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
1ooonfX5o`00017ooo]Z1?l0000KoookJP004ooonfX3o`00O`Gooo]Z1Ol007l9oookJPGo0000;ooo
nfX5o`0000?ooo]Z1Ol0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oo
nfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l0000KoookJP00:OoonfX5
o`0002oooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00006ooonfX0
02Wooo]Z1Ol0000_oookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004OoonfX5o`00
00Kooo]Z1?l0000BoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`00
00Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`00
01_ooo]Z000YoookJPGo0000;ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`00017o
oo]Z1Ol00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013o
oo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013o
oo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017o
oo]Z1?l0000KoookJP00:OoonfX5o`0002oooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z
1?l0000AoookJPGo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z
1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000@oookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000AoookJPCo00006ooonfX002Wooo]Z1Ol0000_oookJPCo00001OoonfX4o`0001;ooo]Z1Ol0
0006oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000AoookJPCo00001ooonfX4o`00017ooo]Z1Ol0
0006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l0
0008oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l0
0008oookJPCo00004OoonfX4o`0001_ooo]Z000YoookJPGo0000;ooonfX4o`0000Gooo]Z1?l0000B
oookJPGo00001_oonfX4o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000A
oookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000A
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000A
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000A
oookJPCo00002?oonfX4o`00013ooo]Z1Ol0000KoookJP00:OoonfX5o`0002oooo]Z1?l00005oook
JPCo00004_oonfX5o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oook
JPGo00004?oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oook
JPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oook
JPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oook
JPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPGo00006ooonfX002Wooo]Z1Ol0000_oookJPCo
00001OoonfX4o`0001;ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo
00001ooonfX5o`00013ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo
00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo
00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo
00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX5o`0001_ooo]Z000YoookJPGo0000
;ooonfX4o`0000Gooo]Z1Ol0000AoookJPCo00001ooonfX5o`00013ooo]Z1?l00008oookJPCo0000
4OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00017ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX5o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l0000LoookJP00:Ooo
nfX5o`0001?ooo]Z1Ol0000GoookJPCo00001OoonfX5o`00017ooo]Z1?l00007oookJPGo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPGo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oo
nfX5o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0001cooo]Z000YoookJPGo00004ooonfX6o`0001Kooo]Z1?l00005oookJPGo00004OoonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00003ooonfX5
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4
o`0000Sooo]Z1?l0000@oookJPCo00007?oonfX002Wooo]Z1Ol0000BoookJPOo00005_oonfX4o`00
00Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`00
00Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`00
00Oooo]Z1Ol0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPGo00003ooonfX4o`00
00Sooo]Z1?l0000@oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`00
00Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l0000LoookJP00:OoonfX5o`0001;o
oo]Z1ol0000FoookJPCo00001_oonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000AoookJPCo00001ooonfX5o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000So
oo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1Ol00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPGo00001ooonfX5o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001co
oo]Z000YoookJPGo00004_oonfX7o`0001Kooo]Z1?l00006oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPGo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00007?oonfX002Wooo]Z1Ol0000AoookJPWo00005OoonfX4o`0000Kooo]Z1?l0
000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0
000?oookJPCo00002OoonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0
000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l0000LoookJP00:OoonfX5o`00017ooo]Z2Ol0000E
oookJPCo00001_oonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000A
oookJPCo00002?oonfX4o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000Yoook
JPGo00004OoonfX9o`0001Cooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oook
JPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00007?oonfX002Wooo]Z1Ol0000AoookJPCo000000?ooo]Zo`000?l000000_l0000DoookJPGo
00001_oonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo
00002?oonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000YoookJPGo0000
4OoonfX4o`000003oookJ_l0003o000000;o00005?oonfX5o`0000Kooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Sooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2OoonfX5o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l0000LoookJP00:OoonfX5o`00017ooo]Z1?l000000ooonf[o0000o`00
0002o`0001Cooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX5o`0000oooo]Z1Ol00008oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oookJPCo00002?oo
nfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00007?oo
nfX002Wooo]Z1Ol0000AoookJPCo000000?ooo]Zo`000?l000000_l0000DoookJPCo00001ooonfX4
o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPGo00002?oonfX4
o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4
o`0000oooo]Z1Ol00008oookJPGo00003ooonfX4o`0001cooo]Z000YoookJPGo00004?oonfX5o`00
0003oookJ_l0003o000000;o00005?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX5o`00
00oooo]Z1?l0000LoookJP00:OoonfX5o`00013ooo]Z1Ol000000ooonf[o0000o`000002o`0001Co
oo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013o
oo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oookJPCo00007?oonfX002Wooo]Z
1Ol0000@oookJPGo000000?ooo]Zo`000?l000000ol0000CoookJPCo00001ooonfX4o`00013ooo]Z
1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z
1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z
1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z
1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00004?oonfX4o`0000;ooo]Z1Ol0
000CoookJPCo00001ooonfX4o`00013ooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000Y
oookJPGo00004?oonfX4o`0000;ooo]Z1Ol0000CoookJPCo00001ooonfX5o`0000oooo]Z1Ol00008
oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:
oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00004?oonfX4o`0000?ooo]Z1?l0000Coook
JPCo00001ooonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oook
JPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo
00004?oonfX4o`0000?ooo]Z1?l0000CoookJPCo00001ooonfX5o`0000oooo]Z1?l00009oookJPCo
00003ooonfX5o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo
00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo
00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo
00003ooonfX4o`0001cooo]Z000YoookJPGo00003ooonfX5o`0000?ooo]Z1?l0000CoookJPCo0000
2?oonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1Ol0000?oookJPCo0000
2OoonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo0000
2OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00003ooo
nfX5o`0000?ooo]Z1?l0000CoookJPCo00002?oonfX4o`0000oooo]Z1?l00009oookJPGo00003_oo
nfX4o`0000Wooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oo
nfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooo
nfX4o`0001cooo]Z000YoookJPGo00003ooonfX5o`0000?ooo]Z1Ol0000BoookJPCo00002?oonfX4
o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5
o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00003ooonfX4o`00
00Cooo]Z1Ol0000BoookJPCo00002?oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`00
01cooo]Z000YoookJPGo00003ooonfX4o`0000Cooo]Z1Ol0000BoookJPCo00002?oonfX4o`0000oo
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000ko
oo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00003ooonfX4o`0000Gooo]Z
1?l0000AoookJPGo00002?oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z
1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0001cooo]Z
000YoookJPGo00003ooonfX4o`0000Gooo]Z1?l0000AoookJPGo00002?oonfX4o`0000oooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0
0009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0
000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0
000:oookJPCo00003ooonfX4o`0001cooo]Z000YoookJPGo00003ooonfX4o`0000Gooo]Z1?l0000A
oookJPGo00002?oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?
oookJPCo00002_oonfX4o`0000kooo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX5o`0001cooo]Z000Yoook
JPGo00003ooonfX4o`0000Gooo]Z1?l0000AoookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000kooo]Z1?l00009oook
JPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX5o`0001cooo]Z000YoookJPGo00003ooonfX4o`0000Gooo]Z1?l0000AoookJPCo
00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo
00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0001cooo]Z000YoookJPGo0000
3_oonfX5o`0000Gooo]Z1?l0000AoookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1Ol0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0001gooo]Z000YoookJPGo00003_oonfX5o`0000Gooo]Z1Ol0000@oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002Ooo
nfX5o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002Ooo
nfX4o`0000kooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002Ooo
nfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000YoookJPGo00003_oonfX5
o`0000Gooo]Z1Ol0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5
o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0001gooo]Z000YoookJPGo00003_oonfX4o`0000Kooo]Z1Ol0000@oookJPCo00002OoonfX4o`00
00oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`00
00gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000YoookJPGo00003_oonfX4o`0000Oo
oo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000?oookJPCo00002OoonfX5o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001go
oo]Z000YoookJPGo00003_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z
1?l0000;oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z
1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000YoookJPGo00003_oonfX4o`0000Oooo]Z1?l0
000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPGo00003OoonfX4o`0000[ooo]Z1?l0
000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000Y
oookJPGo00003_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000;
oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000gooo]Z1?l0000;
oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0001gooo]Z000YoookJPGo00003_oonfX4o`0000Oooo]Z1?l0000@oook
JPCo00002OoonfX4o`0000kooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oook
JPCo00002_oonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oook
JPGo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000YoookJPGo
00003OoonfX5o`0000Oooo]Z1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol0000:oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000gooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo
00003_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0001gooo]Z000YoookJPGo00003OoonfX5o`0000Oooo]Z1?l0000@oookJPCo0000
2OoonfX4o`0000kooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo0000
2ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo0000
2ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPGo0000
2_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003OoonfX4o`0001gooo]Z000YoookJPGo00003Ooo
nfX5o`0000Oooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l0000;oookJPGo00003Ooo
nfX4o`0000Gooo]Z1Ol007l4o`000003oookJ_l007oo001o00?o001o2?oonfX4o`0000_ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003_oonfX4o`0000?o001o1Ooo
nfX2o`00O`Co00001?oonfX5o`00O`Cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0
000=oookJPCo00002ooonfX4o`0000gooo]Z1?l000001?oonf[o001oo`00Ool007l5oookJP;o001o
1?l00004oookJPGo001o1OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPGo00003?oonfX00ol007oo0000o`000002o`0000Co001o0ooonfX5o`00O`Gooo]Z
1Ol007l7oookJP00:OoonfX5o`0000gooo]Z1?l00008oookJPGo00003_oonfX5o`0000Wooo]Z1Ol0
000=oookJPCo00002ooonfX5o`0000gooo]Z1?l00004oookJPKo001o1?l00007o`00O`Oooo]Z1?l0
000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000kooo]Z1?l0
0003o`00O`Cooo]Z0ol007l4o`0000?ooo]Z1ol007l3oookJPCo00003?oonfX4o`0000gooo]Z1?l0
000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo000000Cooo]Zo`00Ool007oo001o
1?oonfX3o`00O`Co00000ooonfX7o`00O`Cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002_oonfX5o`0000cooo]Z00?o001oo`000?l000000_l00004o`00O`;ooo]Z
1ol007l3oookJPOo001o1_oonfX002Wooo]Z1Ol0000=oookJPCo00002?oonfX5o`0000kooo]Z1Ol0
0009oookJPGo00003OoonfX4o`0000_ooo]Z1Ol0000=oookJPCo00000ooonfX4o`00O`03oookJ_l0
07oo001o00Co00000ol007l01?oonf[o001oo`00Ool007l7oookJPCo00002ooonfX4o`0000gooo]Z
1Ol0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00000ol007l4oookJP?o001o
1?l00003oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000cooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`000004oookJ_l007oo001oo`00
O`?ooo]Z1?l007l4o`0000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4oookJPCo00002ooonfX4
o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000<oookJP03o`00Ool0003o
000000;o00001_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l6oookJP00:OoonfX5o`0000gooo]Z1?l00009oookJPCo00003_oonfX5o`0000Wooo]Z1Ol0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l00003oookJP?o001o0ooonfX00ol007oo0000o`00
0003o`000004o`00Oooonf[ooo]ZoookJP?o001o1_oonfX4o`0000_ooo]Z1?l0000=oookJPGo0000
2_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX5o`0000?o001o0ooonfX3o`00O`03oook
J_l0003o000000;o000000?o001ooookJ_l007l00_l007l3oookJP?o001o0_oonfX4o`0000cooo]Z
1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`000004oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`000003o`00Oooonf[o001o00;o
001o0ooonfX3o`00O`?ooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002ooonfX4o`0000gooo]Z1?l00005oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l5oookJP00:OoonfX5o`0000gooo]Z1?l00009oookJPCo00003_oonfX4o`0000_o
oo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l00009oookJP03o`00Ool0003o000000?o
000000Co001ooookJ_oonf[ooo]Z0ol007l6oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00000ol007l3oookJP?o001o00?ooo]Zo`00
0?l000000_l000000ol007oooo]Zo`00O`02o`00O`?ooo]Z0ol007l2oookJPCo00003?oonfX4o`00
00gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo000000Cooo]Zo`00
Ool007oo001o1ooonfX4o`000003o`00Oooonf[o001o00;o001o0ooonfX3o`00O`;ooo]Z1Ol0000;
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l00002
o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000Y
oookJPGo00003?oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<
oookJPCo00003OoonfX4o`0000Wooo]Z00?o001oo`000?l000000ol000001?l007oooo]ZoookJ_oo
nfX3o`00O`Kooo]Z1?l0000;oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooo
nfX4o`0000gooo]Z1?l000001?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`000?l00000
0_l000000ol007oooo]Zo`00O`02o`00O`?ooo]Z0ol007l2oookJPCo00003?oonfX4o`0000gooo]Z
1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo000000Cooo]Zo`00Ool007oo
001o1ooonfX4o`000003o`00Oooonf[o001o00;o001o0ooonfX3o`00O`;ooo]Z1Ol0000;oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l00003o`00O`;o
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000YoookJPGo
00003?oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000Cooo]Z0_l007l2oookJP?o001o1?l000001?l007oooo]ZoookJ_oonfX3o`00
O`Kooo]Z1?l0000;oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`00
00gooo]Z1?l000001?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`000?l000000_l00000
0ol007oooo]Zo`00O`02o`00O`?ooo]Z0ol007l2oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo000000Cooo]Zo`00Ool007oo001o1?oo
nfX2o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_l007l00_l007l3oookJP?o001o0_oo
nfX5o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX002Wooo]Z1Ol0000<oookJPGo00002OoonfX4o`0000kooo]Z1?l0000;oookJPCo00003Ooo
nfX4o`0000cooo]Z1?l0000=oookJPCo00001?oonfX7o`00O`Co000000Co001ooookJ_oonf[ooo]Z
0ol007l6oookJPCo00002ooonfX5o`0000cooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z
1?l0000=oookJPCo000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0003o000000;o
000000?o001ooookJ_l007l00_l007l3oookJP?o001o0_oonfX4o`0000cooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`000004oookJ_l007oo001oo`00
O`Cooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`0000cooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`000005oookJ_l007oo001o
o`00OooonfX00ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000Y
oookJPGo00003?oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<
oookJPCo00003?oonfX5o`0000Cooo]Z1_l007l00ooonf[o0000o`000002o`000004o`00Oooonf[o
oo]ZoookJP?o001o1_oonfX4o`0000cooo]Z1?l0000<oookJPCo00002ooonfX4o`0000kooo]Z1?l0
000;oookJPCo00003OoonfX4o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o0000
o`000002o`000003o`00Oooonf[o001o00;o001o0ooonfX3o`00O`;ooo]Z1?l0000<oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l000001?oonf[o001o
o`00Ool007l4oookJP?o001o1?l00002oookJP?o001o0ooonfX3o`00O`;ooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z00?o001oo`000?l0
00000_l000001Ooonf[o001oo`00Ool007oooo]Z00?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l5oookJP00:OoonfX5o`0000cooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol00004oookJP;o001o1OoonfX4o`00
0004o`00Oooonf[ooo]ZoookJP?o001o1_oonfX4o`0000cooo]Z1?l0000<oookJPCo00002ooonfX4
o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Co001o0ooonfX3o`00O`03oookJ_l0003o
000000;o000000?o001ooookJ_l007l00_l007l3oookJP?o001o0_oonfX4o`0000cooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Co001o1?oonfX2
o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`?ooo]Z0ol007l2oookJPCo00003?oonfX4
o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJP03o`00Ool0003o
000000;o000000Gooo]Zo`00Ool007oo001ooookJP03o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1OoonfX002Wooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPGo00001?oonfX2o`00O`Gooo]Z1?l0
0002o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l00004o`00O`Cooo]Z0ol007l4o`0000?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00001?l007l4oookJP;o001o00?ooo]Zo`000?l0
00000ol00002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`0000cooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX00ol007oo0000o`000002o`00
0004oookJ_l007oo001oo`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o1_oonfX002Wooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00001_oonfX6o`00O`Co00001_l0
07l7oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0
000=oookJPCo00001?l007l4oookJP?o001o1?l00003oookJPOo001o0ooonfX4o`0000cooo]Z1?l0
000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Co001o1Ooo
nfX2o`00O`Go00000_oonfX7o`00O`?ooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l00003o`00O`?ooo]Z1ol007l3oookJPOo001o1_oo
nfX002Wooo]Z1Ol0000<oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000cooo]Z1?l0000<oookJPCo00001_oonfX6o`00O`Co00001Ol007l8oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000;oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo000000Cooo]Z
o`00Ool007oo001o1OoonfX2o`00O`Co00001?oonfX5o`00O`Cooo]Z1?l0000<oookJPCo00003Ooo
nfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l000001?oonf[o001oo`00
Ool007l5oookJP;o001o1Ol00003oookJPGo001o1?oonfX4o`0000cooo]Z1?l0000=oookJPCo0000
2ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000;o001o1OoonfX5o`00O`Gooo]Z
1Ol007l7oookJP00:OoonfX5o`0000_ooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000cooo]Z1?l0
000<oookJPCo00002ooonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000MoookJP00:OoonfX5o`0000_ooo]Z1Ol0000:
oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX5o`0000cooo]Z1?l0000<oookJPCo00002ooonfX5o`0000gooo]Z1?l0000;
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000M
oookJP00:OoonfX5o`0000_ooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000MoookJP00:OoonfX5o`0000_ooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo
00003?oonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo
00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000MoookJP00
:OoonfX5o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo0000
3?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0000cooo]Z1Ol0000MoookJP00:OoonfX5o`0000_ooo]Z1?l0000<oookJPCo00003?oo
nfX5o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oo
nfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003Ooo
nfX4o`0000_ooo]Z1Ol0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003Ooo
nfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000MoookJP007?oonf[o
o`000?oo00008ol00003oookJP007?oonf[oo`000?oo00008ol00003oookJP007?oonf[oo`000?oo
00008ol00003oookJP007?oonf[oo`000?oo00008ol00003oookJP007?oonf[oo`000?oo00008ol0
0003oookJP00:OoonfX5o`0000Wooo]Z1Ol0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;
oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<
oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000cooo]Z1?l0000;
oookJPCo00003OoonfX5o`0000_ooo]Z1?l0000<oookJPCo00003OoonfX4o`0000cooo]Z1?l0000;
oookJPCo00003OoonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJP03o`000?oonf[ooo]Z013ooo]Z000Yoook
JPGo00002OoonfX5o`0000gooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oook
JPGo00002ooonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0001kooo]Z000YoookJPGo00002OoonfX5o`0000gooo]Z1Ol0000;oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo
00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo
00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0001kooo]Z000YoookJPGo0000
2OoonfX4o`0000kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo0000
3?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo0000
2ooonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo0000
3?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0001kooo]Z000YoookJPGo00002OoonfX4o`0000kooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPGo00003?oo
nfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oo
nfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oo
nfX4o`0000cooo]Z1?l0000<oookJPGo00002ooonfX4o`0001kooo]Z000YoookJPGo00002OoonfX4
o`0000oooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002ooonfX4
o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4
o`0000cooo]Z1Ol0000;oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4
o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4
o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000<oookJPGo00002ooonfX4
o`0001kooo]Z000YoookJPGo00002OoonfX4o`0000oooo]Z1?l0000;oookJPCo00003OoonfX4o`00
00_ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`00
00_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003OoonfX4o`00
00_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPGo00003?oonfX4o`00
00_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00_ooo]Z1Ol0000<oookJPGo00002ooonfX4o`0001kooo]Z000YoookJPKo00002?oonfX4o`0000oo
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000go
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000go
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000co
oo]Z1?l0000<oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000go
oo]Z1?l0000;oookJPGo00003?oonfX4o`0000_ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0001ko
oo]Z000YoookJPKo00002?oonfX4o`0000oooo]Z1?l0000:oookJPGo00003OoonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1Ol0000;oookJPGo00003?oonfX4o`0000_ooo]Z
1?l0000=oookJPCo00002ooonfX5o`0000gooo]Z1?l0000;oookJPGo00003?oonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z000YoookJPOo00001ooonfX4o`0000oooo]Z1?l0
000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0
000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0
000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1Ol0
000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX5o`0000gooo]Z1?l0
000;oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z000Y
oookJPOo00001_oonfX5o`0000oooo]Z1?l0000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=
oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002ooonfX4o`0000cooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=
oookJPCo00002ooonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002ooonfX4o`0001kooo]Z000YoookJPSo00001OoonfX5o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oook
JPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oook
JPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oook
JPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000kooo]Z1?l0000;oook
JPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z000YoookJPWo
00001?oonfX5o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002_oonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002ooonfX4o`0001kooo]Z000YoookJPWo00001?oonfX4o`00013ooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX5o`0000[ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000kooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z000YoookJPWo00000ooo
nfX5o`00013ooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oo
nfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000=oookJPGo00002ooo
nfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooo
nfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooo
nfX4o`0001kooo]Z000YoookJP[o00000_oonfX5o`00013ooo]Z1Ol00009oookJPCo00003_oonfX4
o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX5
o`0000[ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z000YoookJP[o00000_oonfX5o`00
013ooo]Z1Ol00009oookJPCo00003_oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPGo00002ooonfX4o`00
00gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`00
00gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`00
00kooo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`00
01kooo]Z000YoookJQ3o00004OoonfX5o`0000Wooo]Z1?l0000>oookJPGo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000ko
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000go
oo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000ko
oo]Z1?l0000;oookJPCo00007_oonfX002Wooo]Z1Ol000000ooonf[o0000o`000008o`0001;ooo]Z
1?l00009oookJPCo00003_oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z
1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z
1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z
1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001kooo]Z
000YoookJPGo000000?ooo]Zo`000?l000002?l0000BoookJPCo00002OoonfX4o`0000oooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0
000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0
000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000NoookJP00:OoonfX5o`0000;ooo]Z2?l0000C
oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>
oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000N
oookJP00:OoonfX5o`0000;ooo]Z2?l0000CoookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000NoookJP00:OoonfX5o`0000?ooo]Z1_l0000DoookJPCo
00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002ooonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000NoookJP00
:OoonfX5o`0000Cooo]Z1Ol0000DoookJPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPGo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000NoookJP00:OoonfX5o`0001gooo]Z1?l00008oookJPGo00003ooo
nfX4o`0000Wooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003_oo
nfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000;oookJPCo00003Ooo
nfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000;oookJPCo00003Ooo
nfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol0000:oookJPCo00003_oo
nfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0001kooo]Z000YoookJPGo00007OoonfX4
o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX5
o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00007_oonfX0
02Wooo]Z1Ol0000MoookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`00
00[ooo]Z1?l0000>oookJPGo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000OoookJP00:OoonfX5o`0001gooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wo
oo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003_oonfX4o`0000Wo
oo]Z1Ol0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0001oooo]Z000YoookJPGo00007OoonfX5o`0000Oooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z
1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002Wooo]Z1Ol0
000MoookJPGo00001ooonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002ooonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0
000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000OoookJP00:OoonfX5o`0001gooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002_oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000>
oookJPCo00002_oonfX4o`0001oooo]Z000YoookJPGo00007_oonfX4o`0000Oooo]Z1?l0000@oook
JPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oook
JPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002Wooo]Z1Ol0000NoookJPCo
00001ooonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPGo
00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002ooonfX4o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo
00002_oonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000OoookJP00
:OoonfX5o`0001kooo]Z1?l00007oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPGo0000
2OoonfX4o`0000kooo]Z1?l0000;oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0001oooo]Z000YoookJPGo00007_oonfX4o`0000Oooo]Z1?l0000@oookJPGo00002?oo
nfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002Ooo
nfX4o`0000oooo]Z1Ol00009oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l0000:oookJPCo00007ooonfX002Wooo]Z1Ol0000NoookJPCo00001ooonfX4
o`00013ooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l00009oookJPCo00003ooonfX5o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX5
o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4
o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000OoookJP00:OoonfX5o`00
01kooo]Z1?l00007oookJPCo00004?oonfX5o`0000Sooo]Z1?l0000?oookJPCo00002OoonfX5o`00
00oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`00
00kooo]Z1Ol00009oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
01oooo]Z000YoookJPGo00007_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`0000oo
oo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013o
oo]Z1?l00009oookJPCo00003_oonfX5o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oo
oo]Z1?l0000:oookJPCo00007ooonfX002Wooo]Z1Ol0000NoookJPCo00001ooonfX4o`00017ooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z
1?l00009oookJPCo00003ooonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z
1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4o`0000oooo]Z
1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oookJPCo00002OoonfX5o`0000kooo]Z
1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000OoookJP00:OoonfX5o`0001kooo]Z1?l0
0007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002OoonfX4o`0000oooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX5o`0000oooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0001oooo]Z000Y
oookJPGo00007_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00002?oonfX4o`0000oooo]Z1?l00009
oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00009
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009
oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00009
oookJPCo00007ooonfX002Wooo]Z1Ol0000NoookJPGo00001OoonfX5o`00017ooo]Z1?l00008oook
JPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oook
JPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oook
JPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oook
JPCo00003ooonfX5o`0000Wooo]Z1?l0000OoookJP00:OoonfX5o`0001kooo]Z1Ol00005oookJPGo
00004OoonfX4o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002OoonfX4o`0001oooo]Z000YoookJPGo0000
7_oonfX5o`0000Gooo]Z1?l0000BoookJPCo00002?oonfX4o`0000oooo]Z1Ol00008oookJPCo0000
4?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo0000
3ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo0000
3ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo0000
4?oonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo0000
7ooonfX002Wooo]Z1Ol0000OoookJPCo00001OoonfX4o`0001;ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooo
nfX5o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oo
nfX4o`0000Wooo]Z1?l0000OoookJP00:OoonfX5o`0001oooo]Z1?l00005oookJPCo00004_oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX5
o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0001oooo]Z000YoookJPGo00007ooonfX4o`00
00Gooo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00007ooonfX002Wo
oo]Z1Ol0000OoookJPCo00001OoonfX4o`0001;ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wo
oo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wo
oo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wo
oo]Z1?l0000OoookJP00:OoonfX5o`0001oooo]Z1?l00005oookJPCo00004_oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002OoonfX4o`0001oooo]Z000YoookJPGo00007ooonfX4o`0000Gooo]Z1?l0
000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Sooo]Z1?l0
000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00007ooonfX002Wooo]Z1Ol0000O
oookJPCo00001OoonfX4o`0001;ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPGo00002?oonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?
oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?
oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000O
oookJP00:OoonfX5o`0001oooo]Z1?l00005oookJPCo00004_oonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002OoonfX4o`0001oooo]Z000YoookJPGo00007ooonfX4o`0000Gooo]Z1?l0000BoookJPCo
00001ooonfX5o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000?oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Sooo]Z1?l0000@oookJPCo
00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00007ooonfX002Wooo]Z1Ol0000OoookJPCo0000
1OoonfX4o`0001;ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo0000
2?oonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000OoookJP00:Ooo
nfX5o`0001oooo]Z1?l00005oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oo
nfX4o`00017ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX5o`0001oooo]Z000YoookJPGo00007ooonfX5o`0000Cooo]Z1?l0000BoookJPCo00001ooonfX4
o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPGo00007ooonfX002Wooo]Z1Ol0000OoookJPGo00001?oonfX4o`00
01;ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00
013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`00
00oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00
00oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000PoookJP00:OoonfX5o`0001oo
oo]Z1Ol00004oookJPCo00004_oonfX5o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00017o
oo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013o
oo]Z1Ol00007oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013o
oo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00017o
oo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00023o
oo]Z000YoookJPGo00008?oonfX4o`0000?ooo]Z1Ol0000BoookJPGo00001_oonfX4o`00017ooo]Z
1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z
1?l00008oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX5o`00013ooo]Z
1?l00008oookJPCo00008?oonfX002Wooo]Z1Ol0000PoookJPCo00000ooonfX5o`0001?ooo]Z1?l0
0006oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000AoookJPCo00001ooonfX5o`00013ooo]Z1?l0
0007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00013ooo]Z1Ol0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1Ol0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l0
0007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000PoookJP00:OoonfX5o`00023ooo]Z1?l00003
oookJPGo00004ooonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007
oookJPCo00004?oonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009
oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00023ooo]Z000Yoook
JPGo00008?oonfX4o`0000?ooo]Z1?l0000DoookJPCo00001_oonfX4o`00017ooo]Z1?l00007oook
JPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oook
JPCo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oook
JPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00008oook
JPCo00008?oonfX002Wooo]Z1Ol0000PoookJPCo00000ooonfX4o`0001Cooo]Z1?l00006oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Sooo]Z1?l0000PoookJP00:OoonfX5o`00023ooo]Z1?l00003oookJPCo0000
5?oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00023ooo]Z000YoookJPGo00008?oo
nfX4o`0000?ooo]Z1?l0000DoookJPCo00001_oonfX4o`00017ooo]Z1?l00007oookJPCo00004_oo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1Ol00007oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00008?oo
nfX002Wooo]Z1Ol0000PoookJPCo00000ooonfX4o`0001Cooo]Z1?l00006oookJPCo00004OoonfX4
o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX5
o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX5o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX5o`00013ooo]Z1?l00007oookJPCo00004OoonfX4
o`0000Sooo]Z1?l0000PoookJP00:OoonfX5o`00023ooo]Z1?l00003oookJPCo00005?oonfX4o`00
00Kooo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`00
00Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`00
00Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPGo00004?oonfX4o`00
00Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00017ooo]Z1?l00007oookJPGo00004?oonfX4o`00
00Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00023ooo]Z000YoookJPGo00008?oonfX5o`0000;o
oo]Z1?l0000DoookJPCo00001_oonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Oo
oo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oo
oo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oo
oo]Z1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oo
oo]Z1Ol0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00008?oonfX002Wooo]Z
1Ol0000PoookJPGo00000_oonfX4o`0001Cooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z
1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Oooo]Z
1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPGo00004?oonfX5o`0000Kooo]Z
1Ol0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000PoookJP00:OoonfX5o`00023ooo]Z1Ol00002oookJPCo00005?oonfX4o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00002?oonfX4o`00023ooo]Z000YoookJPGo00008OoonfX4o`000003oookJ_l0003o
000000?o00005?oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00023ooo]Z000Yoook
JPGo00008OoonfX4o`000003oookJ_l0003o000000?o00005?oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000Boook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00002?oonfX4o`00023ooo]Z000YoookJPGo00008OoonfX4o`000003oookJ_l0003o000000?o
00005?oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001ooonfX4o`00023ooo]Z000CoookJP?o001o
1OoonfX5o`00O`Wooo]Z1Ol0000QoookJPCo000000?ooo]Zo`000?l000000_l0000EoookJPCo0000
1OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
1ooonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
1ooonfX5o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
1ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPGo0000
1_oonfX4o`00017ooo]Z1Ol00007oookJPCo00008?oonfX001?ooo]Z0ol007l4oookJPOo001o2?oo
nfX5o`00027ooo]Z2Ol0000EoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1Ol00006oookJPGo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oo
nfX4o`0000Oooo]Z1?l0000AoookJPGo00001_oonfX4o`00017ooo]Z1Ol00007oookJPCo00008?oo
nfX001?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00027ooo]Z2Ol0
000EoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Kooo]Z1?l0
000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0
000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00008?oonfX001?ooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000QoookJPWo00005OoonfX4o`0000Gooo]Z1?l0000C
oookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000B
oookJPCo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000B
oookJPCo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001ooonfX4o`00023ooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oook
JPOo00008?oonfX8o`0001Gooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000Boook
JPGo00001_oonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000Aoook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000Poook
JP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX5o`0002;ooo]Z1ol0000FoookJPCo
00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000AoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00008?oonfX001?ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol0000RoookJPOo00005_oonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
1_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo0000
1_oonfX5o`00023ooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00008_oo
nfX7o`0001Kooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000CoookJPCo00001_oo
nfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX5o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooo
nfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP004ooonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX5o`0002;ooo]Z1ol0000FoookJPGo00001?oonfX4
o`0001?ooo]Z1Ol00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001ooonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00008OoonfX0013ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol0000RoookJPOo00005_oonfX5o`0000Cooo]Z1?l0000CoookJPGo00001OoonfX4o`00
01?ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
027ooo]Z000@oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0000Roook
JPOo00005ooonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX5o`0001?ooo]Z1?l00005oook
JPGo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oook
JPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oook
JPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00027ooo]Z000BoookJPCo
001o1?oonfX7o`00O`Sooo]Z1Ol0000SoookJPKo00005ooonfX4o`0000Cooo]Z1?l0000DoookJPCo
00001?oonfX5o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Gooo]Z1Ol0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`00027ooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0000SoookJPGo0000
6?oonfX4o`0000?ooo]Z1Ol0000DoookJPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oookJPCo0000
4_oonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo0000
4OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00027ooo]Z000YoookJPGo00009?oo
nfX4o`0001Sooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP00:OoonfX5
o`00043ooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP00:OoonfX5o`00
043ooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX5o`00
01;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP00:OoonfX5o`00043o
oo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;o
oo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP00:OoonfX5o`00043ooo]Z
1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z
1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000QoookJP00:OoonfX5o`00043ooo]Z1?l0
0003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l0
0005oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l0
0005oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000QoookJP00:OoonfX5o`00043ooo]Z1?l00003
oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005
oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005
oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000QoookJP00:OoonfX5o`00043ooo]Z1?l00003oook
JPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00004ooonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oook
JPGo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00004ooonfX5o`0000Gooo]Z1?l0000QoookJP00:OoonfX5o`00043ooo]Z1?l00003oookJPCo
00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo
00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo
00004_oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPGo
00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo
00005?oonfX4o`0000Cooo]Z1Ol0000QoookJP00:OoonfX5o`00043ooo]Z1?l00003oookJPCo0000
5OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo0000
5?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Gooo]Z1Ol0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo0000
5?oonfX4o`0000Cooo]Z1Ol0000QoookJP00:OoonfX5o`00043ooo]Z1Ol00002oookJPCo00005Ooo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oo
nfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oo
nfX4o`0000Gooo]Z1?l0000CoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooo
nfX4o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oo
nfX4o`0000Cooo]Z1Ol0000QoookJP00:OoonfX5o`00043ooo]Z1Ol00002oookJPCo00005OoonfX4
o`0000Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4
o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Gooo]Z1?l0000CoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4
o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4
o`0000Cooo]Z1?l0000RoookJP00:OoonfX5o`00043ooo]Z1Ol00002oookJPCo00005OoonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`00
00Gooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`00
00Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000RoookJP00:OoonfX5o`00047ooo]Z1?l00002oookJPCo00005OoonfX4o`0000Co
oo]Z1?l0000DoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Go
oo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Co
oo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Co
oo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Co
oo]Z1?l0000RoookJP00:OoonfX5o`00047ooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z
1?l0000DoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Cooo]Z
1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z
1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000RoookJP00:OoonfX5o`00047ooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0
000DoookJPCo00001?oonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0
000CoookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0
000DoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000RoookJP00:OoonfX5o`00047ooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000C
oookJPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000R
oookJP00:OoonfX5o`00047ooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000Coook
JPCo00001OoonfX4o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Roook
JP00:OoonfX5o`00047ooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00003oookJPCo
00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo
00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00008_oonfX002Wooo]Z1Ol00011oookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo0000
0ooonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0002;ooo]Z000YoookJPGo0000@OoonfX4o`000003oookJ_l0003o000000?o00005_oo
nfX4o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000RoookJP00:OoonfX5o`00047ooo]Z2Ol0000GoookJPCo00000ooonfX4
o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0002;ooo]Z000YoookJPGo0000@OoonfX9o`0001Oooo]Z1?l00003oookJPCo00005OoonfX4o`00
00?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00008_oonfX002Wo
oo]Z1Ol00011oookJPWo00005ooonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Go
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Go
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Go
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Go
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000RoookJP00:OoonfX5o`0004;ooo]Z
2?l0000GoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z
1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0002;ooo]Z000YoookJPGo0000@_oonfX8o`0001Oooo]Z1?l0
0003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0004oookJPCo00008_oonfX002Wooo]Z1Ol00012oookJPSo00005ooonfX4o`0000;ooo]Z1Ol0000E
oookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPGo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000R
oookJP00:OoonfX5o`0004;ooo]Z1ol0000HoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003oook
JPCo00005OoonfX4o`0000?ooo]Z1Ol0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oook
JPCo00005OoonfX4o`0000?ooo]Z1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oook
JPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oook
JPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX5o`0002;ooo]Z000YoookJPGo
0000@_oonfX7o`0001Sooo]Z1?l00002oookJPGo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo
00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo
00000ooonfX5o`0001Cooo]Z1Ol00002oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo
00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00008_oonfX002Wooo]Z1Ol00012oookJPOo0000
6?oonfX5o`000003oookJ_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1Ol00002oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo0000
1?oonfX4o`0001Cooo]Z1Ol00002oookJPCo00008ooonfX002Wooo]Z1Ol00013oookJPKo00006?oo
nfX5o`000003oookJ_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooo
nfX4o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooo
nfX4o`0001Gooo]Z1Ol00002oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooo
nfX4o`0001Gooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooo
nfX5o`0001Cooo]Z1Ol00002oookJPCo00008ooonfX002Wooo]Z1Ol00013oookJPKo00006?oonfX5
o`000003oookJ_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4
o`0001Gooo]Z1Ol00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4
o`0001Kooo]Z1?l00002oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX4
o`0001Gooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5
o`0001Cooo]Z1Ol00002oookJPCo00008ooonfX002Wooo]Z1Ol00013oookJPKo00006OoonfX4o`00
0003oookJ_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`00
01Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`00
01Kooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`00
01Gooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`00
01Gooo]Z1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol00013oookJPGo00006_oonfX4o`000003
oookJ_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Ko
oo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Go
oo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Ko
oo]Z1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol00014oookJPCo00006_oonfX4o`000003oook
J_l0003o000000;o00005_oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z
1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z
1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z
1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol0001RoookJPCo000000?ooo]Zo`000?l000000_l0
000FoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000SoookJP00:OoonfX5o`0006;ooo]Z2Ol0000FoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002
oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000SoookJP00:OoonfX5o`0006;ooo]Z2Ol0000Foook
JPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Soook
JP00:OoonfX5o`0006;ooo]Z2Ol0000FoookJPGo000000?ooo]Zo`000?l000000ol0000FoookJPCo
00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo
00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000FoookJPCo
00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPGo
00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol0001RoookJPSo0000
6?oonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo0000
0_oonfX4o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo0000
0_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo0000
0_oonfX5o`0001Gooo]Z1?l00002oookJPGo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo0000
0_oonfX4o`0002?ooo]Z000YoookJPGo0000H_oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`00
0003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oo
nfX5o`0001Gooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000ooo
nfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oo
nfX5o`0001Gooo]Z1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000SoookJP00:OoonfX5
o`0006;ooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4
o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000ooonfX4
o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4
o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000GoookJPCo00000_oonfX4
o`0001Kooo]Z1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol0001RoookJPSo00006?oonfX4o`00
0003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
02?ooo]Z000YoookJPGo0000H_oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oo
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Ko
oo]Z1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oo
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000SoookJP00:OoonfX5o`0006;ooo]Z
2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol0001RoookJPSo00006?oonfX4o`000003oookJ_l0
003o000000;o00005ooonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPGo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005_oonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0002?ooo]Z000YoookJPGo0000HooonfX7o`0001Sooo]Z1?l00000
0ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000F
oookJPCo00000_oonfX4o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000F
oookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000SoookJP00:OoonfX5o`0006?ooo]Z1ol0000Hoook
JPWo00005ooonfX:o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol000000ooo
nf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Goook
JPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooo
nf[o0000o`000002o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooo
nf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo00008ooonfX002Wooo]Z1Ol0001SoookJPKo
00006OoonfX9o`0001Oooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l000000ol0000GoookJPCo
000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo
00005ooonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo
000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo
000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0002?ooo]Z000YoookJPGo0000
HooonfX6o`0001Wooo]Z2Ol0000GoookJPWo00005ooonfX4o`000003oookJ_l0003o000000?o0000
5ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo0000
0_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l000000ooonf[o0000
o`000003o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000
o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0002?ooo]Z000YoookJPGo0000HooonfX6o`0001Wooo]Z2?l0000IoookJPSo00005ooo
nfX9o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`00
0003o`0001Kooo]Z1?l00002oookJPCo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`000003oookJ_l0003o000000?o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX5o`000003oookJ_l0003o000000;o00008ooonfX002Wooo]Z1Ol0001ToookJPGo00006OoonfX8
o`0001Wooo]Z2?l0000GoookJPWo00006?oonfX4o`000003oookJ_l0003o000000;o00005ooonfX4
o`000003oookJ_l0003o000000?o00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX4
o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000?o00005ooonfX4
o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4
o`000003oookJ_l0003o000000;o00005ooonfX:o`0002?ooo]Z000YoookJPGo0000I?oonfX4o`00
01_ooo]Z1ol0000IoookJPSo00005ooonfX9o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`00
01Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`00
01Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`00
01Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`00
01Oooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z2Ol0000SoookJP00:OoonfX5o`0008?o
oo]Z1ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oo
oo]Z2Ol0000GoookJP[o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003
oookJ_l0003o000000;o00006?oonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003
oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX9o`0002?o
oo]Z000YoookJPGo0000PooonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX4o`000003oook
J_l0003o000000;o00005ooonfX9o`0001Sooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000HoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000HoookJPSo00009?oonfX002Wooo]Z1Ol00023oookJPOo00006OoonfX8o`0001Sooo]Z2?l0
000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPWo00006?oonfX9o`0001Oooo]Z1?l0
00000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z2Ol0
000GoookJPWo00005ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX8o`0002Cooo]Z000Y
oookJPGo0000PooonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX4o`000003oookJ_l0003o
000000;o00006?oonfX8o`0001Sooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000G
oookJPWo00006?oonfX9o`0001Oooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l000000_l0000H
oookJPSo00009?oonfX002Wooo]Z1Ol00023oookJPOo00006OoonfX8o`0001Sooo]Z2?l0000Hoook
JPCo000000?ooo]Zo`000?l000000_l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2Ol0000Goook
JPWo00006?oonfX9o`0001Oooo]Z2Ol0000GoookJPCo000000?ooo]Zo`000?l000000_l0000Hoook
JPSo00009?oonfX002Wooo]Z1Ol00024oookJPKo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPWo
00006?oonfX8o`0001Sooo]Z2?l0000HoookJPWo00005ooonfX9o`0001Sooo]Z2?l0000HoookJPSo
00006?oonfX4o`000003oookJ_l0003o000000;o00006?oonfX8o`0002Cooo]Z000YoookJPGo0000
Q?oonfX6o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX9o`0001Sooo]Z2?l0000HoookJPSo0000
6?oonfX9o`0001Sooo]Z2?l0000HoookJPSo00006OoonfX7o`0001Sooo]Z2Ol0000HoookJPSo0000
9?oonfX002Wooo]Z1Ol00024oookJPGo00006_oonfX7o`0001[ooo]Z1ol0000HoookJPWo00006?oo
nfX8o`0001Sooo]Z2?l0000HoookJPSo00006OoonfX8o`0001Sooo]Z2?l0000IoookJPOo00006?oo
nfX9o`0001Sooo]Z2?l0000ToookJP00:OoonfX5o`0008Cooo]Z1Ol0000JoookJPOo00006_oonfX7
o`0001Wooo]Z1ol0000IoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000IoookJPSo00006?oonfX8
o`0001Wooo]Z1ol0000HoookJPWo00006?oonfX8o`0002Cooo]Z000YoookJPGo0000XooonfX7o`00
01[ooo]Z1ol0000IoookJPOo00006OoonfX7o`0001Wooo]Z2?l0000HoookJPSo00006OoonfX7o`00
01Wooo]Z2?l0000IoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000ToookJP00:OoonfX5o`000:Co
oo]Z1_l0000JoookJPKo00006_oonfX7o`0001Wooo]Z1ol0000IoookJPSo00006OoonfX7o`0001Wo
oo]Z1ol0000IoookJPSo00006OoonfX7o`0001Wooo]Z2?l0000HoookJPSo00009?oonfX002Wooo]Z
1Ol0002ToookJPKo00006_oonfX6o`0001[ooo]Z1ol0000IoookJPOo00006OoonfX7o`0001[ooo]Z
1ol0000IoookJPOo00006OoonfX8o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0002Cooo]Z
000YoookJPGo0000Y?oonfX5o`0001_ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001[ooo]Z1_l0
000JoookJPOo00006OoonfX7o`0001[ooo]Z1_l0000JoookJPOo00006OoonfX8o`0001Sooo]Z2?l0
000ToookJP003ooonfX9o`00O`?ooo]Z1Ol007l9oookJPGo0000Y?oonfX5o`0001_ooo]Z1_l0000J
oookJPOo00006OoonfX7o`0001[ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001[ooo]Z1_l0000J
oookJPOo00006OoonfX7o`0001Wooo]Z2?l0000ToookJP003ooonfX9o`00O`;ooo]Z1ol007l8oook
JPGo0000a?oonfX6o`0001[ooo]Z1_l0000JoookJPOo00006_oonfX6o`0001[ooo]Z1ol0000Ioook
JPOo00006_oonfX6o`0001[ooo]Z1ol0000JoookJPKo00006OoonfX8o`0002Cooo]Z000?oookJPCo
001o1ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00034oookJPKo00006_oonfX6o`00
01_ooo]Z1_l0000JoookJPKo00006ooonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX7o`00
01[ooo]Z1_l0000JoookJPKo00009OoonfX0013ooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1Ol00035oookJPCo00007?oonfX5o`0001_ooo]Z1_l0000JoookJPKo00006ooonfX6o`0001[o
oo]Z1_l0000JoookJPKo00006_oonfX6o`0001_ooo]Z1_l0000JoookJPKo00009OoonfX0017ooo]Z
1Ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0003SoookJPGo00006ooonfX5o`0001cooo]Z
1Ol0000KoookJPGo00006ooonfX6o`0001[ooo]Z1_l0000JoookJPKo00006ooonfX5o`0001_ooo]Z
1_l0000UoookJP004ooonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]Z1ooo
nfX4o`0001cooo]Z1Ol0000KoookJPGo00006ooonfX5o`0001_ooo]Z1_l0000KoookJPGo00006ooo
nfX5o`0001cooo]Z1?l0000VoookJP005?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX5
o`000?oooo]Z9ooonfX4o`0001cooo]Z1?l0000LoookJPGo00007?oonfX4o`0001cooo]Z1?l0000M
oookJPCo00007?oonfX4o`0002Kooo]Z000EoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z5?oonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z5?oonfX000oooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z5?oonfX0
00oooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003o
oookJ_oooo]Z5?oonfX0013ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oooo]ZoooonfXDoook
JP004OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000oooonf[ooookJQCooo]Z000YoookJPGo0000
oooonf[ooookJQCooo]Z000YoookJPGo0000oooonf[ooookJQCooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-16.9899, -22.3262, \
0.388873, 0.125803}},
  CellTags->"mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],\


Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:23:harmonic_oscillator__example__forced_damped_resonance"]
}, Open  ]],

Cell["Overdamped Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1, 10, 1/2, 1/2]], {t, 0, 200}]\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.101018 0.447418 [
[.2619 .08852 -12 -20 ]
[.2619 .08852 12 0 ]
[.5 .08852 -17 -20 ]
[.5 .08852 17 0 ]
[.7381 .08852 -17 -20 ]
[.7381 .08852 17 0 ]
[.97619 .08852 -17 -20 ]
[.97619 .08852 17 0 ]
[.01131 .01153 -41.9375 -10 ]
[.01131 .01153 0 10 ]
[.01131 .1905 -29 -10 ]
[.01131 .1905 0 10 ]
[.01131 .27999 -29 -10 ]
[.01131 .27999 0 10 ]
[.01131 .36947 -29 -10 ]
[.01131 .36947 0 10 ]
[.01131 .45895 -29 -10 ]
[.01131 .45895 0 10 ]
[.01131 .54844 -14 -10 ]
[.01131 .54844 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .10102 m
.2619 .10727 L
s
gsave
.2619 .08852 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .10102 m
.5 .10727 L
s
gsave
.5 .08852 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .10102 m
.7381 .10727 L
s
gsave
.7381 .08852 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .10102 m
.97619 .10727 L
s
gsave
.97619 .08852 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .10102 m
.07143 .10477 L
s
.11905 .10102 m
.11905 .10477 L
s
.16667 .10102 m
.16667 .10477 L
s
.21429 .10102 m
.21429 .10477 L
s
.30952 .10102 m
.30952 .10477 L
s
.35714 .10102 m
.35714 .10477 L
s
.40476 .10102 m
.40476 .10477 L
s
.45238 .10102 m
.45238 .10477 L
s
.54762 .10102 m
.54762 .10477 L
s
.59524 .10102 m
.59524 .10477 L
s
.64286 .10102 m
.64286 .10477 L
s
.69048 .10102 m
.69048 .10477 L
s
.78571 .10102 m
.78571 .10477 L
s
.83333 .10102 m
.83333 .10477 L
s
.88095 .10102 m
.88095 .10477 L
s
.92857 .10102 m
.92857 .10477 L
s
.01 w
0 .10102 m
1 .10102 L
s
.25 Mabswid
.02381 .01153 m
.03006 .01153 L
s
gsave
.01131 .01153 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .1905 m
.03006 .1905 L
s
gsave
.01131 .1905 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .27999 m
.03006 .27999 L
s
gsave
.01131 .27999 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36947 m
.03006 .36947 L
s
gsave
.01131 .36947 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .45895 m
.03006 .45895 L
s
gsave
.01131 .45895 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .54844 m
.03006 .54844 L
s
gsave
.01131 .54844 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03391 m
.02756 .03391 L
s
.02381 .05628 m
.02756 .05628 L
s
.02381 .07865 m
.02756 .07865 L
s
.02381 .12339 m
.02756 .12339 L
s
.02381 .14576 m
.02756 .14576 L
s
.02381 .16813 m
.02756 .16813 L
s
.02381 .21287 m
.02756 .21287 L
s
.02381 .23524 m
.02756 .23524 L
s
.02381 .25761 m
.02756 .25761 L
s
.02381 .30236 m
.02756 .30236 L
s
.02381 .32473 m
.02756 .32473 L
s
.02381 .3471 m
.02756 .3471 L
s
.02381 .39184 m
.02756 .39184 L
s
.02381 .41421 m
.02756 .41421 L
s
.02381 .43658 m
.02756 .43658 L
s
.02381 .48132 m
.02756 .48132 L
s
.02381 .50369 m
.02756 .50369 L
s
.02381 .52606 m
.02756 .52606 L
s
.02381 .57081 m
.02756 .57081 L
s
.02381 .59318 m
.02756 .59318 L
s
.02381 .61555 m
.02756 .61555 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .54844 m
.02846 .57629 L
.03068 .5884 L
.03178 .59325 L
.03279 .59697 L
.03398 .60032 L
.03527 .60259 L
.03637 .60332 L
.03754 .60285 L
.03878 .6009 L
.03995 .59769 L
.04124 .59265 L
.04262 .58549 L
.04516 .56799 L
.04793 .54335 L
.05297 .489 L
.05785 .43472 L
.06244 .39243 L
.06511 .37508 L
.06584 .37144 L
.06661 .36814 L
.06728 .36576 L
.06799 .36369 L
.06923 .36131 L
.07039 .36046 L
.0711 .36059 L
.07177 .36116 L
.07302 .36335 L
.07367 .36504 L
.07438 .36732 L
.07583 .3732 L
.07842 .38744 L
.08429 .43005 L
.08933 .46581 L
.09071 .4737 L
.09216 .48064 L
.0934 .48532 L
.0941 .48739 L
.09476 .48896 L
.09605 .49089 L
.09722 .49129 L
.09848 .49024 L
.09919 .48896 L
.09985 .48735 L
.10094 .48372 L
.10215 .47842 L
.10458 .46376 L
.10707 .44391 L
.10979 .41799 L
.11474 .36518 L
Mistroke
.11961 .31614 L
.12174 .29856 L
.12403 .28338 L
.12544 .2763 L
.12673 .27145 L
.12797 .26834 L
.12928 .2667 L
.12994 .26652 L
.13066 .26681 L
.13194 .26856 L
.13273 .2704 L
.13347 .27265 L
.13487 .27813 L
.13737 .29167 L
.13969 .30753 L
.14492 .34915 L
.14957 .3834 L
.15084 .39098 L
.15218 .39775 L
.15334 .40249 L
.15457 .40631 L
.15575 .40867 L
.15681 .40969 L
.15789 .40961 L
.1589 .4085 L
.16008 .40594 L
.16117 .40239 L
.16236 .39722 L
.16362 .39037 L
.16607 .37335 L
.1687 .35061 L
.17345 .30269 L
.17905 .24722 L
.18151 .22735 L
.18282 .21856 L
.18424 .21069 L
.18556 .20493 L
.18678 .20112 L
.18794 .19881 L
.18916 .19783 L
.19046 .19839 L
.19166 .20038 L
.19298 .20411 L
.19372 .20687 L
.1944 .20979 L
.19712 .22509 L
.20008 .24668 L
.20545 .29151 L
.20808 .31216 L
.21053 .32862 L
Mistroke
.21187 .33597 L
.21309 .34149 L
.21445 .34614 L
.2152 .348 L
.21591 .34929 L
.21707 .35035 L
.21831 .35003 L
.21947 .34837 L
.22053 .34571 L
.22178 .34121 L
.22312 .33475 L
.22557 .31917 L
.23589 .22196 L
.23848 .19779 L
.24093 .17806 L
.24313 .16396 L
.24437 .15779 L
.24552 .15332 L
.24664 .15018 L
.24787 .14813 L
.24916 .1476 L
.25037 .14859 L
.25168 .15124 L
.25287 .15505 L
.25419 .16066 L
.25557 .16807 L
.26083 .20683 L
.26659 .25621 L
.26913 .27553 L
.27047 .28431 L
.27188 .29227 L
.27312 .29796 L
.27378 .30046 L
.27448 .30272 L
.27572 .30558 L
.27688 .30694 L
.27807 .30698 L
.27938 .30541 L
.28061 .3024 L
.28176 .29833 L
.28392 .28743 L
.28622 .27173 L
.29153 .22409 L
.29714 .16946 L
.29945 .14967 L
.30193 .13213 L
.30335 .12419 L
.30464 .11848 L
.30594 .1143 L
.30717 .11185 L
Mistroke
.30842 .11089 L
.30905 .11098 L
.30974 .11154 L
.31097 .11367 L
.31212 .11695 L
.31347 .12233 L
.31471 .12858 L
.31749 .1467 L
.32282 .19129 L
.32564 .21608 L
.32864 .24015 L
.33009 .25015 L
.33145 .25831 L
.33278 .26489 L
.334 .26963 L
.33517 .2729 L
.3364 .27497 L
.33763 .27558 L
.33833 .27526 L
.33899 .27452 L
.34026 .27189 L
.34147 .26796 L
.34255 .26329 L
.34373 .25704 L
.34638 .23913 L
.34883 .21865 L
.3578 .13377 L
.36026 .11431 L
.3616 .10538 L
.36285 .09832 L
.36401 .09296 L
.36506 .08914 L
.36623 .08612 L
.36748 .08437 L
.36814 .08407 L
.36884 .08422 L
.3701 .0857 L
.3708 .08718 L
.37146 .08899 L
.37294 .09454 L
.37424 .10094 L
.37543 .10793 L
.3781 .12706 L
.38293 .1689 L
.38808 .21301 L
.39075 .23138 L
.39205 .23859 L
.39326 .244 L
.39435 .24783 L
.39551 .25068 L
Mistroke
.39667 .25226 L
.39794 .25247 L
.39914 .25122 L
.40023 .24886 L
.40149 .24474 L
.40268 .23951 L
.40479 .22727 L
.40709 .2103 L
.41695 .11902 L
.41966 .09709 L
.42107 .08738 L
.42257 .07881 L
.42388 .07282 L
.42457 .07028 L
.42531 .06806 L
.42662 .06544 L
.42783 .0645 L
.42848 .06459 L
.42916 .06513 L
.43039 .06726 L
.43108 .06907 L
.43172 .07115 L
.43317 .07724 L
.4356 .09124 L
.43821 .11061 L
.44272 .15028 L
.44763 .19312 L
.45056 .21382 L
.45185 .22108 L
.45327 .22754 L
.45391 .22987 L
.45461 .23197 L
.45586 .23463 L
.45656 .23545 L
.4573 .23579 L
.45862 .23507 L
.45982 .23294 L
.4611 .22915 L
.46231 .22418 L
.46341 .21855 L
.4661 .2008 L
.46865 .17987 L
.47366 .13278 L
.47835 .09088 L
.48071 .07387 L
.48192 .06666 L
.48324 .06017 L
.48399 .05718 L
.48468 .05487 L
.4854 .05295 L
Mistroke
.48606 .05164 L
.4873 .05029 L
.48799 .05021 L
.48863 .05054 L
.4897 .052 L
.49087 .05487 L
.4921 .05923 L
.49324 .06449 L
.49529 .07652 L
.49749 .09255 L
.50707 .177 L
.50964 .1962 L
.51104 .20494 L
.51236 .21177 L
.51348 .21642 L
.51468 .22018 L
.51534 .22164 L
.51602 .22273 L
.51725 .22355 L
.51794 .22336 L
.51857 .22277 L
.5193 .22161 L
.51999 .22004 L
.52121 .21615 L
.52254 .2104 L
.52554 .19202 L
.52832 .16983 L
.53333 .12314 L
.53609 .09756 L
.53871 .07584 L
.54115 .05936 L
.54243 .05245 L
.5438 .04665 L
.54506 .04281 L
.54621 .04065 L
.54736 .03977 L
.54844 .04013 L
.54953 .04166 L
.55073 .04465 L
.55198 .04919 L
.55314 .05466 L
.55523 .06714 L
.55746 .08371 L
.56721 .17 L
.56987 .18952 L
.57127 .19791 L
.57276 .20511 L
.57406 .20981 L
.5748 .2118 L
.57549 .21319 L
Mistroke
.57671 .2145 L
.57801 .21429 L
.57927 .21251 L
.57998 .21082 L
.58065 .20882 L
.58186 .20411 L
.58315 .19768 L
.58561 .1818 L
.58785 .16403 L
.5972 .07862 L
.59947 .06121 L
.60191 .04642 L
.60331 .04012 L
.60458 .03591 L
.60586 .03323 L
.60708 .03216 L
.60839 .03265 L
.60905 .03353 L
.60977 .03499 L
.61106 .0388 L
.61227 .04374 L
.61499 .05925 L
.61792 .08152 L
.62308 .12818 L
.62789 .16979 L
.63027 .18628 L
.63251 .19806 L
.63375 .20273 L
.63445 .20474 L
.6351 .20619 L
.63624 .20776 L
.63745 .20803 L
.63869 .20681 L
.63939 .20547 L
.64002 .20384 L
.64126 .19959 L
.64243 .19429 L
.64505 .17841 L
.64791 .15595 L
.65362 .10324 L
.65641 .07802 L
.65898 .05773 L
.66133 .04292 L
.66251 .0371 L
.6638 .03211 L
.6651 .02867 L
.66583 .02745 L
.66649 .02679 L
.66779 .02675 L
.66901 .02823 L
Mistroke
.67014 .03088 L
.67139 .03519 L
.67269 .04116 L
.67391 .04803 L
.67844 .08212 L
.6838 .13113 L
.6887 .17199 L
.69105 .18682 L
.69238 .19332 L
.69362 .19798 L
.69494 .20137 L
.69613 .20302 L
.69679 .20333 L
.6975 .20319 L
.6988 .20164 L
.70011 .19843 L
.70086 .19588 L
.70155 .19304 L
.70446 .1768 L
.70698 .15796 L
.70968 .13431 L
.7146 .08834 L
.71729 .0651 L
.71983 .04667 L
.72127 .03815 L
.72284 .03087 L
.72353 .02834 L
.72426 .02615 L
.72556 .0235 L
.72688 .02251 L
.7281 .02311 L
.7288 .02412 L
.72944 .02546 L
.73018 .02748 L
.73088 .02986 L
.73331 .04149 L
.73589 .05878 L
.74052 .09841 L
.74598 .14825 L
.74837 .16716 L
.74964 .1758 L
.75099 .18374 L
.7523 .19008 L
.75349 .19452 L
.75468 .19768 L
.75581 .19939 L
.75696 .19986 L
.75801 .19915 L
.75917 .19711 L
.76039 .19357 L
Mistroke
.7616 .18874 L
.76289 .18217 L
.76522 .16707 L
.77052 .12184 L
.77543 .07629 L
.77785 .05637 L
.78009 .04095 L
.78211 .03021 L
.78314 .02612 L
.78427 .02271 L
.7854 .02053 L
.78661 .01956 L
.78776 .01999 L
.78882 .02152 L
.79009 .0248 L
.7913 .02929 L
.79355 .04103 L
.79598 .05788 L
.79862 .07982 L
.80296 .1199 L
.80774 .16097 L
.80904 .17028 L
.81044 .17899 L
.81165 .18529 L
.81297 .19073 L
.81374 .19319 L
.81445 .19497 L
.81513 .19621 L
.81586 .19703 L
.81658 .19734 L
.81725 .19717 L
.8185 .19565 L
.81972 .19275 L
.82099 .1882 L
.82208 .18317 L
.82328 .17653 L
.82843 .13706 L
.83325 .09232 L
.83579 .06954 L
.83848 .04831 L
.84083 .03354 L
.84216 .02709 L
.84342 .02245 L
.84456 .0195 L
.84561 .0179 L
.84677 .01739 L
.84798 .01826 L
.84929 .02083 L
.85003 .02298 L
.85069 .02536 L
Mistroke
.85321 .03786 L
.85616 .05843 L
.85893 .08205 L
.86369 .12609 L
.8662 .14815 L
.86891 .16855 L
.87026 .17697 L
.87154 .18364 L
.87269 .18843 L
.87394 .19229 L
.87513 .19457 L
.87639 .19549 L
.87746 .19504 L
.87865 .19322 L
.8793 .19166 L
.87998 .18957 L
.88121 .18479 L
.88252 .17818 L
.88396 .16938 L
.88896 .1292 L
.89351 .08673 L
.89591 .06547 L
.89845 .04572 L
.90067 .0319 L
.90193 .02577 L
.90312 .0213 L
.9042 .01833 L
.90519 .01661 L
.90633 .01581 L
.90742 .01624 L
.90865 .01814 L
.90996 .02175 L
.9112 .02662 L
.91232 .03218 L
.91508 .04993 L
.91768 .07087 L
.92221 .1125 L
.927 .15445 L
.9295 .17202 L
.93083 .17953 L
.93224 .18597 L
.93355 .19031 L
.93474 .19287 L
.93593 .19406 L
.93707 .19389 L
.93838 .19212 L
.93904 .19059 L
.93977 .18842 L
.94106 .18339 L
.94228 .17735 L
Mistroke
.945 .15964 L
.94794 .13557 L
.95508 .07001 L
.95855 .04272 L
.96007 .03318 L
.96171 .02487 L
.9626 .02132 L
.96343 .0187 L
.96422 .01679 L
.96505 .01542 L
.96593 .01472 L
.96675 .01475 L
.96766 .01555 L
.96863 .01729 L
.9696 .01994 L
.97065 .02382 L
.97258 .03337 L
.97619 .05866 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000A
oookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00
Ool007l00_l007l<oookJPGo0000oooonf[ooookJPoooo]Z0003oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo001o2ooonfX5o`000?oooo]ZoooonfX?oookJP000ooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o2?oonfX5o`00O`Wooo]Z1_l0003ooookJ_?ooo]Z1?l0000FoookJP003ooo
nfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oooo]Ze?oonfX5o`0001[ooo]Z1_l0
000EoookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z]?oonfX5
o`0001[ooo]Z1_l0000JoookJPKo00005OoonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1Ol0003ooookJY?ooo]Z1_l0000JoookJPOo00006OoonfX6o`0001[ooo]Z1ol0000Doook
JP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJWCo
oo]Z1?l0000KoookJPKo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPSo00005?oonfX000oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfYcoookJPKo0000
6_oonfX6o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX9o`0001?ooo]Z000@oookJP?o001o00Co
oo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000oooonfYcoookJPOo0000
6?oonfX8o`0001Sooo]Z2?l0000HoookJPWo00005ooonfX9o`0001?ooo]Z000@oookJPOo001o2?oo
nfX7o`00O`Sooo]Z1Ol0003ooookJUCooo]Z1Ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0
000HoookJPWo00005ooonfX9o`0001?ooo]Z000AoookJPGo001o2_oonfX5o`00O`Wooo]Z1Ol0003o
oookJU?ooo]Z1_l0000IoookJPSo00006?oonfX9o`0001Oooo]Z2?l0000GoookJP[o00005ooonfX4
o`000003oookJ_l0003o000000?o00004_oonfX002kooo]Z1Ol0003ooookJU?ooo]Z1ol0000Hoook
JPSo00006?oonfX9o`0001Kooo]Z2_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000Foook
JPGo000000?ooo]Zo`000?l000000ol0000BoookJP00;_oonfX5o`000?oooo]Z<ooonfX6o`0001Wo
oo]Z2?l0000HoookJPSo00006?oonfX9o`0001Kooo]Z2_l0000FoookJPGo000000?ooo]Zo`000?l0
00000_l0000FoookJPGo000000?ooo]Zo`000?l000000ol0000BoookJP00;_oonfX5o`000?oooo]Z
<ooonfX7o`0001Sooo]Z2?l0000HoookJPWo00005ooonfX4o`000003oookJ_l0003o000000;o0000
5_oonfX:o`0001Kooo]Z1?l00002oookJPCo00005_oonfX5o`0000;ooo]Z1?l0000BoookJP00;_oo
nfX5o`000?oooo]Z<ooonfX7o`0001Sooo]Z2?l0000GoookJP[o00005_oonfX5o`000003oookJ_l0
003o000000?o00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0003oookJPCo00004_oonfX002kooo]Z1Ol0003ooookJS?ooo]Z1ol0000HoookJPWo00005_oonfX:
o`0001Kooo]Z1Ol000000ooonf[o0000o`000003o`0001Gooo]Z1?l00002oookJPGo00005OoonfX4
o`0000;ooo]Z1Ol0000DoookJPGo00000ooonfX4o`0001;ooo]Z000^oookJPGo0000oooonfXDoook
JPGo00006OoonfX8o`0001Oooo]Z2_l0000FoookJPGo000000?ooo]Zo`000?l000000ol0000Eoook
JPGo000000?ooo]Zo`000?l000000ol0000EoookJPCo00000_oonfX5o`0001Cooo]Z1Ol00002oook
JPGo00005?oonfX5o`0000?ooo]Z1?l0000BoookJP00;_oonfX5o`000?oooo]Z4ooonfX6o`0001Wo
oo]Z2Ol0000FoookJP[o00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000ooonfX4o`0001Co
oo]Z1Ol00003oookJPCo00005?oonfX5o`0000;ooo]Z1Ol0000DoookJPGo00000ooonfX4o`0001;o
oo]Z000^oookJPGo0000oooonfXCoookJPOo00005ooonfX:o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0001Gooo]Z1Ol00002oookJPGo00005OoonfX4o`0000?ooo]Z1?l0000DoookJPGo0000
0ooonfX4o`0001Cooo]Z1Ol00003oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000BoookJP00;_oo
nfX5o`000?oooo]Z4_oonfX8o`0001Oooo]Z2_l0000FoookJPCo00000_oonfX5o`0001Cooo]Z1Ol0
0003oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000BoookJP00;_oonfX5o`000?oooo]Z4_oonfX9
o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z1?l00002oookJPGo00005?oonfX5
o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`00017ooo]Z000^oookJPGo0000looonfX5o`00
01Wooo]Z2Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPGo00000ooonfX5o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`00
00Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`00017ooo]Z000^oookJPGo0000l_oonfX6o`0001Wo
oo]Z2Ol0000FoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00003oookJPCo00005?oonfX4o`0000Co
oo]Z1Ol0000CoookJPCo00001?oonfX5o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`0000Co
oo]Z1Ol0000BoookJPGo00001?oonfX5o`00017ooo]Z000^oookJPGo0000l_oonfX6o`0001Wooo]Z
1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l00002oookJPGo00005?oonfX5o`0000?ooo]Z
1?l0000DoookJPCo00001?oonfX5o`0001;ooo]Z1Ol00004oookJPGo00004ooonfX4o`0000Cooo]Z
1Ol0000CoookJPCo00001OoonfX4o`0001;ooo]Z1Ol00005oookJPCo00004OoonfX002kooo]Z1Ol0
003boookJPOo00006?oonfX4o`000003oookJ_l0003o000000;o00005OoonfX5o`0000;ooo]Z1Ol0
000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l00004oookJPGo00004_oonfX5o`0000Gooo]Z1?l0
000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0
000AoookJP00;_oonfX5o`000?7ooo]Z2?l0000GoookJPGo000000?ooo]Zo`000?l000000_l0000E
oookJPGo00000_oonfX5o`0001Cooo]Z1?l00004oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000B
oookJPGo00001OoonfX4o`0001;ooo]Z1Ol00005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000B
oookJPCo00001_oonfX4o`00017ooo]Z000^oookJPGo0000lOoonfX9o`0001Kooo]Z1Ol000000ooo
nf[o0000o`000002o`0001Gooo]Z1Ol00003oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000Boook
JPGo00001OoonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000Boook
JPGo00001OoonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX002kooo]Z1Ol0003aoookJPWo
00005_oonfX5o`000003oookJ_l0003o000000;o00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo
00001?oonfX5o`0001;ooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1Ol00005oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000AoookJP00
;_oonfX5o`000?7ooo]Z2Ol0000FoookJPCo00000_oonfX5o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000Gooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00017ooo]Z1?l00006oookJPCo0000
4OoonfX002kooo]Z1Ol0001doookJPGo001o1OoonfX5o`00Oe3ooo]Z1Ol0000HoookJPGo000000?o
oo]Zo`000?l000000_l00004o`00O`Gooo]Z1Ol007l8oookJPCo00000_oonfX5o`0001Cooo]Z1?l0
0004oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000BoookJPCo000000?o001ooookJ_oonfX00ooo
nfX4o`000003o`00Oooonf[ooo]Z00?ooo]Z1Ol007l7oookJPCo00001_oonfX5o`00017ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000>oookJP;o001o1Ol00002o`00O`?ooo]Z00?o
001oo`000?l000000_l00005oookJPGo001o1ooonfX002kooo]Z1Ol0001coookJPOo001o0ooonfX7
o`00Odoooo]Z1_l0000GoookJPGo000000?ooo]Zo`000?l000000_l00005o`00O`?ooo]Z1ol007l7
oookJPCo00000_oonfX5o`0001Cooo]Z1?l00004oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000B
oookJPCo000000?o001ooookJ_oonfX00_oonfX00ol007oo0000o`000002o`0000;o001o0ooonfX7
o`00O`Gooo]Z1Ol00006oookJPGo00004?oonfX5o`0000Kooo]Z1Ol0000AoookJPCo00001ooonfX4
o`0000kooo]Z0_l007l5o`0000;o001o0_oonfX7o`00O`?ooo]Z1ol007l6oookJP00;_oonfX5o`00
07;ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001oC_oo
nfX7o`0001Oooo]Z1Ol000000ooonf[o0000o`000002o`000003o`00Oooonf[o001o00;o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z1Ol00003oookJPCo00005?oonfX4o`0000Cooo]Z
1Ol0000BoookJPGo00001OoonfX4o`0001;ooo]Z1?l000001?l007oooo]ZoookJ_oonfX2o`00O`Co
00000_l007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1OoonfX5o`0000Kooo]Z1Ol0000@oook
JPGo00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00003_oonfX2o`00O`Go00001?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP00;_oonfX5
o`0007;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Odcooo]Z2?l0
000GoookJPCo00000_oonfX4o`0000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX5o`0000?ooo]Z1?l0000CoookJPGo00001?oonfX5o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`000004o`00Oooonf[ooo]ZoookJP;o001o1Ol00002o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l4oookJPGo00001ooonfX4o`00013ooo]Z1Ol00006oookJPGo00004OoonfX4o`00
00Oooo]Z1?l0000?oookJP03o`00Ool0003o000000;o00001?oonfX3o`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0001hoookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00Odcooo]Z2?l0000FoookJPGo00000_oonfX5o`0000;ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX5o`0000?ooo]Z1Ol0000BoookJPGo00001Ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`000003o`00Oooonf[ooo]Z00?ooo]Z1Ol0
0002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo000000Co001ooookJ_oonf[o
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo
0000N?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m<oookJPSo00005_oonfX5o`00
00;ooo]Z1Ol00002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z1?l00004
oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000AoookJPGo00001_oonfX5o`00017ooo]Z1?l00000
0ol007oooo]ZoookJP03oookJPGo00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o1?oo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004?oo
nfX4o`0000;o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX002kooo]Z1Ol0001coookJP;o001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007m;oookJP[o00005OoonfX5o`0000;ooo]Z1Ol00002oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z1?l00004oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo
00001_oonfX5o`00017ooo]Z1?l000000ol007oooo]ZoookJP02oookJP;o001o1?l00002o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oook
JPCo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00000_l007l2oookJP?o001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0007?ooo]Z1ol007l2oook
JP?o001o0ooonfX3o`00Od_ooo]Z2_l0000EoookJPCo000000Co001ooookJ_oonf[ooo]Z1?l00002
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z1?l00005oookJPCo00004_oo
nfX4o`0000Kooo]Z1Ol0000@oookJPGo00001_oonfX5o`00013ooo]Z1Ol000000ol007oooo]Zoook
JP02oookJP;o001o1?l000000ol007oooo]ZoookJP03o`00O`?ooo]Z0ol007l4oookJPCo00002?oo
nfX5o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00000ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Go
oo]Z000^oookJPGo0000LooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001oBooonfX:o`0001Gooo]Z
1?l000001?l007oooo]ZoookJ_oonfX4o`0000;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1OoonfX4o`0000Gooo]Z1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z1?l00008oook
JPCo00004?oonfX5o`000003o`00Oooonf[ooo]Z00;ooo]Z0_l007l4o`0000?ooo]Z0ol007l3oook
JP?o001o1?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oook
JPGo00003OoonfX00ol007oo0000o`000003o`0000?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0007?ooo]Z0_l007l7
oookJP?o001o0ooonfX3o`00Od_ooo]Z1?l00002oookJPCo00005?oonfX00ol007oo0000o`000002
o`000004o`00Oooonf[ooo]ZoookJPCo00000_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l5oookJPCo00001OoonfX5o`00017ooo]Z1?l00006oookJPGo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPGo000000?o001ooookJ_oonfX00_oonfX2o`00O`Co00000ooonfX3o`00O`?ooo]Z
0ol007l4oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Sooo]Z
1Ol0000=oookJP03o`00Ool0003o000000?o00000ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo0000LooonfX2o`00O`So
oo]Z0ol007l01?oonf[o001oo`00Ool007l_oookJPGo00006?oonfX4o`0000;ooo]Z1?l0000Doook
JPGo000000Co001ooookJ_oonf[ooo]Z1?l000001?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o1OoonfX5o`0000Gooo]Z1Ol0000AoookJPCo00001ooonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000;o001o1?oonfX2o`00O`Co00001?oonfX3o`00O`04oook
J_l007oo001oo`00O`Gooo]Z1?l00009oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPGo
00002?oonfX5o`0000gooo]Z00?o001oo`000?l000000ol00003o`00O`;ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX002kooo]Z1Ol0001doook
JPOo001o0_oonfX7o`00Obkooo]Z1_l0000HoookJPCo00000_oonfX5o`0001?ooo]Z1Ol000001?l0
07oooo]ZoookJ_oonfX5o`0000?o001o0ooonfX7o`00O`Gooo]Z1Ol00005oookJPGo00004OoonfX4
o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00002o`00O`Gooo]Z00?o001o
o`000?l000000_l00002o`00O`;ooo]Z1ol007l4oookJPGo00002OoonfX4o`0000kooo]Z1Ol00009
oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo00000ol007l3oookJPOo001o0ooonfX7
o`00O`Kooo]Z000^oookJPGo0000M?oonfX7o`00O`?ooo]Z1Ol007l_oookJPOo00005ooonfX4o`00
00;ooo]Z1Ol0000CoookJPGo000000Co001ooookJ_oonf[ooo]Z1Ol00002o`00O`Gooo]Z1Ol007l6
oookJPGo00001_oonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPCo00000_l007l5oookJP03o`00Ool0003o000000;o00000_l007l3oookJPGo001o1OoonfX5
o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4
o`0000;o001o1OoonfX5o`00O`Gooo]Z1Ol007l7oookJP00;_oonfX5o`000;;ooo]Z1ol0000Goook
JPCo00000_oonfX5o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Oooo]Z1?l0000@oook
JPGo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000?oook
JPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oook
JPCo00007OoonfX002kooo]Z1Ol0002boookJPOo00005ooonfX4o`0000?ooo]Z1?l0000CoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004?oonfX5o`0000Oooo]Z1Ol0000?oookJPCo
00002?oonfX5o`0000oooo]Z1?l00008oookJPGo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000^oookJPGo0000
/OoonfX9o`0001Gooo]Z1Ol00003oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo0000
1ooonfX4o`00013ooo]Z1Ol00007oookJPGo00003_oonfX5o`0000Sooo]Z1Ol0000?oookJPCo0000
2?oonfX5o`0000kooo]Z1?l0000:oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo0000
2_oonfX5o`0000gooo]Z1?l0000MoookJP00;_oonfX5o`000;7ooo]Z2Ol0000EoookJPGo00000ooo
nfX4o`0001?ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Oooo]Z1Ol0000?oookJPCo00002?oo
nfX5o`0000kooo]Z1Ol00008oookJPGo00003ooonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002_oo
nfX5o`0000gooo]Z1?l0000:oookJPGo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo00007Ooo
nfX002kooo]Z1Ol0002`oookJP[o00005OoonfX5o`0000?ooo]Z1Ol0000BoookJPCo00001_oonfX4
o`00017ooo]Z1Ol00007oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4
o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX5
o`0000gooo]Z1?l0000:oookJPGo00003?oonfX5o`0001gooo]Z000QoookJ_oo0000ool0000No`00
00?ooo]Z000QoookJ_oo0000ool0000No`0000?ooo]Z000QoookJ_oo0000ool0000No`0000?ooo]Z
000QoookJ_oo0000ool0000No`0000?ooo]Z000QoookJ_oo0000ool0000No`0000?ooo]Z000^oook
JPGo0000O?oonfX00ol0003ooo]ZoookJP0aoookJPCo00000ooonfX4o`0001?ooo]Z1Ol00005oook
JPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol00009oook
JPGo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002_oonfX5o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000;oook
JP03o`000?oonf[ooo]Z013ooo]Z000^oookJPGo0000O?oonfX00ol0003ooo]ZoookJP0aoookJPCo
00000ooonfX4o`0001?ooo]Z1?l00006oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002OoonfX4o`0000kooo]Z1Ol00009oookJPGo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002_oonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo
00003?oonfX5o`0000_ooo]Z1?l0000;oookJP03o`000?oonf[ooo]Z013ooo]Z000^oookJPGo0000
TooonfX5o`0001Oooo]Z1Ol00003oookJPCo00004ooonfX4o`0000Oooo]Z1?l0000@oookJPCo0000
2?oonfX4o`0000oooo]Z1Ol00009oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo0000
2_oonfX5o`0000gooo]Z1?l0000:oookJPGo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPGo00002ooonfX4o`0001kooo]Z000^oookJPGo0000T_oo
nfX7o`0001Kooo]Z1Ol00003oookJPGo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002?oo
nfX4o`0000oooo]Z1Ol00009oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX4o`0000cooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003?oo
nfX4o`0000cooo]Z1?l0000=oookJPCo00002_oonfX5o`0001kooo]Z000^oookJPGo0000T_oonfX7
o`0001Kooo]Z1Ol00003oookJPGo00004OoonfX5o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX5
o`0000kooo]Z1Ol00009oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX4
o`0000cooo]Z1Ol0000;oookJPCo00002ooonfX5o`0000cooo]Z1Ol0000;oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000=oookJPCo00002_oonfX5o`0001kooo]Z000^oookJPGo0000TOoonfX8o`00
01Kooo]Z1?l00004oookJPGo00004OoonfX5o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX5o`00
00kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX4o`00
00cooo]Z1Ol0000;oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oookJPGo00003?oonfX5o`00
00_ooo]Z1?l0000=oookJPCo00002_oonfX5o`0001kooo]Z000^oookJPGo0000TOoonfX8o`0001Ko
oo]Z1?l00005oookJPCo00004OoonfX5o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX5o`0000ko
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX4o`0000co
oo]Z1?l0000<oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oookJPGo00003?oonfX5o`0000[o
oo]Z1Ol0000=oookJPCo00002_oonfX4o`0001oooo]Z000^oookJPGo0000TOoonfX9o`0001Gooo]Z
1?l00005oookJPCo00004OoonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000kooo]Z
1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPGo00003?oonfX5o`0000[ooo]Z
1Ol0000=oookJPCo00002_oonfX4o`0001oooo]Z000^oookJPGo0000TOoonfX9o`0001Gooo]Z1?l0
0005oookJPGo00004?oonfX4o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l0
000;oookJPCo00003?oonfX5o`0000_ooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0
000=oookJPCo00002_oonfX4o`0001oooo]Z000^oookJPGo0000TOoonfX9o`0001Cooo]Z1Ol00005
oookJPGo00004?oonfX4o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l0000;
oookJPCo00003?oonfX5o`0000_ooo]Z1Ol0000;oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000<
oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPGo00002OoonfX4o`0001oooo]Z000^oookJPGo0000TOoonfX4o`000003oookJ_l0003o0000
00?o00004ooonfX5o`0000Gooo]Z1Ol0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol00009oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX5o`0000_ooo]Z1?l0000<oook
JPGo00002ooonfX4o`0000cooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00007ooonfX002kooo]Z1Ol0002AoookJPCo
000000?ooo]Zo`000?l000000ol0000CoookJPGo00001_oonfX4o`00013ooo]Z1?l00009oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX5o`0000_ooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000cooo]Z1Ol0000:oookJPGo00003?oonfX5o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000OoookJP00
;_oonfX5o`00093ooo]Z1Ol000000ooonf[o0000o`000003o`0001?ooo]Z1?l00007oookJPCo0000
3ooonfX5o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000;oookJPGo0000
2ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo0000
2_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo0000
2?oonfX5o`0001oooo]Z000^oookJPGo0000T?oonfX5o`0000;ooo]Z1?l0000CoookJPCo00001ooo
nfX4o`0000oooo]Z1Ol00009oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000<oookJPGo00002ooo
nfX5o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX5o`0000gooo]Z1?l0000:oookJPGo00003Ooo
nfX4o`0000[ooo]Z1?l0000>oookJPGo00002?oonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooo
nfX4o`0000Sooo]Z1Ol0000OoookJP00;_oonfX5o`00093ooo]Z1Ol00002oookJPCo00004ooonfX4
o`0000Oooo]Z1?l0000?oookJPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPGo00003?oonfX5
o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002_oonfX4
o`0000kooo]Z1?l00009oookJPGo00003_oonfX5o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4
o`0000oooo]Z1?l00008oookJPGo00007ooonfX002kooo]Z1Ol0002@oookJPCo00000ooonfX4o`00
01?ooo]Z1?l00007oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`00
00cooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000gooo]Z1?l0000:oookJPGo00003OoonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000oooo]Z1?l00008oookJPGo00003_oonfX5o`00
00Wooo]Z1?l0000?oookJPCo00002?oonfX4o`00023ooo]Z000^oookJPGo0000T?oonfX4o`0000?o
oo]Z1?l0000CoookJPCo00001ooonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_o
oo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000?oookJPCo00002?oonfX4o`0000oo
oo]Z1Ol00008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000PoookJP00;_oonfX5o`00093ooo]Z
1?l00003oookJPGo00004_oonfX4o`0000Oooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000;oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPGo00003OoonfX5o`0000Wooo]Z
1?l0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0
002?oookJPGo00000ooonfX5o`0001;ooo]Z1?l00007oookJPGo00003_oonfX4o`0000[ooo]Z1Ol0
000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000=oookJPCo00002_oonfX5o`0000gooo]Z1Ol0
0009oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPGo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00023ooo]Z000^
oookJPGo0000SooonfX5o`0000?ooo]Z1Ol0000AoookJPGo00001ooonfX5o`0000kooo]Z1?l0000:
oookJPGo00003?oonfX5o`0000_ooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=
oookJPGo00002OoonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX5o`0000Sooo]Z1?l0000@
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000P
oookJP00;_oonfX5o`0008oooo]Z1Ol00004oookJPCo00004OoonfX5o`0000Sooo]Z1?l0000>oook
JPCo00002_oonfX5o`0000cooo]Z1Ol0000;oookJPGo00002ooonfX4o`0000gooo]Z1Ol00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1Ol00008oook
JPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00013ooo]Z1Ol00007oook
JPCo00008?oonfX002kooo]Z1Ol0001doookJPCo00005ooonfX4o`0000Gooo]Z1?l0000AoookJPGo
00002?oonfX4o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000:oookJPGo
00003OoonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPGo
00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo
00004?oonfX5o`0000Oooo]Z1?l0000PoookJP00;_oonfX5o`0007?ooo]Z1Ol0000GoookJPCo0000
1OoonfX4o`00017ooo]Z1?l00009oookJPCo00003OoonfX5o`0000_ooo]Z1?l0000<oookJPCo0000
3OoonfX4o`0000[ooo]Z1Ol0000=oookJPGo00002OoonfX4o`0000oooo]Z1?l00008oookJPGo0000
3ooonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo0000
4?oonfX5o`0000Oooo]Z1?l0000@oookJPGo00001_oonfX5o`00023ooo]Z000^oookJPGo0000L_oo
nfX7o`0001Kooo]Z1?l00005oookJPCo00004OoonfX4o`0000Wooo]Z1?l0000=oookJPGo00002ooo
nfX4o`0000cooo]Z1?l0000=oookJPCo00002_oonfX5o`0000kooo]Z1?l00009oookJPCo00003ooo
nfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00004?oo
nfX5o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX5o`00017ooo]Z1?l00006oookJPGo00008?oo
nfX002kooo]Z1Ol0001boookJPOo00005_oonfX4o`0000Gooo]Z1?l0000AoookJPCo00002OoonfX4
o`0000gooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX5o`0000oooo]Z1Ol00007oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPGo00001_oonfX5o`00017ooo]Z1?l00006oookJPGo00004OoonfX4
o`0000Kooo]Z1Ol0000PoookJP00;_oonfX5o`0007;ooo]Z2?l0000EoookJPCo00001OoonfX4o`00
017ooo]Z1?l00009oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`00
00[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPCo00004?oonfX5o`00
00Oooo]Z1?l0000@oookJPGo00001ooonfX4o`00013ooo]Z1Ol00006oookJPCo00004_oonfX4o`00
00Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`00027ooo]Z000^oookJPGo0000LOoonfX9o`0001Co
oo]Z1Ol00005oookJPGo00004?oonfX4o`0000Wooo]Z1?l0000=oookJPCo00003?oonfX4o`0000co
oo]Z1?l0000=oookJPCo00002_oonfX4o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000So
oo]Z1?l0000@oookJPGo00001ooonfX4o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z
1Ol0001aoookJPWo00005?oonfX5o`0000Gooo]Z1Ol0000@oookJPCo00002OoonfX4o`0000gooo]Z
1?l0000<oookJPCo00002ooonfX5o`0000gooo]Z1Ol00009oookJPCo00003ooonfX4o`0000Sooo]Z
1Ol0000?oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX5o`0000Kooo]Z
1Ol0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000QoookJP00;_oonfX5o`00077ooo]Z2Ol0000DoookJPGo00001OoonfX5o`0000oooo]Z1Ol0
0009oookJPGo00003?oonfX4o`0000cooo]Z1Ol0000:oookJPGo00003OoonfX5o`0000Wooo]Z1?l0
000?oookJPCo00002?oonfX5o`0000oooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00001_oonfX5o`00017ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z1?l0
000BoookJPGo00001OoonfX4o`00027ooo]Z000^oookJPGo0000L?oonfX5o`000003oookJ_l0003o
000000;o00005?oonfX4o`0000Oooo]Z1?l0000?oookJPGo00002OoonfX5o`0000cooo]Z1?l0000<
oookJPGo00002_oonfX5o`0000gooo]Z1Ol00009oookJPCo00003ooonfX5o`0000Oooo]Z1?l0000@
oookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000A
oookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000Q
oookJP00;_oonfX5o`00073ooo]Z1Ol000000ooonf[o0000o`000002o`0001Cooo]Z1?l00007oook
JPCo00003ooonfX5o`0000Wooo]Z1Ol0000<oookJPCo00003?oonfX5o`0000[ooo]Z1?l0000?oook
JPCo00002?oonfX5o`0000oooo]Z1Ol00007oookJPCo00004?oonfX5o`0000Kooo]Z1Ol0000Aoook
JPCo00001_oonfX5o`00017ooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPGo00001?oonfX5o`0001;ooo]Z1Ol00005oookJPCo00008OoonfX002kooo]Z1Ol0001`oookJPGo
000000?ooo]Zo`000?l000000ol0000BoookJPGo00001ooonfX4o`0000oooo]Z1?l0000;oookJPCo
00002ooonfX5o`0000gooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0000?oookJPGo
00001ooonfX4o`00017ooo]Z1?l00006oookJPGo00004OoonfX5o`0000Gooo]Z1Ol0000AoookJPGo
00001OoonfX4o`0001;ooo]Z1Ol00005oookJPCo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo
00001?oonfX5o`00027ooo]Z000^oookJPGo0000L?oonfX4o`0000;ooo]Z1Ol0000BoookJPGo0000
1ooonfX4o`0000oooo]Z1?l0000;oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oookJPCo0000
3ooonfX4o`0000Sooo]Z1Ol0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00006oookJPGo0000
4OoonfX5o`0000Gooo]Z1Ol0000AoookJPGo00001OoonfX4o`0001;ooo]Z1Ol00005oookJPCo0000
4ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`00027ooo]Z000^oookJPGo0000L?oo
nfX4o`0000;ooo]Z1Ol0000BoookJPGo00001ooonfX4o`0000oooo]Z1?l0000;oookJPCo00002ooo
nfX5o`0000gooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooo
nfX4o`00017ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001;ooo]Z1Ol00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooo
nfX5o`00027ooo]Z000^oookJPGo0000L?oonfX4o`0000?ooo]Z1?l0000BoookJPCo00002?oonfX5
o`0000kooo]Z1?l0000;oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX5
o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00006oookJPCo00004ooonfX4
o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4
o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0002;ooo]Z000^oookJPGo0000KooonfX5o`00
00?ooo]Z1?l0000BoookJPCo00002?oonfX5o`0000kooo]Z1?l0000;oookJPCo00002ooonfX4o`00
00kooo]Z1Ol00009oookJPCo00003ooonfX5o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00
017ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`00
01?ooo]Z1?l00004oookJPGo00004ooonfX5o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX4o`00
02;ooo]Z000^oookJPGo0000KooonfX5o`0000?ooo]Z1Ol0000AoookJPCo00002?oonfX5o`0000ko
oo]Z1?l0000;oookJPCo00002ooonfX4o`0000kooo]Z1Ol00008oookJPGo00003ooonfX5o`0000Oo
oo]Z1?l0000AoookJPCo00001_oonfX5o`00017ooo]Z1?l00005oookJPGo00004ooonfX4o`0000Co
oo]Z1Ol0000CoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00003oookJPCo00005?oonfX5o`0000;o
oo]Z1Ol0000EoookJPCo00000_oonfX5o`0002;ooo]Z000^oookJPGo0000KooonfX5o`0000?ooo]Z
1Ol0000AoookJPCo00002OoonfX4o`0000gooo]Z1Ol0000;oookJPCo00002ooonfX4o`0000kooo]Z
1Ol00008oookJPGo00004?oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX5o`00017ooo]Z
1?l00005oookJPGo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`0001?ooo]Z
1Ol00003oookJPCo00005?oonfX5o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX5o`0002;ooo]Z
000^oookJPGo0000KooonfX4o`0000Cooo]Z1Ol0000AoookJPCo00002OoonfX4o`0000gooo]Z1Ol0
000;oookJPGo00002_oonfX4o`0000oooo]Z1?l00008oookJPGo00004?oonfX4o`0000Kooo]Z1Ol0
000AoookJPCo00001_oonfX5o`00017ooo]Z1Ol00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000;ooo]Z1Ol0
000EoookJPCo00000_oonfX5o`0002;ooo]Z000^oookJPGo0000KooonfX4o`0000Gooo]Z1?l0000@
oookJPGo00002OoonfX4o`0000gooo]Z1Ol0000;oookJPGo00002_oonfX4o`0000oooo]Z1?l00008
oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000AoookJPGo00001OoonfX4o`0001;ooo]Z1Ol00004
oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000DoookJPGo00000_oonfX5o`0001Gooo]Z1?l00002
oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0002?ooo]Z000^oook
JPGo0000KooonfX4o`0000Gooo]Z1?l0000@oookJPGo00002OoonfX4o`0000gooo]Z1?l0000<oook
JPGo00002_oonfX4o`0000oooo]Z1?l00008oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000Boook
JPGo00001OoonfX4o`0001;ooo]Z1Ol00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000Doook
JPGo00000_oonfX5o`0001Gooo]Z1?l00002oookJPGo00005OoonfX5o`000003oookJ_l0003o0000
00;o00005_oonfX4o`0000;ooo]Z1?l0000SoookJP004OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o
001oo`00O`07o`00O`Oooo]Z1Ol0001_oookJPCo00001OoonfX4o`00013ooo]Z1Ol00009oookJPCo
00003OoonfX4o`0000gooo]Z1?l00009oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000AoookJPCo
00001_oonfX4o`0001;ooo]Z1Ol00005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPGo
00000ooonfX4o`0001Cooo]Z1Ol00002oookJPGo00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPGo
000000?ooo]Zo`000?l000000_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000SoookJP00
4?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0001_oookJPCo0000
1OoonfX4o`00013ooo]Z1?l0000:oookJPGo00003?oonfX4o`0000gooo]Z1?l00009oookJPGo0000
3ooonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPCo0000
4ooonfX4o`0000Cooo]Z1?l0000EoookJPCo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo0000
5_oonfX4o`000003oookJ_l0003o000000?o00005_oonfX5o`000003oookJ_l0003o000000;o0000
5_oonfX:o`0002?ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oook
J_l007oo001o00;o001o3?oonfX5o`0006oooo]Z1?l00005oookJPGo00003ooonfX4o`0000[ooo]Z
1Ol0000<oookJPCo00003OoonfX4o`0000Wooo]Z1Ol0000?oookJPGo00001ooonfX4o`00017ooo]Z
1Ol00004oookJPGo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00000ooonfX5o`0001Gooo]Z
1?l00002oookJPGo00005OoonfX5o`000003oookJ_l0003o000000;o00005_oonfX:o`0001Oooo]Z
2Ol0000FoookJP[o00008ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX4o`00O`_ooo]Z1Ol0
001^oookJPGo00001OoonfX5o`0000oooo]Z1?l0000:oookJPGo00003?oonfX4o`0000gooo]Z1?l0
0009oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000AoookJPGo00001?oonfX5o`0001?ooo]Z1?l0
0004oookJPGo00004ooonfX5o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX5o`0001Gooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Kooo]Z2_l0000GoookJPWo00005ooonfX9o`0002?ooo]Z000?
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oookJPKo0000KOoonfX5o`0000Gooo]Z1Ol0000?
oookJPCo00002ooonfX4o`0000cooo]Z1?l0000=oookJPGo00002?oonfX4o`00013ooo]Z1Ol00006
oookJPGo00004OoonfX5o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00002
oookJPGo00005OoonfX5o`000003oookJ_l0003o000000;o00005_oonfX:o`0001Kooo]Z2Ol0000H
oookJPWo00005ooonfX8o`0002Cooo]Z000?oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oook
JPGo0000K_oonfX5o`0000Kooo]Z1?l0000?oookJPCo00002ooonfX4o`0000_ooo]Z1Ol0000=oook
JPGo00002?oonfX4o`00017ooo]Z1?l00006oookJPGo00004_oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1Ol00002oookJPCo00005_oonfX5o`000003oookJ_l0003o0000
00;o00005ooonfX9o`0001Oooo]Z2?l0000HoookJPSo00006?oonfX8o`0002Cooo]Z000?oookJP?o
001o0ooonfX3o`00O`_ooo]Z0ol007l8oookJPGo0000K_oonfX4o`0000Oooo]Z1?l0000?oookJPCo
00002ooonfX4o`0000_ooo]Z1Ol0000=oookJPGo00002?oonfX4o`00017ooo]Z1?l00006oookJPGo
00004_oonfX4o`0000Cooo]Z1?l0000DoookJPGo00000_oonfX5o`0001Gooo]Z1Ol000000ooonf[o
0000o`000002o`0001Kooo]Z2_l0000GoookJPWo00005ooonfX8o`0001Sooo]Z2?l0000IoookJPOo
00009?oonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0001DoookJPCo0000
5_oonfX4o`0000Oooo]Z1?l0000>oookJPGo00002ooonfX4o`0000_ooo]Z1Ol0000>oookJPCo0000
2?oonfX4o`00017ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPGo0000
0_oonfX5o`0001Gooo]Z2_l0000GoookJPWo00005ooonfX8o`0001Sooo]Z2?l0000IoookJPOo0000
6OoonfX6o`0002Gooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0005?ooo]Z1Ol0000FoookJPCo00001ooonfX4o`0000kooo]Z1Ol0000;oookJPGo00002_oo
nfX4o`0000oooo]Z1?l00008oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000CoookJPCo00001?oo
nfX4o`0001Cooo]Z1Ol00002oookJPGo00005OoonfX:o`0001Oooo]Z2Ol0000GoookJPSo00006Ooo
nfX7o`0001Wooo]Z1_l0000KoookJPGo00009OoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l7oookJPGo0000D_oonfX7o`0001Gooo]Z1?l00007oookJPGo00003OoonfX5
o`0000_ooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX4
o`0001?ooo]Z1Ol00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000GoookJPWo00005ooonfX8
o`0001Sooo]Z2?l0000IoookJPKo00006ooonfX5o`0004Gooo]Z000@oookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000D_oonfX7o`0001Gooo]Z1?l00007
oookJPGo00003OoonfX4o`0000cooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1Ol0000A
oookJPCo00001_oonfX4o`0001?ooo]Z1Ol00002oookJPGo00005OoonfX5o`000003oookJ_l0003o
000000;o00005ooonfX8o`0001Sooo]Z2?l0000IoookJPKo00006ooonfX4o`0006Kooo]Z000@oook
JPOo001o2?oonfX7o`00O`Sooo]Z1Ol0001BoookJPSo00005?oonfX4o`0000Oooo]Z1Ol0000=oook
JPCo00003OoonfX4o`0000[ooo]Z1?l0000?oookJPCo00001ooonfX5o`00017ooo]Z1Ol00005oook
JPCo00004ooonfX5o`0000;ooo]Z1Ol0000EoookJPGo000000?ooo]Zo`000?l000000_l0000Goook
JPSo00006?oonfX8o`0001[ooo]Z1Ol00025oookJP004OoonfX5o`00O`[ooo]Z1Ol007l9oookJPGo
0000D_oonfX8o`0001Cooo]Z1?l00008oookJPCo00003OoonfX4o`0000gooo]Z1?l0000:oookJPCo
00003ooonfX5o`0000Kooo]Z1Ol0000AoookJPGo00001?oonfX5o`0001Cooo]Z1?l00002oookJPGo
00005OoonfX5o`000003oookJ_l0003o000000;o00005ooonfX8o`0001Wooo]Z1_l0002UoookJP00
;_oonfX5o`00057ooo]Z2Ol0000DoookJPCo00002?oonfX4o`0000gooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000oooo]Z1Ol00006oookJPCo00004_oonfX5o`0000Cooo]Z1Ol0000DoookJPCo0000
0_oonfX4o`0001Oooo]Z2Ol0000GoookJPSo00006_oonfX4o`000:Kooo]Z000^oookJPGo0000DOoo
nfX9o`0001?ooo]Z1Ol00008oookJPCo00003OoonfX4o`0000gooo]Z1?l00009oookJPGo00003ooo
nfX5o`0000Kooo]Z1?l0000CoookJPCo00001?oonfX5o`0001Cooo]Z1?l00002oookJPCo00005ooo
nfX9o`0001Sooo]Z1_l00035oookJP00;_oonfX5o`00057ooo]Z2Ol0000CoookJPGo00002?oonfX4
o`0000gooo]Z1?l0000=oookJPGo00002?oonfX5o`00013ooo]Z1?l00006oookJPCo00004ooonfX4
o`0000Cooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Oooo]Z2Ol0000HoookJPKo0000aOoonfX0
02kooo]Z1Ol0001AoookJPCo000000?ooo]Zo`000?l000000_l0000CoookJPGo00002?oonfX4o`00
00gooo]Z1?l0000=oookJPGo00002?oonfX5o`00013ooo]Z1?l00006oookJPCo00004ooonfX4o`00
00Cooo]Z1?l0000EoookJPCo000000?ooo]Zo`000?l000000ol0000GoookJPSo00006_oonfX4o`00
0<Kooo]Z000^oookJPGo0000D?oonfX5o`000003oookJ_l0003o000000?o00004_oonfX4o`0000Wo
oo]Z1Ol0000;oookJPGo00003OoonfX5o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX4o`0001?o
oo]Z1?l00003oookJPGo00005OoonfX:o`0001Oooo]Z2?l0003ToookJP00;_oonfX5o`00053ooo]Z
1Ol000000ooonf[o0000o`000003o`0001;ooo]Z1?l00009oookJPGo00002ooonfX5o`0000kooo]Z
1?l00008oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000CoookJPCo00000ooonfX5o`0001Gooo]Z
2_l0000HoookJPKo0000iOoonfX002kooo]Z1Ol0001@oookJPGo000000?ooo]Zo`000?l000000ol0
000BoookJPCo00002OoonfX5o`0000_ooo]Z1Ol0000>oookJPCo00002?oonfX4o`00017ooo]Z1?l0
0005oookJPGo00004ooonfX5o`0000;ooo]Z1Ol0000EoookJPWo00006_oonfX5o`000>Gooo]Z000^
oookJPGo0000D?oonfX4o`0000?ooo]Z1?l0000BoookJPCo00002_oonfX4o`0000_ooo]Z1?l0000?
oookJPCo00002?oonfX4o`00017ooo]Z1?l00005oookJPGo00004ooonfX5o`0000;ooo]Z1?l0000G
oookJPSo0000oooonfX5oookJP00;_oonfX5o`0004oooo]Z1Ol00003oookJPGo00004OoonfX4o`00
00[ooo]Z1?l0000;oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000AoookJPGo00001?oonfX5o`00
01?ooo]Z1Ol00002oookJPCo00005ooonfX8o`000?oooo]Z1OoonfX002kooo]Z1Ol0001?oookJPGo
00000ooonfX5o`00017ooo]Z1?l0000:oookJPCo00002ooonfX4o`0000oooo]Z1?l00008oookJPCo
00004OoonfX5o`0000Cooo]Z1?l0000EoookJPGo000000?ooo]Zo`000?l000000_l0000HoookJPOo
0000oooonfX5oookJP00;_oonfX5o`0004oooo]Z1Ol00003oookJPGo00004OoonfX4o`0000[ooo]Z
1?l0000;oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000AoookJPGo00001?oonfX4o`0001Gooo]Z
2_l0000HoookJPKo0000oooonfX6oookJP00;_oonfX5o`0004oooo]Z1?l00005oookJPCo00004Ooo
nfX4o`0000[ooo]Z1?l0000;oookJPCo00003ooonfX5o`0000Kooo]Z1Ol0000BoookJPCo00001?oo
nfX4o`0001Gooo]Z2_l0000IoookJPCo0000oooonfX7oookJP00;_oonfX5o`0004oooo]Z1?l00005
oookJPCo00004?oonfX5o`0000[ooo]Z1?l0000;oookJPCo00003ooonfX5o`0000Kooo]Z1Ol0000B
oookJPCo00001?oonfX4o`0001Kooo]Z2Ol0003ooookJRCooo]Z000^oookJPGo0000CooonfX4o`00
00Gooo]Z1?l0000@oookJPGo00002_oonfX5o`0000Wooo]Z1Ol0000?oookJPGo00001_oonfX5o`00
01;ooo]Z1?l00004oookJPCo00005_oonfX8o`000?oooo]Z9OoonfX002kooo]Z1Ol0001?oookJPCo
00001OoonfX4o`00013ooo]Z1Ol0000:oookJPGo00002OoonfX5o`00013ooo]Z1?l00006oookJPCo
00004ooonfX4o`0000?ooo]Z1Ol0000FoookJPSo0000oooonfXUoookJP00;_oonfX5o`0004oooo]Z
1?l00005oookJPGo00003ooonfX4o`0000_ooo]Z1Ol00009oookJPGo00004?oonfX4o`0000Kooo]Z
1?l0000CoookJPGo00000_oonfX5o`0001Oooo]Z1ol0003ooookJRGooo]Z000^oookJPGo0000C_oo
nfX5o`0000Gooo]Z1Ol0000?oookJPCo00003?oonfX4o`0000Wooo]Z1?l0000AoookJPCo00001_oo
nfX4o`0001?ooo]Z1Ol00002oookJPGo00005ooonfX6o`000?oooo]Z9_oonfX002kooo]Z1Ol0001>
oookJPGo00001OoonfX5o`0000oooo]Z1?l0000<oookJPCo00002OoonfX4o`00017ooo]Z1?l00006
oookJPCo00004ooonfX5o`0000;ooo]Z1?l0000HoookJPKo0000oooonfXVoookJP00;_oonfX5o`00
04kooo]Z1Ol00006oookJPCo00003ooonfX4o`0000cooo]Z1?l00009oookJPCo00004OoonfX4o`00
00Kooo]Z1?l0000DoookJP[o0000oooonfY4oookJP00;_oonfX5o`0004kooo]Z1?l00007oookJPCo
00003ooonfX4o`0000cooo]Z1?l00009oookJPCo00004OoonfX4o`0000Gooo]Z1Ol0000DoookJP[o
0000oooonfY4oookJP00;_oonfX5o`0004kooo]Z1?l00007oookJPCo00003ooonfX4o`0000cooo]Z
1?l00009oookJPCo00004OoonfX5o`0000Cooo]Z1Ol0000DoookJP[o0000oooonfY4oookJP00;_oo
nfX5o`0004kooo]Z1?l00007oookJPCo00003_oonfX5o`0000cooo]Z1?l00009oookJPCo00004Ooo
nfX5o`0000Cooo]Z1Ol0000EoookJPSo0000oooonfY5oookJP00;_oonfX5o`0004kooo]Z1?l00007
oookJPCo00003_oonfX5o`0000cooo]Z1Ol00007oookJPGo00004OoonfX5o`0000Cooo]Z1?l0000F
oookJPSo0000oooonfY5oookJP00;_oonfX5o`0004kooo]Z1?l00007oookJPCo00003_oonfX5o`00
00cooo]Z1Ol00007oookJPGo00004_oonfX4o`0000Cooo]Z1?l0000FoookJPSo0000oooonfY5oook
JP00;_oonfX5o`0004kooo]Z1?l00007oookJPCo00003_oonfX4o`0000gooo]Z1Ol00007oookJPGo
00004_oonfX4o`0000?ooo]Z1Ol0000FoookJPOo0000oooonfY6oookJP00;_oonfX5o`0004kooo]Z
1?l00007oookJPGo00003OoonfX4o`0000kooo]Z1?l00007oookJPCo00004ooonfX5o`0000;ooo]Z
1Ol0000GoookJPKo0000oooonfY6oookJP00;_oonfX5o`0004kooo]Z1?l00007oookJPGo00003Ooo
nfX4o`0000kooo]Z1?l00007oookJPCo00004ooonfX5o`0000;ooo]Z1Ol0000HoookJPGo0000oooo
nfY6oookJP00;_oonfX5o`0004gooo]Z1Ol00007oookJPGo00003OoonfX4o`0000kooo]Z1?l00007
oookJPCo00004ooonfX5o`0000;ooo]Z1?l0003ooookJVCooo]Z000^oookJPGo0000COoonfX5o`00
00Sooo]Z1?l0000=oookJPCo00003_oonfX4o`0000Oooo]Z1?l0000DoookJPCo00000_oonfX4o`00
0?oooo]ZI?oonfX002kooo]Z1Ol0001=oookJPGo00002?oonfX4o`0000gooo]Z1?l0000>oookJPCo
00001ooonfX4o`0001Cooo]Z1?l00002oookJPCo0000oooonfYToookJP00;_oonfX5o`0004gooo]Z
1?l00009oookJPCo00003?oonfX5o`0000kooo]Z1?l00007oookJPCo00005?oonfX4o`0000;ooo]Z
1?l0003ooookJVCooo]Z000^oookJPGo0000=?oonfX4o`0001Gooo]Z1?l00009oookJPCo00003?oo
nfX5o`0000kooo]Z1Ol00005oookJPGo00005?oonfX4o`000003oookJ_l0003o000000?o0000oooo
nfYToookJP00;_oonfX5o`0003?ooo]Z1_l0000DoookJPCo00002OoonfX4o`0000cooo]Z1Ol0000>
oookJPGo00001OoonfX5o`0001Cooo]Z2_l0003ooookJVCooo]Z000^oookJPGo0000<ooonfX6o`00
01Cooo]Z1?l00009oookJPGo00002ooonfX4o`0000oooo]Z1Ol00005oookJPGo00005?oonfX:o`00
0?oooo]ZI?oonfX002kooo]Z1Ol0000boookJPSo00004ooonfX4o`0000Wooo]Z1Ol0000;oookJPCo
00004?oonfX4o`0000Gooo]Z1?l0000EoookJPWo0000oooonfYUoookJP004OoonfX5o`00O`Cooo]Z
0ol007l6oookJP?o001o2?oonfX5o`0003;ooo]Z2?l0000CoookJPCo00002OoonfX5o`0000_ooo]Z
1?l0000@oookJPCo00001OoonfX4o`0001Kooo]Z2?l0003ooookJVGooo]Z000@oookJPOo001o0ooo
nfX3o`00O`Kooo]Z0ol007l8oookJPGo0000<OoonfX:o`00017ooo]Z1Ol0000:oookJPCo00002ooo
nfX4o`00013ooo]Z1?l00005oookJPCo00005_oonfX8o`000?oooo]ZIOoonfX0013ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0000aoookJP[o00004Ooo
nfX5o`0000[ooo]Z1?l0000;oookJPCo00004?oonfX4o`0000Gooo]Z1?l0000GoookJPKo0000oooo
nfYVoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJPWo001o1ooonfX5o`00037ooo]Z2_l0000A
oookJPGo00002_oonfX4o`0000[ooo]Z1Ol0000@oookJPCo00001OoonfX4o`0001Oooo]Z1_l0003o
oookJVKooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPKo0000<?oonfX4o`00
00;ooo]Z1?l0000AoookJPCo00002ooonfX4o`0000[ooo]Z1Ol0000@oookJPGo00000ooonfX5o`00
01Sooo]Z1?l0003ooookJVOooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o
001o2?oonfX5o`00037ooo]Z1?l00002oookJPCo00004OoonfX4o`0000_ooo]Z1?l0000:oookJPGo
00004?oonfX5o`0000?ooo]Z1Ol0003ooookJX?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJP?o001o2?oonfX5o`00037ooo]Z1?l00002oookJPGo00004?oonfX4o`0000_ooo]Z
1Ol00009oookJPCo00004OoonfX5o`0000?ooo]Z1Ol0003ooookJX?ooo]Z000?oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000<OoonfX4o`0000;ooo]Z
1Ol0000@oookJPCo00002ooonfX5o`0000Wooo]Z1?l0000BoookJPCo00000ooonfX4o`000?oooo]Z
Q?oonfX000oooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
1Ol0000aoookJPCo00000_oonfX5o`00013ooo]Z1?l0000;oookJPGo00002OoonfX4o`0001;ooo]Z
1Ol00002oookJPCo0000oooonfZ4oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o2?oo
nfX5o`00037ooo]Z1?l00003oookJPCo00004?oonfX4o`0000cooo]Z1?l00009oookJPCo00004_oo
nfX5o`0000;ooo]Z1?l0003ooookJXCooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o2_oo
nfX5o`00O`Sooo]Z1Ol0000`oookJPGo00000ooonfX4o`00013ooo]Z1?l0000<oookJPCo00002Ooo
nfX4o`0001;ooo]Z1Ol00002oookJPCo0000oooonfZ4oookJP004?oonfX7o`00O`_ooo]Z1?l007l8
oookJPGo0000<?oonfX5o`0000?ooo]Z1?l0000?oookJPGo00003?oonfX4o`0000Wooo]Z1?l0000C
oookJPCo000000?ooo]Zo`000?l000000ol0003ooookJXCooo]Z000AoookJPGo001o3OoonfX3o`00
O`Sooo]Z1Ol0000`oookJPGo00000ooonfX4o`0000oooo]Z1Ol0000<oookJPCo00002?oonfX5o`00
01?ooo]Z1?l000000ooonf[o0000o`000003o`000?oooo]ZQ?oonfX002kooo]Z1Ol0000`oookJPCo
00001?oonfX4o`0000oooo]Z1Ol0000<oookJPGo00001ooonfX5o`0001?ooo]Z1?l000000ooonf[o
0000o`000003o`000?oooo]ZQ?oonfX002kooo]Z1Ol0000`oookJPCo00001?oonfX5o`0000kooo]Z
1?l0000=oookJPGo00001ooonfX5o`0001?ooo]Z2Ol0003ooookJXGooo]Z000^oookJPGo0000<?oo
nfX4o`0000Cooo]Z1Ol0000>oookJPCo00003OoonfX5o`0000Oooo]Z1?l0000DoookJPWo0000oooo
nfZ5oookJP00;_oonfX5o`0002oooo]Z1Ol00004oookJPGo00003_oonfX4o`0000kooo]Z1?l00007
oookJPCo00005?oonfX9o`000?oooo]ZQOoonfX002kooo]Z1Ol0000_oookJPGo00001OoonfX4o`00
00kooo]Z1?l0000>oookJPCo00001ooonfX4o`0001Gooo]Z2?l0003ooookJXGooo]Z000^oookJPGo
0000;ooonfX5o`0000Gooo]Z1?l0000>oookJPCo00003_oonfX5o`0000Kooo]Z1?l0000EoookJPOo
0000oooonfZ6oookJP00;_oonfX5o`0002oooo]Z1?l00006oookJPCo00003_oonfX4o`0000kooo]Z
1Ol00006oookJPCo00005OoonfX7o`000?oooo]ZQ_oonfX002kooo]Z1Ol0000_oookJPCo00001_oo
nfX4o`0000kooo]Z1?l0000>oookJPGo00001_oonfX4o`0001Kooo]Z1_l0003ooookJXKooo]Z000^
oookJPGo0000;_oonfX5o`0000Kooo]Z1?l0000>oookJPCo00003ooonfX4o`0000Gooo]Z1Ol0000G
oookJPCo0000oooonfZ7oookJP00;_oonfX5o`0002kooo]Z1Ol00006oookJPCo00003OoonfX5o`00
00oooo]Z1?l00005oookJPGo0000oooonfZRoookJP00;_oonfX5o`0002kooo]Z1Ol00006oookJPGo
00003?oonfX5o`0000oooo]Z1?l00005oookJPGo0000oooonfZRoookJP00;_oonfX5o`0002kooo]Z
1?l00007oookJPGo00003?oonfX5o`0000oooo]Z1?l00005oookJPCo0000oooonfZSoookJP00;_oo
nfX5o`0002kooo]Z1?l00007oookJPGo00003?oonfX4o`00013ooo]Z1Ol00004oookJPCo0000oooo
nfZSoookJP00;_oonfX5o`0002kooo]Z1?l00008oookJPCo00003?oonfX4o`00013ooo]Z1Ol00004
oookJPCo0000oooonfZSoookJP00;_oonfX5o`0002kooo]Z1?l00008oookJPCo00003?oonfX4o`00
013ooo]Z1Ol00004oookJPCo0000oooonfZSoookJP00;_oonfX5o`0002kooo]Z1?l00008oookJPCo
00003?oonfX4o`00017ooo]Z1?l00004oookJPCo0000oooonfZSoookJP00;_oonfX5o`0002kooo]Z
1?l00008oookJPCo00003?oonfX4o`00017ooo]Z1?l00003oookJPGo0000oooonfZSoookJP00;_oo
nfX5o`0002gooo]Z1Ol00008oookJPGo00002ooonfX4o`00017ooo]Z1?l00003oookJPGo0000oooo
nfZSoookJP00;_oonfX5o`0002gooo]Z1Ol00008oookJPGo00002ooonfX4o`00017ooo]Z1?l00003
oookJPGo0000oooonfZSoookJP00;_oonfX5o`0002gooo]Z1Ol00008oookJPGo00002ooonfX4o`00
017ooo]Z1Ol00002oookJPCo0000oooonfZToookJP00;_oonfX5o`0002gooo]Z1?l0000:oookJPCo
00002ooonfX4o`00017ooo]Z1Ol00002oookJPCo0000oooonfZToookJP00;_oonfX5o`0002gooo]Z
1?l0000:oookJPCo00002ooonfX4o`00017ooo]Z1Ol00002oookJPCo0000oooonfZToookJP00;_oo
nfX5o`0002gooo]Z1?l0000:oookJPCo00002_oonfX5o`0001;ooo]Z1?l000000ooonf[o0000o`00
0003o`000?oooo]ZY?oonfX002kooo]Z1Ol0000]oookJPCo00002_oonfX4o`0000[ooo]Z1Ol0000B
oookJPCo000000?ooo]Zo`000?l000000ol0003ooookJZCooo]Z000^oookJPGo0000;OoonfX4o`00
00[ooo]Z1Ol00009oookJPGo00004_oonfX4o`000003oookJ_l0003o000000?o0000oooonfZToook
JP00;_oonfX5o`0002gooo]Z1?l0000:oookJPGo00002OoonfX4o`0001?ooo]Z2Ol0003ooookJZGo
oo]Z000^oookJPGo0000;OoonfX4o`0000[ooo]Z1Ol00009oookJPCo00004ooonfX9o`000?oooo]Z
YOoonfX002kooo]Z1Ol0000]oookJPCo00002ooonfX4o`0000Wooo]Z1?l0000CoookJPWo0000oooo
nfZUoookJP00;_oonfX5o`0002gooo]Z1?l0000;oookJPCo00002OoonfX4o`0001Cooo]Z1ol0003o
oookJZKooo]Z000^oookJPGo0000;OoonfX4o`0000_ooo]Z1?l00009oookJPCo00005?oonfX7o`00
0?oooo]ZY_oonfX002kooo]Z1Ol0000/oookJPGo00002ooonfX4o`0000Wooo]Z1?l0000EoookJPKo
0000oooonfZVoookJP00;_oonfX5o`0002cooo]Z1Ol0000;oookJPCo00002OoonfX4o`0001Gooo]Z
1Ol0003ooookJZOooo]Z000^oookJPGo0000;?oonfX5o`0000_ooo]Z1Ol00007oookJPGo0000oooo
nf[1oookJP00;_oonfX5o`0001Cooo]Z1Ol0000CoookJPCo00003?oonfX5o`0000Oooo]Z1Ol0003o
oookJ/7ooo]Z000^oookJPGo00004ooonfX6o`0001?ooo]Z1?l0000<oookJPGo00001ooonfX5o`00
0?oooo]Z`OoonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0000CoookJPKo
00004ooonfX4o`0000gooo]Z1?l00007oookJPCo0000oooonf[2oookJP004?oonfX7o`00O`?ooo]Z
0ol007l2oookJPOo001o2?oonfX5o`0001;ooo]Z2?l0000BoookJPCo00003OoonfX4o`0000Oooo]Z
1?l0003ooookJ/;ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z
0ol007l2oookJP?o001o1ooonfX5o`0001;ooo]Z2?l0000BoookJPCo00003OoonfX4o`0000Oooo]Z
1?l0003ooookJ/;ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0001;ooo]Z2?l0000BoookJPCo00003OoonfX4o`0000Kooo]Z1Ol0003ooookJ/;ooo]Z000?
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX6o`00017ooo]Z2Ol0000A
oookJPCo00003OoonfX4o`0000Kooo]Z1Ol0003ooookJ/;ooo]Z000?oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l007l2oookJP?o001o1ooonfX5o`0001;ooo]Z2Ol0000AoookJPCo00003OoonfX4o`00
00Kooo]Z1Ol0003ooookJ/;ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2?l007l8oookJPGo
00004OoonfX:o`00017ooo]Z1?l0000=oookJPGo00001OoonfX4o`000?oooo]Z`ooonfX000oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0000AoookJPGo
000000?ooo]Zo`000?l000000_l0000@oookJPGo00003OoonfX5o`0000Gooo]Z1?l0003ooookJ/?o
oo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l=oookJPGo00004OoonfX5o`000003oook
J_l0003o000000;o00004?oonfX5o`0000gooo]Z1Ol00005oookJPCo0000oooonf[3oookJP003ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o3OoonfX5o`00017ooo]Z1?l00002oookJPCo00004?oo
nfX5o`0000kooo]Z1?l00005oookJPCo0000oooonf[3oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0ol007l2oookJP?o001o1ooonfX5o`00017ooo]Z1?l00002oookJPGo00003ooo
nfX4o`0000oooo]Z1?l00004oookJPGo0000oooonf[3oookJP004?oonfX7o`00O`Sooo]Z1ol007l8
oookJPGo00004?oonfX5o`0000;ooo]Z1Ol0000?oookJPCo00003ooonfX4o`0000Cooo]Z1Ol0003o
oookJ/?ooo]Z000AoookJPGo001o2ooonfX4o`00O`Wooo]Z1Ol0000@oookJPGo00000_oonfX5o`00
00oooo]Z1?l0000?oookJPCo00001?oonfX5o`000?oooo]Z`ooonfX002kooo]Z1Ol0000@oookJPGo
00000ooonfX4o`0000oooo]Z1?l0000?oookJPGo00000ooonfX4o`000?oooo]Za?oonfX002kooo]Z
1Ol0000@oookJPCo00001?oonfX4o`0000oooo]Z1?l0000?oookJPGo00000ooonfX4o`000?oooo]Z
a?oonfX002kooo]Z1Ol0000@oookJPCo00001?oonfX4o`0000oooo]Z1?l0000?oookJPGo00000ooo
nfX4o`000?oooo]Za?oonfX002kooo]Z1Ol0000@oookJPCo00001?oonfX4o`0000kooo]Z1Ol0000@
oookJPCo00000ooonfX4o`000?oooo]Za?oonfX002kooo]Z1Ol0000@oookJPCo00001?oonfX4o`00
00kooo]Z1Ol0000@oookJPGo000000?ooo]Zo`000?l000000ol0003ooookJ/Cooo]Z000^oookJPGo
00004?oonfX4o`0000Cooo]Z1Ol0000=oookJPGo00004?oonfX5o`000003oookJ_l0003o000000?o
0000oooonf[4oookJP00;_oonfX5o`00013ooo]Z1?l00004oookJPGo00003OoonfX4o`00017ooo]Z
1Ol000000ooonf[o0000o`000003o`000?oooo]Za?oonfX002kooo]Z1Ol0000?oookJPGo00001?oo
nfX5o`0000gooo]Z1?l0000BoookJPCo000000?ooo]Zo`000?l000000_l0003ooookJ/Gooo]Z000^
oookJPGo00003ooonfX5o`0000Gooo]Z1?l0000=oookJPCo00004_oonfX4o`000003oookJ_l0003o
000000;o0000oooonf[5oookJP00;_oonfX5o`0000oooo]Z1Ol00005oookJPCo00003OoonfX4o`00
01;ooo]Z2Ol0003ooookJ/Gooo]Z000^oookJPGo00003ooonfX4o`0000Kooo]Z1?l0000=oookJPCo
00004_oonfX9o`000?oooo]ZaOoonfX002kooo]Z1Ol0000?oookJPCo00001_oonfX4o`0000gooo]Z
1?l0000BoookJPWo0000oooonf[5oookJP00;_oonfX5o`0000oooo]Z1?l00006oookJPGo00002ooo
nfX5o`0001;ooo]Z2?l0003ooookJ/Kooo]Z000^oookJPGo00003ooonfX4o`0000Kooo]Z1Ol0000;
oookJPGo00004ooonfX7o`000?oooo]Za_oonfX002kooo]Z1Ol0000>oookJPGo00001_oonfX5o`00
00_ooo]Z1Ol0000DoookJPGo0000oooonf[7oookJP00;_oonfX5o`0000kooo]Z1Ol00007oookJPCo
00002ooonfX4o`000?oooo]ZhOoonfX002kooo]Z1Ol0000>oookJPGo00001ooonfX4o`0000_ooo]Z
1?l0003ooookJ^7ooo]Z000^oookJPGo00003_oonfX4o`0000Sooo]Z1?l0000;oookJPCo0000oooo
nf[QoookJP00;_oonfX5o`0000kooo]Z1?l00008oookJPCo00002ooonfX4o`000?oooo]ZhOoonfX0
02kooo]Z1Ol0000>oookJPCo00002?oonfX5o`0000[ooo]Z1?l0003ooookJ^7ooo]Z000^oookJPGo
00003_oonfX4o`0000Sooo]Z1Ol0000:oookJPCo0000oooonf[QoookJP00;_oonfX5o`0000kooo]Z
1?l00008oookJPGo00002_oonfX4o`000?oooo]ZhOoonfX002kooo]Z1Ol0000=oookJPGo00002Ooo
nfX4o`0000[ooo]Z1?l0003ooookJ^7ooo]Z000^oookJPGo00003OoonfX5o`0000Wooo]Z1?l0000:
oookJPCo0000oooonf[QoookJP00;_oonfX5o`0000gooo]Z1Ol00009oookJPCo00002OoonfX5o`00
0?oooo]ZhOoonfX002kooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000Wooo]Z1Ol0003ooookJ^7o
oo]Z000^oookJPGo00003OoonfX4o`0000[ooo]Z1Ol00008oookJPGo0000oooonf[QoookJP00;_oo
nfX5o`0000gooo]Z1?l0000:oookJPGo00002?oonfX4o`000?oooo]Zh_oonfX002kooo]Z1Ol0000=
oookJPCo00002_oonfX5o`0000Sooo]Z1?l0003ooookJ^;ooo]Z000^oookJPGo00003OoonfX4o`00
00_ooo]Z1?l00008oookJPCo0000oooonf[RoookJP00;_oonfX5o`0000gooo]Z1?l0000;oookJPCo
00002?oonfX4o`000?oooo]Zh_oonfX002kooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000Sooo]Z
1?l0003ooookJ^;ooo]Z000^oookJPGo00003OoonfX4o`0000_ooo]Z1Ol00007oookJPCo0000oooo
nf[RoookJP00;_oonfX5o`0000cooo]Z1Ol0000;oookJPGo00001_oonfX5o`000?oooo]Zh_oonfX0
02kooo]Z1Ol0000<oookJPGo00002ooonfX5o`0000Kooo]Z1Ol0003ooookJ^;ooo]Z000AoookJPGo
001o1?oonfX3o`00O`?ooo]Z1Ol007l9oookJPGo00003?oonfX5o`0000cooo]Z1?l00006oookJPGo
0000oooonf[RoookJP004?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0000cooo]Z
1?l0000=oookJPCo00001_oonfX4o`000?oooo]ZhooonfX0013ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0000<oookJPCo
00003OoonfX4o`0000Kooo]Z1?l0003ooookJ^?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0000cooo]Z1?l0000=oookJPCo00001OoonfX5o`000?oooo]Z
hooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo00002ooo
nfX4o`0000gooo]Z1Ol00004oookJPGo0000oooonf[SoookJP003ooonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000<oookJPCo00003OoonfX5o`0000Cooo]Z1Ol0003o
oookJ^?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo00003?oonfX4o`00
00gooo]Z1Ol00004oookJPCo0000oooonf[ToookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2?oonfX5o`0000cooo]Z1?l0000>oookJPCo00001?oonfX4o`000?oooo]Zi?oonfX000oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00003?oonfX4o`0000kooo]Z
1?l00004oookJPCo0000oooonf[ToookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0000<oookJPCo00003_oonfX5o`0000?ooo]Z1?l0003ooookJ^Cooo]Z000@
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00003?oo
nfX4o`0000kooo]Z1Ol00002oookJPGo0000oooonf[ToookJP004?oonfX7o`00O`Sooo]Z1ol007l8
oookJPGo00003?oonfX4o`0000kooo]Z1Ol00002oookJPGo0000oooonf[ToookJP004OoonfX5o`00
O`[ooo]Z1Ol007l9oookJPGo00003?oonfX4o`0000oooo]Z1?l00002oookJPGo0000oooonf[Toook
JP00;_oonfX5o`0000_ooo]Z1Ol0000?oookJPGo000000?ooo]Zo`000?l000000_l0003ooookJ^Go
oo]Z000^oookJPGo00002ooonfX5o`0000oooo]Z1Ol000000ooonf[o0000o`000002o`000?oooo]Z
iOoonfX002kooo]Z1Ol0000;oookJPGo00003ooonfX:o`000?oooo]ZiOoonfX002kooo]Z1Ol0000;
oookJPCo00004OoonfX9o`000?oooo]ZiOoonfX002kooo]Z1Ol0000;oookJPCo00004OoonfX9o`00
0?oooo]ZiOoonfX002kooo]Z1Ol0000;oookJPCo00004OoonfX8o`000?oooo]Zi_oonfX002kooo]Z
1Ol0000;oookJPCo00004OoonfX8o`000?oooo]Zi_oonfX002kooo]Z1Ol0000;oookJPCo00004Ooo
nfX8o`000?oooo]Zi_oonfX002kooo]Z1Ol0000;oookJPCo00004_oonfX7o`000?oooo]Zi_oonfX0
02kooo]Z1Ol0000;oookJPCo00004_oonfX6o`000?oooo]ZiooonfX002kooo]Z1Ol0000;oookJPCo
00004ooonfX5o`000?oooo]ZiooonfX002kooo]Z1Ol0000;oookJPCo0000oooonf[ooookJP00;_oo
nfX5o`0000[ooo]Z1Ol0003ooookJ_oooo]Z000^oookJPGo00002_oonfX5o`000?oooo]ZoooonfX0
02kooo]Z1Ol0000:oookJPGo0000oooonf[ooookJP00;_oonfX5o`0000[ooo]Z1?l0003ooookJ_oo
oo]Z0OoonfX002kooo]Z1Ol0000:oookJPCo0000oooonf[ooookJP7ooo]Z000^oookJPGo00002_oo
nfX4o`000?oooo]ZoooonfX1oookJP00;_oonfX5o`0000[ooo]Z1?l0003ooookJ_oooo]Z0OoonfX0
02kooo]Z1Ol0000:oookJPCo0000oooonf[ooookJP7ooo]Z000^oookJPGo00002_oonfX4o`000?oo
oo]ZoooonfX1oookJP00;_oonfX5o`0000Wooo]Z1Ol0003ooookJ_oooo]Z0OoonfX002kooo]Z1Ol0
0009oookJPGo0000oooonf[ooookJP7ooo]Z000^oookJPGo00002OoonfX5o`000?oooo]ZoooonfX1
oookJP00;_oonfX5o`0000Wooo]Z1?l0003ooookJ_oooo]Z0_oonfX002kooo]Z1Ol00009oookJPCo
0000oooonf[ooookJP;ooo]Z000^oookJPGo00002OoonfX4o`000?oooo]ZoooonfX2oookJP00;_oo
nfX5o`0000Wooo]Z1?l0003ooookJ_oooo]Z0_oonfX002kooo]Z1Ol00009oookJPCo0000oooonf[o
oookJP;ooo]Z000^oookJPGo00002OoonfX4o`000?oooo]ZoooonfX2oookJP00;_oonfX5o`0000Wo
oo]Z1?l0003ooookJ_oooo]Z0_oonfX002kooo]Z1Ol00008oookJPGo0000oooonf[ooookJP;ooo]Z
000^oookJPGo00002?oonfX5o`000?oooo]ZoooonfX2oookJP00;_oonfX5o`0000Sooo]Z1Ol0003o
oookJ_oooo]Z0_oonfX002kooo]Z1Ol00008oookJPCo0000oooonf[ooookJP?ooo]Z000RoookJP?o
001o2OoonfX5o`0000Sooo]Z1?l0003ooookJ_oooo]Z0ooonfX002;ooo]Z0ol007l9oookJPGo0000
2?oonfX4o`000?oooo]ZoooonfX3oookJP008_oonfX3o`00O`Wooo]Z1Ol00008oookJPCo0000oooo
nf[ooookJP?ooo]Z000RoookJP?o001o2OoonfX5o`0000Sooo]Z1?l0003ooookJ_oooo]Z0ooonfX0
02;ooo]Z0ol007l9oookJPKo00001ooonfX4o`000?oooo]ZoooonfX3oookJP008_oonfX3o`00O`Wo
oo]Z1Ol00008oookJPCo0000oooonf[ooookJP?ooo]Z000RoookJP?o001o2OoonfX5o`0000Sooo]Z
1?l0003ooookJ_oooo]Z0ooonfX002;ooo]Z0ol007l9oookJPGo00001ooonfX5o`000?oooo]Zoooo
nfX3oookJP008_oonfX3o`00O`Wooo]Z1Ol00007oookJPGo0000oooonf[ooookJP?ooo]Z000Ooook
JPKo001o2OoonfX5o`0000Oooo]Z1Ol0003ooookJ_oooo]Z0ooonfX001oooo]Z1_l007l9oookJPGo
00001ooonfX4o`000?oooo]ZoooonfX4oookJP008OoonfX4o`00O`Wooo]Z1_l00006oookJPCo0000
oooonf[ooookJPCooo]Z000RoookJP?o001o2OoonfX6o`0000Kooo]Z1?l0003ooookJ_oooo]Z1?oo
nfX002kooo]Z1_l00006oookJPCo0000oooonf[ooookJPCooo]Z000^oookJPKo00001_oonfX4o`00
0?oooo]ZoooonfX4oookJP00;_oonfX6o`0000Kooo]Z1?l0003ooookJ_oooo]Z1?oonfX002kooo]Z
1ol00004oookJPGo0000oooonf[ooookJPCooo]Z000^oookJPOo00001?oonfX5o`000?oooo]Zoooo
nfX4oookJP00;_oonfX7o`0000Cooo]Z1Ol0003ooookJ_oooo]Z1?oonfX002kooo]Z1ol00004oook
JPCo0000oooonf[ooookJPGooo]Z000^oookJPOo00001?oonfX4o`000?oooo]ZoooonfX5oookJP00
;_oonfX7o`0000?ooo]Z1Ol0003ooookJ_oooo]Z1OoonfX002kooo]Z2?l00002oookJPGo0000oooo
nf[ooookJPGooo]Z000^oookJPSo00000_oonfX5o`000?oooo]ZoooonfX5oookJP00;_oonfX8o`00
00;ooo]Z1?l0003ooookJ_oooo]Z1_oonfX002kooo]Z2?l000000ooonf[o0000o`000003o`000?oo
oo]ZoooonfX6oookJP00;_oonfX8o`000003oookJ_l0003o000000?o0000oooonf[ooookJPKooo]Z
000^oookJPSo000000?ooo]Zo`000?l000000ol0003ooookJ_oooo]Z1_oonfX002kooo]Z2?l00000
0ooonf[o0000o`000002o`000?oooo]ZoooonfX7oookJP00;_oonfX=o`000?oooo]ZoooonfX7oook
JP00;_oonfX=o`000?oooo]ZoooonfX7oookJP00;_oonfX=o`000?oooo]ZoooonfX7oookJP00;_oo
nfX=o`000?oooo]ZoooonfX7oookJP00;_oonfX5o`000003oookJ_l0003o000000Go0000oooonf[o
oookJPOooo]Z000^oookJPGo000000?ooo]Zo`000?l000001?l0003ooookJ_oooo]Z2?oonfX002ko
oo]Z1Ol000000ooonf[o0000o`000003o`000?oooo]ZoooonfX9oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-19.0923, -0.279163, \
0.39264, 0.0041789}},
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"]
}, Open  ]],

Cell["Damped Near Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1,  .05, 1/2\  + \ \ 0.05, 1/2]], {t, 0, 200}, 
      PlotPoints \[Rule] 200]\)], "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.308199 0.0140428 [
[.2619 .2957 -12 -20 ]
[.2619 .2957 12 0 ]
[.5 .2957 -17 -20 ]
[.5 .2957 17 0 ]
[.7381 .2957 -17 -20 ]
[.7381 .2957 17 0 ]
[.97619 .2957 -17 -20 ]
[.97619 .2957 17 0 ]
[.01131 .02734 -36.9375 -10 ]
[.01131 .02734 0 10 ]
[.01131 .16777 -36.9375 -10 ]
[.01131 .16777 0 10 ]
[.01131 .44863 -24 -10 ]
[.01131 .44863 0 10 ]
[.01131 .58905 -24 -10 ]
[.01131 .58905 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .3082 m
.2619 .31445 L
s
gsave
.2619 .2957 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .3082 m
.5 .31445 L
s
gsave
.5 .2957 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .3082 m
.7381 .31445 L
s
gsave
.7381 .2957 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .3082 m
.97619 .31445 L
s
gsave
.97619 .2957 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .3082 m
.07143 .31195 L
s
.11905 .3082 m
.11905 .31195 L
s
.16667 .3082 m
.16667 .31195 L
s
.21429 .3082 m
.21429 .31195 L
s
.30952 .3082 m
.30952 .31195 L
s
.35714 .3082 m
.35714 .31195 L
s
.40476 .3082 m
.40476 .31195 L
s
.45238 .3082 m
.45238 .31195 L
s
.54762 .3082 m
.54762 .31195 L
s
.59524 .3082 m
.59524 .31195 L
s
.64286 .3082 m
.64286 .31195 L
s
.69048 .3082 m
.69048 .31195 L
s
.78571 .3082 m
.78571 .31195 L
s
.83333 .3082 m
.83333 .31195 L
s
.88095 .3082 m
.88095 .31195 L
s
.92857 .3082 m
.92857 .31195 L
s
.01 w
0 .3082 m
1 .3082 L
s
.25 Mabswid
.02381 .02734 m
.03006 .02734 L
s
gsave
.01131 .02734 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02381 .16777 m
.03006 .16777 L
s
gsave
.01131 .16777 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .44863 m
.03006 .44863 L
s
gsave
.01131 .44863 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .58905 m
.03006 .58905 L
s
gsave
.01131 .58905 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05543 m
.02756 .05543 L
s
.02381 .08351 m
.02756 .08351 L
s
.02381 .1116 m
.02756 .1116 L
s
.02381 .13969 m
.02756 .13969 L
s
.02381 .19586 m
.02756 .19586 L
s
.02381 .22394 m
.02756 .22394 L
s
.02381 .25203 m
.02756 .25203 L
s
.02381 .28011 m
.02756 .28011 L
s
.02381 .33628 m
.02756 .33628 L
s
.02381 .36437 m
.02756 .36437 L
s
.02381 .39246 m
.02756 .39246 L
s
.02381 .42054 m
.02756 .42054 L
s
.02381 .47671 m
.02756 .47671 L
s
.02381 .5048 m
.02756 .5048 L
s
.02381 .53288 m
.02756 .53288 L
s
.02381 .56097 m
.02756 .56097 L
s
.02381 .61714 m
.02756 .61714 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .32224 m
.02395 .32225 L
.02408 .32226 L
.02423 .32228 L
.02437 .32231 L
.02462 .32238 L
.02489 .32249 L
.02519 .32265 L
.02551 .32286 L
.02608 .32333 L
.02722 .32465 L
.02847 .32661 L
.03355 .33774 L
.03485 .34062 L
.03609 .34303 L
.0372 .34479 L
.03783 .34558 L
.03841 .34615 L
.0387 .34637 L
.03901 .34657 L
.03916 .34664 L
.03931 .3467 L
.03945 .34675 L
.03958 .34678 L
.03973 .34681 L
.03981 .34681 L
.03989 .34682 L
.04003 .34682 L
.04018 .34681 L
.04026 .34679 L
.04034 .34678 L
.04052 .34672 L
.04068 .34666 L
.04083 .34659 L
.04111 .34641 L
.0414 .34618 L
.04192 .34561 L
.04248 .3448 L
.04309 .34367 L
.04432 .34052 L
.04545 .33668 L
.04798 .32469 L
.05029 .30998 L
.0528 .2909 L
.05773 .24963 L
.06019 .23088 L
.06139 .22295 L
.06249 .21668 L
.06354 .21167 L
.06469 .2075 L
Mistroke
.06532 .20583 L
.06563 .20518 L
.0659 .20469 L
.06617 .20431 L
.06646 .204 L
.06662 .20387 L
.06677 .20378 L
.06691 .20373 L
.06706 .20369 L
.0672 .20368 L
.06729 .20369 L
.06736 .20371 L
.06751 .20376 L
.06766 .20384 L
.06779 .20394 L
.06792 .20405 L
.0682 .20439 L
.06851 .20488 L
.06879 .20543 L
.06943 .20709 L
.06994 .20883 L
.07051 .21115 L
.07164 .21713 L
.07288 .22566 L
.07401 .23512 L
.07654 .2617 L
.08137 .32726 L
.08601 .39453 L
.08837 .42413 L
.08962 .43745 L
.09095 .44943 L
.09224 .45839 L
.09285 .46167 L
.09341 .46414 L
.09398 .46603 L
.09428 .46679 L
.09459 .46742 L
.09473 .46763 L
.09487 .46782 L
.09499 .46794 L
.09513 .46805 L
.09527 .46813 L
.09543 .46817 L
.09558 .46816 L
.09571 .46812 L
.09587 .46802 L
.09594 .46796 L
.09603 .46788 L
.09632 .46748 L
.09648 .46718 L
Mistroke
.09666 .46681 L
.09698 .46597 L
.09761 .46374 L
.09818 .46104 L
.09933 .45367 L
.10042 .44435 L
.10281 .41648 L
.10503 .38263 L
.10975 .29376 L
.11477 .19611 L
.11728 .15527 L
.11839 .14039 L
.1196 .12665 L
.12077 .11619 L
.12133 .11223 L
.12186 .10913 L
.12215 .10772 L
.12247 .1064 L
.12273 .10549 L
.12302 .10467 L
.12333 .10401 L
.1235 .10374 L
.12358 .10365 L
.12366 .10356 L
.12381 .10345 L
.12394 .10339 L
.12409 .10338 L
.12417 .1034 L
.12425 .10343 L
.12441 .10354 L
.12448 .10362 L
.12457 .10372 L
.12486 .1042 L
.12503 .10457 L
.1252 .10503 L
.12552 .10607 L
.12615 .10883 L
.12672 .1122 L
.12787 .12136 L
.12896 .13293 L
.13136 .16743 L
.13358 .20903 L
.13831 .31739 L
.14333 .43533 L
.14585 .48448 L
.14696 .50237 L
.14817 .51893 L
.14934 .53162 L
.15044 .54026 L
.15104 .54366 L
Mistroke
.15159 .54588 L
.1519 .54675 L
.15207 .54712 L
.15223 .54739 L
.15237 .54757 L
.15252 .5477 L
.1526 .54775 L
.15268 .54777 L
.15283 .54777 L
.15291 .54774 L
.15299 .5477 L
.15313 .54757 L
.15329 .54736 L
.15346 .54706 L
.15377 .54631 L
.15405 .54538 L
.15469 .5424 L
.15538 .53796 L
.15653 .52751 L
.1578 .51191 L
.16015 .4725 L
.16267 .41749 L
.16766 .2859 L
.17246 .16054 L
.17466 .11343 L
.17591 .09113 L
.17708 .0737 L
.17823 .06026 L
.17882 .05479 L
.17947 .04999 L
.18011 .04646 L
.18046 .04507 L
.18063 .04454 L
.18079 .04412 L
.18094 .04379 L
.1811 .04352 L
.18124 .04334 L
.18138 .04324 L
.18152 .04319 L
.18168 .0432 L
.18176 .04324 L
.18185 .04331 L
.182 .04348 L
.18208 .04361 L
.18216 .04375 L
.18231 .04405 L
.18263 .04498 L
.18292 .04606 L
.18322 .0475 L
.18392 .05184 L
Mistroke
.18455 .05713 L
.18573 .07013 L
.18698 .08816 L
.18935 .13367 L
.19156 .18708 L
.19626 .32113 L
.20125 .46206 L
.20375 .51919 L
.20485 .53979 L
.20606 .55877 L
.20722 .57295 L
.20775 .57808 L
.20831 .58252 L
.20859 .58441 L
.20891 .58618 L
.20919 .58753 L
.20945 .58852 L
.20976 .58941 L
.20993 .58976 L
.21001 .58989 L
.2101 .59 L
.21024 .59015 L
.21038 .59023 L
.21053 .59024 L
.21061 .59021 L
.21069 .59017 L
.21084 .59002 L
.21092 .58992 L
.211 .58978 L
.21129 .58914 L
.21145 .58865 L
.21163 .58804 L
.21195 .58666 L
.21257 .583 L
.21314 .57854 L
.21423 .56716 L
.21538 .55123 L
.21775 .50649 L
.21997 .45271 L
.22467 .31441 L
.22967 .16493 L
.23218 .10254 L
.23328 .07955 L
.23449 .05793 L
.23557 .04217 L
.23674 .02927 L
.23738 .02403 L
.23797 .02042 L
.23825 .0191 L
.23856 .01797 L
Mistroke
.2387 .01756 L
.23885 .01719 L
.23899 .01692 L
.23912 .01673 L
.23927 .01658 L
.23935 .01653 L
.23944 .0165 L
.23952 .0165 L
.23961 .01652 L
.23977 .01663 L
.23992 .01681 L
.24005 .01704 L
.2402 .01736 L
.24036 .01779 L
.24069 .01895 L
.241 .02037 L
.2417 .0248 L
.24232 .02998 L
.24288 .03579 L
.24414 .05251 L
.24642 .09459 L
.24892 .15539 L
.25381 .3021 L
.25852 .44586 L
.26092 .50798 L
.26219 .5356 L
.26353 .56025 L
.26472 .57785 L
.26535 .5854 L
.26603 .59207 L
.26666 .59685 L
.26723 .60007 L
.2675 .60124 L
.26765 .60175 L
.2678 .60221 L
.26795 .60258 L
.26809 .60285 L
.26822 .60306 L
.26835 .6032 L
.26849 .6033 L
.26864 .60332 L
.26878 .60327 L
.26891 .60316 L
.26906 .60297 L
.26923 .60267 L
.26938 .60229 L
.26953 .60188 L
.26982 .60084 L
.27013 .59936 L
.27077 .59535 L
Mistroke
.27133 .59078 L
.27193 .58474 L
.273 .57095 L
.27555 .52484 L
.27797 .46596 L
.28258 .32881 L
.28748 .17858 L
.28974 .1189 L
.29219 .06702 L
.29354 .04549 L
.29412 .03774 L
.29477 .03048 L
.29534 .0252 L
.29595 .0207 L
.29629 .01875 L
.2966 .01731 L
.29691 .01617 L
.29705 .01576 L
.2972 .0154 L
.29735 .01511 L
.29749 .01492 L
.29762 .01479 L
.29776 .01472 L
.29791 .01472 L
.29805 .01478 L
.2982 .01493 L
.29829 .01504 L
.29837 .01517 L
.29867 .01587 L
.29884 .01639 L
.299 .01697 L
.2996 .01991 L
.30012 .02337 L
.30068 .02817 L
.30182 .04097 L
.30305 .0591 L
.30417 .0794 L
.30669 .13647 L
.31148 .27456 L
.31609 .41512 L
.31866 .48411 L
.32099 .5351 L
.32216 .55548 L
.32343 .57314 L
.32401 .57964 L
.32462 .58537 L
.32518 .58958 L
.32572 .59263 L
.326 .59389 L
.32631 .59495 L
Mistroke
.32645 .59531 L
.3266 .59564 L
.32672 .59586 L
.32686 .59604 L
.32702 .59617 L
.32716 .59622 L
.32724 .59622 L
.32732 .5962 L
.32741 .59615 L
.32749 .59608 L
.32764 .5959 L
.32778 .59567 L
.32794 .59533 L
.32809 .59493 L
.32835 .59403 L
.32864 .59282 L
.32915 .59001 L
.3297 .58605 L
.3303 .58062 L
.33153 .56611 L
.33265 .54903 L
.33517 .49867 L
.33996 .36963 L
.34458 .23148 L
.34716 .16078 L
.34949 .1065 L
.35066 .08382 L
.35193 .06332 L
.35312 .04806 L
.35422 .03778 L
.35479 .03389 L
.3551 .03218 L
.3554 .03084 L
.35568 .02985 L
.35582 .02942 L
.35598 .02904 L
.3561 .02878 L
.35625 .02855 L
.35638 .0284 L
.3565 .02831 L
.35665 .02826 L
.35674 .02826 L
.35682 .02829 L
.35697 .02839 L
.35713 .02857 L
.35728 .02883 L
.35743 .02914 L
.3577 .0299 L
.35802 .03111 L
.35832 .0325 L
Mistroke
.35899 .03666 L
.35956 .04124 L
.36017 .04722 L
.36126 .0607 L
.36375 .1033 L
.36632 .1616 L
.36874 .22648 L
.37336 .36 L
.3757 .42424 L
.37828 .48637 L
.37946 .5104 L
.38072 .53272 L
.38191 .54991 L
.38302 .56245 L
.38362 .56783 L
.38417 .5718 L
.38478 .57515 L
.38512 .57651 L
.38527 .57702 L
.38543 .57749 L
.38558 .57785 L
.38574 .57815 L
.38583 .57829 L
.38591 .57839 L
.38607 .57854 L
.38621 .57861 L
.38637 .57861 L
.38652 .57854 L
.38665 .57842 L
.38674 .57832 L
.38683 .57819 L
.38699 .57789 L
.3873 .57711 L
.38765 .57584 L
.38798 .57435 L
.38855 .571 L
.38916 .56637 L
.39025 .55535 L
.39156 .53797 L
.39275 .5184 L
.39756 .41005 L
.40219 .28255 L
.40453 .21902 L
.40711 .15584 L
.40959 .10614 L
.41067 .08863 L
.41185 .07282 L
.41299 .0611 L
.41361 .05621 L
.41419 .05265 L
Mistroke
.41452 .05104 L
.41483 .04981 L
.41511 .04894 L
.41541 .04825 L
.41556 .04799 L
.41565 .04788 L
.41574 .04779 L
.41582 .04773 L
.41592 .04768 L
.416 .04765 L
.41608 .04765 L
.41624 .0477 L
.41638 .04781 L
.41654 .048 L
.41671 .04828 L
.41699 .04894 L
.41729 .04989 L
.41783 .05224 L
.41841 .05569 L
.41905 .06054 L
.42019 .07199 L
.42125 .08569 L
.42372 .12762 L
.42596 .17607 L
.43078 .29993 L
.43541 .42001 L
.43776 .47196 L
.439 .49557 L
.44034 .51729 L
.44162 .53415 L
.44279 .54596 L
.44336 .55036 L
.44397 .55419 L
.44425 .55559 L
.44455 .55686 L
.44481 .55774 L
.44509 .55851 L
.44525 .55885 L
.4454 .5591 L
.44556 .5593 L
.44565 .55938 L
.44574 .55943 L
.44588 .55948 L
.44604 .55947 L
.44619 .55939 L
.44633 .55926 L
.44641 .55917 L
.44649 .55905 L
.44664 .55879 L
.44698 .55795 L
Mistroke
.44734 .55673 L
.44767 .55529 L
.44824 .55215 L
.44886 .54773 L
.45011 .5358 L
.45135 .52013 L
.45247 .50283 L
.455 .45475 L
.45982 .33887 L
.46446 .22098 L
.46682 .16781 L
.4694 .11951 L
.47059 .10188 L
.47186 .08652 L
.47247 .08049 L
.47306 .07566 L
.47362 .07181 L
.47416 .06895 L
.47445 .06769 L
.47476 .06659 L
.47505 .06581 L
.47532 .0653 L
.47546 .06509 L
.4756 .06494 L
.47575 .06485 L
.47584 .06482 L
.47592 .06481 L
.47607 .06484 L
.47616 .06489 L
.47624 .06495 L
.47639 .06511 L
.47655 .06534 L
.47681 .06587 L
.4771 .06665 L
.47761 .06859 L
.47821 .07178 L
.47877 .07553 L
.47996 .08614 L
.48106 .09903 L
.48356 .13808 L
.48827 .23994 L
.49329 .36435 L
.4958 .42274 L
.49812 .46941 L
.50038 .50578 L
.50151 .52001 L
.50216 .52672 L
.50276 .53217 L
.50335 .53658 L
.50399 .54039 L
Mistroke
.50428 .54174 L
.50458 .54295 L
.50486 .54388 L
.50512 .54455 L
.50526 .54484 L
.50541 .54511 L
.50557 .54531 L
.50565 .54539 L
.50573 .54546 L
.50588 .54553 L
.50601 .54554 L
.50617 .5455 L
.50631 .54541 L
.50639 .54534 L
.50647 .54524 L
.50664 .54499 L
.50695 .54436 L
.5073 .54332 L
.50764 .54205 L
.50824 .53906 L
.50889 .53476 L
.51008 .52426 L
.51124 .51086 L
.51232 .49578 L
.51704 .40508 L
.52206 .28468 L
.52458 .22482 L
.5269 .1749 L
.5293 .13137 L
.53155 .10081 L
.53265 .08993 L
.53321 .08546 L
.53382 .08147 L
.53417 .07961 L
.53449 .07817 L
.5348 .07705 L
.53513 .07608 L
.53527 .07575 L
.53543 .07545 L
.53556 .07524 L
.5357 .07506 L
.53586 .07493 L
.53594 .07489 L
.53602 .07486 L
.53617 .07485 L
.53632 .0749 L
.53647 .07501 L
.53655 .0751 L
.53663 .07519 L
.53679 .07543 L
Mistroke
.53696 .07577 L
.53727 .07655 L
.53755 .07749 L
.53824 .08059 L
.53889 .0846 L
.54006 .09432 L
.54133 .10847 L
.54371 .14418 L
.54624 .19306 L
.55078 .29804 L
.55563 .41143 L
.55785 .45633 L
.55911 .47837 L
.56029 .49626 L
.56155 .51234 L
.5627 .52389 L
.56329 .52862 L
.56393 .53281 L
.56428 .53468 L
.5646 .53614 L
.56494 .53738 L
.56524 .53826 L
.56538 .53858 L
.56553 .53888 L
.56567 .53911 L
.5658 .53928 L
.56596 .53941 L
.56604 .53947 L
.56612 .5395 L
.56626 .53952 L
.56641 .53948 L
.56654 .53941 L
.56669 .53927 L
.56684 .53907 L
.56698 .53884 L
.56723 .53829 L
.5675 .53753 L
.56817 .53486 L
.5688 .53132 L
.56999 .52209 L
.57115 .50984 L
.57239 .49358 L
.57461 .45687 L
.57917 .35945 L
.58401 .24384 L
.58868 .14752 L
.5911 .1112 L
.59231 .09753 L
.593 .09132 L
.59364 .08646 L
Mistroke
.59424 .08288 L
.59455 .08134 L
.59488 .07998 L
.59516 .07905 L
.59547 .07824 L
.5956 .07796 L
.59575 .07771 L
.59588 .07753 L
.59601 .0774 L
.59616 .07729 L
.59625 .07726 L
.59633 .07724 L
.59648 .07726 L
.59663 .07734 L
.59671 .0774 L
.5968 .07749 L
.59695 .07769 L
.59712 .07797 L
.5973 .07837 L
.59761 .07922 L
.59794 .08039 L
.59853 .08318 L
.59917 .08715 L
.59976 .0917 L
.6011 .105 L
.60353 .13904 L
.60579 .18044 L
.60827 .23418 L
.61313 .34993 L
.6178 .45189 L
.62022 .49284 L
.62145 .5093 L
.62277 .5232 L
.62341 .52854 L
.62402 .53267 L
.62456 .53561 L
.62484 .53683 L
.62515 .53795 L
.62544 .53879 L
.62571 .53938 L
.62586 .53962 L
.626 .5398 L
.62616 .53994 L
.62631 .54002 L
.62644 .54004 L
.62657 .54001 L
.62669 .53996 L
.62682 .53986 L
.62695 .5397 L
.6271 .53948 L
Mistroke
.62737 .53894 L
.62766 .53815 L
.62797 .53708 L
.62852 .53455 L
.62918 .53054 L
.62978 .52598 L
.63109 .5131 L
.63233 .4974 L
.63474 .45794 L
.63696 .41303 L
.64171 .30152 L
.64628 .19523 L
.64882 .1456 L
.65114 .11008 L
.65229 .09671 L
.65289 .09086 L
.65354 .08559 L
.65416 .08149 L
.65472 .07859 L
.65499 .07747 L
.65529 .07648 L
.65556 .07573 L
.65582 .07523 L
.65597 .075 L
.65612 .07484 L
.65625 .07475 L
.65639 .07469 L
.65654 .07469 L
.65662 .07471 L
.6567 .07475 L
.65685 .07487 L
.65699 .07503 L
.65713 .07523 L
.65727 .07549 L
.65752 .07609 L
.65779 .07691 L
.65809 .07803 L
.65872 .0811 L
.65938 .08545 L
.66058 .096 L
.66182 .11039 L
.66316 .12971 L
.66559 .17346 L
.67053 .28573 L
.67528 .4001 L
.67767 .45088 L
.67986 .4896 L
.68098 .50598 L
.6822 .52072 L
.68287 .52733 L
Mistroke
.6835 .5325 L
.68414 .53682 L
.68472 .53988 L
.68502 .54109 L
.68534 .54215 L
.68566 .54295 L
.68584 .54328 L
.68592 .5434 L
.686 .54351 L
.68616 .54366 L
.68631 .54375 L
.68645 .54378 L
.68658 .54376 L
.68673 .54369 L
.68689 .54355 L
.68697 .54345 L
.68705 .54333 L
.68721 .54307 L
.68749 .54241 L
.68781 .54144 L
.68838 .53904 L
.68894 .5359 L
.68945 .5323 L
.69073 .52061 L
.69193 .50613 L
.69417 .47084 L
.69882 .3718 L
.70376 .25047 L
.70622 .19364 L
.70852 .14729 L
.71073 .11145 L
.71197 .09583 L
.7131 .0847 L
.71368 .08019 L
.7143 .07633 L
.71482 .0738 L
.71512 .07268 L
.7154 .07183 L
.71571 .07115 L
.71586 .07089 L
.71595 .07078 L
.71603 .07069 L
.71618 .07057 L
.71633 .07051 L
.71647 .0705 L
.71661 .07055 L
.71676 .07066 L
.71684 .07074 L
.71693 .07085 L
.71723 .07137 L
Mistroke
.7174 .07177 L
.71758 .07228 L
.71791 .07341 L
.71854 .0764 L
.71913 .08008 L
.72046 .09162 L
.72163 .10532 L
.72288 .12329 L
.7279 .22373 L
.73274 .34289 L
.73739 .44992 L
.7398 .49371 L
.74103 .51165 L
.74235 .52713 L
.74298 .53316 L
.74359 .53793 L
.74417 .5417 L
.74472 .54439 L
.74523 .54623 L
.74549 .5469 L
.74563 .54718 L
.74578 .54742 L
.74593 .54761 L
.74606 .54774 L
.74621 .54781 L
.74629 .54783 L
.74637 .54783 L
.74651 .54779 L
.74664 .54771 L
.74679 .54756 L
.74693 .54736 L
.74722 .5468 L
.74749 .54607 L
.74779 .54505 L
.7481 .54369 L
.74875 .54012 L
.74935 .53592 L
.75049 .52533 L
.75157 .5124 L
.75397 .47466 L
.75619 .43023 L
.76092 .31684 L
.76547 .20527 L
.768 .15172 L
.77031 .1121 L
.77149 .0963 L
.77258 .08448 L
.77372 .07529 L
.77433 .07177 L
.77464 .07032 L
Mistroke
.77497 .06907 L
.77528 .06817 L
.77544 .0678 L
.77562 .06747 L
.77578 .06724 L
.77592 .0671 L
.77607 .067 L
.77621 .06697 L
.77629 .06697 L
.77637 .06699 L
.77646 .06703 L
.77654 .06709 L
.77669 .06724 L
.77685 .06747 L
.77702 .0678 L
.77721 .06824 L
.77755 .06926 L
.77814 .07183 L
.7787 .07506 L
.77997 .0854 L
.78124 .09959 L
.78243 .11641 L
.78467 .15584 L
.78929 .26102 L
.79421 .38449 L
.79666 .44038 L
.79895 .48504 L
.80114 .51822 L
.80237 .5321 L
.8035 .54153 L
.80407 .54506 L
.80439 .54664 L
.80469 .54789 L
.80496 .54884 L
.80526 .54965 L
.80539 .54992 L
.80553 .55017 L
.80565 .55034 L
.80579 .55048 L
.80587 .55054 L
.80595 .55059 L
.80611 .55062 L
.80627 .55059 L
.80641 .55051 L
.8065 .55043 L
.80658 .55034 L
.80673 .55011 L
.8069 .54981 L
.80708 .54939 L
.80738 .54848 L
Mistroke
.8077 .54725 L
.80828 .54436 L
.80888 .54044 L
.80943 .53606 L
.81066 .52351 L
.81287 .49201 L
.81518 .44863 L
.81768 .39226 L
.82261 .26848 L
.82506 .20876 L
.82735 .15864 L
.82969 .1165 L
.83084 .09982 L
.83191 .08706 L
.83308 .07634 L
.83369 .07207 L
.83401 .07027 L
.83435 .06862 L
.83467 .06737 L
.83496 .06645 L
.83523 .06578 L
.83537 .06552 L
.83552 .0653 L
.83566 .06515 L
.83579 .06506 L
.83593 .06501 L
.83607 .06501 L
.8362 .06506 L
.83632 .06514 L
.83645 .06528 L
.83659 .06547 L
.83687 .06604 L
.83717 .06687 L
.83771 .06897 L
.8383 .07208 L
.83893 .07651 L
.84007 .08703 L
.84114 .09968 L
.8436 .13874 L
.84584 .18417 L
.85066 .30137 L
.8553 .41616 L
.85765 .46623 L
.85889 .48908 L
.86023 .51018 L
.86151 .52664 L
.86268 .53823 L
.86325 .54257 L
.86386 .54636 L
.86414 .54777 L
Mistroke
.86444 .54904 L
.8647 .54994 L
.86498 .55072 L
.86513 .55105 L
.86529 .55134 L
.86538 .55147 L
.86547 .55157 L
.86555 .55165 L
.86563 .55171 L
.86577 .55178 L
.86593 .55179 L
.86607 .55174 L
.86622 .55163 L
.86638 .55144 L
.86655 .55117 L
.86686 .55048 L
.86723 .54932 L
.86757 .54795 L
.86813 .54495 L
.86875 .54072 L
.87 .52923 L
.87124 .51403 L
.87237 .49719 L
.87489 .45019 L
.87972 .33613 L
.88436 .21936 L
.88672 .16652 L
.8893 .11849 L
.89049 .10096 L
.89176 .08571 L
.89238 .07975 L
.89296 .07497 L
.89353 .07119 L
.89406 .0684 L
.89435 .06718 L
.89467 .06613 L
.89495 .0654 L
.89508 .06514 L
.89522 .06492 L
.89537 .06474 L
.8955 .06462 L
.89559 .06457 L
.89567 .06454 L
.89582 .06454 L
.89598 .0646 L
.89612 .06471 L
.8962 .0648 L
.89628 .06491 L
.89645 .06519 L
.89674 .06584 L
Mistroke
.89701 .06663 L
.8976 .0691 L
.89815 .07221 L
.89867 .0759 L
.89983 .08654 L
.90106 .10146 L
.90328 .13684 L
.90829 .24723 L
.91313 .36962 L
.91777 .47306 L
.92018 .51263 L
.92139 .52777 L
.92207 .53475 L
.92272 .54029 L
.92331 .54441 L
.92362 .54621 L
.92395 .54785 L
.92423 .54901 L
.92453 .55004 L
.92481 .55077 L
.92507 .55126 L
.92522 .55146 L
.9253 .55154 L
.92538 .55161 L
.92554 .55168 L
.92563 .5517 L
.92571 .55169 L
.92585 .55164 L
.926 .55152 L
.92615 .55135 L
.92629 .55114 L
.92659 .5505 L
.92692 .54951 L
.92727 .54815 L
.92759 .5466 L
.9282 .543 L
.92885 .53801 L
.93004 .52616 L
.93228 .49491 L
.93465 .45048 L
.93718 .39356 L
.94221 .26721 L
.94473 .20585 L
.94704 .15568 L
.94945 .1131 L
.95063 .09669 L
.9517 .08456 L
.9528 .07505 L
.9534 .07113 L
.95397 .06831 L
Mistroke
.95428 .06717 L
.9546 .06622 L
.95487 .06563 L
.95502 .06538 L
.95517 .06521 L
.95533 .06508 L
.95541 .06505 L
.9555 .06503 L
.95565 .06504 L
.95579 .06511 L
.95588 .06518 L
.95597 .06527 L
.95612 .06548 L
.95629 .06577 L
.95647 .06618 L
.95675 .067 L
.95706 .06811 L
.95761 .07076 L
.95827 .07495 L
.95887 .07975 L
.96017 .09326 L
.96141 .10979 L
.96381 .15109 L
.96603 .19823 L
.97076 .31489 L
.97531 .4258 L
.97619 .44497 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wo
oo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0
003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooook
J_oooo]Z5?oonfX002Wooo]Z1Ol0002?oookJPCo0000oooonfZ0oookJP00:OoonfX5o`0006oooo]Z
1Ol0000KoookJPGo0000oooonfYooookJP00:OoonfX5o`0006oooo]Z1Ol0000JoookJPKo0000oooo
nfYooookJP00:OoonfX5o`0006oooo]Z1Ol0000JoookJPKo0000oooonfYooookJP003ooonfX9o`00
O`?ooo]Z1Ol007l9oookJPGo0000KooonfX5o`0001[ooo]Z1_l0003ooookJWoooo]Z000?oookJPWo
001o0_oonfX7o`00O`Sooo]Z1Ol0001_oookJPKo00006OoonfX6o`000?oooo]ZOooonfX000oooo]Z
1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006oooo]Z1_l0000IoookJPKo
0000oooonfYooookJP000ooonfX:o`00O`?ooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Oooo]Z
1Ol0001^oookJPOo00006OoonfX7o`0001[ooo]Z1?l0003ooookJV3ooo]Z0003oookJP[o001o1?oo
nfX5o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`0006cooo]Z1ol0000IoookJPOo00006Ooo
nfX6o`000?oooo]ZGooonfX001?ooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001^
oookJPOo00006OoonfX7o`0001Wooo]Z1_l0003ooookJUoooo]Z000DoookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000K_oonfX7o`0001Wooo]Z1ol0000IoookJPKo0000oooonfYOoook
JP005OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000K_oonfX7o`00
01Wooo]Z1ol0000IoookJPKo0000oooonfYOoookJP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o1ooonfX5o`0006kooo]Z1ol0000HoookJPSo00006OoonfX6o`00
0?oooo]ZGooonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Oooo]Z1Ol0001^oookJPOo00006?oonfX8o`0001Wooo]Z1_l0003ooookJUoooo]Z000?oookJPCo
001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000K_oonfX7o`00
01Sooo]Z2?l0000IoookJPOo0000oooonfYNoookJP004?oonfX7o`00O`?ooo]Z1ol007l8oookJPGo
0000D?oonfX4o`0001[ooo]Z1ol0000HoookJPSo00006OoonfX7o`000?oooo]ZG_oonfX0017ooo]Z
1Ol007l5oookJPGo001o2OoonfX5o`00053ooo]Z1Ol0000IoookJPOo00006?oonfX8o`0001Sooo]Z
2?l0003ooookJUkooo]Z000YoookJPGo0000D?oonfX5o`0001Wooo]Z2?l0000GoookJPSo00006?oo
nfX8o`0001_ooo]Z0_l0003ooookJT7ooo]Z000YoookJPGo0000D?oonfX5o`0001Wooo]Z2?l0000G
oookJPSo00006?oonfX8o`0001[ooo]Z1?l0003ooookJT3ooo]Z000YoookJPGo0000CooonfX6o`00
01Wooo]Z2?l0000GoookJPSo00006?oonfX8o`0001Wooo]Z1_l0003ooookJSoooo]Z000YoookJPGo
0000CooonfX7o`0001Oooo]Z2Ol0000GoookJPWo00005ooonfX8o`0001Wooo]Z1_l0003ooookJSoo
oo]Z000YoookJPGo0000CooonfX7o`0001Oooo]Z2Ol0000GoookJPWo00005ooonfX8o`0001Wooo]Z
1_l0003ooookJSoooo]Z000YoookJPGo0000CooonfX7o`0001Oooo]Z2Ol0000GoookJPWo00005ooo
nfX8o`0001Wooo]Z1_l0003ooookJSoooo]Z000YoookJPGo0000CooonfX7o`0001Oooo]Z1?l00000
0ooonf[o0000o`000002o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z2Ol0000I
oookJPKo0000oooonfXooookJP00:OoonfX5o`0004oooo]Z1ol0000GoookJPCo000000?ooo]Zo`00
0?l000000_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPWo00006OoonfX7o`00
0?oooo]Z?_oonfX002Wooo]Z1Ol0001?oookJPOo00005ooonfX4o`000003oookJ_l0003o000000;o
00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX9o`0001Sooo]Z2?l0003ooookJSko
oo]Z000YoookJPGo0000CooonfX7o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`000003oookJ_l0003o000000;o00006?oonfX8o`000?oooo]Z
?_oonfX002Wooo]Z1Ol0001?oookJPSo00005_oonfX4o`000003oookJ_l0003o000000;o00005_oo
nfX4o`0000;ooo]Z1?l0000FoookJPCo000000?ooo]Zo`000?l000000_l0000HoookJPSo00006_oo
nfX5o`000;kooo]Z1?l0000LoookJPCo00007?oonfX5o`0001_ooo]Z000YoookJPGo0000CooonfX8
o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`000003oookJ_l0003o000000;o00006?oonfX8o`0001[ooo]Z1Ol0002MoookJPGo00006ooonfX5
o`0001_ooo]Z1_l0000KoookJPGo00006ooonfX002Wooo]Z1Ol0001>oookJPWo00005_oonfX4o`00
0003oookJ_l0003o000000;o00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo000000?ooo]Zo`00
0?l000000_l0000HoookJPSo00006OoonfX6o`0009gooo]Z1Ol0000KoookJPKo00006_oonfX6o`00
01_ooo]Z1Ol0000KoookJP00:OoonfX5o`0004kooo]Z2Ol0000EoookJPGo000000?ooo]Zo`000?l0
00000_l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l000000ooonf[o0000o`000002o`0001So
oo]Z2?l0000IoookJPKo0000OOoonfX4o`0001cooo]Z1Ol0000KoookJPKo00006_oonfX6o`0001_o
oo]Z1Ol0000KoookJP00:OoonfX5o`0004kooo]Z2Ol0000EoookJPGo000000?ooo]Zo`000?l00000
0_l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z
2?l0000IoookJPOo0000O?oonfX5o`0001[ooo]Z1ol0000JoookJPKo00006_oonfX6o`0001[ooo]Z
1_l0000KoookJP00:OoonfX5o`0004kooo]Z1?l000000ooonf[o0000o`000002o`0001Gooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`000003oookJ_l0
003o000000?o00005ooonfX8o`0001Wooo]Z1ol0000LoookJP;o0000?_oonfX4o`0001_ooo]Z1_l0
000JoookJPOo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPOo00006_oonfX002Wooo]Z1Ol0001>
oookJPCo000000?ooo]Zo`000?l000000_l0000EoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003
oookJPCo00005OoonfX4o`000003oookJ_l0003o000000?o00005ooonfX8o`0001Wooo]Z1ol0000J
oookJPGo0000??oonfX5o`0001_ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001[ooo]Z1ol0000I
oookJPOo00006_oonfX002Wooo]Z1Ol0001>oookJPCo000000?ooo]Zo`000?l000000_l0000Eoook
JPCo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`000003oookJ_l0003o0000
00?o00005ooonfX8o`0001Wooo]Z1ol0000JoookJPKo00006ooonfX5o`0001_ooo]Z1_l0000Joook
JPKo00006_oonfX7o`0001Wooo]Z1ol0000JoookJPOo00006OoonfX7o`0001[ooo]Z000YoookJPGo
0000C_oonfX4o`000003oookJ_l0003o000000;o00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPCo
00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005ooonfX9o`0001Oooo]Z2?l0000JoookJPKo
00006ooonfX5o`0001_ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001Wooo]Z1ol0000IoookJPSo
00006OoonfX7o`0001[ooo]Z000YoookJPGo0000C_oonfX4o`000003oookJ_l0003o000000;o0000
5OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo0000
5_oonfX:o`0001Oooo]Z2?l0000JoookJPKo00006_oonfX6o`0001_ooo]Z1_l0000JoookJPOo0000
6OoonfX8o`0001Sooo]Z1ol0000IoookJPSo00006?oonfX8o`0001[ooo]Z000YoookJPGo0000COoo
nfX5o`000003oookJ_l0003o000000;o00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooo
nfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX:o`0001Oooo]Z2Ol0000IoookJPKo00006_oo
nfX7o`0001[ooo]Z1_l0000IoookJPSo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oo
nfX8o`0001[ooo]Z000YoookJPGo0000COoonfX5o`000003oookJ_l0003o000000;o00005OoonfX4
o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX5
o`000003oookJ_l0003o000000;o00005ooonfX9o`0001Sooo]Z1ol0000JoookJPOo00006OoonfX7
o`0001Wooo]Z2?l0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006_oonfX0
02Wooo]Z1Ol0001=oookJPGo000000?ooo]Zo`000?l000000_l0000EoookJPCo00000ooonfX4o`00
01Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Oooo]Z2Ol0000HoookJPOo00006_oonfX7o`0001Wooo]Z1ol0000IoookJPSo00006OoonfX8o`00
01Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001[ooo]Z000YoookJPGo0000COoonfX4o`0000;o
oo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000;o
oo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001So
oo]Z1ol0000JoookJPOo00006OoonfX7o`0001Wooo]Z2?l0000IoookJPSo00006?oonfX8o`0001So
oo]Z2?l0000HoookJPWo00006OoonfX002Wooo]Z1Ol0001=oookJPCo00000_oonfX4o`0001Gooo]Z
1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX8o`0001Wooo]Z
1ol0000IoookJPOo00006OoonfX8o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z
2Ol0000IoookJP00:OoonfX5o`0004gooo]Z1?l00002oookJPCo00005OoonfX4o`0000?ooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000GoookJPCo000000?ooo]Zo`000?l000000_l0000HoookJPSo00006OoonfX7o`0001Wooo]Z2?l0
000HoookJPSo00006?oonfX9o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX9o`0001Wooo]Z000Y
oookJPGo0000COoonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Cooo]Z1Ol00003
oookJPCo00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Oooo]Z1?l00000
0ooonf[o0000o`000002o`0001Sooo]Z2?l0000IoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000H
oookJPWo00005ooonfX:o`0001Kooo]Z2Ol0000HoookJPCo000000?ooo]Zo`000?l000000_l0000I
oookJP00:OoonfX5o`0004gooo]Z1?l00002oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000Doook
JPGo00000ooonfX4o`0001Cooo]Z1Ol00002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000Foook
JPGo000000?ooo]Zo`000?l000000_l0000HoookJPSo00006?oonfX8o`0001Wooo]Z2?l0000Hoook
JPSo00006?oonfX9o`0001Oooo]Z2_l0000FoookJP[o00005ooonfX4o`000003oookJ_l0003o0000
00;o00006OoonfX002Wooo]Z1Ol0001=oookJPCo00000_oonfX4o`0001Gooo]Z1?l00003oookJPCo
00005?oonfX5o`0000?ooo]Z1?l0000DoookJPGo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo
00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX9o`0001Sooo]Z2?l0000IoookJPSo
00006?oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z2_l0000FoookJP[o
00005ooonfX4o`000003oookJ_l0003o000000;o00006OoonfX002Wooo]Z1Ol0001=oookJPCo0000
0_oonfX4o`0001Gooo]Z1?l00003oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo0000
0ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o0000
5ooonfX9o`0001Sooo]Z2Ol0000HoookJPSo00006?oonfX9o`0001Oooo]Z1?l000000ooonf[o0000
o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`000003oookJ_l0003o000000?o0000
5ooonfX4o`000003oookJ_l0003o000000;o00006OoonfX002Wooo]Z1Ol0001=oookJPCo00000_oo
nfX5o`0001Cooo]Z1?l00003oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oo
nfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPWo00006?oo
nfX9o`0001Sooo]Z2?l0000HoookJPWo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`00
0002o`0001Wooo]Z000YoookJPGo0000<OoonfX5o`0001Oooo]Z1?l00002oookJPGo00005?oonfX4
o`0000?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000003
o`0001Oooo]Z2Ol0000HoookJPSo00006?oonfX9o`0001Oooo]Z1?l000000ooonf[o0000o`000002
o`0001Oooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Z
o`000?l000000ol0000HoookJP00:OoonfX5o`00037ooo]Z1Ol0000GoookJPCo00000_oonfX5o`00
01Cooo]Z1?l00003oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`00
01Gooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`00
0?l000000ol0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJP[o00005_oonfX5o`00
0003oookJ_l0003o000000;o00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX4o`00
00;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`000003o`00
01Sooo]Z000YoookJPGo0000<?oonfX6o`0001Oooo]Z1?l00003oookJPCo00005?oonfX4o`0000?o
oo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000;o
oo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Oo
oo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z2_l0000FoookJPGo000000?ooo]Zo`000?l0
00000_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o000000?o00006?oonfX002Wooo]Z
1Ol0000`oookJPKo00005ooonfX4o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Cooo]Z
1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0000EoookJPCo00000_oonfX5o`0001Gooo]Z
1?l00002oookJPCo00005ooonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJP[o00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX5o`000003oook
J_l0003o000000?o00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1Ol00002oookJPCo00006?oonfX002Wooo]Z1Ol0000`oookJPKo00005ooonfX4o`0000?ooo]Z1?l0
000DoookJPCo00000ooonfX5o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0
000EoookJPCo00000_oonfX5o`0001Gooo]Z1?l00002oookJPCo00005ooonfX4o`0000;ooo]Z1?l0
000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000HoookJP00:OoonfX5o`00033ooo]Z1ol0000F
oookJPCo00000ooonfX4o`0001Cooo]Z1?l00003oookJPGo00004ooonfX4o`0000Cooo]Z1Ol0000C
oookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000G
oookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1Ol00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000ooonfX4o`0001Sooo]Z000Yoook
JPGo0000<?oonfX7o`0001Kooo]Z1?l00003oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000Coook
JPCo00001OoonfX4o`0001?ooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000Eoook
JPCo00000_oonfX4o`0001Oooo]Z1?l00002oookJPCo00005ooonfX4o`000003oookJ_l0003o0000
00;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oook
JPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oook
JPCo00006?oonfX002Wooo]Z1Ol0000`oookJPOo00005_oonfX4o`0000?ooo]Z1?l0000DoookJPCo
00001?oonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000EoookJPCo
00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005ooonfX4o`0000;ooo]Z1?l0000GoookJPCo
000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPGo
00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`0000?ooo]Z1?l0000HoookJP00:OoonfX5o`00033ooo]Z1ol0000FoookJPCo0000
0ooonfX4o`0001Cooo]Z1?l00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
1?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPGo0000
0_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000ooonfX4o`0001Sooo]Z000YoookJPGo0000<?oo
nfX7o`0001Kooo]Z1?l00003oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000EoookJPCo00000_oo
nfX5o`0001Gooo]Z1Ol00002oookJPCo00005ooonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005Ooo
nfX4o`0000?ooo]Z1Ol0000EoookJPCo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00006?oo
nfX002Wooo]Z1Ol0000`oookJPOo00005_oonfX4o`0000?ooo]Z1?l0000CoookJPGo00001?oonfX4
o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4
o`0001Gooo]Z1?l00002oookJPGo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPGo000000?ooo]Z
o`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4
o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Gooo]Z1?l00002oookJPGo00005OoonfX4
o`0000?ooo]Z1?l0000HoookJP00:OoonfX5o`0002oooo]Z2?l0000FoookJPCo00000ooonfX5o`00
01;ooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001?oonfX4o`00
01Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000ooonfX4o`00
01Kooo]Z1Ol000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`00
00?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005OoonfX4o`00
00;ooo]Z1Ol0000EoookJPCo00000ooonfX4o`0001Sooo]Z000YoookJPGo0000;ooonfX8o`0001Go
oo]Z1Ol00003oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Go
oo]Z1?l00003oookJPCo00005_oonfX5o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;o
oo]Z1?l0000FoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Co
oo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00006?oonfX002Wooo]Z
1Ol0000_oookJPSo00005OoonfX5o`0000?ooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z
1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000EoookJPCo00000_oonfX5o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z
1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Sooo]Z
000YoookJPGo0000;ooonfX9o`0001Cooo]Z1Ol00004oookJPCo00004_oonfX4o`0000Gooo]Z1?l0
000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005OoonfX4o`0000?ooo]Z1?l0
000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0
000HoookJP00:OoonfX5o`0002oooo]Z2Ol0000DoookJPCo00001OoonfX4o`0001;ooo]Z1?l00005
oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Gooo]Z1?l00003
oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000EoookJPGo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00003
oookJPGo00005ooonfX002Wooo]Z1Ol0000_oookJPWo00005?oonfX4o`0000Gooo]Z1?l0000Boook
JPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Cooo]Z1Ol0000Coook
JPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1Ol00002oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000Doook
JPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000Eoook
JPCo00000ooonfX5o`0001Oooo]Z000YoookJPGo0000;_oonfX5o`000003oookJ_l0003o000000;o
00005?oonfX4o`0000Gooo]Z1?l0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo
00004_oonfX5o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo
00005OoonfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo
00005OoonfX5o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo
00005?oonfX5o`0000?ooo]Z1?l0000DoookJPGo00000ooonfX5o`0001Oooo]Z000YoookJPGo0000
;_oonfX5o`000003oookJ_l0003o000000;o00005?oonfX4o`0000Gooo]Z1?l0000BoookJPCo0000
1OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX5o`0000Cooo]Z1Ol0000CoookJPCo0000
1?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPGo0000
0ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo0000
1?oonfX4o`0001Oooo]Z000YoookJPGo0000;_oonfX5o`000003oookJ_l0003o000000;o00005?oo
nfX4o`0000Gooo]Z1?l0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oo
nfX5o`0000Gooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005Ooo
nfX4o`0000Cooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005Ooo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX5o`0001?ooo]Z1Ol00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPGo00001?oonfX4o`0001Oooo]Z000YoookJPGo0000;_oonfX4
o`0000;ooo]Z1?l0000DoookJPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPCo00004ooonfX4
o`0000Gooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4
o`0000Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005OoonfX4
o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX5
o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00005ooonfX0
02Wooo]Z1Ol0000^oookJPCo00000_oonfX4o`0001Cooo]Z1?l00005oookJPCo00004_oonfX4o`00
00Gooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5o`00
00?ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Gooo]Z1?l0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Gooo]Z1?l0000GoookJP00:OoonfX5o`0002kooo]Z1?l00002oookJPCo00005?oonfX4o`0000Go
oo]Z1?l0000BoookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Co
oo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Co
oo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Co
oo]Z1?l0000DoookJPCo00001OoonfX4o`0001Oooo]Z000YoookJPGo0000;_oonfX4o`0000;ooo]Z
1?l0000DoookJPCo00001OoonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Gooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z
1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00005ooonfX002Wooo]Z1Ol0
000^oookJPCo00000_oonfX4o`0001Cooo]Z1?l00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000BoookJPCo00001OoonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0
000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0
000GoookJP00:OoonfX5o`0002kooo]Z1?l00002oookJPCo00004ooonfX5o`0000Gooo]Z1?l0000B
oookJPCo00001_oonfX4o`00017ooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000C
oookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001OoonfX4o`0001Oooo]Z000YoookJPGo0000;_oonfX4o`0000;ooo]Z1Ol0000Boook
JPGo00001OoonfX4o`00017ooo]Z1Ol00006oookJPCo00004OoonfX5o`0000Gooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Eoook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00005ooonfX002Wooo]Z1Ol0000^oookJPCo
00000_oonfX5o`0001;ooo]Z1Ol00005oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000AoookJPGo
00001OoonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000CoookJPCo
00001?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo
00001OoonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000GoookJP00
:OoonfX5o`0002kooo]Z1?l00002oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo0000
1_oonfX4o`00017ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo0000
1OoonfX5o`0001?ooo]Z1?l00004oookJPCo00005?oonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
1OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1OoonfX4o`0001Oooo]Z000YoookJPGo0000;_oonfX4o`0000?ooo]Z1?l0000BoookJPCo00001_oo
nfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Cooo]Z1Ol0000CoookJPGo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000DoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPGo00001?oo
nfX5o`0001?ooo]Z1?l00005oookJPCo00005ooonfX002Wooo]Z1Ol0000^oookJPCo00000ooonfX4
o`0001;ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001?oonfX5
o`0001?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1Ol00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000GoookJP00:OoonfX5o`00
02kooo]Z1?l00003oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000@oookJPCo00001ooonfX4o`00
017ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1Ol00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5o`00
01?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4o`00
01Oooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0000^oookJPCo00000ooonfX4o`0001;o
oo]Z1?l00006oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001_oonfX5o`00017o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?o
oo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPGo00001?oonfX4o`0001Co
oo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;o
oo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000GoookJP004ooonfX3o`00O`Cooo]Z
1ol007l8oookJPGo0000;_oonfX4o`0000?ooo]Z1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z
1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z
1?l00004oookJPGo00004ooonfX5o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001?ooo]Z
1?l00005oookJPCo00005ooonfX001?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`0002gooo]Z1Ol00003oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo0000
1ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo0000
1_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo0000
1OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo0000
1OoonfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo0000
1OoonfX4o`0001Oooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0002gooo]Z1Ol00003oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooo
nfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00005oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001Oooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7
o`0002_ooo]Z1Ol00003oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001Oooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000;OoonfX4o`00
00Cooo]Z1?l0000BoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX4o`00
00Oooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000CoookJPCo00001OoonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPCo00005ooonfX001?o
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000]oookJPCo00001?oonfX4o`0001;o
oo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?o
oo]Z1?l00005oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;o
oo]Z1Ol00005oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000GoookJP004ooonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0002gooo]Z1?l00004oookJPCo00004_oonfX4o`0000Oooo]Z
1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Kooo]Z
1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000CoookJPCo00001OoonfX5o`0001Kooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol0
07l7oookJPGo0000;OoonfX4o`0000Cooo]Z1?l0000BoookJPCo00001ooonfX4o`00013ooo]Z1?l0
0007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1Ol0
0005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l0
0005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l0
0005oookJPGo00005_oonfX0013ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000]
oookJPCo00001?oonfX4o`0001;ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000A
oookJPCo00001ooonfX4o`00013ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000C
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000F
oookJP004?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000;OoonfX4
o`0000Cooo]Z1?l0000BoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX4
o`0000Oooo]Z1?l0000@oookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00005_oonfX0
01;ooo]Z1?l007l4oookJPOo001o2?oonfX5o`0002gooo]Z1?l00004oookJPCo00004_oonfX4o`00
00Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX5o`00
00Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`00
00Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPGo00001_oonfX4o`0001Kooo]Z000CoookJP?o001o1OoonfX5o`00O`Wo
oo]Z1Ol0000]oookJPCo00001?oonfX4o`0001;ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oo
oo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oo
oo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Ko
oo]Z1?l0000FoookJP00:OoonfX5o`0002cooo]Z1Ol00004oookJPCo00004_oonfX4o`0000Oooo]Z
1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001ooonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001ooonfX4o`0001Kooo]Z000YoookJPGo0000;?oonfX5o`0000Cooo]Z1?l0
000BoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000@oookJPCo00001ooonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00005_oonfX002Wooo]Z1Ol0000/
oookJPGo00001?oonfX5o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000A
oookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000A
oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000F
oookJP00:OoonfX5o`0002cooo]Z1?l00005oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000@oook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000Aoook
JPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001ooonfX4o`0001Kooo]Z000YoookJPGo0000;?oonfX4o`0000Gooo]Z1Ol0000@oookJPGo
00001ooonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo
00001ooonfX5o`00013ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo
00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00005_oonfX002Wooo]Z1Ol0000/oookJPCo0000
1_oonfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo0000
1ooonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000AoookJPGo0000
1ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo0000
1ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
1ooonfX4o`00017ooo]Z1Ol00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:Ooo
nfX5o`0002cooo]Z1?l00006oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00001ooo
nfX5o`00013ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooo
nfX5o`00013ooo]Z1Ol00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX5o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooo
nfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1Ol0000AoookJPCo00001ooo
nfX4o`0001Kooo]Z000YoookJPGo0000;?oonfX4o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00007oookJPGo00004?oonfX5o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX5
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4
o`00017ooo]Z1?l00007oookJPCo00005_oonfX002Wooo]Z1Ol0000/oookJPCo00001_oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00
017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00
01;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00
017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:OoonfX5o`0001;o
oo]Z1Ol0000EoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000So
oo]Z1?l0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Oo
oo]Z1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oo
oo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oo
oo]Z1?l0000FoookJP00:OoonfX5o`0001;ooo]Z1Ol0000EoookJPCo00001_oonfX4o`00013ooo]Z
1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000?oookJPGo00001ooonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z
1Ol00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z
1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00013ooo]Z
1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:OoonfX5o`00017ooo]Z1ol0
000DoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0
000?oookJPGo00001ooonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Oooo]Z1?l0
000AoookJPCo00001ooonfX5o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00001ooonfX5o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000FoookJP00:OoonfX5o`00017ooo]Z1ol0000DoookJPCo00001_oonfX4o`00013ooo]Z1?l00008
oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00001ooonfX5o`0000oooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007
oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1Ol00007
oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z1?l00008
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:OoonfX5o`00017ooo]Z1ol0000Doook
JPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000Foook
JP00:OoonfX5o`00017ooo]Z1ol0000DoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPGo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo
00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:OoonfX5o`00013ooo]Z2Ol0000CoookJPCo0000
1_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2OoonfX4o`0000kooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00017ooo]Z1?l00007oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000FoookJP00:Ooo
nfX5o`00013ooo]Z2Ol0000CoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1Ol00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000FoookJP00:OoonfX5o`00013ooo]Z2Ol0000CoookJPCo00001_oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000kooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00017ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000EoookJP00:OoonfX5o`00
013ooo]Z1?l000000ooonf[o0000o`000002o`0001?ooo]Z1?l00006oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`00
00Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00
00Sooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000AoookJPCo00001ooonfX5o`0001Gooo]Z000YoookJPGo00003ooonfX5o`000003
oookJ_l0003o000000?o00004OoonfX5o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX5o`0000ko
oo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`00013o
oo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013o
oo]Z1Ol00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00017o
oo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013o
oo]Z1Ol00007oookJPGo00005OoonfX002Wooo]Z1Ol0000?oookJPGo000000?ooo]Zo`000?l00000
0ol0000AoookJPGo00001_oonfX4o`00013ooo]Z1?l00008oookJPGo00003_oonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Oooo]Z
1Ol0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Sooo]Z
1?l0000EoookJP00:OoonfX5o`0000oooo]Z1Ol000000ooonf[o0000o`000003o`00017ooo]Z1Ol0
0006oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX5o`0000oooo]Z1Ol0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00002?oonfX4o`0001Gooo]Z000Y
oookJPGo00003ooonfX4o`0000?ooo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00009
oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000EoookJP00:OoonfX5o`0000oooo]Z1?l00003oook
JPCo00004OoonfX4o`0000Oooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Sooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00008oook
JPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oook
JPCo00005OoonfX002Wooo]Z1Ol0000?oookJPCo00000ooonfX4o`00017ooo]Z1?l00007oookJPGo
00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo
00003_oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0001Gooo]Z000YoookJPGo0000
3ooonfX4o`0000?ooo]Z1?l0000AoookJPCo00001ooonfX5o`0000oooo]Z1?l00009oookJPCo0000
3_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPGo0000
3ooonfX4o`0000Wooo]Z1?l0000EoookJP00:OoonfX5o`0000oooo]Z1?l00003oookJPCo00004Ooo
nfX4o`0000Sooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00005Ooo
nfX002Wooo]Z1Ol0000?oookJPCo00000ooonfX4o`00017ooo]Z1?l00008oookJPCo00003ooonfX4
o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4
o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX5
o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0001Gooo]Z000YoookJPGo00003ooonfX4o`00
00?ooo]Z1?l0000AoookJPCo00002?oonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`00
00Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000EoookJP00:OoonfX5o`0000oooo]Z1?l00003oookJPCo00004OoonfX4o`0000So
oo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wo
oo]Z1?l0000>oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPGo00003ooonfX4o`0000Wo
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wo
oo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX5o`0000So
oo]Z1?l0000?oookJPGo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00005OoonfX002Wooo]Z
1Ol0000>oookJPGo00000ooonfX5o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX5o`0000Sooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00003ooonfX5o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0001Gooo]Z000YoookJPGo00003_oonfX5o`0000?ooo]Z1Ol0
000@oookJPCo00002?oonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0
000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1Ol0
000>oookJPGo00002?oonfX5o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0
000EoookJP00:OoonfX5o`0000kooo]Z1Ol00003oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002OoonfX4o`00013ooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPGo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002OoonfX5o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1Ol0000>
oookJPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo00005OoonfX002Wooo]Z1Ol0000>oook
JPCo00001OoonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oook
JPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oook
JPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000?oook
JPCo00002OoonfX5o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000?oook
JPCo00002OoonfX4o`0001Gooo]Z000YoookJPGo00003_oonfX4o`0000Gooo]Z1?l0000@oookJPCo
00002?oonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000kooo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000EoookJP00
:OoonfX5o`0000kooo]Z1?l00005oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000?oookJPCo0000
2OoonfX4o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo0000
2OoonfX5o`0000kooo]Z1Ol00009oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00009oookJPCo00005OoonfX002Wooo]Z1Ol0000>oookJPCo00001Ooo
nfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l00009oookJPGo00003OoonfX4o`0000Wooo]Z1Ol0000>oookJPGo00002Ooo
nfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002Ooo
nfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002Ooo
nfX4o`0001Gooo]Z000YoookJPGo00003_oonfX4o`0000Gooo]Z1Ol0000?oookJPCo00002?oonfX4
o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX5
o`0000gooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4
o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4
o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000EoookJP00:OoonfX5o`00
00kooo]Z1?l00005oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPGo00002OoonfX4o`00
00kooo]Z1?l00009oookJPCo00003_oonfX5o`0000Wooo]Z1Ol0000=oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1Ol00009oookJPGo00005?oonfX002Wooo]Z1Ol0000=oookJPGo00001OoonfX5o`0000oo
oo]Z1?l00008oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000ko
oo]Z1Ol0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0001Co
oo]Z000YoookJPGo00003OoonfX5o`0000Kooo]Z1?l0000?oookJPCo00002?oonfX4o`0000kooo]Z
1Ol00009oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000oooo]Z
1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX5o`0000kooo]Z
1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000DoookJP00:OoonfX5o`0000gooo]Z1Ol0
0006oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
0009oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000;oookJPCo00005?oonfX002Wooo]Z1Ol0000=oookJPCo00001ooonfX4o`0000oooo]Z1?l00008
oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000;
oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002OoonfX5o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001Cooo]Z000Yoook
JPGo00003OoonfX4o`0000Oooo]Z1?l0000?oookJPCo00002?oonfX5o`0000gooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000Wooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX5o`0000Wooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000DoookJP00:OoonfX5o`0000gooo]Z1?l00007oookJPCo
00003ooonfX4o`0000Sooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l00009oookJPGo
00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPGo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo
00005?oonfX002Wooo]Z1Ol0000=oookJPCo00001ooonfX4o`0000oooo]Z1?l00009oookJPCo0000
3OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000gooo]Z1?l0000;oookJPCo0000
3?oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0001Cooo]Z000YoookJPGo00003?oo
nfX5o`0000Oooo]Z1?l0000>oookJPGo00002OoonfX4o`0000gooo]Z1?l0000:oookJPCo00003_oo
nfX4o`0000Wooo]Z00?o001oo`000?l000000_l00005oookJPGo001o0ooonfX4o`0000_ooo]Z1?l0
000<oookJPGo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Oooo]Z0ol0
07l00ooonf[o0000o`000002o`0000Go001o1OoonfX3o`00O`Go00002_oonfX4o`0000kooo]Z1?l0
000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00001_oonfX3o`00O`03oookJ_l0
003o000000;o00001Ol007l5oookJPCo001o1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l000000ooonf[o001oo`00O`07o`00O`03oookJ_l0
003o000000;o00000ol007l5oookJPGo001o1ooonfX002Wooo]Z1Ol0000<oookJPGo00001ooonfX4
o`0000kooo]Z1Ol00009oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002?oonfX2
o`00O`Co000000Co001ooookJ_oonf[ooo]Z1ol007l2oookJPCo00002ooonfX4o`0000cooo]Z1?l0
000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00001ooonfX3o`00O`03oookJ_l0
003o000000;o00001_l007l3oookJPCo001o1Ol0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00006oookJP?o001o00?ooo]Zo`000?l000000_l0
0006o`00O`?ooo]Z1Ol007l4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`000003oookJ_l007oo001o00Oo001o00?ooo]Zo`000?l000000_l0
0004o`00O`?ooo]Z1ol007l6oookJP00:OoonfX5o`0000cooo]Z1Ol00007oookJPCo00003_oonfX5
o`0000Wooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l00007oookJP?o001o1?l00000
1?l007oooo]ZoookJ_oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00007oookJP?o001o
00?ooo]Zo`000?l000000_l00002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
0000o`000003o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000Kooo]Z0ol007l00ooonf[o0000o`000002o`0000;o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l007oo000000?o00002ooonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo000000?ooo]Zo`00Ool007l00_l007l6oook
JPCo000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000Y
oookJPGo00003?oonfX4o`0000Sooo]Z1?l0000>oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000Oooo]Z0ol007l4o`0000;o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l0003o000000;o00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003_oo
nfX4o`0000[ooo]Z1?l0000>oookJPCo00001ooonfX3o`00O`03oookJ_l0003o000000;o000000Co
001ooookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00002ooonfX4o`0000ko
oo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00001_oonfX3o`00O`03
oookJ_l0003o000000;o000000Co001ooookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPCo00000_oonfX4o`00O`Gooo]Z1?l00002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Gooo]Z000YoookJPGo00003?oonfX4o`0000Sooo]Z1Ol0000=oookJPCo00002_oonfX4
o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z1?l00002o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000_ooo]Z1?l0000<oookJPCo00002ooo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Oooo]Z0ol007l00ooonf[o0000o`00
0002o`000004o`00Oooonf[ooo]ZoookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000_o
oo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000Ko
oo]Z0ol007l00ooonf[o0000o`000002o`0000Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z1Ol0000=oook
JPCo00000ooonfX5o`00O`?ooo]Z1?l00002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Gooo]Z000YoookJPGo00003?oonfX4o`0000Sooo]Z1Ol0000=oookJPCo00002_oonfX4o`00
00gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z1?l00002o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4
o`0000kooo]Z1?l0000:oookJPGo00003OoonfX4o`0000Oooo]Z0ol007l00ooonf[o0000o`000002
o`000004o`00Oooonf[ooo]ZoookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000_ooo]Z
1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000:oookJPCo00003OoonfX5o`0000Kooo]Z
0ol007l00ooonf[o0000o`000002o`0000Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo
00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z1Ol0000=oookJPCo
00001OoonfX4o`00O`;ooo]Z1?l00002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Gooo]Z000YoookJPGo00003?oonfX4o`0000Sooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000go
oo]Z1?l0000:oookJPCo00003OoonfX5o`0000Sooo]Z0_l007l4o`0000;o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`03oookJ_l0003o000000;o00002ooonfX4o`0000cooo]Z1?l0000;oook
JPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00001ooonfX3o`00O`03oookJ_l0003o0000
00;o000000Co001ooookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPCo00002ooo
nfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00001_oo
nfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_oonfX01?l007l01?oonf[o001oo`00
Ool007l3oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPGo00003?oonfX5o`0000[ooo]Z
1Ol0000=oookJPCo00001_oonfX3o`00O`;ooo]Z1?l00002oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z000YoookJPGo00002ooonfX5o`0000Wooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z0_l007l4o`000003o`00
Oooonf[ooo]Z00?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o00002ooonfX4o`0000cooo]Z
1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00001ooonfX3o`00O`03oook
J_l0003o000000;o000000Co001ooookJ_oonf[ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oook
JPCo00002ooonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oook
JPGo00001_oonfX3o`00O`03oookJ_l0003o000000?o00001Ol007l2oookJP?o001o0ooonfX4o`00
00_ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`00
00Oooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1OoonfX002Wooo]Z1Ol0000;oookJPGo00002OoonfX4o`0000gooo]Z1?l0000:oook
JPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPCo00002OoonfX2o`00O`Co00000ooonfX3o`00
O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`00
00kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Oooo]Z0ol007l00ooonf[o0000o`000002o`00
0004o`00Oooonf[ooo]ZoookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`0000cooo]Z1?l0
000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Oooo]Z0ol0
07l00ooonf[o0000o`000003o`0000Co001o0ooonfX3o`00O`?ooo]Z1?l0000;oookJPCo00003_oo
nfX4o`0000[ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l000001?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`000?l000000_l00002oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Gooo]Z000YoookJPGo00002ooonfX5o`0000Wooo]Z1?l0000=oookJPCo0000
2_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000Wooo]Z0_l007l4o`0000?ooo]Z
0ol007l3oookJP?o001o00?ooo]Zo`000?l000000_l0000;oookJPCo00003?oonfX4o`0000_ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l00004oookJPKo001o00?ooo]Zo`000?l00000
0_l000001?l007oooo]ZoookJ_oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l0000<oook
JPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l00004oook
JPKo001o00?ooo]Zo`000?l000000ol00007oookJP?o001o0ooonfX4o`0000_ooo]Z1?l0000>oook
JPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`000004oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1OoonfX002Wooo]Z1Ol0000;oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:
oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002OoonfX2o`00O`Co00001?oonfX3
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0
000>oookJPCo00002ooonfX4o`0000gooo]Z1?l00004oookJPKo001o00?ooo]Zo`000?l000000_l0
0002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000cooo]Z
1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000Cooo]Z
1_l007l2oookJPCo00002?oonfX3o`00O`03oookJ_l007oo000000?o00002ooonfX4o`0000gooo]Z
1Ol0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPGo000000?ooo]Zo`00Ool007l0
0_l007l2oookJP?o001o00?ooo]Zo`000?l000000_l000001?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o1_oonfX002Wooo]Z1Ol0000;oookJPCo00002_oonfX4o`0000go
oo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000<oookJPCo00002_oonfX00ol007oo
0000o`000002o`0000;o001o0_oonfX7o`00O`;ooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_o
oo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l00006oookJPCo001o00?ooo]Zo`000?l0
00000_l00006o`00O`?ooo]Z1?l007l4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX4o`0000go
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000Kooo]Z1?l007l2oookJPCo00001_l007l2oookJPGo
001o1?l0000;oookJPCo00003OoonfX5o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000co
oo]Z1Ol00002oookJPOo001o0_oonfX4o`0000Co001o0ooonfX7o`00O`Kooo]Z000YoookJPGo0000
2ooonfX4o`0000[ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1?l0000:oookJPGo0000
3?oonfX4o`0000[ooo]Z00?o001oo`000?l000000_l00002o`00O`?ooo]Z1Ol007l3oookJPCo0000
2ooonfX4o`0000cooo]Z1?l0000;oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo0000
1ooonfX3o`00O`03oookJ_l0003o000000;o00001Ol007l5oookJP?o001o1?l0000<oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l00007oookJP?o001o
0_oonfX4o`0000Ko001o0ooonfX4o`00O`Co00002ooonfX5o`0000cooo]Z1Ol0000;oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPCo00001?oonfX5o`00O`?ooo]Z1?l00003o`00O`Gooo]Z
1Ol007l7oookJP00:OoonfX5o`0000_ooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0
000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000<oookJPCo00002ooonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPGo00004ooonfX002Wooo]Z1Ol0000:
oookJPGo00002_oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000=
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000=
oookJPCo00002ooonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX5o`0001?ooo]Z000YoookJPGo00002_oonfX5o`0000[ooo]Z1?l0000=oook
JPCo00002_oonfX4o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX5o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000Coook
JP00:OoonfX5o`0000[ooo]Z1Ol0000:oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000<oookJPCo
00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo
00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000cooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo
00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo00004ooonfX002Wooo]Z1Ol0000:oookJPCo0000
2ooonfX4o`0000gooo]Z1?l0000:oookJPGo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo0000
2ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo0000
2ooonfX4o`0000gooo]Z1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPGo0000
2ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPGo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo0000
3OoonfX4o`0001?ooo]Z000YoookJPGo00002_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oo
nfX5o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooo
nfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oo
nfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000CoookJP007?oonf[o
o`000?oo00008ol00003oookJP007?oonf[oo`000?oo00008ol00003oookJP007?oonf[oo`000?oo
00008ol00003oookJP007?oonf[oo`000?oo00008ol00003oookJP007?oonf[oo`000?oo00008ol0
0003oookJP00:OoonfX5o`0000Wooo]Z1?l0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000;
oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPCo00000ooonfX00ol0003ooo]ZoookJP06
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003OoonfX4o`0000;ooo]Z00?o0000oookJ_oonfX01_oonfX5o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l00002
oookJP03o`000?oonf[ooo]Z00Oooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPGo00004_oonfX002Wooo]Z1Ol00008oook
JPGo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oook
JPCo00002ooonfX4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX5o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oook
JPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00002ooonfX5o`0000cooo]Z1?l0000<oook
JPCo00003OoonfX4o`0001?ooo]Z000YoookJPGo00002?oonfX5o`0000gooo]Z1?l0000;oookJPCo
00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo
00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000<oookJPCo
00003?oonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000CoookJP00
:OoonfX5o`0000Sooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000cooo]Z1?l0000<oookJPGo00002ooonfX5o`0000cooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0000cooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo0000
3?oonfX4o`0000cooo]Z1?l0000=oookJPCo00004ooonfX002Wooo]Z1_l00007oookJPCo00003_oo
nfX4o`0000_ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00002ooo
nfX4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oo
nfX4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oo
nfX5o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000cooo]Z1?l0000<oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003Ooo
nfX4o`0001?ooo]Z000YoookJPKo00001ooonfX4o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPGo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPGo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000CoookJP00:OoonfX7o`00
00Kooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000;oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX5o`00
00_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX5o`00
00_ooo]Z1?l0000=oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`00
00cooo]Z1?l0000=oookJPCo00004ooonfX002Wooo]Z1ol00006oookJPCo00003_oonfX4o`0000_o
oo]Z1?l0000<oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00002ooonfX5o`0000_o
oo]Z1?l0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000co
oo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_o
oo]Z1?l0000=oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000co
oo]Z1?l0000<oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0001?o
oo]Z000YoookJPSo00001?oonfX5o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z
1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000_ooo]Z
1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z
1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPGo00003?oonfX5o`0000[ooo]Z
1?l0000=oookJPCo00002ooonfX5o`0000gooo]Z1?l0000CoookJP00:OoonfX8o`0000Cooo]Z1Ol0
000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0
000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0
000=oookJPCo00002ooonfX5o`0000cooo]Z1Ol0000:oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0
000=oookJPCo00004ooonfX002Wooo]Z2?l00004oookJPGo00003_oonfX4o`0000_ooo]Z1?l0000<
oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=
oookJPCo00002ooonfX4o`0000kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=
oookJPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<
oookJPGo00002_oonfX4o`0000gooo]Z1?l0000;oookJPGo00003OoonfX4o`0001?ooo]Z000Yoook
JPWo00000ooonfX4o`0000oooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oook
JPCo00002ooonfX4o`0000kooo]Z1?l0000CoookJP00:OoonfX9o`0000?ooo]Z1?l0000?oookJPCo
00002ooonfX4o`0000cooo]Z1Ol0000:oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000<oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000:oookJPGo00003?oonfX4o`0000cooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo
00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo
00004ooonfX002Wooo]Z2_l000000ooonf[o0000o`000003o`0000oooo]Z1Ol00009oookJPGo0000
3?oonfX5o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX5o`0000cooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000[ooo]Z1Ol0000<oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3OoonfX4o`0000cooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z1?l0000CoookJP00:Ooo
nfX@o`0000oooo]Z1Ol00009oookJPGo00003?oonfX5o`0000[ooo]Z1?l0000<oookJPCo00002ooo
nfX5o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000=oookJPGo00002ooo
nfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oo
nfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000=oookJPCo00002ooo
nfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPGo00002_oo
nfX4o`0000kooo]Z1?l0000CoookJP00:OoonfX@o`0000oooo]Z1Ol00009oookJPGo00003OoonfX4
o`0000[ooo]Z1?l0000<oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000[ooo]Z1?l0000=oookJPGo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000;oookJPCo00003OoonfX5
o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z1?l0000;oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z1Ol0000BoookJP00:OoonfX5o`00
0003oookJ_l0003o000000Oo00004OoonfX4o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX5o`00
00gooo]Z1?l0000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX5o`0001;ooo]Z000YoookJPGo00000_oonfX8o`00017o
oo]Z1?l00009oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000<oookJPGo00002_oonfX4o`0000go
oo]Z1?l0000;oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000go
oo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000go
oo]Z1?l0000;oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000ko
oo]Z1Ol0000BoookJP00:OoonfX5o`0000;ooo]Z2?l0000AoookJPCo00002OoonfX4o`0000kooo]Z
1?l0000:oookJPCo00003?oonfX5o`0000[ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000gooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000gooo]Z
1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00004_oonfX002Wooo]Z1Ol0
0003oookJPKo00004_oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`0000cooo]Z1Ol0
000:oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00006ooonfX4o`0000Wooo]Z1?l0000>
oookJPCo00002OoonfX5o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000Yoook
JPGo00006ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX5o`0000gooo]Z1?l0000:oook
JPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00006ooonfX4o`0000Wooo]Z1?l0000>oookJPCo
00002OoonfX5o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo0000
6ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3ooonfX4o`0001;ooo]Z000YoookJPGo00006ooonfX4o`0000Wooo]Z1?l0000>oookJPCo00002Ooo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00006ooonfX5
o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4
o`0001;ooo]Z000YoookJPGo00006ooonfX5o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`00
00kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`00
00kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00006ooonfX5o`0000So
oo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;o
oo]Z000YoookJPGo00007?oonfX4o`0000Sooo]Z1?l0000>oookJPCo00002OoonfX4o`0000kooo]Z
1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000oooo]Z
1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z
1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00007?oonfX4o`0000Oooo]Z1Ol0
000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0
000?oookJPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0001;ooo]Z000Y
oookJPGo00007?oonfX4o`0000Oooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:
oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000oooo]Z1?l00009
oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:
oookJPCo00003ooonfX4o`0001;ooo]Z000YoookJPGo00007?oonfX4o`0000Oooo]Z1Ol0000>oook
JPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oook
JPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oook
JPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0001;ooo]Z000YoookJPGo
00007?oonfX4o`0000Oooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo
00003OoonfX5o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo
00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPGo
00003ooonfX4o`0001;ooo]Z000YoookJPGo00007?oonfX4o`0000Oooo]Z1?l0000?oookJPGo0000
2?oonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX5o`0000Wooo]Z1?l0000>oookJPCo0000
2_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo0000
2OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo0000
2OoonfX4o`0000oooo]Z1?l00009oookJPGo00003ooonfX4o`0001;ooo]Z000YoookJPGo00007?oo
nfX4o`0000Oooo]Z1?l0000?oookJPGo00002?oonfX4o`0000kooo]Z1?l0000:oookJPCo00003Ooo
nfX5o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oo
nfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4o`0000oooo]Z1?l00009oookJPCo00003ooo
nfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oo
nfX4o`0001;ooo]Z000YoookJPGo00007?oonfX4o`0000Oooo]Z1?l0000?oookJPGo00002?oonfX4
o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4
o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5
o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002_oonfX4
o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo00007?oonfX4o`00
00Oooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00Wooo]Z1?l0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0000:oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000?oookJPGo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`00
01;ooo]Z000YoookJPGo00007?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000ko
oo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000>oookJPGo00002OoonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1Ol00008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo00007?oonfX5o`0000Kooo]Z
1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPGo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPGo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0001;ooo]Z
000YoookJPGo00007?oonfX5o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1?l0
0009oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol0
0008oookJPGo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`0000oooo]Z1Ol0
0008oookJPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo00007OoonfX4o`0000Kooo]Z1?l0000@
oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000?
oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000@
oookJPCo00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?
oookJPGo00002?oonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0001;ooo]Z000Yoook
JPGo00007OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1?l00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX5o`0000kooo]Z1?l00009oook
JPGo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00009oook
JPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`0000oooo]Z1Ol00008oook
JPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo00007OoonfX4o`0000Kooo]Z1?l0000@oookJPCo
00002?oonfX4o`0000kooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002?oonfX5o`0000kooo]Z1Ol00008oookJPGo00003_oonfX5o`0000Wooo]Z1?l0000?oookJPGo
00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000@oookJPCo
00002?oonfX5o`0000oooo]Z1?l00009oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo
00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo0000
7OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00002?oonfX4o`0000kooo]Z1Ol00008oookJPCo0000
3ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX5o`0000kooo]Z1Ol00008oookJPCo0000
3ooonfX5o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Sooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo0000
3ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0001;ooo]Z000YoookJPGo00007OoonfX4o`0000Kooo]Z1?l0000@oookJPCo00001ooo
nfX5o`0000kooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oo
nfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPGo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001;ooo]Z000YoookJPGo00007OoonfX4
o`0000Kooo]Z1?l0000@oookJPCo00001ooonfX5o`0000oooo]Z1?l00008oookJPCo00003ooonfX4
o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00008oookJPCo00003ooonfX5
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5
o`00017ooo]Z000YoookJPGo00007OoonfX4o`0000Gooo]Z1Ol0000@oookJPCo00001ooonfX5o`00
00oooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00
013ooo]Z1Ol00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX5o`00017ooo]Z000YoookJPGo00007OoonfX4o`0000Go
oo]Z1Ol0000@oookJPCo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000So
oo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`0000Oo
oo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPGo00003ooonfX5o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX5o`00017o
oo]Z000YoookJPGo00007OoonfX4o`0000Gooo]Z1Ol0000@oookJPCo00001ooonfX4o`00013ooo]Z
1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z
1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo00007OoonfX4o`0000Gooo]Z1?l0
000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0
000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000Y
oookJPGo00007OoonfX4o`0000Gooo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00008
oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007
oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo00007OoonfX5o`0000Cooo]Z1?l0000Aoook
JPCo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000Aoook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000Aoook
JPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo
00007OoonfX5o`0000Cooo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z1?l00008oookJPCo
00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo
00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004OoonfX4o`00017ooo]Z000YoookJPGo00007OoonfX5o`0000Cooo]Z1?l0000AoookJPCo0000
1ooonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo0000
2?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo00007_oo
nfX4o`0000Cooo]Z1?l0000AoookJPGo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004Ooo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004Ooo
nfX4o`00017ooo]Z000YoookJPGo00007_oonfX4o`0000Cooo]Z1?l0000AoookJPGo00001_oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4
o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo00007_oonfX4o`00
00Cooo]Z1?l0000AoookJPGo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`00
00Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00
00Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`00
00Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004OoonfX4o`00
017ooo]Z000YoookJPGo00007_oonfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00013o
oo]Z1?l00008oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013o
oo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX5o`00013o
oo]Z1?l00008oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00017o
oo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013o
oo]Z1?l00008oookJPCo00004OoonfX4o`00017ooo]Z000YoookJPGo00007_oonfX4o`0000Cooo]Z
1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Oooo]Z
1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000AoookJPCo00001ooonfX5o`00013ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z
1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z
1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z1Ol00006oookJPGo00004OoonfX4o`00017ooo]Z
000YoookJPGo00007_oonfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l0
0008oookJPCo00003ooonfX5o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX5o`00013ooo]Z1Ol0
0007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00017ooo]Z1?l0
0007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z1Ol0
0006oookJPGo00004OoonfX4o`00017ooo]Z000YoookJPGo00007_oonfX4o`0000Cooo]Z1?l0000B
oookJPCo00001_oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Oooo]Z1?l0000@
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000A
oookJPCo00001ooonfX4o`00017ooo]Z1Ol00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000A
oookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000A
oookJPCo00001ooonfX5o`00013ooo]Z1Ol00006oookJPGo00004OoonfX4o`00017ooo]Z000Yoook
JPGo00007_oonfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oook
JPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00007oook
JPCo00004OoonfX5o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`00017ooo]Z000YoookJPGo00007_oonfX5o`0000;ooo]Z1Ol0000BoookJPCo
00001_oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo
00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPGo
00001_oonfX4o`0001;ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000AoookJPCo
00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017ooo]Z000YoookJPGo0000
7_oonfX5o`0000;ooo]Z1Ol0000BoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPGo0000
4?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo0000
4?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`00017ooo]Z000YoookJPGo00007_oonfX5o`0000;ooo]Z1Ol0000BoookJPCo00001_oo
nfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooo
nfX5o`00013ooo]Z1?l00007oookJPGo00004?oonfX5o`0000Oooo]Z1?l0000AoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017ooo]Z000YoookJPGo00007ooonfX4
o`0000;ooo]Z1?l0000CoookJPCo00001_oonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX4
o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX5o`00013ooo]Z1?l00007oookJPCo00004OoonfX5
o`0000Kooo]Z1Ol0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX5
o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`00017ooo]Z000YoookJPGo00007ooonfX4o`0000;ooo]Z1?l0000CoookJPCo00001_oonfX4o`00
013ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX5o`00
013ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1Ol0000AoookJPCo00001ooonfX4o`00
01;ooo]Z1?l00006oookJPGo00004OoonfX5o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`00
01?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017ooo]Z000YoookJPGo00007ooonfX4o`0000;o
oo]Z1?l0000CoookJPCo00001_oonfX4o`00013ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Oo
oo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1Ol0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Go
oo]Z1Ol0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000AoookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017o
oo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0000OoookJPCo00000_oonfX4o`0001?ooo]Z
1?l00006oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`00013ooo]Z
1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`00017ooo]Z
1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00004OoonfX001?ooo]Z0ol0
07l4oookJPOo001o2?oonfX5o`0001oooo]Z1?l00002oookJPCo00004ooonfX4o`0000Kooo]Z1?l0
000@oookJPGo00001_oonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Oooo]Z1?l0
000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0
000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0000AoookJP004ooonfX3o`00O`Cooo]Z0ol007l0
1?oonf[o001oo`00Ool007l8oookJPGo00007ooonfX4o`0000;ooo]Z1?l0000CoookJPCo00001Ooo
nfX5o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000@oookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oo
nfX4o`0001?ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017ooo]Z000CoookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l7oookJPGo00007ooonfX4o`0000;ooo]Z1?l0000CoookJPCo00001OoonfX5
o`00017ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000@oookJPCo00001ooonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001_oonfX4
o`0001;ooo]Z1Ol00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4
o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l7oookJPOo00007OoonfX4o`000003oookJ_l0003o000000?o00004ooonfX4o`00
00Gooo]Z1Ol0000AoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPGo00004?oonfX4o`00
00Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`00
00Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Kooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0000AoookJP004ooonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o1ooonfX5o`0001oooo]Z1?l000000ooonf[o0000o`000003o`0001?o
oo]Z1?l00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017o
oo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1Ol00005oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000WoookJP004ooonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o1ooonfX5o`0001oooo]Z1?l000000ooonf[o0000o`000003o`0001?ooo]Z
1?l00005oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`00017ooo]Z
1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z
1?l00005oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00006oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000WoookJP004ooonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`0001oooo]Z2Ol0000DoookJPCo00001OoonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001OoonfX5o`0001?ooo]Z1?l0
0005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001?ooo]Z1?l0
0005oookJPCo00004ooonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00009ooonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000O
oookJPWo00005?oonfX4o`0000Gooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006
oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005
oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0002Oooo]Z000@oook
JPKo001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007ooonfX9o`0001Cooo]Z1?l00005oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001?ooo]Z1?l00005oook
JPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX5o`0000Gooo]Z1?l0000WoookJP004?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJPGo00008?oonfX8o`0001Cooo]Z1Ol00004oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`00
00Gooo]Z1?l0000WoookJP004_oonfX4o`00O`Cooo]Z1ol007l8oookJPGo00008?oonfX8o`0001Co
oo]Z1Ol00004oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;o
oo]Z1?l00005oookJPGo00004_oonfX5o`0000Gooo]Z1?l0000WoookJP004ooonfX3o`00O`Gooo]Z
1Ol007l9oookJPGo00008?oonfX7o`0001Gooo]Z1Ol00004oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Gooo]Z
1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z
1Ol0000CoookJPGo00001?oonfX5o`0001;ooo]Z1?l00005oookJPGo00004ooonfX4o`0000Gooo]Z
1?l0000WoookJP00:OoonfX5o`00023ooo]Z1ol0000FoookJPCo00001?oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0005oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l0
0005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001Cooo]Z1?l0
0004oookJPGo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX5o`0001?ooo]Z1?l0
0005oookJPCo00009ooonfX002Wooo]Z1Ol0000PoookJPOo00005_oonfX4o`0000Cooo]Z1?l0000B
oookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001OoonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000D
oookJPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000D
oookJPCo00001?oonfX5o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000D
oookJPCo00001OoonfX4o`0002Oooo]Z000YoookJPGo00008OoonfX6o`0001Kooo]Z1?l00004oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oook
JPCo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00001?oonfX4o`0001?ooo]Z1?l00005oook
JPCo00005?oonfX4o`0000Gooo]Z1?l0000WoookJP00:OoonfX5o`00027ooo]Z1_l0000FoookJPCo
00001?oonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo
00001OoonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPGo
00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000CoookJPCo
00001OoonfX4o`0001Cooo]Z1?l00005oookJPCo00009ooonfX002Wooo]Z1Ol0000QoookJPGo0000
5ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo0000
4ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00004oookJPCo0000
4ooonfX5o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo0000
4ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5o`0002Oooo]Z000YoookJPGo0000?Ooo
nfX4o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1?l00006oookJPCo00004_oo
nfX4o`0000Kooo]Z1?l0000BoookJPGo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooo
nfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00004oookJPCo00004ooo
nfX5o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00004ooo
nfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5o`0002Oooo]Z000YoookJPGo0000?OoonfX4
o`0000Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1Ol00005oookJPCo00004_oonfX4
o`0000Gooo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4
o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00004oookJPCo00005?oonfX4
o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00004ooonfX4
o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5o`0002Oooo]Z000YoookJPGo0000?OoonfX4o`00
00Cooo]Z1?l0000BoookJPCo00001_oonfX4o`00017ooo]Z1Ol00005oookJPCo00004_oonfX4o`00
00Gooo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`00
00Cooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00004ooonfX5o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Co
oo]Z1?l0000BoookJPCo00001OoonfX5o`00017ooo]Z1Ol00005oookJPCo00004_oonfX4o`0000Go
oo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX5o`0000Co
oo]Z1?l0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Co
oo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00004ooonfX5o`0000Co
oo]Z1?l0000DoookJPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z
1?l0000BoookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX5o`0000?ooo]Z
1Ol0000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z
1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00004ooonfX5o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z1?l0
000BoookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX5o`0000?ooo]Z1Ol0
000DoookJPCo00001?oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0
000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z1?l0000B
oookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000D
oookJPCo00000ooonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000Cooo]Z1?l0000E
oookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`0000?ooo]Z1Ol0000D
oookJPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z1?l0000Boook
JPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000Eoook
JPGo00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000Doook
JPCo00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z1?l0000BoookJPCo
00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPGo
00000_oonfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000EoookJPCo
00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000DoookJPCo
00001?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX4o`0000Cooo]Z1?l0000BoookJPGo0000
1?oonfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPGo0000
0_oonfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1Ol0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo0000
1?oonfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX5o`0000;ooo]Z1Ol0000BoookJPGo00001?oo
nfX4o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oo
nfX4o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oo
nfX5o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPGo00000ooo
nfX4o`0002Sooo]Z000YoookJPGo0000?OoonfX5o`0000;ooo]Z1Ol0000BoookJPGo00001?oonfX4
o`0001?ooo]Z1?l00005oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4
o`0001Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX5
o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPGo00000ooonfX4
o`0002Sooo]Z000YoookJPGo0000?OoonfX5o`0000;ooo]Z1Ol0000CoookJPCo00001?oonfX4o`00
01?ooo]Z1?l00004oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`00
01Cooo]Z1?l00004oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX5o`00
01Gooo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPGo00000ooonfX4o`00
02Sooo]Z000YoookJPGo0000?_oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?o
oo]Z1?l00004oookJPGo00004_oonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00003oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00003oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000FoookJPCo00000ooonfX4o`0002So
oo]Z000YoookJPGo0000?_oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z
1?l00004oookJPGo00004_oonfX5o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z
1?l00004oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1Ol00002oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00003oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPCo00000ooonfX4o`0002Sooo]Z
000YoookJPGo0000?_oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l0
0004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l0
0004oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol0
0002oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000FoookJPGo000000?ooo]Zo`000?l000000_l0
000FoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0
000XoookJP00:OoonfX5o`0003kooo]Z1?l00002oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000C
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000D
oookJPCo00001?oonfX4o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1Ol00000
0ooonf[o0000o`000002o`0001Kooo]Z1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000F
oookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00002
oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000XoookJP00:OoonfX5o`0003kooo]Z1?l00002oook
JPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oook
JPCo00005?oonfX4o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Kooo]Z1?l000000ooo
nf[o0000o`000003o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooo
nf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o0000
00;o00005_oonfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oook
JPCo0000:?oonfX002Wooo]Z1Ol0000noookJPCo00000_oonfX4o`0001Cooo]Z1?l00004oookJPCo
00004ooonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPCo
00005OoonfX5o`0000?ooo]Z1?l0000FoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPGo
000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo
00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o
0000o`000003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000XoookJP00
:OoonfX5o`0003kooo]Z1?l00002oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000EoookJPGo0000
0ooonfX4o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z1?l000000ooonf[o0000
o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo0000
5ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`000003oookJ_l0003o000000?o0000
5_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0002Sooo]Z000YoookJPGo0000?_oo
nfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00002oookJPGo00005_oo
nfX4o`000003oookJ_l0003o000000;o00006?oonfX4o`000003oookJ_l0003o000000;o00005ooo
nfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?o
oo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo00000_oo
nfX4o`0001Kooo]Z1?l00002oookJPGo0000:?oonfX002Wooo]Z1Ol0000noookJPCo00000_oonfX4
o`0001Cooo]Z1?l00004oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000FoookJPCo000000?ooo]Z
o`000?l000000_l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo000000?ooo]Z
o`000?l000000_l0000GoookJP[o00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4
o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5
o`0002Sooo]Z000YoookJPGo0000?_oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001?oonfX4o`00
01?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX4o`00
01Kooo]Z1?l00002oookJPGo00005_oonfX4o`000003oookJ_l0003o000000;o00006?oonfX9o`00
01Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z2_l0000GoookJPCo000000?ooo]Zo`00
0?l000000_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo0000:OoonfX002Wooo]Z1Ol0000noookJPCo00000_oonfX4o`0001Co
oo]Z1?l00004oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`000?l0
00000_l0000HoookJPWo00005ooonfX9o`0001Oooo]Z2_l0000GoookJPCo000000?ooo]Zo`000?l0
00000_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo0000:OoonfX002Wooo]Z1Ol0000noookJPCo00000_oonfX4o`0001Cooo]Z
1?l00004oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z
1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPCo000000?ooo]Zo`000?l00000
0_l0000HoookJPWo00005ooonfX9o`0001Sooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPGo000000?ooo]Zo`000?l00000
0_l0000FoookJPCo00000_oonfX4o`0002Wooo]Z000YoookJPGo0000?_oonfX4o`000003oookJ_l0
003o000000?o00005?oonfX4o`0000Cooo]Z1?l0000CoookJPGo00000ooonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z1?l0
00000ooonf[o0000o`000002o`0001Sooo]Z2?l0000HoookJPWo00006?oonfX8o`0001Sooo]Z1?l0
00000ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1Ol0
00000ooonf[o0000o`000002o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0002Wooo]Z000Y
oookJPGo0000?_oonfX4o`000003oookJ_l0003o000000?o00005?oonfX4o`0000Cooo]Z1?l0000C
oookJPGo00000ooonfX4o`0001Cooo]Z1Ol00003oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000F
oookJPCo00000_oonfX4o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z2?l0000I
oookJPSo00006?oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00000
0ooonf[o0000o`000002o`0001Oooo]Z2_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000Y
oookJP00:OoonfX5o`0003kooo]Z2_l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1Ol00003oook
JPCo00005?oonfX5o`0000;ooo]Z1Ol0000DoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oook
JPCo00005ooonfX9o`0001Sooo]Z2?l0000IoookJPOo00006OoonfX8o`0001Sooo]Z1?l000000ooo
nf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Sooo]Z2Ol0000Foook
JPGo000000?ooo]Zo`000?l000000_l0000YoookJP00:OoonfX5o`0003kooo]Z2Ol0000EoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00003oookJPCo00005?oonfX5o`0000;ooo]Z1Ol0000DoookJPGo
00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Oooo]Z2Ol0000HoookJPSo
00006OoonfX7o`0001Wooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPWo
00006?oonfX9o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0002Wooo]Z000YoookJPGo0000
?_oonfX9o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1?l0000EoookJPCo0000
0_oonfX5o`0001Gooo]Z1?l00002oookJPCo00005_oonfX:o`0001Oooo]Z2Ol0000HoookJPSo0000
6OoonfX7o`0001Wooo]Z2?l0000HoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPWo0000
6?oonfX8o`0001Sooo]Z1?l000000ooonf[o0000o`000002o`0002Wooo]Z000YoookJPGo0000?ooo
nfX8o`0001Gooo]Z1Ol00002oookJPGo00005?oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oo
nfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX:o`0001Sooo]Z2?l0000HoookJPSo00006Ooo
nfX7o`0001Wooo]Z2?l0000HoookJPWo00005ooonfX9o`0001Sooo]Z2?l0000HoookJPCo000000?o
oo]Zo`000?l000000_l0000YoookJP00:OoonfX5o`0003oooo]Z2?l0000EoookJPGo00000_oonfX5
o`0001Cooo]Z1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4
o`0001Oooo]Z2Ol0000HoookJPSo00006OoonfX6o`0001[ooo]Z1ol0000IoookJPSo00006?oonfX9
o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX9o`0002Wooo]Z000YoookJPGo0000?ooonfX8o`00
01Gooo]Z1Ol00002oookJPGo00005?oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005ooonfX8o`0001Wooo]Z2?l0000IoookJPKo00006_oonfX7o`00
01Wooo]Z2?l0000HoookJPWo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPWo0000:OoonfX002Wo
oo]Z1Ol0000ooookJPSo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Go
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000GoookJPSo00006OoonfX7o`0001[o
oo]Z1_l0000JoookJPOo00006OoonfX8o`0001Wooo]Z2?l0000HoookJPOo00006OoonfX8o`0001So
oo]Z2Ol0000YoookJP00:OoonfX5o`0003oooo]Z2?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z
1?l00003oookJPCo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Oooo]Z
2?l0000IoookJPOo00006_oonfX6o`0001[ooo]Z1ol0000IoookJPSo00006OoonfX7o`0001Wooo]Z
1ol0000IoookJPSo00006?oonfX8o`0002[ooo]Z000YoookJPGo0000?ooonfX7o`0001Oooo]Z1?l0
0002oookJPCo00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005ooonfX8o`0001Wooo]Z1ol0000JoookJPKo00006ooonfX6o`0001Wooo]Z2?l0
000IoookJPOo00006OoonfX7o`0001Wooo]Z2?l0000HoookJPSo0000:_oonfX002Wooo]Z1Ol00010
oookJPKo00005ooonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002
oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX8o`0001Wooo]Z1ol0000J
oookJPKo00006ooonfX5o`0001_ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001Wooo]Z1ol0000I
oookJPSo0000:_oonfX002Wooo]Z1Ol00010oookJPKo00005ooonfX4o`0000;ooo]Z1?l0000Eoook
JPCo00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o0000
00;o00005ooonfX8o`0001Wooo]Z1ol0000KoookJPGo00006ooonfX5o`0001_ooo]Z1_l0000Joook
JPOo00006OoonfX7o`0001Wooo]Z1ol0000JoookJPOo0000:_oonfX002Wooo]Z1Ol00010oookJPKo
00005ooonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002oookJPCo
00005_oonfX5o`000003oookJ_l0003o000000;o00005ooonfX8o`0001[ooo]Z1_l0000KoookJPCo
00007?oonfX5o`0001_ooo]Z1_l0000JoookJPOo00006OoonfX7o`0001Wooo]Z1ol0000JoookJPOo
0000:_oonfX002Wooo]Z1Ol00010oookJPKo00005ooonfX4o`0000;ooo]Z1?l0000EoookJPCo0000
0ooonfX4o`0001Gooo]Z1?l00002oookJPCo00005ooonfX9o`0001Oooo]Z2?l0000JoookJPGo0000
G?oonfX6o`0001[ooo]Z1ol0000IoookJPOo00006_oonfX6o`0001[ooo]Z1ol0000ZoookJP00:Ooo
nfX5o`00043ooo]Z1_l0000GoookJPCo00000_oonfX4o`0001Gooo]Z1Ol000000ooonf[o0000o`00
0003o`0001Gooo]Z1?l00002oookJPCo00005ooonfX9o`0001Oooo]Z2?l0000JoookJPGo0000GOoo
nfX4o`0001cooo]Z1Ol0000KoookJPKo00006_oonfX6o`0001[ooo]Z1ol0000ZoookJP00:OoonfX5
o`00043ooo]Z1_l0000GoookJPGo000000?ooo]Zo`000?l000000_l0000EoookJPGo000000?ooo]Z
o`000?l000000ol0000EoookJPCo00000_oonfX4o`0001Oooo]Z2Ol0000GoookJPSo00006_oonfX5
o`0007gooo]Z1Ol0000KoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000[oookJP00:OoonfX5o`00
043ooo]Z1Ol0000HoookJPGo000000?ooo]Zo`000?l000000_l0000EoookJPGo000000?ooo]Zo`00
0?l000000ol0000EoookJPCo00000_oonfX4o`0001Oooo]Z2?l0000HoookJPSo0000W?oonfX5o`00
01_ooo]Z1_l0000JoookJPKo00006_oonfX6o`0002_ooo]Z000YoookJPGo0000GOoonfX5o`000003
oookJ_l0003o000000;o00005_oonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`0000;o
oo]Z1?l0000GoookJPSo00006OoonfX7o`000;cooo]Z1Ol0000KoookJPKo00006_oonfX6o`0002_o
oo]Z000YoookJPGo0000G_oonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`000003oook
J_l0003o000000;o00005_oonfX4o`0000;ooo]Z1?l0000GoookJPSo00006OoonfX6o`000;kooo]Z
1?l0000KoookJPGo00007?oonfX5o`0002_ooo]Z000YoookJPGo0000G_oonfX4o`000003oookJ_l0
003o000000;o00005_oonfX4o`000003oookJ_l0003o000000;o00005_oonfX4o`000003oookJ_l0
003o000000?o00005ooonfX8o`0001Wooo]Z1_l0003ooookJRoooo]Z000YoookJPGo0000G_oonfX9
o`0001Kooo]Z1?l000000ooonf[o0000o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000003
o`0001Oooo]Z2?l0000IoookJPKo0000oooonfX_oookJP00:OoonfX5o`0005kooo]Z2Ol0000Foook
JPCo000000?ooo]Zo`000?l000000_l0000FoookJPCo000000?ooo]Zo`000?l000000ol0000Goook
JPSo00006OoonfX6o`000?oooo]Z;ooonfX002Wooo]Z1Ol0001NoookJPWo00005_oonfX4o`000003
oookJ_l0003o000000;o00005_oonfX4o`000003oookJ_l0003o000000;o00006?oonfX8o`0001[o
oo]Z1Ol0003ooookJRoooo]Z000YoookJPGo0000G_oonfX8o`0001Oooo]Z1?l000000ooonf[o0000
o`000002o`0001Kooo]Z2Ol0000HoookJPSo0000oooonfY>oookJP00:OoonfX5o`0005kooo]Z2?l0
000GoookJPCo000000?ooo]Zo`000?l000000_l0000FoookJPWo00006?oonfX7o`000?oooo]ZCooo
nfX002Wooo]Z1Ol0001NoookJPSo00005ooonfX4o`000003oookJ_l0003o000000;o00005_oonfX9
o`0001Sooo]Z1ol0003ooookJToooo]Z000YoookJPGo0000G_oonfX8o`0001Oooo]Z1?l000000ooo
nf[o0000o`000002o`0001Oooo]Z2?l0000HoookJPOo0000oooonfY?oookJP00:OoonfX5o`0005ko
oo]Z2?l0000GoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJPSo00006?oonfX7o`000?oo
oo]ZCooonfX002Wooo]Z1Ol0001NoookJPSo00005ooonfX4o`000003oookJ_l0003o000000;o0000
5ooonfX8o`0001Sooo]Z1ol0003ooookJToooo]Z000YoookJPGo0000G_oonfX8o`0001Oooo]Z1?l0
00000ooonf[o0000o`000002o`0001Oooo]Z2?l0000IoookJPKo0000oooonfY?oookJP00:OoonfX5
o`0005kooo]Z1ol0000HoookJPWo00005ooonfX8o`0001Wooo]Z1_l0003ooookJToooo]Z000Yoook
JPGo0000G_oonfX7o`0001Sooo]Z2Ol0000GoookJPSo00006OoonfX6o`000?oooo]ZCooonfX000oo
oo]Z2Ol007l3oookJPGo001o2OoonfX5o`0005oooo]Z1_l0000HoookJPWo00005ooonfX8o`0001Wo
oo]Z1Ol0003ooookJU3ooo]Z000?oookJPWo001o0_oonfX7o`00O`Sooo]Z1Ol0001OoookJPKo0000
6?oonfX8o`0001Sooo]Z2?l0000JoookJPCo0000oooonfY@oookJP003ooonfX4o`00O`Oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000GooonfX6o`0001Sooo]Z2?l0000HoookJPSo0000
oooonfY^oookJP004?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1ooonfX5o`0005oooo]Z1_l0
000IoookJPOo00006OoonfX7o`000?oooo]ZK_oonfX0017ooo]Z1Ol007l3oookJP?o001o0ooonfX3
o`00O`Oooo]Z1ol0001MoookJPKo00006OoonfX7o`0001Wooo]Z1_l0003ooookJVoooo]Z000Coook
JPCo001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000GooonfX6o`0001Wooo]Z1ol0000Ioook
JPKo0000oooonfY_oookJP005?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX5o`0005oo
oo]Z1_l0000IoookJPOo00006OoonfX6o`000?oooo]ZKooonfX001Gooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`00063ooo]Z1?l0000JoookJPOo00006OoonfX6o`000?oo
oo]ZKooonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0001noookJPOo00006OoonfX6o`000?oooo]ZKooonfX000oooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0001noookJPOo00006OoonfX6o`000?oo
oo]ZKooonfX000oooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol0001noookJPOo00006_oonfX4o`000?oooo]ZL?oonfX0013ooo]Z1ol007l3oookJPOo001o
2?oonfX5o`0007kooo]Z1ol0003ooookJXkooo]Z000AoookJPGo001o1OoonfX5o`00O`Wooo]Z1Ol0
001ooookJPGo0000oooonfZ?oookJP00:OoonfX5o`0007oooo]Z1Ol0003ooookJXoooo]Z000Yoook
JPGo0000OooonfX5o`000?oooo]ZSooonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z
1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003o
oookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oo
oo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-16.9899, -23.3441, \
0.388873, 0.131866}},
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"]
}, Open  ]],

Cell["Heavily damped Near Resonance:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[y[1, 2.5, 1/2\  + \ \ 0.05, 1/2]], {t, 0, 200}, 
      PlotPoints \[Rule] 200]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.230136 0.269514 [
[.2619 .21764 -12 -20 ]
[.2619 .21764 12 0 ]
[.5 .21764 -17 -20 ]
[.5 .21764 17 0 ]
[.7381 .21764 -17 -20 ]
[.7381 .21764 17 0 ]
[.97619 .21764 -17 -20 ]
[.97619 .21764 17 0 ]
[.01131 .09538 -41.9375 -10 ]
[.01131 .09538 0 10 ]
[.01131 .36489 -29 -10 ]
[.01131 .36489 0 10 ]
[.01131 .49965 -14 -10 ]
[.01131 .49965 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .23014 m
.2619 .23639 L
s
gsave
.2619 .21764 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.5 .23014 m
.5 .23639 L
s
gsave
.5 .21764 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.7381 .23014 m
.7381 .23639 L
s
gsave
.7381 .21764 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.97619 .23014 m
.97619 .23639 L
s
gsave
.97619 .21764 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .23014 m
.07143 .23389 L
s
.11905 .23014 m
.11905 .23389 L
s
.16667 .23014 m
.16667 .23389 L
s
.21429 .23014 m
.21429 .23389 L
s
.30952 .23014 m
.30952 .23389 L
s
.35714 .23014 m
.35714 .23389 L
s
.40476 .23014 m
.40476 .23389 L
s
.45238 .23014 m
.45238 .23389 L
s
.54762 .23014 m
.54762 .23389 L
s
.59524 .23014 m
.59524 .23389 L
s
.64286 .23014 m
.64286 .23389 L
s
.69048 .23014 m
.69048 .23389 L
s
.78571 .23014 m
.78571 .23389 L
s
.83333 .23014 m
.83333 .23389 L
s
.88095 .23014 m
.88095 .23389 L
s
.92857 .23014 m
.92857 .23389 L
s
.01 w
0 .23014 m
1 .23014 L
s
.25 Mabswid
.02381 .09538 m
.03006 .09538 L
s
gsave
.01131 .09538 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .36489 m
.03006 .36489 L
s
gsave
.01131 .36489 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .49965 m
.03006 .49965 L
s
gsave
.01131 .49965 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .12233 m
.02756 .12233 L
s
.02381 .14928 m
.02756 .14928 L
s
.02381 .17623 m
.02756 .17623 L
s
.02381 .20318 m
.02756 .20318 L
s
.02381 .25709 m
.02756 .25709 L
s
.02381 .28404 m
.02756 .28404 L
s
.02381 .31099 m
.02756 .31099 L
s
.02381 .33794 m
.02756 .33794 L
s
.02381 .39184 m
.02756 .39184 L
s
.02381 .4188 m
.02756 .4188 L
s
.02381 .44575 m
.02756 .44575 L
s
.02381 .4727 m
.02756 .4727 L
s
.02381 .06843 m
.02756 .06843 L
s
.02381 .04148 m
.02756 .04148 L
s
.02381 .01453 m
.02756 .01453 L
s
.02381 .5266 m
.02756 .5266 L
s
.02381 .55355 m
.02756 .55355 L
s
.02381 .5805 m
.02756 .5805 L
s
.02381 .60746 m
.02756 .60746 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .49965 m
.02847 .54319 L
.03089 .57156 L
.03218 .58382 L
.03288 .58945 L
.03355 .59396 L
.03417 .5974 L
.0345 .59891 L
.03484 .60028 L
.03514 .60124 L
.03546 .60208 L
.0356 .60239 L
.03575 .60267 L
.03588 .60287 L
.03602 .60305 L
.03617 .60319 L
.03632 .60327 L
.0364 .6033 L
.03648 .60332 L
.03664 .60331 L
.03678 .60324 L
.03692 .60315 L
.03707 .60299 L
.03722 .60278 L
.03749 .60227 L
.03775 .60165 L
.03832 .59971 L
.03893 .59687 L
.03958 .59284 L
.04078 .58304 L
.04194 .5705 L
.04302 .55636 L
.04775 .46897 L
.0523 .35929 L
.05715 .23906 L
.05938 .18999 L
.06182 .14472 L
.06424 .11095 L
.06487 .10414 L
.06555 .09789 L
.06615 .0933 L
.06678 .08936 L
.06709 .08779 L
.06742 .08632 L
.06773 .08521 L
.06802 .0844 L
.06818 .08403 L
.06835 .0837 L
.06853 .08343 L
.06862 .08332 L
Mistroke
.06871 .08325 L
.06879 .08318 L
.06887 .08314 L
.06895 .08311 L
.06904 .0831 L
.06912 .08311 L
.06921 .08313 L
.06935 .08321 L
.06951 .08335 L
.06964 .08352 L
.0698 .08378 L
.06995 .08408 L
.07022 .08474 L
.07051 .08566 L
.07117 .08848 L
.07178 .09198 L
.07295 .10097 L
.07404 .11204 L
.07653 .14581 L
.0812 .23301 L
.08617 .3379 L
.08865 .38585 L
.09095 .42364 L
.09318 .45167 L
.09442 .46308 L
.09555 .47053 L
.09614 .47327 L
.09644 .47435 L
.09676 .47531 L
.09704 .47593 L
.09719 .4762 L
.09734 .4764 L
.09747 .47654 L
.09761 .47664 L
.09775 .4767 L
.09787 .47671 L
.09802 .47668 L
.09817 .4766 L
.09832 .47646 L
.09845 .4763 L
.0986 .47607 L
.09876 .47575 L
.09909 .47493 L
.09941 .47387 L
.09976 .47246 L
.10038 .46923 L
.10162 .46023 L
.10295 .44669 L
.10538 .41287 L
.11031 .31618 L
Mistroke
.11506 .20735 L
.11963 .11247 L
.12197 .07463 L
.12328 .05793 L
.12449 .0456 L
.12571 .03648 L
.12635 .03305 L
.12668 .03166 L
.12704 .03045 L
.12721 .02999 L
.12738 .02958 L
.12754 .02926 L
.12769 .02902 L
.12784 .02884 L
.12799 .02871 L
.12808 .02866 L
.12816 .02862 L
.12831 .0286 L
.12845 .02864 L
.1286 .02872 L
.12872 .02883 L
.12886 .029 L
.12901 .02923 L
.12917 .02954 L
.12946 .03025 L
.12975 .03116 L
.13006 .03235 L
.13062 .03505 L
.13128 .03919 L
.13188 .04381 L
.13319 .05659 L
.13443 .07188 L
.13907 .15226 L
.14401 .25994 L
.14876 .35898 L
.15115 .39898 L
.15333 .42676 L
.15454 .43793 L
.15509 .44201 L
.15568 .44558 L
.15601 .44723 L
.15631 .4485 L
.15661 .44959 L
.15689 .4504 L
.15721 .45111 L
.15738 .45139 L
.15747 .4515 L
.15756 .45161 L
.15772 .45173 L
.15787 .4518 L
Mistroke
.15796 .45181 L
.15804 .45181 L
.1582 .45175 L
.15834 .45166 L
.15849 .4515 L
.15863 .45131 L
.15876 .45109 L
.15907 .4504 L
.15937 .44952 L
.15996 .44717 L
.16061 .44366 L
.16176 .43506 L
.16283 .42446 L
.16531 .39115 L
.16755 .35183 L
.17238 .24862 L
.17703 .14568 L
.17938 .1 L
.18063 .07895 L
.18197 .05934 L
.18326 .04371 L
.18443 .03248 L
.185 .02815 L
.18561 .02426 L
.18619 .02139 L
.18673 .01943 L
.18702 .01865 L
.18729 .01812 L
.18743 .0179 L
.18758 .01772 L
.18766 .01766 L
.18774 .0176 L
.18789 .01753 L
.18803 .01752 L
.18819 .01756 L
.18833 .01765 L
.18846 .01777 L
.18858 .01792 L
.18872 .01812 L
.18898 .01866 L
.18931 .01954 L
.1896 .02055 L
.19027 .02358 L
.19088 .0273 L
.19147 .03163 L
.19262 .04242 L
.19386 .057 L
.19608 .09043 L
.2011 .19092 L
.20593 .29871 L
Mistroke
.21059 .38682 L
.213 .41918 L
.21421 .43106 L
.21489 .43634 L
.21554 .44037 L
.21613 .44321 L
.21646 .44445 L
.21677 .44537 L
.21703 .44597 L
.21718 .44624 L
.21732 .44645 L
.21746 .44661 L
.21761 .44674 L
.21775 .4468 L
.21789 .44682 L
.21805 .44678 L
.2182 .44669 L
.21828 .44662 L
.21836 .44653 L
.21852 .44632 L
.21882 .44575 L
.2191 .44504 L
.21974 .4427 L
.22042 .43918 L
.22156 .43091 L
.22278 .41885 L
.22499 .38941 L
.22998 .29508 L
.23478 .18767 L
.23939 .09421 L
.24177 .05721 L
.24298 .04251 L
.24431 .02975 L
.2449 .02532 L
.24552 .02151 L
.24605 .01896 L
.24635 .01782 L
.24663 .01693 L
.24679 .01652 L
.24696 .01614 L
.24711 .01588 L
.24726 .01564 L
.24743 .01545 L
.24753 .01538 L
.24761 .01533 L
.24777 .01528 L
.24786 .01528 L
.24794 .0153 L
.24809 .01537 L
.24823 .01549 L
Mistroke
.24839 .01567 L
.24856 .01593 L
.24887 .01659 L
.24915 .01739 L
.24974 .01965 L
.25036 .02291 L
.25147 .03095 L
.25267 .04264 L
.25398 .05888 L
.25886 .14455 L
.26355 .24818 L
.26594 .30092 L
.26854 .35316 L
.27083 .3917 L
.27213 .40963 L
.27335 .42344 L
.2745 .43353 L
.27514 .43792 L
.27573 .44111 L
.27632 .44347 L
.27666 .44445 L
.27697 .44513 L
.27714 .4454 L
.27722 .44551 L
.2773 .44559 L
.27744 .44571 L
.2776 .44579 L
.27775 .44581 L
.27784 .4458 L
.27792 .44577 L
.27801 .44572 L
.27809 .44566 L
.27827 .44546 L
.27842 .44524 L
.27857 .44497 L
.27884 .44433 L
.27914 .44345 L
.27946 .44226 L
.28003 .43952 L
.28056 .43634 L
.28178 .4266 L
.28306 .41287 L
.28544 .37899 L
.28765 .33908 L
.29235 .238 L
.29734 .12913 L
.29985 .0832 L
.30095 .06605 L
.30216 .04968 L
.30324 .03753 L
Mistroke
.3044 .02723 L
.30505 .02283 L
.30563 .01964 L
.30592 .01839 L
.30622 .01724 L
.30652 .01635 L
.30679 .01571 L
.30693 .01544 L
.30709 .0152 L
.30726 .01501 L
.30734 .01494 L
.30743 .01489 L
.30758 .01483 L
.30772 .01483 L
.30779 .01485 L
.30788 .01489 L
.30803 .015 L
.30816 .01514 L
.30831 .01535 L
.30862 .01593 L
.30889 .01667 L
.30916 .01752 L
.30979 .02025 L
.31037 .02358 L
.31169 .03388 L
.31287 .04634 L
.31397 .06049 L
.31646 .10064 L
.32117 .19774 L
.32617 .30888 L
.32868 .35834 L
.33099 .39621 L
.33324 .42374 L
.33438 .43361 L
.33502 .43795 L
.33562 .44114 L
.33622 .44347 L
.33656 .44441 L
.33673 .44477 L
.33688 .44504 L
.33702 .44526 L
.33718 .44543 L
.33732 .44554 L
.33745 .44559 L
.3376 .44561 L
.33775 .44557 L
.33783 .44553 L
.33792 .44546 L
.33807 .44531 L
.33822 .44511 L
Mistroke
.33836 .44487 L
.33867 .44417 L
.33895 .44336 L
.33924 .4423 L
.33975 .44001 L
.3403 .43678 L
.34152 .4273 L
.34264 .41578 L
.34516 .38078 L
.34994 .28806 L
.35454 .18507 L
.3571 .13064 L
.35943 .08733 L
.3606 .06874 L
.36186 .05132 L
.36304 .03783 L
.36414 .02788 L
.36474 .02364 L
.36529 .02047 L
.36589 .01775 L
.36623 .01662 L
.36654 .0158 L
.3667 .01547 L
.36685 .01522 L
.36702 .015 L
.36718 .01486 L
.36732 .01477 L
.36746 .01474 L
.3676 .01475 L
.36776 .01482 L
.36792 .01496 L
.36801 .01506 L
.36809 .01516 L
.36839 .0157 L
.36856 .0161 L
.36875 .01661 L
.36908 .01775 L
.36967 .02036 L
.37022 .02354 L
.37148 .03333 L
.3727 .04615 L
.37401 .06331 L
.37898 .15346 L
.38377 .25996 L
.38838 .35573 L
.39075 .39501 L
.39207 .41255 L
.39328 .42562 L
.39452 .43572 L
.39517 .43965 L
Mistroke
.3955 .44127 L
.39586 .44272 L
.39617 .44376 L
.39646 .4445 L
.3966 .44479 L
.39675 .44505 L
.39689 .44524 L
.39702 .44539 L
.39717 .4455 L
.39725 .44554 L
.39734 .44556 L
.39743 .44557 L
.39752 .44555 L
.3976 .44553 L
.39768 .44548 L
.39783 .44535 L
.39792 .44526 L
.398 .44516 L
.39829 .44464 L
.39857 .44397 L
.39888 .44301 L
.3995 .44042 L
.40007 .43722 L
.40061 .43355 L
.40181 .42293 L
.40311 .40806 L
.40567 .36953 L
.40809 .32368 L
.4127 .22259 L
.41761 .11747 L
.41988 .07729 L
.42234 .04366 L
.42368 .03031 L
.42427 .0257 L
.42492 .02156 L
.42554 .01853 L
.42611 .01649 L
.42642 .01569 L
.42671 .01517 L
.42687 .01497 L
.42696 .01488 L
.42704 .01482 L
.42719 .01474 L
.42727 .01472 L
.42736 .01472 L
.4275 .01476 L
.42764 .01483 L
.42779 .01497 L
.42795 .01518 L
.42812 .01546 L
Mistroke
.42828 .01579 L
.42858 .01657 L
.42911 .01849 L
.42969 .02133 L
.43033 .02533 L
.431 .03056 L
.43221 .04241 L
.43458 .07413 L
.43679 .11247 L
.44147 .21172 L
.44646 .32145 L
.44895 .36882 L
.45126 .40433 L
.45241 .41837 L
.4535 .42906 L
.45463 .43745 L
.45523 .44073 L
.45554 .44211 L
.45588 .44333 L
.45619 .44423 L
.45647 .44485 L
.45661 .44508 L
.45676 .44527 L
.4569 .44541 L
.45703 .4455 L
.45718 .44555 L
.45732 .44555 L
.45747 .4455 L
.45756 .44544 L
.45764 .44538 L
.4578 .4452 L
.45797 .44493 L
.45829 .44427 L
.45863 .44331 L
.45893 .44222 L
.45961 .43897 L
.46024 .43502 L
.46083 .43048 L
.46326 .4041 L
.46548 .3699 L
.47025 .27415 L
.47483 .17158 L
.47738 .11879 L
.47971 .07751 L
.48086 .06024 L
.48212 .0443 L
.4833 .03228 L
.4844 .02374 L
.48495 .02055 L
.48554 .01787 L
Mistroke
.48585 .01676 L
.48619 .01585 L
.48648 .01529 L
.48664 .01505 L
.48679 .01489 L
.48695 .01477 L
.48704 .01474 L
.48712 .01472 L
.48727 .01473 L
.48735 .01475 L
.48743 .0148 L
.48758 .01491 L
.48773 .01509 L
.48788 .01531 L
.48801 .01556 L
.48833 .01633 L
.48869 .01744 L
.48932 .0202 L
.48997 .02394 L
.49057 .02831 L
.4917 .03865 L
.49423 .0713 L
.49666 .11313 L
.49889 .15828 L
.50366 .26463 L
.50825 .35922 L
.51061 .39756 L
.51192 .4146 L
.51313 .42723 L
.51436 .43679 L
.51501 .44045 L
.51534 .44195 L
.5157 .44327 L
.51601 .44418 L
.5163 .44481 L
.51643 .44505 L
.51658 .44525 L
.51672 .4454 L
.51685 .44549 L
.51693 .44553 L
.51702 .44555 L
.51718 .44555 L
.51733 .44549 L
.51747 .44538 L
.51762 .44522 L
.51779 .44497 L
.51813 .44428 L
.51843 .44342 L
.51876 .44225 L
.51936 .43947 L
Mistroke
.51994 .43598 L
.52048 .43205 L
.5217 .42078 L
.523 .40536 L
.52535 .36951 L
.52755 .32811 L
.53222 .22636 L
.53718 .1197 L
.53965 .0759 L
.54086 .05814 L
.54195 .04437 L
.54302 .03336 L
.54417 .0242 L
.54481 .02044 L
.54509 .01909 L
.54539 .01781 L
.54566 .01686 L
.54595 .01604 L
.54611 .01567 L
.54626 .01538 L
.5464 .01516 L
.54655 .01497 L
.5467 .01483 L
.54685 .01475 L
.54699 .01472 L
.54712 .01473 L
.54726 .01479 L
.54742 .01492 L
.5475 .015 L
.54758 .01511 L
.54774 .01534 L
.54803 .01596 L
.54831 .01673 L
.54884 .01868 L
.54946 .02182 L
.55004 .02551 L
.55134 .0366 L
.5525 .04957 L
.55359 .06418 L
.55608 .10525 L
.56075 .20262 L
.56571 .3127 L
.56819 .36113 L
.5705 .39829 L
.57164 .41322 L
.57272 .42489 L
.57332 .43028 L
.57397 .43523 L
.57451 .43867 L
.5751 .44159 L
Mistroke
.57541 .44281 L
.57569 .44374 L
.57597 .44447 L
.57624 .445 L
.57639 .44522 L
.57648 .44531 L
.57655 .44539 L
.57669 .44549 L
.57684 .44555 L
.57692 .44556 L
.57701 .44555 L
.57716 .44549 L
.57724 .44544 L
.57732 .44537 L
.5775 .44517 L
.57766 .44493 L
.57783 .4446 L
.57814 .44382 L
.57872 .44174 L
.57941 .4383 L
.58004 .43418 L
.5812 .42422 L
.5823 .41224 L
.58478 .37635 L
.58946 .28448 L
.59443 .17329 L
.59692 .12164 L
.59922 .08018 L
.60145 .0484 L
.6027 .03485 L
.60383 .02546 L
.60442 .02171 L
.60504 .0186 L
.60557 .01666 L
.60587 .01586 L
.60615 .0153 L
.60631 .01507 L
.60639 .01497 L
.60647 .01488 L
.60655 .01482 L
.60663 .01477 L
.60678 .01472 L
.60693 .01472 L
.60708 .01478 L
.60723 .01489 L
.60736 .01503 L
.60752 .01525 L
.60766 .0155 L
.60799 .01627 L
.60832 .01727 L
Mistroke
.60866 .0186 L
.6093 .02183 L
.6099 .02565 L
.61123 .03716 L
.61242 .05048 L
.61367 .06758 L
.61823 .15119 L
.6231 .25927 L
.62778 .35659 L
.63034 .39828 L
.63151 .41356 L
.63276 .42677 L
.63341 .43229 L
.63402 .43663 L
.63461 .44005 L
.63516 .44247 L
.63567 .44414 L
.63594 .44473 L
.63608 .445 L
.63622 .4452 L
.63637 .44537 L
.63651 .44548 L
.63666 .44554 L
.63674 .44556 L
.63682 .44555 L
.63695 .44552 L
.63709 .44544 L
.63724 .4453 L
.63737 .44512 L
.63767 .4446 L
.63794 .44392 L
.63824 .44298 L
.63856 .44174 L
.63922 .43847 L
.63981 .43464 L
.64096 .425 L
.64205 .41331 L
.64447 .37895 L
.64669 .33881 L
.65145 .2364 L
.65603 .13617 L
.65857 .08827 L
.6609 .0533 L
.66205 .03975 L
.66331 .02816 L
.66388 .02401 L
.66449 .02042 L
.66501 .01804 L
.66531 .01697 L
.66559 .01615 L
Mistroke
.66587 .01551 L
.66602 .01525 L
.66618 .01502 L
.66626 .01493 L
.66635 .01485 L
.66651 .01475 L
.66666 .01472 L
.6668 .01473 L
.66694 .01479 L
.66706 .01488 L
.6672 .01502 L
.66734 .01523 L
.66764 .0158 L
.66792 .01651 L
.66854 .01875 L
.66921 .02221 L
.67043 .03115 L
.67168 .04362 L
.67281 .05768 L
.67534 .09762 L
.68017 .19689 L
.68482 .30066 L
.68718 .34842 L
.68977 .39241 L
.69096 .4088 L
.69224 .42327 L
.69344 .43376 L
.69396 .4373 L
.69454 .44049 L
.69512 .44293 L
.69544 .44393 L
.69573 .44465 L
.69587 .44491 L
.69601 .44514 L
.69613 .44529 L
.69627 .44542 L
.69641 .44551 L
.69656 .44556 L
.69671 .44555 L
.69684 .44549 L
.697 .44538 L
.69708 .4453 L
.69716 .44519 L
.69746 .4447 L
.69763 .44433 L
.69781 .44386 L
.69813 .44281 L
.69877 .44005 L
.69935 .43672 L
.70054 .42748 L
Mistroke
.70164 .41616 L
.70414 .38157 L
.70887 .29031 L
.7139 .178 L
.71642 .12508 L
.71874 .08286 L
.721 .04994 L
.72215 .03712 L
.72279 .03111 L
.7234 .02626 L
.72399 .02233 L
.72463 .01897 L
.72491 .0178 L
.72522 .01676 L
.7255 .01598 L
.72576 .01542 L
.72591 .01517 L
.72605 .01498 L
.72621 .01484 L
.72629 .01478 L
.72638 .01474 L
.72652 .01472 L
.72666 .01473 L
.72681 .01481 L
.72696 .01493 L
.72703 .01502 L
.72712 .01513 L
.72729 .0154 L
.72759 .01606 L
.72795 .0171 L
.72828 .01835 L
.72888 .02127 L
.72954 .0254 L
.73073 .03538 L
.7319 .04803 L
.73297 .06216 L
.73771 .14682 L
.74226 .24752 L
.74711 .34995 L
.74933 .38818 L
.75059 .40614 L
.75177 .42009 L
.75294 .43109 L
.75354 .43557 L
.75419 .43951 L
.75454 .44126 L
.75487 .44261 L
.75518 .44365 L
.75552 .44453 L
.75567 .44483 L
Mistroke
.75582 .44509 L
.75597 .44529 L
.75611 .44542 L
.75626 .44552 L
.75635 .44555 L
.75643 .44556 L
.75657 .44554 L
.75673 .44546 L
.75688 .44534 L
.75697 .44524 L
.75705 .44513 L
.75738 .44453 L
.75767 .4438 L
.75797 .4428 L
.75868 .43969 L
.75932 .43586 L
.76057 .42572 L
.76175 .41302 L
.76416 .37878 L
.76638 .33869 L
.77112 .23667 L
.77568 .13678 L
.77821 .08902 L
.78053 .05393 L
.78171 .03996 L
.78281 .0296 L
.78395 .02161 L
.78456 .0186 L
.78487 .01737 L
.7852 .01633 L
.78551 .01559 L
.78568 .01527 L
.78585 .01504 L
.786 .01488 L
.78613 .01478 L
.78629 .01472 L
.78644 .01472 L
.78652 .01474 L
.7866 .01478 L
.78669 .01484 L
.78677 .01491 L
.78692 .01508 L
.78708 .01532 L
.78745 .01609 L
.78778 .01708 L
.78835 .01934 L
.78896 .02267 L
.79021 .03202 L
.79145 .04464 L
.79257 .05884 L
Mistroke
.7951 .09906 L
.79992 .1983 L
.80455 .30162 L
.8069 .34902 L
.80948 .39281 L
.81066 .40903 L
.81193 .4234 L
.81313 .43382 L
.8137 .43768 L
.81423 .44053 L
.8148 .44294 L
.81512 .44393 L
.81541 .44465 L
.81555 .44491 L
.81569 .44513 L
.81581 .44529 L
.81594 .44542 L
.81609 .44551 L
.81622 .44555 L
.81637 .44555 L
.81652 .44549 L
.81667 .44538 L
.81675 .4453 L
.81684 .4452 L
.81713 .44471 L
.8173 .44435 L
.81748 .44388 L
.8178 .44284 L
.81844 .44011 L
.81902 .43678 L
.8202 .42764 L
.8213 .41641 L
.8238 .382 L
.82851 .29128 L
.83351 .17938 L
.83602 .1266 L
.83834 .0842 L
.84059 .05111 L
.84173 .03812 L
.84237 .03199 L
.84298 .027 L
.84356 .02297 L
.8442 .01947 L
.84448 .01823 L
.84478 .01712 L
.84507 .01626 L
.84532 .01564 L
.84548 .01534 L
.84565 .01508 L
.84582 .01489 L
Mistroke
.84592 .01482 L
.846 .01476 L
.84609 .01473 L
.84617 .01472 L
.84631 .01473 L
.84647 .0148 L
.84656 .01486 L
.84665 .01494 L
.84679 .01512 L
.84692 .01532 L
.84723 .01595 L
.84752 .01677 L
.84784 .01788 L
.84847 .02079 L
.84906 .02431 L
.85039 .03515 L
.85156 .04787 L
.85281 .06447 L
.85782 .15606 L
.86265 .26362 L
.8673 .35947 L
.8697 .39838 L
.87093 .41425 L
.87224 .42789 L
.87288 .43314 L
.87348 .43729 L
.87407 .44053 L
.87461 .44283 L
.87487 .44369 L
.87512 .44436 L
.87538 .4449 L
.87552 .44512 L
.87567 .44531 L
.87581 .44544 L
.87596 .44552 L
.87604 .44555 L
.87612 .44556 L
.87627 .44553 L
.87642 .44546 L
.87656 .44534 L
.87668 .44519 L
.87682 .44499 L
.8771 .44443 L
.87741 .44361 L
.87796 .44158 L
.87862 .43825 L
.87922 .43434 L
.88052 .42309 L
.88175 .40907 L
.88414 .37365 L
Mistroke
.88636 .33269 L
.89109 .2302 L
.8961 .12185 L
.89862 .07693 L
.89973 .06043 L
.90094 .04497 L
.90203 .03358 L
.9032 .02425 L
.90385 .02043 L
.90444 .01778 L
.90472 .0168 L
.90503 .01594 L
.90517 .01562 L
.90532 .01534 L
.90546 .01512 L
.90559 .01496 L
.90573 .01483 L
.90588 .01475 L
.90603 .01472 L
.90618 .01474 L
.90633 .01481 L
.90647 .01492 L
.90659 .01506 L
.90672 .01526 L
.90703 .01587 L
.90736 .01675 L
.90794 .01897 L
.90849 .02174 L
.90899 .02494 L
.91015 .03438 L
.91141 .04792 L
.9126 .0637 L
.91483 .10009 L
.91945 .19509 L
.92436 .30447 L
.92664 .35019 L
.92909 .39182 L
.93044 .41031 L
.93168 .42411 L
.93287 .43424 L
.93346 .43816 L
.93412 .4415 L
.93442 .44273 L
.93475 .44381 L
.93506 .44459 L
.93521 .44488 L
.93535 .44511 L
.93549 .44528 L
.93561 .44541 L
.93575 .4455 L
Mistroke
.9359 .44555 L
.93604 .44555 L
.9362 .4455 L
.93634 .44539 L
.93648 .44525 L
.93664 .44503 L
.93681 .44472 L
.93712 .44399 L
.93742 .44305 L
.9377 .44201 L
.93833 .43895 L
.939 .43471 L
.94015 .42516 L
.94137 .41181 L
.94358 .3803 L
.94857 .28293 L
.95337 .17539 L
.958 .08451 L
.96038 .04972 L
.96159 .03631 L
.96223 .03037 L
.96292 .02512 L
.9635 .02147 L
.96413 .01836 L
.96441 .01729 L
.96471 .01636 L
.96499 .01567 L
.96525 .0152 L
.96541 .01499 L
.96549 .0149 L
.96557 .01483 L
.96571 .01475 L
.96587 .01472 L
.96596 .01472 L
.96604 .01474 L
.96619 .01483 L
.96628 .0149 L
.96636 .01498 L
.96654 .01522 L
.9667 .0155 L
.96685 .01582 L
.96713 .01656 L
.96776 .01888 L
.96833 .02174 L
.96894 .02572 L
.97019 .03633 L
.97134 .04911 L
.97242 .06343 L
.97619 .12895 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000UOoonfX2o`0005gooo]Z0ol0002NoookJP;o0000
7OoonfX2o`0005Oooo]Z000^oookJPGo0000L_oonfX5o`0001_ooo]Z1_l0000JoookJPKo00006_oo
nfX5o`0001_ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1Ol0000KoookJPKo00006_oo
nfX6o`0001[ooo]Z1_l0000JoookJPKo00006ooonfX5o`0001Gooo]Z000^oookJPGo0000DooonfX4
o`0001_ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6
o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6
o`0001[ooo]Z1_l0000EoookJP00;_oonfX5o`0005;ooo]Z1_l0000JoookJPKo00006_oonfX6o`00
01[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`00
01[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00005OoonfX002ko
oo]Z1Ol0001BoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[o
oo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[o
oo]Z1_l0000JoookJPKo00006_oonfX6o`0001Gooo]Z000^oookJPGo0000D_oonfX6o`0001[ooo]Z
1_l0000JoookJPKo00006OoonfX7o`0001[ooo]Z1_l0000IoookJPOo00006_oonfX6o`0001[ooo]Z
1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z
1_l0000EoookJP00;_oonfX5o`0005;ooo]Z1_l0000IoookJPOo00006_oonfX6o`0001Wooo]Z1ol0
000IoookJPSo00006?oonfX7o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX7o`0001[ooo]Z1ol0
000IoookJPKo00006_oonfX7o`0001Sooo]Z2?l0000HoookJPSo00005?oonfX002kooo]Z1Ol0001B
oookJPKo00006OoonfX7o`0001Wooo]Z1ol0000IoookJPOo00006OoonfX8o`0001Sooo]Z1ol0000I
oookJPSo00006?oonfX8o`0001Sooo]Z1ol0000IoookJPSo00006?oonfX7o`0001Wooo]Z2?l0000H
oookJPSo00006?oonfX8o`0001Cooo]Z000^oookJPGo0000<ooonfX4o`0001[ooo]Z1ol0000Ioook
JPSo00006?oonfX7o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000Hoook
JPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000Hoook
JPSo00005?oonfX002kooo]Z1Ol0000boookJPKo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPSo
00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo
00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000DoookJP00
;_oonfX5o`0003;ooo]Z1_l0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo0000
6?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo0000
6?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Cooo]Z000^oookJPGo0000<_oo
nfX6o`0001Wooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oo
nfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oo
nfX8o`0001Sooo]Z2?l0000HoookJPSo00005?oonfX002kooo]Z1Ol0000boookJPKo00006OoonfX8
o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8
o`0001Sooo]Z2?l0000GoookJPWo00006?oonfX8o`0001Oooo]Z2Ol0000HoookJPSo00006?oonfX8
o`0001Sooo]Z2?l0000DoookJP00;_oonfX5o`0003;ooo]Z1_l0000IoookJPSo00005ooonfX:o`00
01Oooo]Z2?l0000HoookJPSo00005ooonfX:o`0001Oooo]Z2?l0000HoookJPSo00006?oonfX8o`00
01Oooo]Z2_l0000GoookJPSo00005ooonfX9o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`00
01Cooo]Z000^oookJPGo0000<_oonfX7o`0001Oooo]Z2Ol0000GoookJP[o00005ooonfX8o`0001So
oo]Z2?l0000GoookJP[o00005_oonfX9o`0001Oooo]Z2Ol0000HoookJPSo00005ooonfX:o`0001Oo
oo]Z2?l0000GoookJP[o00005ooonfX8o`0001Sooo]Z2?l0000HoookJPSo00005?oonfX002kooo]Z
1Ol0000aoookJPSo00005ooonfX9o`0001Oooo]Z2_l0000GoookJPWo00005ooonfX9o`0001Kooo]Z
2_l0000FoookJPWo00005ooonfX9o`0001Sooo]Z2?l0000GoookJPCo000000?ooo]Zo`000?l00000
0ol0000GoookJPSo00005ooonfX4o`000003oookJ_l0003o000000?o00005ooonfX8o`0001Oooo]Z
2_l0000GoookJPSo00005?oonfX002kooo]Z1Ol0000aoookJPSo00005ooonfX9o`0001Oooo]Z1?l0
0002oookJPCo00005ooonfX9o`0001Oooo]Z2Ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z2Ol0
000GoookJP[o00005_oonfX9o`0001Oooo]Z1?l00002oookJPCo00005ooonfX9o`0001Kooo]Z1?l0
00000ooonf[o0000o`000003o`0001Oooo]Z2Ol0000FoookJP[o00005_oonfX:o`0001?ooo]Z000^
oookJPGo0000<OoonfX8o`0001Oooo]Z1?l000000ooonf[o0000o`000002o`0001Oooo]Z1?l00002
oookJPCo00005_oonfX:o`0001Kooo]Z2_l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00000
0ooonf[o0000o`000002o`0001Oooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z2_l0000F
oookJPCo00000_oonfX4o`0001Kooo]Z2_l0000FoookJPCo00000_oonfX4o`0001Kooo]Z2_l0000F
oookJP[o00005_oonfX:o`0001?ooo]Z000^oookJPGo0000<OoonfX8o`0001Oooo]Z1?l000000ooo
nf[o0000o`000002o`0001Oooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o0000
00;o00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo000000?ooo]Zo`000?l000000ol0000Foook
JP[o00005_oonfX4o`0000;ooo]Z1?l0000FoookJP[o00005_oonfX4o`0000;ooo]Z1?l0000Foook
JP[o00005_oonfX4o`0000;ooo]Z1?l0000FoookJP[o00004ooonfX002kooo]Z1Ol0000aoookJPSo
00005ooonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`0000;ooo]Z1?l0000FoookJPGo
000000?ooo]Zo`000?l000000_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPCo
00000_oonfX4o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo
000000?ooo]Zo`000?l000000_l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o
0000o`000002o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00
;_oonfX5o`00037ooo]Z2Ol0000FoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo0000
0_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo0000
0_oonfX4o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000CoookJP00;_oonfX5o`00033ooo]Z2_l0000FoookJPCo000000?o
oo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oo
nfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001?ooo]Z000^oookJPGo0000<?oonfX:
o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00004ooonfX0
02kooo]Z1Ol0000`oookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`00
01Kooo]Z1?l00002oookJPCo00004ooonfX002kooo]Z1Ol0000`oookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Ko
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Go
oo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00;_oonfX5o`00033ooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z
1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Gooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001?ooo]Z
000^oookJPGo0000<?oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005OoonfX5o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1Ol0
0002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00005_oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Kooo]Z1?l0
0002oookJPCo00004ooonfX002kooo]Z1Ol0000`oookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00002
oookJPCo00005OoonfX5o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX5o`0001Gooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000ooonfX4o`0001Gooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000CoookJP00;_oonfX5o`00033ooo]Z1?l00002oook
JPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z1?l00003oook
JPCo00005OoonfX5o`0000;ooo]Z1?l0000EoookJPGo00000ooonfX4o`0001Gooo]Z1?l00002oook
JPGo00005OoonfX4o`0000;ooo]Z1?l0000EoookJPGo00000ooonfX4o`0001Gooo]Z1?l00002oook
JPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00003oook
JPCo00005OoonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001?ooo]Z000^oookJPGo
0000<?oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo
00005OoonfX4o`0000?ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo
00005OoonfX4o`0000;ooo]Z1Ol0000DoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00003oookJPCo
00005OoonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo
00004ooonfX002kooo]Z1Ol0000`oookJPCo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo0000
5OoonfX5o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1?l00003oookJPCo0000
5OoonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Cooo]Z1Ol00002oookJPCo0000
5OoonfX5o`0000?ooo]Z1?l0000EoookJPCo00000_oonfX5o`0001Cooo]Z1Ol00002oookJPCo0000
5_oonfX4o`0000;ooo]Z1Ol0000DoookJPGo00000ooonfX4o`0001Cooo]Z1Ol00002oookJPCo0000
5OoonfX5o`0000;ooo]Z1?l0000CoookJP00;_oonfX5o`00033ooo]Z1?l00002oookJPCo00005Ooo
nfX5o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oo
nfX4o`0000?ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00003oookJPCo00005?oo
nfX5o`0000;ooo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00002oookJPGo00005?oo
nfX5o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX5o`0001Cooo]Z1Ol00003oookJPCo00005?oo
nfX5o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001?ooo]Z000^oookJPGo0000<?oonfX4
o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1?l00003oookJPCo00005OoonfX4
o`0000?ooo]Z1Ol0000DoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5
o`0000?ooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX5
o`0000;ooo]Z1Ol0000DoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00002oookJPGo00005?oonfX5
o`0000?ooo]Z1?l0000DoookJPGo00000_oonfX4o`0001Gooo]Z1?l00003oookJPCo00004ooonfX0
02kooo]Z1Ol0000`oookJPCo00000_oonfX4o`0001Gooo]Z1?l00003oookJPGo00005?oonfX4o`00
00?ooo]Z1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPCo00005OoonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l00003oookJPCo00005OoonfX5o`00
00?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`00
00?ooo]Z1?l0000CoookJP00;_oonfX5o`00033ooo]Z1?l00002oookJPCo00005OoonfX4o`0000?o
oo]Z1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?o
oo]Z1?l0000EoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?o
oo]Z1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?o
oo]Z1Ol0000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?o
oo]Z1Ol0000DoookJPCo00000ooonfX4o`0001?ooo]Z000^oookJPGo0000<?oonfX4o`0000;ooo]Z
1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000ooonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPCo00004ooonfX002kooo]Z1Ol0
000`oookJPCo00000_oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0
000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1?l0
000CoookJP00;_oonfX5o`0001?ooo]Z1Ol0000HoookJPCo00000_oonfX4o`0001Gooo]Z1?l00004
oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003
oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004
oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000BoookJP00;_oonfX5o`0001?ooo]Z1Ol0000Hoook
JPCo00000_oonfX4o`0001Gooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000Doook
JPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000Boook
JP00;_oonfX5o`0001;ooo]Z1_l0000GoookJPGo00000_oonfX5o`0001Cooo]Z1?l00004oookJPCo
00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000?ooo]Z1Ol0000BoookJP00;_oonfX5o`0001;ooo]Z1_l0000GoookJPGo0000
0_oonfX5o`0001Cooo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX5o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000BoookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`0001;ooo]Z1_l0000GoookJPGo00000_oo
nfX5o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oo
nfX5o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oo
nfX5o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000BoookJP004?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0001;ooo]Z1ol0000FoookJPCo00001?oonfX4
o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX5
o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5
o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5
o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0000BoookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0000BoookJPOo00005_oonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oo
nfX4o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oo
nfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001?oo
nfX5o`0001?ooo]Z1?l00004oookJPCo00004_oonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0001;ooo]Z1ol0000FoookJPCo00001?oonfX4
o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPGo00001?oonfX5
o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1Ol0000CoookJPCo00001?oonfX5
o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00004oookJPCo00005?oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00004oookJPGo00004ooonfX4o`0000Cooo]Z1?l0000BoookJP000ooonfX:o`00
O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1_l0000@oookJPSo00005_oonfX4o`00
00Cooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX5o`00
00Gooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPGo00004ooonfX4o`00
00Cooo]Z1Ol0000CoookJPCo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`00
00Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00004oookJPCo00004_oonfX000oo
oo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0000AoookJPSo00005_oonfX4o`0000Co
oo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX5o`0000Go
oo]Z1?l0000BoookJPGo00001?oonfX4o`0001?ooo]Z1Ol00005oookJPCo00004_oonfX5o`0000Go
oo]Z1?l0000BoookJPGo00001?oonfX5o`0001?ooo]Z1?l00005oookJPCo00004ooonfX4o`0000Go
oo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00005oookJPCo00004ooonfX4o`0000Go
oo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z1?l00004oookJPCo00004_oonfX000oooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPGo00004OoonfX8o`0001Kooo]Z
1?l00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?ooo]Z
1?l00006oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000CoookJPGo00001OoonfX4o`0001;ooo]Z
1Ol00005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4o`0001;ooo]Z
1Ol00005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPGo00001OoonfX4o`0001?ooo]Z
1?l00005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000BoookJPGo00001?oonfX4o`0001;ooo]Z
000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo00004OoonfX8o`0001Kooo]Z1?l0
0004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000CoookJPGo00001OoonfX4o`0001;ooo]Z1Ol0
0005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000BoookJPGo00001OoonfX4o`0001;ooo]Z1Ol0
0005oookJPCo00004ooonfX4o`0000Cooo]Z1?l0000CoookJPGo00001OoonfX4o`0001?ooo]Z1?l0
0005oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000BoookJPGo00001?oonfX4o`0001;ooo]Z000?
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l9oookJPGo00004OoonfX8o`0001Gooo]Z1Ol00004
oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006
oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001;ooo]Z1Ol00005
oookJPCo00004_oonfX5o`0000Cooo]Z1Ol0000BoookJPGo00001OoonfX4o`0001?ooo]Z1?l00005
oookJPCo00004_oonfX5o`0000Gooo]Z1?l0000BoookJPGo00001?oonfX4o`0001;ooo]Z000?oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l=oookJPGo00004OoonfX8o`0001Gooo]Z1Ol00004oook
JPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX5o`0000Cooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1Ol00005oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX4o`0001;ooo]Z000@oookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`gooo]Z1Ol0000AoookJPWo00005?oonfX5o`00
00Cooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`00
00Kooo]Z1?l0000BoookJPGo00001?oonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX5o`00
00Gooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPCo00004_oonfX0013o
oo]Z1ol007l9oookJPOo001o1ooonfX5o`00017ooo]Z2Ol0000DoookJPCo00001OoonfX4o`0001?o
oo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001OoonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000BoookJP004OoonfX5o`00O`[ooo]Z
1ol007l7oookJPGo00004OoonfX9o`0001Cooo]Z1?l00005oookJPGo00004_oonfX4o`0000Gooo]Z
1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z
1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000BoookJPCo00001OoonfX4o`0001;ooo]Z000^oookJPGo00004OoonfX4o`000003oookJ_l0
003o000000;o00005?oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX5o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l0
0005oookJPGo00004OoonfX002kooo]Z1Ol0000AoookJPCo000000?ooo]Zo`000?l000000_l0000D
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000A
oookJP00;_oonfX5o`00017ooo]Z1?l000000ooonf[o0000o`000002o`0001Cooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX5o`00017ooo]Z000^oookJPGo
00004?oonfX5o`000003oookJ_l0003o000000;o00005?oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`00017ooo]Z1Ol00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004OoonfX002kooo]Z1Ol0000@oookJPGo0000
00?ooo]Zo`000?l000000_l0000DoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4OoonfX5o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX4o`00017ooo]Z1Ol00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000AoookJP00;_oonfX5o`00013ooo]Z1Ol000000ooonf[o0000o`00
0002o`0001Cooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000AoookJPCo00001ooo
nfX4o`00017ooo]Z1Ol00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`00017ooo]Z000^oookJPGo00004?oonfX4o`0000;ooo]Z1?l0000DoookJPCo00001_oonfX4
o`00017ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4
o`00017ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX5
o`00017ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4
o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000AoookJP00;_oonfX5o`00
013ooo]Z1?l00002oookJPCo00005?oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX4o`00
017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`00
017ooo]Z1Ol00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00
017ooo]Z1?l00006oookJPCo00004OoonfX002kooo]Z1Ol0000@oookJPCo00000_oonfX4o`0001Co
oo]Z1?l00006oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX4o`00017o
oo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00017o
oo]Z1Ol00007oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX5o`00017o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`00017o
oo]Z000^oookJPGo00004?oonfX4o`0000;ooo]Z1Ol0000CoookJPCo00001_oonfX4o`00017ooo]Z
1?l00007oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00001ooonfX5o`00013ooo]Z
1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00017ooo]Z
1?l00006oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00007oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000AoookJP00;_oonfX5o`00013ooo]Z1?l0
0002oookJPGo00004ooonfX4o`0000Kooo]Z1?l0000AoookJPCo00001ooonfX4o`00017ooo]Z1?l0
0007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX4o`0001;ooo]Z1?l0
0006oookJPGo00004?oonfX5o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00017ooo]Z1?l0
0006oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX5o`00013ooo]Z1?l0
0008oookJPCo00004OoonfX4o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4o`00013ooo]Z1Ol0
0006oookJPCo00004OoonfX002kooo]Z1Ol0000@oookJPCo00000_oonfX5o`0001?ooo]Z1?l00006
oookJPCo00004OoonfX4o`0000Oooo]Z1?l0000AoookJPCo00001ooonfX5o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z1Ol00006
oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX5o`00013ooo]Z1?l00008
oookJPCo00004OoonfX4o`0000Kooo]Z1Ol0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00006
oookJPGo00004OoonfX4o`0000Oooo]Z1?l0000@oookJPGo00001_oonfX4o`00017ooo]Z000^oook
JPGo00003ooonfX5o`0000?ooo]Z1?l0000CoookJPCo00001_oonfX4o`00017ooo]Z1?l00007oook
JPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oook
JPCo00004OoonfX5o`0000Oooo]Z1?l0000@oookJPGo00001_oonfX5o`00017ooo]Z1?l00007oook
JPCo00004?oonfX5o`0000Kooo]Z1Ol0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00006oook
JPGo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo00001_oonfX5o`00017ooo]Z1?l00007oook
JPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX5o`0000?ooo]Z1?l0000BoookJPGo
00001_oonfX4o`00017ooo]Z1?l00007oookJPCo00004OoonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002?oonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Oooo]Z1?l0000@oookJPCo
00001ooonfX5o`00013ooo]Z1Ol00007oookJPCo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo
00002?oonfX4o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000AoookJPCo
00001_oonfX5o`00017ooo]Z1?l00007oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo0000
3ooonfX5o`0000?ooo]Z1?l0000BoookJPGo00001_oonfX5o`00013ooo]Z1?l00007oookJPCo0000
4OoonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo0000
4?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX5o`00013ooo]Z1Ol00007oookJPCo0000
4?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00017ooo]Z1?l00007oookJPCo0000
4?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000BoookJPGo00001_oo
nfX5o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPGo00001ooo
nfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4
o`0000Cooo]Z1?l0000BoookJPCo00001ooonfX5o`00013ooo]Z1?l00007oookJPGo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPGo00001ooonfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4
o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00002?oonfX4o`00
013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1Ol00007oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Co
oo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001co
oo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0
000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000^
oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000Boook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo
00003ooonfX4o`0000Cooo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1?l0000BoookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000?oookJPGo0000
2?oonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0001cooo]Z000^oookJPGo00003ooo
nfX4o`0000Cooo]Z1?l0000BoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4o`0000oooo]Z1Ol00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooo
nfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0001cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1Ol0000AoookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000?oookJPCo00002OoonfX4
o`0000oooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000>oookJPGo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000?oookJPGo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0001cooo]Z000^oookJPGo00003ooonfX4o`00
00Cooo]Z1Ol0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`00
00Sooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`00
00Sooo]Z1Ol0000>oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`00
00Sooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`00
00Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`00
01cooo]Z000^oookJPGo00003ooonfX4o`0000Cooo]Z1Ol0000AoookJPCo00002?oonfX4o`00013o
oo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002OoonfX4o`00013o
oo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`0000oo
oo]Z1Ol00008oookJPCo00003ooonfX5o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013o
oo]Z1?l00008oookJPCo00003ooonfX5o`0001cooo]Z000^oookJPGo00003_oonfX5o`0000Gooo]Z
1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z
1?l0000>oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oookJPCo00003ooonfX4o`0000Wooo]Z
1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0001gooo]Z
000^oookJPGo00003_oonfX5o`0000Gooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`00013ooo]Z1?l0
0008oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oooo]Z1Ol0
0008oookJPCo00003ooonfX4o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPCo00003ooonfX4o`0001gooo]Z000^oookJPGo00003_oonfX5o`0000Gooo]Z1?l0000A
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>
oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX5o`0000Wooo]Z1?l0000>
oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00003ooonfX4o`0000Wooo]Z1Ol0000>
oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1?l0000?
oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPGo00003_oonfX4o`0001gooo]Z000^oook
JPGo00003_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`0000oooo]Z1Ol00008oook
JPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX4o`0000oooo]Z1?l00009oook
JPGo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1Ol00008oook
JPCo00003ooonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l00009oook
JPGo00003_oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oook
JPGo00003_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1?l0000AoookJPCo
00002?oonfX4o`0000oooo]Z1Ol00008oookJPGo00003_oonfX4o`0000Wooo]Z1Ol0000>oookJPCo
00002OoonfX5o`0000kooo]Z1?l00009oookJPGo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo
00002OoonfX5o`0000kooo]Z1Ol00008oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002OoonfX5o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000Wooo]Z1Ol0000>oookJPCo
00002OoonfX5o`0000oooo]Z1?l00008oookJPGo00003_oonfX4o`0001gooo]Z000^oookJPGo0000
3_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`0000oooo]Z1Ol00008oookJPGo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1Ol00008oookJPCo0000
3ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002OoonfX5o`0000kooo]Z1Ol00009oookJPCo0000
3_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00002?oo
nfX5o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002Ooo
nfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002Ooo
nfX5o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000>oookJPCo00002Ooo
nfX5o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4
o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX5o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4
o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX5o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Ko
oo]Z1?l0000@oookJPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001go
oo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1?l0000@oookJPGo00002OoonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1?l0
000@oookJPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0001gooo]Z000^
oookJPGo00003_oonfX4o`0000Kooo]Z1Ol0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0001gooo]Z000^oookJPGo00003_oonfX4o`0000Kooo]Z1Ol0000?oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Cooo]Z1Ol007l00ooo
nf[o0000o`000002o`0000Go001o2OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`000004oookJ_l007oo001oo`00O`Gooo]Z00?o001o
o`000?l000000_l00005oookJPGo001o1?oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4
o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000?o001o1OoonfX2o`00O`Co00001?oonfX5
o`00O`Gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4
o`0000gooo]Z00?o001oo`000?l000000_l00004o`00O`?ooo]Z1Ol007l5oookJPGo001o1ooonfX0
02kooo]Z1Ol0000>oookJPCo00001_oonfX5o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00000ooonfX7o`00O`Co00001_l007l8oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo000000Cooo]Zo`00
Ool007oo001o1?oonfX2o`00O`Co000000Co001ooookJ_oonf[ooo]Z1ol007l3oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00000ol0
07l4oookJP?o001o1?l00003oookJPOo001o1?oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX00ol007oo0000o`000002o`0000Co001o0_oo
nfX7o`00O`?ooo]Z1ol007l6oookJP00;_oonfX5o`0000kooo]Z1?l00007oookJPCo00003ooonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00002oookJPCo001o00Cooo]Z
o`00Ool007oo001o1?l00002o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l000001?oonf[o001o
o`00Ool007l4oookJP;o001o1?l000001?l007oooo]ZoookJ_oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4
o`0000kooo]Z1?l00003o`00O`?ooo]Z1?l007l4o`0000?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l4oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000=oookJP03o`00Ool0003o000000;o00001_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l6oookJP00;_oonfX5o`0000kooo]Z1?l00007oookJPCo0000
3ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00002oookJP?o001o
0ooonfX2o`00O`Co000000Co001ooookJ_oonf[ooo]Z0ol007l7oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000<oookJPGo000000Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Co00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000?o001o0ooonfX3o`00O`03oookJ_l0003o000000;o000000?o001ooookJ_l007l00_l007l3
oookJP?o001o0ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Gooo]Z000^oookJPGo00003_oonfX4o`0000Oooo]Z1?l0000?oookJPCo00002_oonfX4
o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000Sooo]Z0_l007l4o`000004o`00Oooonf[o
oo]ZoookJP?o001o1ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPGo00003?oonfX5o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007l4o`0000;o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00003o`00O`Oooo]Z1?l000000ol007oo
oo]Zo`00O`02o`00O`?ooo]Z0ol007l3oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00000_l007l3oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0000kooo]Z1?l00007oookJPCo
00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00008oookJP;o
001o1?l000001?l007oooo]ZoookJ_oonfX3o`00O`Oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1Ol000001?oonf[o001oo`00Ool007l3
oookJP?o001o1?l00002o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJPCo00002_oo
nfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00000ol0
07l7oookJPCo000000?o001ooookJ_l007l00_l007l3oookJP?o001o0ooonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000?o001o0_oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0
000>oookJPCo00001ooonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00000ooonfX2o`00O`;ooo]Z0ol007l4o`000004o`00Oooonf[ooo]ZoookJP?o001o
1ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo0000
3?oonfX4o`0000;ooo]Z0ol007l3oookJP?o001o1?l00002o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l2oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00000ol007l4oookJP;o001o00?ooo]Zo`000?l000000_l000000ol007oo
oo]Zo`00O`02o`00O`?ooo]Z0ol007l3oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000=oookJPGo00000ol007l2oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0000kooo]Z1?l00007oookJPCo
00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l00003oookJPOo
001o1?l000001?l007oooo]ZoookJ_oonfX3o`00O`Oooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l00002oookJP?o001o0ooonfX3o`00
O`Co00000_l007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX4o`0000[ooo]Z1?l0000=
oookJPGo00002_oonfX5o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000?o001o1?oonfX3
o`00O`Co00000_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPGo000000Gooo]Zo`00Ool007oo001ooook
JP03o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0
000>oookJPCo00001ooonfX4o`0000oooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000=oookJPGo00000ooonfX6o`00O`03oookJ_l0003o000000;o000000Co001ooookJ_oonf[ooo]Z
0ol007l7oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003?oonfX5o`0000_ooo]Z
1?l0000<oookJPCo00000_oonfX3o`00O`?ooo]Z0ol007l4o`0000;o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`;ooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000=oookJPCo
00002_oonfX4o`0000gooo]Z1Ol00003o`00O`Cooo]Z0ol007l4o`0000;ooo]Z0ol007l3oookJP?o
001o0ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003OoonfX5o`000005oookJ_l007oo001oo`00OooonfX00ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo00003_oonfX4o`0000Oooo]Z1?l0000?oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003OoonfX5o`0000?ooo]Z0_l007l5oook
JPCo000000Co001ooookJ_oonf[ooo]Z0ol007l7oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPGo00003?oonfX5o`0000_ooo]Z1?l0000<oookJPCo00001Ol007l3oookJP?o001o1?l00002
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o0000o`000003o`0000[ooo]Z1?l0
000=oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000?o001o1?oo
nfX2o`00O`03oookJ_l0003o000000;o00000_oonfX3o`00O`?ooo]Z0ol007l3oookJPCo00002_oo
nfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000=oookJPCo00000_oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1OoonfX002kooo]Z1Ol0000>oookJPCo00001ooonfX4o`0000oooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1Ol0000<oookJPGo00000ooonfX2o`00O`Gooo]Z1?l00002o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000<oookJPGo
00002ooonfX4o`0000cooo]Z1?l00005o`00O`Cooo]Z0_l007l5o`0000?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l2oookJPGo00002_oonfX4o`0000gooo]Z1?l0000<oookJPCo00003OoonfX4o`00
00[ooo]Z1?l0000=oookJPGo00000ol007l4oookJP;o001o00?ooo]Zo`000?l000000_l00003oook
JP?o001o00Cooo]Zo`00Ool007oo001o1?oonfX4o`0000[ooo]Z1?l0000=oookJPGo00002_oonfX5
o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000;ooo]Z0ol007l2oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000^oookJPGo00003_oo
nfX4o`0000Oooo]Z1?l0000?oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00003?oo
nfX4o`0000Gooo]Z1_l007l4o`0000Ko001o1ooonfX5o`0000[ooo]Z1?l0000=oookJPGo00002ooo
nfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`000003oookJ_l007oo001o00;o001o1?oo
nfX2o`00O`Go00000ooonfX7o`00O`;ooo]Z1Ol0000:oookJPCo00003OoonfX4o`0000cooo]Z1?l0
000<oookJPGo00002_oonfX4o`0000gooo]Z1?l00004o`00O`Gooo]Z0_l007l4o`000003o`00Oooo
nf[ooo]Z00Oo001o0ooonfX5o`0000[ooo]Z1?l0000=oookJPGo00002_oonfX5o`0000cooo]Z1Ol0
000:oookJPCo00003OoonfX4o`0000Co001o0ooonfX7o`00O`?ooo]Z1ol007l6oookJP00;_oonfX5
o`0000gooo]Z1Ol00007oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5
o`0000cooo]Z1?l00005oookJPKo001o1?l00005o`00O`Sooo]Z1Ol0000:oookJPCo00003OoonfX5
o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l00002oookJP?o001o1OoonfX0
0ol007oo0000o`000003o`0000Cooo]Z1Ol007l3oookJPCo00002ooonfX4o`0000gooo]Z1?l0000<
oookJPCo00003?oonfX5o`0000[ooo]Z1Ol0000<oookJPCo000000Cooo]Zo`00Ool007oo001o1Ooo
nfX2o`00O`Co000000Co001ooookJ_oonf[ooo]Z1Ol007l4oookJPGo00002_oonfX4o`0000gooo]Z
1?l0000;oookJPGo00003?oonfX5o`0000[ooo]Z1Ol0000<oookJPCo00000ol007l5oookJPGo001o
1OoonfX5o`00O`Oooo]Z000^oookJPGo00003OoonfX5o`0000Oooo]Z1?l0000?oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX4o`0000gooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oo
nfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPGo00002_oo
nfX5o`0000cooo]Z1?l0000;oookJPCo00003OoonfX5o`0000[ooo]Z1Ol0000<oookJPCo00003?oo
nfX4o`0000cooo]Z1Ol0000:oookJPGo00003?oonfX4o`0001kooo]Z000^oookJPGo00003OoonfX5
o`0000Oooo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4
o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000cooo]Z1?l0000<oookJPCo00002ooonfX5o`0000cooo]Z1?l0000;oookJPCo00003OoonfX4
o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4
o`0001kooo]Z000^oookJPGo00003OoonfX4o`0000Sooo]Z1Ol0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX5o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000;oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0001kooo]Z000^oookJPGo00003OoonfX4o`0000So
oo]Z1Ol0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000;oookJPCo00003?oonfX4o`0000_o
oo]Z1Ol0000<oookJPCo00002ooonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000co
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4o`0000co
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4o`0000co
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0001ko
oo]Z000^oookJPGo00003OoonfX4o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`0000gooo]Z
1Ol0000;oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00003?oonfX4o`0001kooo]Z000^oookJPGo00003OoonfX4o`0000Wooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000_ooo]Z1Ol0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0001kooo]Z000Q
oookJ_oo0000ool0000No`0000?ooo]Z000QoookJ_oo0000ool0000No`0000?ooo]Z000QoookJ_oo
0000ool0000No`0000?ooo]Z000QoookJ_oo0000ool0000No`0000?ooo]Z000QoookJ_oo0000ool0
000No`0000?ooo]Z000^oookJPGo00003OoonfX4o`0000Wooo]Z1?l0000=oookJPCo00002ooonfX5
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000_ooo]Z00?o0000oookJ_oonfX04?oonfX0
02kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`00
00cooo]Z1?l0000<oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000go
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000co
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_o
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_o
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000co
oo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00007_oonfX002kooo]Z
1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1Ol0000;oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z
1?l0000<oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;oookJPCo00003?oonfX5o`0000_ooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0
000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00007_oonfX002kooo]Z1Ol0000=
oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000:
oookJPGo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000;
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000<
oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<
oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000<
oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1Ol0000:oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPGo00003OoonfX4o`0000[ooo]Z1Ol0000<oook
JPGo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oook
JPCo00003?oonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1?l0000<oook
JPGo00002_oonfX5o`0000cooo]Z1?l0000<oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo
00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000cooo]Z1Ol0000:oookJPCo
00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPGo
00003OoonfX4o`0000[ooo]Z1Ol0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo
00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000<oookJPCo
00003?oonfX5o`0000_ooo]Z1?l0000<oookJPGo00002_oonfX5o`0000cooo]Z1Ol0000;oookJPCo
00007_oonfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000cooo]Z1?l0000<oookJPCo0000
3?oonfX4o`0000gooo]Z1?l0000:oookJPGo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo0000
2_oonfX5o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000_ooo]Z1?l0000<oookJPGo0000
2ooonfX4o`0000cooo]Z1?l0000<oookJPCo00003?oonfX5o`0000_ooo]Z1?l0000=oookJPCo0000
2_oonfX5o`0000cooo]Z1Ol0000;oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo00002Ooo
nfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003Ooo
nfX4o`0000cooo]Z1?l0000<oookJPGo00002ooonfX4o`0000gooo]Z1?l0000:oookJPCo00003_oo
nfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000cooo]Z1?l0000<oookJPCo00003Ooo
nfX4o`0000[ooo]Z1Ol0000<oookJPGo00002ooonfX4o`0000cooo]Z1?l0000;oookJPGo00003?oo
nfX5o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000;oookJPCo00007_oo
nfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`0000gooo]Z1?l0000<oookJPCo00003?oonfX4
o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000<oookJPGo00002ooonfX4
o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5
o`0000cooo]Z1?l0000<oookJPCo00003OoonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002ooonfX4
o`0000cooo]Z1?l0000;oookJPGo00003OoonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4
o`0000kooo]Z1?l0000;oookJPCo00007_oonfX002kooo]Z1Ol0000=oookJPCo00002OoonfX4o`00
00gooo]Z1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX4o`00
00_ooo]Z1Ol0000<oookJPGo00002ooonfX4o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`00
00[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000:oookJPGo00003OoonfX4o`00
00[ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPGo00003OoonfX4o`00
00_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00007_oonfX002ko
oo]Z1Ol0000=oookJPCo00002OoonfX5o`0000cooo]Z1?l0000<oookJPCo00003?oonfX4o`0000go
oo]Z1?l0000:oookJPCo00003OoonfX4o`0000_ooo]Z1Ol0000=oookJPCo00002ooonfX4o`0000go
oo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000go
oo]Z1Ol0000:oookJPGo00003OoonfX4o`0000[ooo]Z1?l0000>oookJPCo00002ooonfX4o`0000co
oo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000ko
oo]Z1?l0000:oookJPGo00007_oonfX002kooo]Z1Ol0000<oookJPGo00002OoonfX5o`0000cooo]Z
1?l0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z
1?l0000>oookJPCo00002_oonfX4o`0000gooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000[ooo]Z
1?l0000>oookJPCo00002ooonfX4o`0000cooo]Z1?l0000;oookJPCo00003_oonfX4o`0000_ooo]Z
1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPGo00007_oonfX002kooo]Z1Ol0
000<oookJPGo00002OoonfX5o`0000_ooo]Z1Ol0000<oookJPCo00003?oonfX4o`0000gooo]Z1?l0
000:oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000cooo]Z1?l0
000;oookJPCo00003_oonfX4o`0000_ooo]Z1?l0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0
000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPGo00002_oonfX4o`0000_ooo]Z1Ol0000<
oookJPCo00003?oonfX4o`0000gooo]Z1?l0000:oookJPCo00003OoonfX5o`0000[ooo]Z1?l0000>
oookJPCo00002_oonfX5o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>
oookJPCo00002_oonfX5o`0000cooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=
oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oook
JPCo00002ooonfX4o`0000_ooo]Z1Ol0000<oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000gooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX5o`0000cooo]Z1Ol0000:oook
JPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oook
JPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000=oookJPCo
00002ooonfX5o`0000gooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo
00002_oonfX4o`0000gooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000[ooo]Z1Ol0000=oookJPCo
00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo0000
2ooonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX5o`0000gooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
3_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo0000
7ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oo
nfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4
o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4
o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX0
02kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000=oookJPCo00002ooonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`00
00kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_o
oo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[o
oo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z
1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000=oookJPGo00002_oonfX4o`0000kooo]Z
1?l00009oookJPGo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z
1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0
000=oookJPGo00002_oonfX4o`0000kooo]Z1Ol00008oookJPGo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX4o`0000[ooo]Z1?l0
000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<
oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol00008
oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:
oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002OoonfX5o`0000kooo]Z1?l0000:
oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1Ol00008oookJPCo00003ooonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oook
JPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oook
JPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003_oonfX5o`0000Wooo]Z1?l0000>oook
JPCo00002OoonfX5o`0000kooo]Z1?l0000:oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo
00002ooonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l00008oookJPCo
00003ooonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1Ol00009oookJPCo
00003_oonfX4o`0000[ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000kooo]Z1?l0000:oookJPCo
00003_oonfX5o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l00009oookJPGo
00003_oonfX5o`0000Wooo]Z1?l0000>oookJPCo00002OoonfX4o`0000oooo]Z1Ol00009oookJPCo
00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000>oookJPCo0000
2_oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1Ol0000>oookJPCo0000
2_oonfX4o`0000kooo]Z1Ol00009oookJPCo00003_oonfX4o`0000[ooo]Z1?l0000>oookJPGo0000
2OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Sooo]Z1Ol0000>oookJPGo0000
2OoonfX4o`0000kooo]Z1?l00009oookJPGo00003_oonfX5o`0000Wooo]Z1?l0000>oookJPGo0000
2?oonfX4o`0000oooo]Z1Ol00009oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooo
nfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l00008oookJPCo00003ooo
nfX5o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oo
nfX4o`0000Wooo]Z1Ol0000>oookJPGo00002OoonfX4o`0000kooo]Z1?l0000:oookJPCo00003ooo
nfX4o`0000Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPGo00003ooo
nfX4o`0000Wooo]Z1?l0000>oookJPGo00002?oonfX4o`0000oooo]Z1Ol00009oookJPCo00007ooo
nfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4
o`0000oooo]Z1?l00008oookJPCo00003ooonfX5o`0000Sooo]Z1Ol0000>oookJPGo00002OoonfX4
o`0000oooo]Z1?l00009oookJPCo00003_oonfX4o`0000Wooo]Z1Ol0000>oookJPGo00002OoonfX4
o`0000kooo]Z1?l0000:oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4
o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000>oookJPGo00002?oonfX4
o`00013ooo]Z1?l00009oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`00
00_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`00
00Sooo]Z1?l0000?oookJPGo00002OoonfX4o`0000oooo]Z1?l00009oookJPCo00003_oonfX5o`00
00Sooo]Z1Ol0000?oookJPCo00002OoonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`00
00Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1?l00009oookJPCo00004?oonfX4o`00
00Wooo]Z1?l0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00007ooonfX002ko
oo]Z1Ol0000<oookJPCo00002ooonfX4o`0000_ooo]Z1?l0000>oookJPCo00002_oonfX4o`0000oo
oo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oo
oo]Z1?l00009oookJPCo00003_oonfX5o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000ko
oo]Z1Ol00009oookJPCo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000ko
oo]Z1?l00009oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX4o`00013o
oo]Z1?l00009oookJPCo00007ooonfX002kooo]Z1Ol0000<oookJPCo00002ooonfX4o`0000[ooo]Z
1Ol0000>oookJPCo00002_oonfX4o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPGo00003_oonfX5o`0000Sooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol00009oookJPCo00003ooonfX4o`0000Sooo]Z
1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Wooo]Z
1?l0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00009oookJPCo00007ooonfX002kooo]Z1Ol0
000;oookJPGo00002ooonfX4o`0000[ooo]Z1Ol0000>oookJPCo00002OoonfX5o`0000oooo]Z1?l0
0008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l0
0008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000kooo]Z1Ol0
0008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l0
0008oookJPGo00007ooonfX002kooo]Z1Ol0000;oookJPGo00002ooonfX4o`0000[ooo]Z1Ol0000>
oookJPCo00002OoonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@
oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000@
oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPGo00003ooonfX4o`0000Sooo]Z1?l0000@
oookJPCo00002OoonfX4o`0000kooo]Z1Ol00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?
oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPGo00007ooonfX002kooo]Z1Ol0000;oook
JPGo00002ooonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX5o`0000oooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oook
JPGo00003ooonfX4o`0000Sooo]Z1?l0000@oookJPCo00002OoonfX4o`0000oooo]Z1?l00008oook
JPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oook
JPGo00007ooonfX002kooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000?oookJPCo
00002OoonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo
00002?oonfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Wooo]Z1?l0000?oookJPCo
00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo0000
3?oonfX4o`0000[ooo]Z1?l0000?oookJPCo00002OoonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX5o`0000oooo]Z1?l00008oookJPCo0000
4?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo0000
8?oonfX002kooo]Z1Ol0000;oookJPCo00003?oonfX4o`0000[ooo]Z1?l0000?oookJPGo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oo
nfX5o`0000oooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1Ol0000?oookJPCo00002?oo
nfX4o`00013ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003?oonfX5
o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4
o`0000Sooo]Z1Ol0000?oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00008?oonfX0
02kooo]Z1Ol0000;oookJPCo00003?oonfX5o`0000Wooo]Z1?l0000?oookJPGo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00
013ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003?oonfX5o`0000Wo
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000So
oo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z
1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z
1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX5o`00013ooo]Z
1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Sooo]Z1?l0
000@oookJPCo00001ooonfX5o`00013ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;
oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00007
oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008
oookJPCo00004?oonfX4o`0000Sooo]Z1?l0000@oookJPCo00001ooonfX5o`00013ooo]Z1?l00008
oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oook
JPCo00002?oonfX4o`00013ooo]Z1Ol00006oookJPGo00004?oonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oook
JPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Sooo]Z1?l0000@oook
JPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo
00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00013ooo]Z1Ol00006oookJPCo
00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo
00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPGo00001ooonfX4o`00013ooo]Z1?l00007oookJPGo
00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1?l00008oookJPCo
00008?oonfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1Ol00006oookJPCo00004OoonfX4o`0000Oooo]Z1Ol0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPCo0000
2?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1Ol0000@oookJPGo0000
1ooonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX5o`0000Oooo]Z1?l0000@oookJPCo0000
1ooonfX4o`00017ooo]Z1?l00008oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003Ooo
nfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00006oookJPCo00004Ooo
nfX5o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00008oookJPCo00004?oo
nfX4o`0000Oooo]Z1?l0000AoookJPGo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004Ooo
nfX5o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1Ol00007oookJPCo00008?oo
nfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4
o`00017ooo]Z1?l00006oookJPCo00004OoonfX5o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4
o`00013ooo]Z1?l00008oookJPCo00004?oonfX4o`0000Oooo]Z1?l0000AoookJPCo00002?oonfX4
o`00013ooo]Z1?l00007oookJPGo00004?oonfX4o`0000Oooo]Z1?l0000BoookJPCo00001ooonfX4
o`00013ooo]Z1?l00007oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4
o`00017ooo]Z1Ol00007oookJPCo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`00
00Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00017ooo]Z1?l00006oookJPCo00004OoonfX5o`00
00Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1Ol00007oookJPCo00004?oonfX4o`00
00Oooo]Z1?l0000AoookJPCo00002?oonfX4o`00013ooo]Z1?l00007oookJPGo00004?oonfX5o`00
00Kooo]Z1?l0000BoookJPCo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004_oonfX4o`00
00Oooo]Z1?l0000@oookJPCo00001ooonfX4o`00017ooo]Z1Ol00006oookJPGo00008?oonfX002ko
oo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00002?oonfX4o`00017o
oo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX5o`00013o
oo]Z1Ol00007oookJPCo00004?oonfX5o`0000Kooo]Z1?l0000AoookJPCo00002?oonfX4o`00013o
oo]Z1?l00007oookJPGo00004?oonfX5o`0000Kooo]Z1?l0000BoookJPCo00001ooonfX4o`00013o
oo]Z1Ol00006oookJPCo00004_oonfX4o`0000Oooo]Z1?l0000@oookJPCo00001ooonfX4o`0001;o
oo]Z1?l00006oookJPGo00008?oonfX002kooo]Z1Ol0000;oookJPCo00003OoonfX4o`0000Wooo]Z
1?l0000@oookJPCo00001ooonfX5o`00017ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z
1?l0000AoookJPGo00001_oonfX5o`00013ooo]Z1Ol00006oookJPGo00004?oonfX5o`0000Kooo]Z
1?l0000AoookJPGo00001ooonfX4o`00013ooo]Z1?l00007oookJPCo00004OoonfX5o`0000Kooo]Z
1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Oooo]Z
1?l0000@oookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00008?oonfX002kooo]Z1Ol0
000;oookJPCo00003OoonfX4o`0000Wooo]Z1?l0000@oookJPCo00001ooonfX5o`00017ooo]Z1?l0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX5o`00017ooo]Z1?l0
0006oookJPGo00004?oonfX5o`0000Kooo]Z1?l0000AoookJPGo00001_oonfX5o`00013ooo]Z1Ol0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z1Ol0
0006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000@oookJPGo00001_oonfX4o`0001;ooo]Z1?l0
0006oookJPCo00008OoonfX002kooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000Wooo]Z1?l0000@
oookJPCo00001ooonfX5o`00017ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPGo00004OoonfX4o`0000Kooo]Z1?l0000A
oookJPGo00001_oonfX5o`00013ooo]Z1Ol00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX5o`00017ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1Ol0000@
oookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z1Ol0000:oook
JPGo00003OoonfX4o`0000Sooo]Z1Ol0000@oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX5o`00013ooo]Z1Ol00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1Ol0000AoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oook
JPCo00008OoonfX002kooo]Z1Ol0000:oookJPGo00003OoonfX4o`0000Sooo]Z1Ol0000@oookJPGo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo
00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z1Ol0000:oookJPCo0000
3_oonfX4o`0000Sooo]Z1Ol0000@oookJPGo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo0000
8OoonfX002kooo]Z1Ol0000:oookJPCo00003_oonfX4o`0000Sooo]Z1?l0000AoookJPGo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z1Ol0000:oookJPCo00003_oonfX5
o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4
o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX0
02kooo]Z1Ol0000:oookJPCo00003_oonfX5o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`00
01;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z1Ol0000:oookJPCo00003_oonfX5o`0000Oo
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Ko
oo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00008OoonfX002kooo]Z
1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001_oonfX4o`0001;ooo]Z
1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX5o`0001;ooo]Z
1?l00006oookJPCo00008OoonfX002kooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000BoookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Kooo]Z1?l0
000BoookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00008OoonfX0017ooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Cooo]Z1Ol0000B
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00008OoonfX0013ooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`Sooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX5o`0000Cooo]Z1?l0000Coook
JPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1Ol0000Boook
JPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000Boook
JPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo00008OoonfX0013ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8
oookJPGo00002_oonfX4o`0000oooo]Z1?l00007oookJPCo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001OoonfX5o`0001;ooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000B
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPGo00004_oonfX4o`0000Kooo]Z1?l0000B
oookJPCo00001OoonfX5o`0001;ooo]Z1?l00006oookJPCo00004_oonfX4o`0000Gooo]Z1?l0000C
oookJPCo00001_oonfX4o`00027ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o1ooonfX5o`0000[ooo]Z1?l0000?oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00005oook
JPCo00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oook
JPCo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oook
JPCo00004ooonfX4o`0000Gooo]Z1Ol0000QoookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1ooonfX6o`0000Wooo]Z1?l0000?oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo
00004_oonfX5o`0000Cooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo
00004_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00005oookJPCo
00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00006oookJPCo
00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001_oonfX4o`0001;ooo]Z1?l00005oookJPCo
00004ooonfX4o`0000Gooo]Z1Ol0000QoookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o
1ooonfX5o`0000[ooo]Z1?l0000?oookJPCo00001ooonfX4o`0001;ooo]Z1?l00006oookJPCo0000
4_oonfX5o`0000Cooo]Z1Ol0000BoookJPCo00001OoonfX4o`0001?ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00005oookJPCo0000
4ooonfX4o`0000Gooo]Z1?l0000CoookJPGo00001?oonfX4o`0001?ooo]Z1?l00005oookJPGo0000
4_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX5o`0001;ooo]Z1?l00005oookJPCo0000
4ooonfX4o`0000Gooo]Z1Ol0000QoookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00O`Oooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000BoookJPCo00001_oo
nfX4o`0001;ooo]Z1Ol00004oookJPGo00004_oonfX4o`0000Gooo]Z1?l0000CoookJPCo00001Ooo
nfX5o`0001;ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001Ooo
nfX4o`0001?ooo]Z1?l00005oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPCo00001Ooo
nfX5o`0001;ooo]Z1Ol00004oookJPCo00004ooonfX4o`0000Gooo]Z1Ol0000BoookJPGo00001?oo
nfX4o`0001?ooo]Z1?l00005oookJPCo00008_oonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX7
o`00O`Sooo]Z1Ol0000:oookJPCo00003ooonfX4o`0000Oooo]Z1?l0000BoookJPCo00001OoonfX5
o`0001?ooo]Z1?l00004oookJPCo00004ooonfX4o`0000Gooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX4
o`0001?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX5
o`0001;ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z1Ol0000BoookJPGo00001?oonfX4
o`0001?ooo]Z1Ol00004oookJPCo00008_oonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00
O`Wooo]Z1Ol0000:oookJPCo00003ooonfX5o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX5o`00
01?ooo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1?l00005oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX4o`00
01?ooo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`00
01?ooo]Z1Ol00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`00
01?ooo]Z1Ol00004oookJPCo00008_oonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`go
oo]Z1Ol0000:oookJPCo00003ooonfX5o`0000Kooo]Z1?l0000BoookJPCo00001OoonfX5o`0001?o
oo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPCo00001OoonfX4o`0001?o
oo]Z1Ol00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?o
oo]Z1Ol00004oookJPCo00008_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o
001o3OoonfX5o`0000[ooo]Z1?l0000?oookJPGo00001_oonfX4o`0001;ooo]Z1?l00005oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`0001?ooo]Z1Ol00004oookJPCo
00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001?ooo]Z1?l00005oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo
00005?oonfX4o`0000Cooo]Z1?l0000RoookJP004?oonfX7o`00O`Wooo]Z1ol007l7oookJPGo0000
2_oonfX4o`00013ooo]Z1?l00006oookJPCo00004_oonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000CoookJPGo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00004ooonfX5o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo0000
1?oonfX4o`0002;ooo]Z000AoookJPGo001o2_oonfX7o`00O`Oooo]Z1Ol0000:oookJPCo00004?oo
nfX4o`0000Kooo]Z1?l0000BoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oo
nfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00008_oo
nfX002kooo]Z1Ol0000:oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000BoookJPGo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000CoookJPGo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4
o`0001Cooo]Z1?l00004oookJPCo00008_oonfX002kooo]Z1Ol0000:oookJPCo00004?oonfX4o`00
00Kooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`00
00Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00008_oonfX002ko
oo]Z1Ol0000:oookJPCo00004?oonfX4o`0000Kooo]Z1?l0000CoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Co
oo]Z1?l00004oookJPCo00008_oonfX002kooo]Z1Ol00009oookJPGo00004?oonfX4o`0000Kooo]Z
1?l0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX5o`0000;ooo]Z
1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX5o`0000?ooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z
1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00008_oonfX002kooo]Z1Ol0
0009oookJPGo00004?oonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0003oookJPGo00005?oonfX5o`0000;ooo]Z1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1Ol0
0003oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l0
0004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo00000ooonfX4o`0001Cooo]Z1?l0
0004oookJPCo00008_oonfX002kooo]Z1Ol00009oookJPGo00004?oonfX4o`0000Gooo]Z1Ol0000C
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005OoonfX4o`0000;ooo]Z1Ol0000D
oookJPCo00000ooonfX5o`0001Cooo]Z1Ol00003oookJPCo00005?oonfX5o`0000?ooo]Z1?l0000D
oookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000Cooo]Z1?l0000D
oookJPGo00000_oonfX5o`0001Cooo]Z1?l00004oookJPCo00008_oonfX002kooo]Z1Ol00009oook
JPCo00004OoonfX4o`0000Gooo]Z1Ol0000CoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oook
JPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00003oook
JPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00002oook
JPGo00005OoonfX4o`0000?ooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oook
JPCo00005?oonfX4o`0000Cooo]Z1?l0000DoookJPGo00000_oonfX5o`0001Cooo]Z1?l00004oook
JPCo00008_oonfX002kooo]Z1Ol00009oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000DoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000DoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo
00000ooonfX4o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`0000;ooo]Z1Ol0000DoookJPCo
00001?oonfX4o`0001Cooo]Z1?l00003oookJPGo00005?oonfX4o`0000Cooo]Z1?l0000EoookJPCo
00000_oonfX5o`0001Cooo]Z1?l00003oookJPGo00008_oonfX002kooo]Z1Ol00009oookJPCo0000
4OoonfX4o`0000Gooo]Z1?l0000DoookJPCo00001?oonfX4o`0001Cooo]Z1?l00004oookJPCo0000
5?oonfX4o`0000?ooo]Z1Ol0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPCo0000
5_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPGo0000
5OoonfX4o`0000;ooo]Z1Ol0000DoookJPCo00001?oonfX4o`0001Cooo]Z1Ol00002oookJPGo0000
5?oonfX4o`0000Cooo]Z1?l0000EoookJPCo00000_oonfX4o`0001Gooo]Z1?l00003oookJPGo0000
8_oonfX002kooo]Z1Ol00009oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000DoookJPCo00000ooo
nfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX4o`0000?ooo]Z1Ol0000DoookJPCo00000ooo
nfX5o`0001Cooo]Z1?l00003oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooo
nfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1Ol0000DoookJPCo00000ooo
nfX5o`0001Cooo]Z1Ol00002oookJPGo00005?oonfX4o`0000?ooo]Z1Ol0000EoookJPCo00000_oo
nfX4o`0001Gooo]Z1?l00003oookJPGo00008_oonfX002kooo]Z1Ol00009oookJPCo00004OoonfX4
o`0000Gooo]Z1?l0000DoookJPCo00000ooonfX5o`0001Cooo]Z1?l00004oookJPCo00005?oonfX5
o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX5o`0001Cooo]Z1?l00003oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4
o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX5o`0001Cooo]Z1Ol00002oookJPCo00005OoonfX5
o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo00008ooonfX0
02kooo]Z1Ol00009oookJPCo00004OoonfX4o`0000Gooo]Z1?l0000DoookJPCo00000ooonfX5o`00
01Cooo]Z1Ol00003oookJPCo00005?oonfX5o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`00
01Gooo]Z1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPCo00000ooonfX4o`00
01Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX5o`00
01Gooo]Z1?l00002oookJPCo00005OoonfX5o`0000;ooo]Z1Ol0000EoookJPCo00000_oonfX4o`00
01Gooo]Z1Ol00002oookJPCo00008ooonfX002kooo]Z1Ol00009oookJPCo00004OoonfX5o`0000Co
oo]Z1?l0000DoookJPCo00000ooonfX4o`0001Gooo]Z1Ol00002oookJPGo00005?oonfX5o`0000;o
oo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo00005_oonfX4o`0000;o
oo]Z1?l0000EoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;o
oo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005OoonfX5o`0000;o
oo]Z1?l0000FoookJPCo00000_oonfX4o`0001Gooo]Z1Ol00002oookJPCo00008ooonfX002kooo]Z
1Ol00009oookJPCo00004OoonfX5o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Gooo]Z
1Ol00002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Gooo]Z
1Ol00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z
1?l00002oookJPCo00008ooonfX002kooo]Z1Ol00009oookJPCo00004OoonfX5o`0000Cooo]Z1?l0
000DoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002oookJPGo00005OoonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0
000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00008ooonfX002kooo]Z1Ol00009
oookJPCo00004_oonfX4o`0000Cooo]Z1?l0000DoookJPCo00000ooonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000EoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002
oookJPCo00008ooonfX002kooo]Z1Ol00009oookJPCo00004_oonfX4o`0000Cooo]Z1?l0000Doook
JPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000Foook
JPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00008ooonfX002kooo]Z1Ol00009oookJPCo
00004_oonfX4o`0000Cooo]Z1?l0000DoookJPGo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo
00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo
00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo
00000_oonfX4o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPCo
00000_oonfX4o`0002?ooo]Z000^oookJPGo00002OoonfX4o`0001;ooo]Z1?l00004oookJPCo0000
5?oonfX5o`000003oookJ_l0003o000000?o00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo0000
00?ooo]Zo`000?l000000_l0000FoookJPGo000000?ooo]Zo`000?l000000_l0000FoookJPCo0000
00?ooo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1?l000000ooonf[o0000
o`000003o`0001Kooo]Z1?l00002oookJPCo00005_oonfX4o`0000;ooo]Z1?l0000FoookJPGo0000
00?ooo]Zo`000?l000000_l0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000
o`000002o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l00002oookJPCo0000
8ooonfX002kooo]Z1Ol00009oookJPCo00004_oonfX4o`0000Cooo]Z1?l0000EoookJPCo000000?o
oo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`00
0002o`0001Kooo]Z1Ol000000ooonf[o0000o`000002o`0001Kooo]Z2_l0000FoookJPCo000000?o
oo]Zo`000?l000000ol0000FoookJPCo000000?ooo]Zo`000?l000000ol0000FoookJPCo000000?o
oo]Zo`000?l000000ol0000FoookJPCo00000_oonfX4o`0001Kooo]Z1Ol000000ooonf[o0000o`00
0002o`0001Kooo]Z1?l00002oookJPCo00005_oonfX5o`000003oookJ_l0003o000000;o00005_oo
nfX4o`000003oookJ_l0003o000000?o00005_oonfX:o`0002?ooo]Z000^oookJPGo00002OoonfX4
o`0001;ooo]Z1?l00004oookJPCo00005OoonfX4o`000003oookJ_l0003o000000?o00005_oonfX4
o`0000;ooo]Z1?l0000FoookJP[o00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX:
o`0001Kooo]Z1?l000000ooonf[o0000o`000003o`0001Kooo]Z1?l000000ooonf[o0000o`000002
o`0001Oooo]Z2_l0000FoookJP[o00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX4
o`000003oookJ_l0003o000000?o00005_oonfX5o`000003oookJ_l0003o000000;o00005_oonfX4
o`000003oookJ_l0003o000000?o00005_oonfX:o`0002?ooo]Z000^oookJPGo00002OoonfX4o`00
01;ooo]Z1?l00003oookJPGo00005OoonfX4o`000003oookJ_l0003o000000;o00005ooonfX4o`00
00;ooo]Z1?l0000GoookJPWo00005ooonfX9o`0001Kooo]Z2Ol0000GoookJPCo000000?ooo]Zo`00
0?l000000ol0000FoookJPWo00005ooonfX:o`0001Kooo]Z2_l0000GoookJPWo00005_oonfX4o`00
0003oookJ_l0003o000000?o00005ooonfX9o`0001Kooo]Z2Ol0000GoookJP[o00008ooonfX002ko
oo]Z1Ol00009oookJPCo00004_oonfX4o`0000?ooo]Z1Ol0000EoookJPCo000000?ooo]Zo`000?l0
00000_l0000GoookJPCo00000_oonfX4o`0001Oooo]Z2Ol0000GoookJPWo00005ooonfX8o`0001Oo
oo]Z2Ol0000GoookJPWo00005ooonfX9o`0001Oooo]Z2_l0000GoookJPWo00005_oonfX4o`000003
oookJ_l0003o000000?o00005ooonfX9o`0001Kooo]Z2Ol0000HoookJPSo00009?oonfX002kooo]Z
1Ol00009oookJPCo00004_oonfX4o`0000?ooo]Z1Ol0000EoookJPCo000000?ooo]Zo`000?l00000
0_l0000GoookJP[o00005ooonfX8o`0001Sooo]Z2Ol0000GoookJPSo00005ooonfX9o`0001Oooo]Z
2Ol0000HoookJPSo00006?oonfX8o`0001Sooo]Z2Ol0000FoookJPWo00006?oonfX9o`0001Kooo]Z
2Ol0000HoookJPSo00009?oonfX002kooo]Z1Ol00009oookJPCo00004_oonfX4o`0000?ooo]Z1?l0
000FoookJPCo000000?ooo]Zo`000?l000000_l0000GoookJP[o00005ooonfX8o`0001Sooo]Z2?l0
000HoookJPSo00005ooonfX9o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0
000GoookJPWo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00009?oonfX002kooo]Z1Ol00009
oookJPCo00004_oonfX4o`0000?ooo]Z1?l0000FoookJPCo000000?ooo]Zo`000?l000000_l0000G
oookJP[o00005ooonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000H
oookJPSo00006?oonfX8o`0001Sooo]Z2?l0000GoookJPWo00006?oonfX8o`0001Sooo]Z2?l0000H
oookJPSo00009?oonfX002kooo]Z1Ol00009oookJPCo00004_oonfX4o`0000?ooo]Z1?l0000Foook
JPCo000000?ooo]Zo`000?l000000_l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000Hoook
JPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000Hoook
JPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00009?oonfX002kooo]Z1Ol00009oookJPCo
00004_oonfX4o`0000?ooo]Z1?l0000FoookJPWo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo
00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo
00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0002Cooo]Z000^oookJPGo0000
2OoonfX4o`0001;ooo]Z1?l00003oookJPCo00005_oonfX9o`0001Sooo]Z2?l0000HoookJPSo0000
6?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo0000
6?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000ToookJP00;_oo
nfX5o`0000Wooo]Z1?l0000BoookJPGo00000_oonfX4o`0001Kooo]Z2Ol0000HoookJPSo00006?oo
nfX7o`0001Wooo]Z1ol0000IoookJPSo00006?oonfX8o`0001Sooo]Z2?l0000HoookJPSo00006?oo
nfX8o`0001Sooo]Z1ol0000IoookJPSo00006?oonfX7o`0001Wooo]Z2?l0000HoookJPSo00009?oo
nfX002kooo]Z1Ol00009oookJPCo00004_oonfX5o`000003oookJ_l0003o000000?o00005ooonfX8
o`0001Sooo]Z2?l0000HoookJPOo00006OoonfX7o`0001Wooo]Z2?l0000IoookJPOo00006?oonfX8
o`0001Sooo]Z2?l0000HoookJPSo00006?oonfX7o`0001Wooo]Z2?l0000HoookJPOo00006OoonfX8
o`0001Sooo]Z2?l0000ToookJP00;_oonfX5o`0000Wooo]Z1?l0000BoookJPGo000000?ooo]Zo`00
0?l000000ol0000GoookJPSo00006?oonfX7o`0001Wooo]Z1ol0000IoookJPOo00006OoonfX8o`00
01Wooo]Z1ol0000HoookJPOo00006OoonfX8o`0001Sooo]Z2?l0000HoookJPOo00006OoonfX8o`00
01Sooo]Z1ol0000JoookJPOo00006?oonfX8o`0002Cooo]Z000^oookJPGo00002?oonfX5o`0001?o
oo]Z1?l000000ooonf[o0000o`000003o`0001Oooo]Z2?l0000HoookJPOo00006_oonfX6o`0001[o
oo]Z1_l0000IoookJPOo00006_oonfX6o`0001Wooo]Z1ol0000JoookJPKo00006OoonfX7o`0001[o
oo]Z1_l0000IoookJPSo00006OoonfX6o`0001[ooo]Z1_l0000JoookJPKo00009OoonfX002kooo]Z
1Ol00008oookJPGo00004ooonfX4o`000003oookJ_l0003o000000;o00006?oonfX7o`0001[ooo]Z
1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z
1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z
1_l0000UoookJP00;_oonfX5o`0000Sooo]Z1Ol0000CoookJPCo000000?ooo]Zo`000?l000000_l0
000HoookJPOo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0
000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0
000JoookJPKo00006_oonfX6o`0002Gooo]Z000^oookJPGo00002?oonfX4o`0001Cooo]Z1?l00000
0ooonf[o0000o`000002o`0001Sooo]Z1ol0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000J
oookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00006_oonfX6o`0001[ooo]Z1_l0000J
oookJPKo00006_oonfX6o`0001[ooo]Z1_l0000JoookJPKo00009OoonfX002kooo]Z1Ol00008oook
JPCo00005?oonfX4o`000003oookJ_l0003o000000;o00006OoonfX6o`0001[ooo]Z1_l0000Koook
JPCo00006ooonfX5o`0001cooo]Z1?l0000LoookJPCo00007?oonfX4o`0001cooo]Z1?l0000Loook
JPCo00006ooonfX5o`0001_ooo]Z1Ol0000LoookJPCo00007?oonfX4o`0001cooo]Z1?l0000Voook
JP00;_oonfX5o`0000Sooo]Z1?l0000DoookJPCo000000?ooo]Zo`000?l000000_l0000IoookJPKo
00006ooonfX4o`000?oooo]ZYooonfX002kooo]Z1Ol00008oookJPCo00005?oonfX4o`000003oook
J_l0003o000000;o00006OoonfX6o`000?oooo]Za_oonfX002kooo]Z1Ol00008oookJPCo00005?oo
nfX4o`000003oookJ_l0003o000000;o00006OoonfX5o`000?oooo]ZaooonfX002kooo]Z1Ol00008
oookJPCo00005?oonfX9o`000?oooo]ZiOoonfX002kooo]Z1Ol00008oookJPCo00005?oonfX9o`00
0?oooo]ZiOoonfX002kooo]Z1Ol00008oookJPCo00005?oonfX9o`000?oooo]ZiOoonfX002kooo]Z
1Ol00008oookJPCo00005OoonfX8o`000?oooo]ZiOoonfX002kooo]Z1Ol00008oookJPCo00005Ooo
nfX8o`000?oooo]ZiOoonfX002kooo]Z1Ol00008oookJPCo00005OoonfX8o`000?oooo]ZiOoonfX0
02kooo]Z1Ol00008oookJPCo00005OoonfX8o`000?oooo]ZiOoonfX002kooo]Z1Ol00008oookJPCo
00005OoonfX7o`000?oooo]Zi_oonfX002kooo]Z1Ol00008oookJPCo00005OoonfX7o`000?oooo]Z
i_oonfX002kooo]Z1Ol00008oookJPCo00005OoonfX7o`000?oooo]Zi_oonfX002kooo]Z1Ol00008
oookJPCo00005OoonfX7o`000?oooo]Zi_oonfX002kooo]Z1Ol00008oookJPCo00005_oonfX6o`00
0?oooo]Zi_oonfX002kooo]Z1Ol00008oookJPCo00005_oonfX5o`000?oooo]ZiooonfX002kooo]Z
1Ol00008oookJPCo00005_oonfX5o`000?oooo]ZiooonfX002kooo]Z1Ol00008oookJPCo0000oooo
nf[ooookJP?ooo]Z000^oookJPGo00001ooonfX5o`000?oooo]ZoooonfX3oookJP00;_oonfX5o`00
00Oooo]Z1Ol0003ooookJ_oooo]Z0ooonfX002kooo]Z1Ol00007oookJPGo0000oooonf[ooookJP?o
oo]Z000^oookJPGo00001ooonfX4o`000?oooo]ZoooonfX4oookJP008_oonfX3o`00O`Wooo]Z1Ol0
0007oookJPCo0000oooonf[ooookJPCooo]Z000RoookJP?o001o2OoonfX5o`0000Oooo]Z1?l0003o
oookJ_oooo]Z1?oonfX002;ooo]Z0ol007l9oookJPGo00001ooonfX4o`000?oooo]ZoooonfX4oook
JP008_oonfX3o`00O`Wooo]Z1Ol00007oookJPCo0000oooonf[ooookJPCooo]Z000RoookJP?o001o
2OoonfX6o`0000Kooo]Z1?l0003ooookJ_oooo]Z1?oonfX002;ooo]Z0ol007l9oookJPGo00001ooo
nfX4o`000?oooo]ZoooonfX4oookJP008_oonfX3o`00O`Wooo]Z1Ol00007oookJPCo0000oooonf[o
oookJPCooo]Z000RoookJP?o001o2OoonfX5o`0000Oooo]Z1?l0003ooookJ_oooo]Z1?oonfX002;o
oo]Z0ol007l9oookJPGo00001ooonfX4o`000?oooo]ZoooonfX4oookJP007ooonfX6o`00O`Wooo]Z
1Ol00007oookJPCo0000oooonf[ooookJPCooo]Z000OoookJPKo001o2OoonfX5o`0000Oooo]Z1?l0
003ooookJ_oooo]Z1?oonfX0027ooo]Z1?l007l9oookJPGo00001_oonfX5o`000?oooo]ZoooonfX4
oookJP008_oonfX3o`00O`Wooo]Z1Ol00006oookJPGo0000oooonf[ooookJPCooo]Z000^oookJPGo
00001_oonfX5o`000?oooo]ZoooonfX4oookJP00;_oonfX5o`0000Kooo]Z1?l0003ooookJ_oooo]Z
1OoonfX002kooo]Z1_l00005oookJPCo0000oooonf[ooookJPGooo]Z000^oookJPKo00001OoonfX4
o`000?oooo]ZoooonfX5oookJP00;_oonfX6o`0000Gooo]Z1?l0003ooookJ_oooo]Z1OoonfX002ko
oo]Z1_l00005oookJPCo0000oooonf[ooookJPGooo]Z000^oookJPKo00001OoonfX4o`000?oooo]Z
oooonfX5oookJP00;_oonfX6o`0000Gooo]Z1?l0003ooookJ_oooo]Z1OoonfX002kooo]Z1_l00005
oookJPCo0000oooonf[ooookJPGooo]Z000^oookJPKo00001OoonfX4o`000?oooo]ZoooonfX5oook
JP00;_oonfX7o`0000Cooo]Z1?l0003ooookJ_oooo]Z1OoonfX002kooo]Z1ol00004oookJPCo0000
oooonf[ooookJPGooo]Z000^oookJPOo00001?oonfX4o`000?oooo]ZoooonfX5oookJP00;_oonfX7
o`0000?ooo]Z1Ol0003ooookJ_oooo]Z1OoonfX002kooo]Z1ol00003oookJPGo0000oooonf[ooook
JPGooo]Z000^oookJPOo00000ooonfX5o`000?oooo]ZoooonfX5oookJP00;_oonfX7o`0000?ooo]Z
1?l0003ooookJ_oooo]Z1_oonfX002kooo]Z1ol00003oookJPCo0000oooonf[ooookJPKooo]Z000^
oookJPOo00000ooonfX4o`000?oooo]ZoooonfX6oookJP00;_oonfX7o`0000?ooo]Z1?l0003ooook
J_oooo]Z1_oonfX002kooo]Z1ol00003oookJPCo0000oooonf[ooookJPKooo]Z000^oookJPSo0000
0_oonfX4o`000?oooo]ZoooonfX6oookJP00;_oonfX8o`0000;ooo]Z1?l0003ooookJ_oooo]Z1_oo
nfX002kooo]Z2?l00002oookJPCo0000oooonf[ooookJPKooo]Z000^oookJPSo00000_oonfX4o`00
0?oooo]ZoooonfX6oookJP00;_oonfX8o`0000;ooo]Z1?l0003ooookJ_oooo]Z1_oonfX002kooo]Z
2?l00002oookJPCo0000oooonf[ooookJPKooo]Z000^oookJPSo00000_oonfX4o`000?oooo]Zoooo
nfX6oookJP00;_oonfX8o`0000;ooo]Z1?l0003ooookJ_oooo]Z1_oonfX002kooo]Z2?l00002oook
JPCo0000oooonf[ooookJPKooo]Z000^oookJPSo00000_oonfX4o`000?oooo]ZoooonfX6oookJP00
;_oonfX8o`0000;ooo]Z1?l0003ooookJ_oooo]Z1_oonfX002kooo]Z3_l0003ooookJ_oooo]Z1_oo
nfX002kooo]Z3_l0003ooookJ_oooo]Z1_oonfX002kooo]Z3_l0003ooookJ_oooo]Z1_oonfX002ko
oo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0
003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0003ooook
J_oooo]Z1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z
1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX0
02kooo]Z3Ol0003ooookJ_oooo]Z1ooonfX002kooo]Z1Ol000000ooonf[o0000o`000004o`000?oo
oo]ZoooonfX8oookJP00;_oonfX5o`000003oookJ_l0003o000000Co0000oooonf[ooookJPSooo]Z
000^oookJPGo000000?ooo]Zo`000?l000001?l0003ooookJ_oooo]Z2?oonfX002kooo]Z1Ol00000
0ooonf[o0000o`000004o`000?oooo]ZoooonfX8oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-19.0923, -0.938493, \
0.39264, 0.00693736}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
WindowSize->{1304, 920},
WindowMargins->{{25, Automatic}, {Automatic, 0}},
WindowTitle->"Lecture 23 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
ShowCellLabel->False,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:23:noise__addition_to_simulated_differential_equation"->{
    Cell[2280, 67, 803, 14, 135, "Input",
      CellTags->
      "mmtag:23:noise__addition_to_simulated_differential_equation"]},
  "mmtag:23:Nest[]"->{
    Cell[3450, 97, 113, 2, 50, "Input",
      CellTags->"mmtag:23:Nest[]"],
    Cell[3566, 101, 619, 10, 112, "Output",
      CellTags->"mmtag:23:Nest[]"]},
  "mmtag:23:noise__random"->{
    Cell[441214, 21239, 97, 2, 50, "Input",
      CellTags->"mmtag:23:noise__random"],
    Cell[441314, 21243, 616230, 23386, 364, 388779, 20573, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:23:noise__random"],
    Cell[1057547, 44631, 168, 4, 55, "Output",
      CellTags->"mmtag:23:noise__random"]},
  "mmtag:23:noise__periodic_bias"->{
    Cell[1059517, 44684, 178, 3, 67, "Input",
      CellTags->"mmtag:23:noise__periodic_bias"],
    Cell[1059698, 44689, 429127, 21097, 364, 388433, 20590, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:23:noise__periodic_bias"],
    Cell[1488828, 65788, 175, 4, 55, "Output",
      CellTags->"mmtag:23:noise__periodic_bias"],
    Cell[1489006, 65794, 472322, 21673, 364, 391539, 20671, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:23:noise__periodic_bias"],
    Cell[1961331, 87469, 175, 4, 55, "Output",
      CellTags->"mmtag:23:noise__periodic_bias"]},
  "mmtag:23:resonance_phenomena"->{
    Cell[1961586, 87478, 620, 13, 98, "Text",
      CellTags->{
      "mmtag:23:resonance_phenomena", "mmtag:23:natural_frequency"}]},
  "mmtag:23:natural_frequency"->{
    Cell[1961586, 87478, 620, 13, 98, "Text",
      CellTags->{
      "mmtag:23:resonance_phenomena", "mmtag:23:natural_frequency"}]},
  "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"->{
    Cell[1962567, 87511, 289, 6, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"],
    Cell[1962859, 87519, 822, 13, 161, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"]},
  "mmtag:23:harmonic_oscillator__homogeneous_and_particular_solutions"->{
    Cell[1963696, 87535, 397, 9, 66, "Text",
      CellTags->
      "mmtag:23:harmonic_oscillator__homogeneous_and_particular_solutions"]},
  "mmtag:23:resonance_phenomena__picking_out_singular_behavior"->{
    Cell[1966574, 87619, 340, 6, 50, "Input",
      CellTags->
      "mmtag:23:resonance_phenomena__picking_out_singular_behavior"],
    Cell[1966917, 87627, 155, 3, 24, "Message",
      CellTags->
      "mmtag:23:resonance_phenomena__picking_out_singular_behavior"],
    Cell[1967075, 87632, 1325, 19, 208, "Output",
      CellTags->
      "mmtag:23:resonance_phenomena__picking_out_singular_behavior"]},
  "mmtag:23:harmonic_oscillator__visualization_function_for_damped_forced"->{
    Cell[1969425, 87683, 130, 2, 48, "Subtitle",
      CellTags->
      "mmtag:23:harmonic_oscillator__visualization_function_for_damped_\
forced"]},
  "mmtag:23:harmonic_oscillator__example_solution_function_for_damped_forced"->{\

    Cell[1969771, 87695, 442, 8, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example_solution_function_for_damped_\
forced"]},
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"->{
    Cell[1970346, 87712, 193, 4, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],
    Cell[1970542, 87718, 109141, 2570, 364, 27241, 1553, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],
    Cell[2079686, 90290, 213, 5, 55, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"]},
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"->{
    Cell[2079979, 90302, 211, 4, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"]\
,
    Cell[2080193, 90308, 136385, 3055, 364, 30945, 1748, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"]\
,
    Cell[2216581, 93365, 218, 5, 55, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"]\
},
  "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"->{
    Cell[2216872, 93377, 160, 2, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],
    Cell[2217037, 93382, 150403, 2636, 364, 18623, 1004, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],
    Cell[2367445, 96021, 208, 4, 55, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"]},
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"->{
    Cell[2367730, 96032, 165, 3, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],
    Cell[2367898, 96037, 76123, 1779, 364, 20565, 1088, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],
    Cell[2444024, 97818, 215, 5, 55, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"]},
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"->{
    Cell[2444317, 97830, 212, 4, 50, "Input",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],
    Cell[2444532, 97836, 148141, 3070, 364, 27503, 1575, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],
    Cell[2592676, 100908, 216, 5, 55, "Output",
      CellTags->
      "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:23:noise__addition_to_simulated_differential_equation", 2725529, \
103766},
  {"mmtag:23:Nest[]", 2725682, 103770},
  {"mmtag:23:noise__random", 2725869, 103775},
  {"mmtag:23:noise__periodic_bias", 2726233, 103783},
  {"mmtag:23:resonance_phenomena", 2726874, 103796},
  {"mmtag:23:natural_frequency", 2727043, 103800},
  {"mmtag:23:harmonic_oscillator__general_solution_for_damped_forced", \
2727250, 103804},
  {"mmtag:23:harmonic_oscillator__homogeneous_and_particular_solutions", \
2727604, 103811},
  {"mmtag:23:resonance_phenomena__picking_out_singular_behavior", 2727811, \
103815},
  {"mmtag:23:harmonic_oscillator__visualization_function_for_damped_forced", \
2728295, 103825},
  {"mmtag:23:harmonic_oscillator__example_solution_function_for_damped_\
forced", 2728526, 103830},
  {"mmtag:23:harmonic_oscillator__example__forced_undamped_resonance", \
2728750, 103836},
  {"mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance", \
2729301, 103847},
  {"mmtag:23:harmonic_oscillator__example__forced_damped_resonance", 2729866, \
103861},
  {"mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance", \
2730408, 103872},
  {"mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance", \
2730962, 103883}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 36, 0, 64, "Title"],
Cell[1793, 53, 105, 3, 48, "Subtitle"],
Cell[1901, 58, 376, 7, 98, "Text"],
Cell[2280, 67, 803, 14, 135, "Input",
  CellTags->"mmtag:23:noise__addition_to_simulated_differential_equation"],
Cell[3086, 83, 175, 5, 49, "Text"],
Cell[3264, 90, 161, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[3450, 97, 113, 2, 50, "Input",
  CellTags->"mmtag:23:Nest[]"],
Cell[3566, 101, 619, 10, 112, "Output",
  CellTags->"mmtag:23:Nest[]"]
}, Open  ]],
Cell[4200, 114, 113, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[4338, 120, 59, 1, 50, "Input"],
Cell[4400, 123, 436644, 21106, 364, 385886, 20475, "GraphicsData", \
"PostScript", "Graphics"],
Cell[441047, 21231, 130, 3, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[441214, 21239, 97, 2, 50, "Input",
  CellTags->"mmtag:23:noise__random"],
Cell[441314, 21243, 616230, 23386, 364, 388779, 20573, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:23:noise__random"],
Cell[1057547, 44631, 168, 4, 55, "Output",
  CellTags->"mmtag:23:noise__random"]
}, Open  ]],
Cell[1057730, 44638, 211, 6, 46, "Text"],
Cell[1057944, 44646, 1167, 22, 152, "Input"],
Cell[1059114, 44670, 172, 3, 50, "Input"],
Cell[1059289, 44675, 64, 0, 46, "Text"],
Cell[1059356, 44677, 136, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[1059517, 44684, 178, 3, 67, "Input",
  CellTags->"mmtag:23:noise__periodic_bias"],
Cell[1059698, 44689, 429127, 21097, 364, 388433, 20590, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:23:noise__periodic_bias"],
Cell[1488828, 65788, 175, 4, 55, "Output",
  CellTags->"mmtag:23:noise__periodic_bias"],
Cell[1489006, 65794, 472322, 21673, 364, 391539, 20671, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:23:noise__periodic_bias"],
Cell[1961331, 87469, 175, 4, 55, "Output",
  CellTags->"mmtag:23:noise__periodic_bias"]
}, Open  ]],
Cell[1961521, 87476, 62, 0, 48, "Subtitle"],
Cell[1961586, 87478, 620, 13, 98, "Text",
  CellTags->{"mmtag:23:resonance_phenomena", "mmtag:23:natural_frequency"}],

Cell[CellGroupData[{
Cell[1962231, 87495, 67, 1, 55, "Input"],
Cell[1962301, 87498, 52, 1, 57, "Output"]
}, Open  ]],
Cell[1962368, 87502, 174, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[1962567, 87511, 289, 6, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"],
Cell[1962859, 87519, 822, 13, 161, "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__general_solution_for_damped_forced"]
}, Open  ]],
Cell[1963696, 87535, 397, 9, 66, "Text",
  CellTags->
  "mmtag:23:harmonic_oscillator__homogeneous_and_particular_solutions"],

Cell[CellGroupData[{
Cell[1964118, 87548, 135, 3, 50, "Input"],
Cell[1964256, 87553, 579, 9, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1964872, 87567, 155, 3, 50, "Input"],
Cell[1965030, 87572, 334, 5, 101, "Output"]
}, Open  ]],
Cell[1965379, 87580, 92, 3, 46, "Text"],
Cell[1965474, 87585, 72, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[1965571, 87589, 104, 2, 50, "Input"],
Cell[1965678, 87593, 264, 4, 75, "Output"]
}, Open  ]],
Cell[1965957, 87600, 188, 4, 46, "Text"],
Cell[1966148, 87606, 264, 4, 75, "Output"],
Cell[1966415, 87612, 134, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[1966574, 87619, 340, 6, 50, "Input",
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"],
Cell[1966917, 87627, 155, 3, 24, "Message",
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"],
Cell[1967075, 87632, 1325, 19, 208, "Output",
  CellTags->"mmtag:23:resonance_phenomena__picking_out_singular_behavior"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1968437, 87656, 538, 10, 112, "Subsubsection"],
Cell[1968978, 87668, 151, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[1969154, 87675, 93, 1, 50, "Input"],
Cell[1969250, 87678, 160, 2, 101, "Output"]
}, Open  ]],
Cell[1969425, 87683, 130, 2, 48, "Subtitle",
  CellTags->
  "mmtag:23:harmonic_oscillator__visualization_function_for_damped_forced"],
Cell[1969558, 87687, 210, 6, 46, "Text"],
Cell[1969771, 87695, 442, 8, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example_solution_function_for_damped_forced"]\
,
Cell[1970218, 87706, 65, 0, 46, "Text"],
Cell[1970286, 87708, 35, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[1970346, 87712, 193, 4, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],
Cell[1970542, 87718, 109141, 2570, 364, 27241, 1553, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"],
Cell[2079686, 90290, 213, 5, 55, "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_resonance"]
}, Open  ]],
Cell[2079914, 90298, 40, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[2079979, 90302, 211, 4, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"],
Cell[2080193, 90308, 136385, 3055, 364, 30945, 1748, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"],
Cell[2216581, 93365, 218, 5, 55, "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_undamped_near_resonance"]
}, Open  ]],
Cell[2216814, 93373, 33, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[2216872, 93377, 160, 2, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],
Cell[2217037, 93382, 150403, 2636, 364, 18623, 1004, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_resonance"],
Cell[2367445, 96021, 208, 4, 55, "Output",
  CellTags->"mmtag:23:harmonic_oscillator__example__forced_damped_resonance"]
}, Open  ]],
Cell[2367668, 96028, 37, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[2367730, 96032, 165, 3, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],
Cell[2367898, 96037, 76123, 1779, 364, 20565, 1088, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"],
Cell[2444024, 97818, 215, 5, 55, "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_overdamped_resonance"]
}, Open  ]],
Cell[2444254, 97826, 38, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[2444317, 97830, 212, 4, 50, "Input",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],
Cell[2444532, 97836, 148141, 3070, 364, 27503, 1575, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"],
Cell[2592676, 100908, 216, 5, 55, "Output",
  CellTags->
  "mmtag:23:harmonic_oscillator__example__forced_damped_near_resonance"]
}, Open  ]],
Cell[2592907, 100916, 46, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[2592978, 100920, 125, 2, 50, "Input"],
Cell[2593106, 100924, 131472, 2814, 364, 25927, 1506, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2724581, 103740, 130, 3, 55, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

